#define _REGEX_RE_COMP
#include <stdio.h>
#include <regex.h>
#include "stock.h" 

int
  match_string (char * spec, char * string);


int match_stachans_(char *, char *, char *, int, int, int);

int
match_stachans (stachans, sta, chan)

char *          stachans;
char *                    sta;
char *                         chan;

/*
 *	match_stachans determines if a particular station-channel pair
 *	matches a station-channel specification from a comma delimited
 *	list of specs. It returns 0 if no match is found or the number in
 *	the list if a match is found. The specification list is a single
 *	NULL terminated character string.
 */

{
  static char *string = NULL;
  static int size_string = 0;
  int i, l, ilist, ret;
  char *ptr, *colon;
  
  /*
  char *strtok();
  char *strchr();
  */
  if (!stachans) return (0);
  if (stachans[0] == '\0') return (0);
  if (!strcmp(stachans, "*")) return (1);
  /*
   *	Copy into a temporary string.
   */
  if (!string) {
    size_string = strlen(stachans) + 2;
    string = (char *) malloc (size_string);
    if (string == NULL) return (-1);
  } else {
    if (strlen(stachans)+2 > size_string) {
      free (string);
      size_string = strlen(stachans) + 2;
      string = (char *) malloc (size_string);
      if (string == NULL) return (-1);
    }
  }
  for (i=0,ptr=string; i<strlen(stachans); i++) 
    if (stachans[i] != ' ' && stachans[i] != '\t' 
	&& stachans[i] != '\n') *ptr++ = stachans[i];
  *ptr = '\0';
  if (string[0] == '\0') return (0);
  if (!strcmp(string, "*")) return (1);
  /*
   *	comma parsing loop
   */
  ilist = 1;
  ptr = string;
  l = strlen(string)+1;
  for (i=0,ptr=string; i<l; i++) {
    if (string[i] != '\0' && string[i] != ',') continue;
    string[i] = '\0';
    if (*ptr == '\0') {
      ilist++;
      ptr = &string[i+1];
      continue;
    }
    /*
     *		parse a single station-channel spec.
     */
    if (!strcmp(ptr, "*")) return (ilist);
    /*
     *		look for a ':' - look for channel match
     */
    colon = strchr (ptr, ':');
    if (colon) {
      *colon = '\0';
      colon++;
      ret = match_string (colon, chan);
      if (ret < 0) return (-1);
      if (!ret) {
	ilist++;
	ptr = &string[i+1];
	continue;
      }
    }
    /*
     *		now look for a station match
     */
    ret = match_string (ptr, sta);
    if (ret < 0) return (-1);
    if (ret) return (ilist);
    ptr = &string[i+1];
    ilist++;
  }
  /*
   *	Nothing found - return 0
   */
  return (0);
}

int
  match_string (spec, string)

char *        spec;
char *              string;

{
  char *ret;
  static char tmp_spec[512];
  
  if (!spec) return (0);
  if (spec[0] == '\0') return (0);
  if (!strcmp(spec, "*")) return (1);
  if (spec[0] == '^') strcpy (tmp_spec, spec); else {
    strcpy (tmp_spec, "^");
    strcat (tmp_spec, spec);
  }
  if (tmp_spec[strlen(tmp_spec)-1] != '$') strcat (tmp_spec, "$");
#ifdef STELLAR
  ret = (char *) regcmp (tmp_spec, NULL);
  if (!ret) {
    fprintf (stderr, "match_string: error from regcmp.\n", ret);
    return (-1);
  }
  if (!regex (ret, string)) return (0); else return (1);
#else
  ret = (char *) re_comp (tmp_spec);
  if (ret) {
    fprintf (stderr, "match_string: %s.\n", ret);
    return (-1);
  }
  return (re_exec(string));
#endif
}

char *fixfstring ( s, n ) 
char *s ; 
int n ; 
{ 
    char *new ; 
    allot ( char *, new, n+1 ) ; 
    strncpy ( new, s, n ) ; 
    while ( new[--n] == ' ')  ;
    new[++n] = 0 ; 
    return new ; 
}


int match_stachans__( stachans_, sta_, chan_, lenstachans, lensta, lenchan )  
char *stachans_, *sta_, *chan_ ; 
int lenstachans, lensta, lenchan ;
{
    char *stachans, *sta, *chan ; 
    int retcode ; 

    stachans = fixfstring ( stachans_, lenstachans ) ; 
    sta = fixfstring ( sta_, lensta ) ; 
    chan = fixfstring ( chan_, lenchan ) ; 
    retcode = match_stachans ( stachans, sta, chan )  ;
    free ( stachans ) ; 
    free ( sta ) ; 
    free ( chan ) ; 
    return retcode ; 
}

    
