	subroutine mhr_axis_seis(xmin,xmax,ymin,ymax,icomp,ncomp
     +)
c		draws one (the icomp^th) of ncomp axes.
c		xmin, xmax, ymin, ymax are input
c		as are labels and titles.
c		variable names are chosen to be identical to the CSS 3.0
c		attribute names with the relation name appended preceded
c		by an underscore (e.g., lat_centryd, lat_origin, sta_wfdisc, etc).
c
c		declarations and common blocks are included for the 
c		following relations:
c
c		  affiliation, arrival, assoc, centryd (hybrid 2.8), event, 
c		  gregion, instrument, network, moment (hybrid 2.8), origin,
c		  remark, sensor, site, sitechan, sregion, wfdisc
c
c		additional relations include: select, wfedit, spdisc, tape,
c			tapefile, tapedata, ftdisc, disp
c
c		in addition there are declarations for: db io and filter files.
c
c		the dimensions of all variables except those for the event 
c		relations are declared so that entire tables are stored.
c		the event relations are: 
c			centryd, event, origin, gregion, moment, sregion
c
c		order of variables in common blocks differ slightly from
c		in the definition of the relation in order to minimize 
c		misalignment complaints during compilation.


c	implicit integer(i-n), real(a-h,o-z)

c		data base io declarations (3.0)
	character*80 dbin, dbout, dbcmt, dbegn, dbwfdisc
	integer idbin, idbout, idbcmt, idbegn, idbwfdisc
	common/c_dbio/idbin,idbout,dbin,dbout,dbcmt,idbcmt,dbegn
     +,idbegn,
     *    dbwfdisc,idbwfdisc



c		centryd declarations (2.8 with modifications)
c			modifications are:
c			remark has been replaced with commid_centryd
c			lddate_centryd added at end
c			nrlpb interpreted as no. records of LP body waves
c			nrmw interpreted as no. records of mantle waves
	character*10 dused_centryd
	character*15 auth_centryd
	character*17 lddate_centryd
	integer orid_centryd, jdate_centryd, nslpb_centryd, nrlp
     +b_centryd,
     *    tmnlpb_centryd, nsmw_centryd, nrmw_centryd, tmnmw_cen
     +tryd, commid_centryd
	real lat_centryd, lon_centryd, depth_centryd, coterr_cen
     +tryd, claerr_centryd, 
     *    cloerr_centryd, cdperr_centryd, durat_centryd
	real*8 time_centryd
	common/c_centryd/orid_centryd, jdate_centryd, time_centr
     +yd,
     *    lat_centryd, lon_centryd, depth_centryd, coterr_centr
     +yd, claerr_centryd, 
     *    cloerr_centryd, cdperr_centryd, durat_centryd, nslpb_
     +centryd, nrlpb_centryd,
     *    tmnlpb_centryd, nsmw_centryd, nrmw_centryd, tmnmw_cen
     +tryd, commid_centryd, 
     *    dused_centryd, auth_centryd, lddate_centryd



c		event declarations (3.0)
	character*15 evname_event, auth_event
	character*17 lddate_event
	integer evid_event, prefor_event, commid_event
	common/c_event/evid_event, prefor_event, commid_event,
     *     auth_event, lddate_event, evname_event



c		filter declarations (3.0)
	parameter (mpz = 100, mfir = 500, mstages = 20)
	character*4 type_filter
	character*80 dfile_filter
	integer np_filter, nz_filter, nstages_filter
	real a0_filter, coefn_filter, coefd_filter, coefnerr_fil
     +ter, 
     *    coefderr_filter
	complex zero_filter, pole_filter, zererr_filter, polerr_
     +filter
	common/c_filter/a0_filter(mstages), nz_filter(mstages), 
     +np_filter(mstages), 
     *    zero_filter(mstages, mpz), zererr_filter(mstages, mpz
     +), 
     *    pole_filter(mstages, mpz), polerr_filter(mstages, mpz
     +), 
     *    nnum_filter(mstages), nden_filter(mstages), srate_fil
     +ter(mstages),
     *    coefn_filter(mstages, mfir), coefnerr_filter(mstages,
     + mfir), 
     *    coefd_filter(mstages, mfir), coefderr_filter(mstages,
     + mfir), 
     *    type_filter(mstages), nstages_filter, dfile_filter, i
     +resp_filter


c		geographical region (gregion) declarations (3.0)
	character*17 lddate_gregion
	character*40 grname_gregion
	integer grn_gregion
	common/c_gregion/grn_gregion, grname_gregion, lddate_gre
     +gion



c		instrument declarations (3.0)
	parameter (minstrument = 5500)
	character band_instrument, digital_instrument
	character*6 instype_instrument, rsptype_instrument
	character*17 lddate_instrument
	character*32 dfile_instrument
	character*50 insname_instrument
	character*64 dir_instrument
	integer inid_instrument
	real samprate_instrument, ncalib_instrument, ncalper_ins
     +trument
	common/c_instrument/inid_instrument(minstrument), 
     *     insname_instrument(minstrument), instype_instrument(
     +minstrument), 
     *     band_instrument(minstrument), digital_instrument(min
     +strument), 
     *     samprate_instrument(minstrument), ncalib_instrument(
     +minstrument), 
     *     ncalper_instrument(minstrument), dir_instrument(mins
     +trument), 
     *     dfile_instrument(minstrument), rsptype_instrument(mi
     +nstrument),
     *     lddate_instrument(minstrument), nrowinstrument





c		moment declarations (2.8 with modifications)
c			modifications are:
c			remark has been replaced with commid_moment
c			lddate_moment added at end
c			nslpb, nrlpb, tmnlpb, nsmw, nrmw, tmnmw have
c			   been left out since they're in centryd
c			slips have been replaced with rakes
	character*10 dused_moment
	character*15 auth_moment
	character*17 lddate_moment
	integer orid_moment, mexpon_moment, commid_moment
	real bestdc_moment, mrr_moment, mtt_moment, mff_moment, 
     +mrt_moment,
     *    mrf_moment, mtf_moment, mrrerr_moment, mtterr_moment,
     + mfferr_moment,
     *    mrterr_moment, mrferr_moment, mtferr_moment, paxval_m
     +oment, paxplg_moment, 
     *    paxazm_moment, naxval_moment, naxplg_moment, naxazm_m
     +oment, taxval_moment, 
     *    taxplg_moment, taxazm_moment, str1_moment, dip1_momen
     +t, rake1_moment, 
     *    str2_moment, dip2_moment, rake2_moment
	common/c_moment/orid_moment, mexpon_moment, bestdc_momen
     +t, 
     *    mrr_moment, mtt_moment, mff_moment, mrt_moment, mrf_m
     +oment, mtf_moment,
     *    mrrerr_moment, mtterr_moment, mfferr_moment, mrterr_m
     +oment, mrferr_moment,
     *    mtferr_moment, paxval_moment, paxplg_moment, paxazm_m
     +oment, naxval_moment, 
     *    naxplg_moment, naxazm_moment, taxval_moment, taxplg_m
     +oment, taxazm_moment, 
     *    str1_moment, dip1_moment, rake1_moment, str2_moment, 
     +dip2_moment, rake2_moment, 
     *    commid_moment, dused_moment, auth_moment, lddate_mome
     +nt


c		origin declarations (3.0)
	character dtype_origin
	character*7 etype_origin
	character*15 algorithm_origin, auth_origin 
	character*17 lddate_origin
	integer orid_origin, evid_origin, jdate_origin, nass_ori
     +gin,
     *    ndef_origin, ndp_origin, grn_origin, srn_origin, mbid
     +_origin, 
     *    msid_origin, mlid_origin, commid_origin
	real lat_origin, lon_origin, depth_origin, depdp_origin,
     + mb_origin,
     *    ms_origin, ml_origin
	real*8 time_origin
	common/c_origin/time_origin, lat_origin, lon_origin, dep
     +th_origin,
     *    orid_origin, evid_origin, jdate_origin, nass_origin, 
     +ndef_origin, 
     *    ndp_origin, grn_origin, srn_origin, depdp_origin, mb_
     +origin,
     *    mbid_origin, ms_origin, msid_origin, ml_origin, mlid_
     +origin, 
     *    commid_origin, algorithm_origin, auth_origin, lddate_
     +origin, 
     *    dtype_origin, etype_origin 



c		remark declarations (3.0)
	parameter (mremark = 10000)
	character*17 lddate_remark
	character*80 remark_remark
	integer commid_remark, lineno_remark
	common/c_remark/commid_remark(mremark), lineno_remark(mr
     +emark), 
     *      remark_remark(mremark), lddate_remark(mremark), nro
     +wremark

c		select declarations (mhr)
	parameter (mselect=5000)	
	integer selid_select, nmode_select, lmode_select, commid
     +_select
	character st_select
	character*6 sta_select
	character*8 chan_select
	character*15 author_select
	character*16 comment_select
	character*17 lddate_select
	character*32 dbwfdisc_select
	character*64 dir_select
	common/c_select/selid_select(mselect), sta_select(mselec
     +t), 
     *    chan_select(mselect), nmode_select(mselect), st_selec
     +t(mselect),
     *    lmode_select(mselect), comment_select(mselect), 
     *    dir_select(mselect), dbwfdisc_select(mselect), 
     *    author_select(mselect), commid_select(mselect), 
     *    lddate_select(mselect), nrowselect



c		sensor declarations (3.0)
	parameter(msensor=8000)
	character instant_sensor
	character*6 sta_sensor
	character*8 chan_sensor
	character*17 lddate_sensor
	integer inid_sensor, chanid_sensor, jdate_sensor
	real calratio_sensor, calper_sensor, tshift_sensor
	real*8 time_sensor, endtime_sensor
	common/c_sensor/sta_sensor(msensor), chan_sensor(msensor
     +),
     *      time_sensor(msensor), endtime_sensor(msensor),
     *      inid_sensor(msensor), chanid_sensor(msensor), jdate
     +_sensor(msensor),
     *      calratio_sensor(msensor), calper_sensor(msensor), t
     +shift_sensor(msensor),
     *      instant_sensor(msensor), lddate_sensor(msensor), nr
     +owsensor



c		site declarations (3.0)
	parameter (msite = 500)
	character*4 statype_site 
	character*6 sta_site, refsta_site
	character*17 lddate_site 
	character*50 staname_site
	integer ondate_site, offdate_site	
	real lat_site, lon_site, elev_site, deast_site, dnorth_s
     +ite
	common/csite/sta_site(msite), ondate_site(msite), offdat
     +e_site(msite),
     *     lat_site(msite), lon_site(msite), elev_site(msite), 
     +staname_site(msite), 
     *     statype_site(msite), refsta_site(msite), dnorth_site
     +(msite), 
     *     deast_site(msite), lddate_site(msite), nrowsite



c		sitechan declarations (3.0)
	parameter(msitechan=6500)
	character*4 ctype_sitechan
	character*6 sta_sitechan
	character*8 chan_sitechan
	character*17 lddate_sitechan
	character*50 descrip_sitechan
	integer ondate_sitechan, offdate_sitechan, chanid_sitech
     +an
	real edepth_sitechan, hang_sitechan, vang_sitechan
	common/csitechan/sta_sitechan(msitechan), chan_sitechan(
     +msitechan),
     *     ondate_sitechan(msitechan), chanid_sitechan(msitecha
     +n), 
     *     offdate_sitechan(msitechan), ctype_sitechan(msitecha
     +n), 
     *     edepth_sitechan(msitechan), hang_sitechan(msitechan)
     +, 
     *     vang_sitechan(msitechan), descrip_sitechan(msitechan
     +),
     *     lddate_sitechan(msitechan), nrowsitechan


c		seismic region (sregion) declarations (3.0)
	character*17 lddate_sregion
	character*40 srname_sregion
	integer srn_sregion
	common/c_sregion/srn_sregion, srname_sregion, lddate_sre
     +gion


c		wfdisc declarations (3.0)
	parameter(mwfdisc = 10000)
	character segtype_wfdisc, clip_wfdisc
	character*2 datatype_wfdisc
	character*6 sta_wfdisc, instype_wfdisc
	character*8 chan_wfdisc
	character*17 lddate_wfdisc
	character*32 dfile_wfdisc
	character*64 dir_wfdisc
	integer wfid_wfdisc, chanid_wfdisc, jdate_wfdisc, nsamp_
     +wfdisc, 
     *     foff_wfdisc, commid_wfdisc
	real samprate_wfdisc, calib_wfdisc, calper_wfdisc
	real*8 time_wfdisc, endtime_wfdisc
	common/c_wfdisc/sta_wfdisc(mwfdisc), chan_wfdisc(mwfdisc
     +), time_wfdisc(mwfdisc), 
     *     wfid_wfdisc(mwfdisc), chanid_wfdisc(mwfdisc), jdate_
     +wfdisc(mwfdisc),
     *     endtime_wfdisc(mwfdisc), nsamp_wfdisc(mwfdisc), samp
     +rate_wfdisc(mwfdisc),
     *     calib_wfdisc(mwfdisc), calper_wfdisc(mwfdisc), insty
     +pe_wfdisc(mwfdisc), 
     *     segtype_wfdisc(mwfdisc), datatype_wfdisc(mwfdisc), c
     +lip_wfdisc(mwfdisc), 
     *     dir_wfdisc(mwfdisc), dfile_wfdisc(mwfdisc), foff_wfd
     +isc(mwfdisc), 
     *     commid_wfdisc(mwfdisc), lddate_wfdisc(mwfdisc), nrow
     +wfdisc

c		wfedit declarations (mhr)
	parameter (mwfedit = 10000)
	character*6 sta_wfedit
	character*8 chan_wfedit,probtype_wfedit,edtype_wfedit
	character*15 auth_wfedit
	character*17 lddate_wfedit
	integer edid_wfedit, commid_wfedit
	real*8 time_wfedit, endtime_wfedit
	common/c_wfedit/sta_wfedit(mwfedit), chan_wfedit(mwfedit
     +),
     *     edid_wfedit(mwfedit), time_wfedit(mwfedit), endtime_
     +wfedit(mwfedit),  
     *     probtype_wfedit(mwfedit), edtype_wfedit(mwfedit), co
     +mmid_wfedit(mwfedit),
     *     auth_wfedit(mwfedit), lddate_wfedit(mwfedit), nrowwf
     +edit


c		disp, dispdata and disperr declarations (mhr)
c			disp
	parameter (mdisp = 500, mdispdata = 100)
	character*2 stage_disp
	character*6 sta_disp
	character*8 chan_disp, wavetype_disp
	character*16 model_disp
	character*17 lddate_disp
	character*32 dfile_disp, dfileerr_disp
	character*64 dir_disp
	integer dispid_disp, jdate_disp, orid_disp, nfreq_disp,
     *     commid_disp
	real range_disp, backaz_disp, az_disp, t01_disp, tc1_dis
     +p, 
     *     tc2_disp, t02_disp
	real*8 time_disp
	common/c_disp/sta_disp(mdisp), chan_disp(mdisp), 
     *     dispid_disp(mdisp), wavetype_disp(mdisp), jdate_disp
     +(mdisp),
     *     orid_disp(mdisp), time_disp(mdisp), range_disp(mdisp
     +),
     *     backaz_disp(mdisp), az_disp(mdisp), nfreq_disp(mdisp
     +),
     *     stage_disp(mdisp), t01_disp(mdisp), tc1_disp(mdisp),
     +
     *     tc2_disp(mdisp), t02_disp(mdisp), model_disp(mdisp),
     + 
     *	   dir_disp(mdisp), dfile_disp(mdisp), dfileerr_di
     +sp(mdisp), 
     *     commid_disp(mdisp), lddate_disp(mdisp), nrowdisp

c			dispdata
	integer nfreq_dispdata
	real f_dispdata, t_dispdata, groupvel_dispdata, 
     *     dgroupvel_dispdata, phasevel_dispdata, dphasevel_dis
     +pdata,
     *     amp_dispdata, damp_dispdata, pol_dispdata, dpol_disp
     +data,
     *     filt1_dispdata, filt2_dispdata
	common/c_dispdata/nfreq_dispdata, f_dispdata(mdispdata),
     + 
     *     filt1_dispdata(mdispdata), filt2_dispdata(mdispdata)
     +,
     *     t_dispdata(mdispdata), groupvel_dispdata(mdispdata),
     + 
     *     dgroupvel_dispdata(mdispdata),
     *     phasevel_dispdata(mdispdata), dphasevel_dispdata(mdi
     +spdata),
     *     amp_dispdata(mdispdata), damp_dispdata(mdispdata),
     *     pol_dispdata(mdispdata), dpol_dispdata(mdispdata)
c			disperr
	integer nfreq_disperr
	real f_disperr, t_disperr, groupvel_disperr, 
     *     dgroupvel_disperr, phasevel_disperr, dphasevel_dispe
     +rr,
     *     amp_disperr, damp_disperr, pol_disperr, dpol_disperr
     +
	common/c_disperr/nfreq_disperr, f_disperr(mdispdata), 
     *     t_disperr(mdispdata), groupvel_disperr(mdispdata), 
     *     dgroupvel_disperr(mdispdata),
     *     phasevel_disperr(mdispdata), dphasevel_disperr(mdisp
     +data),
     *     amp_disperr(mdispdata), damp_disperr(mdispdata),
     *     pol_disperr(mdispdata), dpol_disperr(mdispdata)

c			ftdisc and ftimag
	parameter (mftdisc = 500, mftimag = 250)
	character*2 datatype_ftdisc, stage_ftdisc
	character*6 sta_ftdisc
	character*8 chan_ftdisc, wavetype_ftdisc, imagefield_ftd
     +isc
	character*16 imagetype_ftdisc, xaxistype_ftdisc, yaxisty
     +pe_ftdisc
	character*17 lddate_ftdisc
	character*32 dfile_ftdisc
	character*64 dir_ftdisc
	integer ftid_ftdisc, jdate_ftdisc, orid_ftdisc, commid_f
     +tdisc,
     *     numtot_ftdisc, numimage_ftdisc, ny_ftdisc, nx_ftdisc
     +
	real range_ftdisc
	real*8 time_ftdisc
	common/c_ftdisc/sta_ftdisc(mftdisc), chan_ftdisc(mftdisc
     +), 
     *     ftid_ftdisc(mftdisc), wavetype_ftdisc(mftdisc), jdat
     +e_ftdisc(mftdisc), 
     *     orid_ftdisc(mftdisc), time_ftdisc(mftdisc), range_ft
     +disc(mftdisc), stage_ftdisc(mftdisc), 
     *     imagetype_ftdisc(mftdisc), imagefield_ftdisc(mftdisc
     +), xaxistype_ftdisc(mftdisc), 
     *     yaxistype_ftdisc(mftdisc), numtot_ftdisc(mftdisc), n
     +umimage_ftdisc(mftdisc),
     *     ny_ftdisc(mftdisc), nx_ftdisc(mftdisc), datatype_ftd
     +isc(mftdisc), 
     *     dir_ftdisc(mftdisc), dfile_ftdisc(mftdisc),  
     *	   commid_ftdisc(mftdisc), lddate_ftdisc(mftdisc),
     + nrowftdisc
	real imag_ftimag_re, imag_ftimag_im, xaxis_ftimag, yaxis
     +_ftimag
	common/c_ftimag/imag_ftimag_re(mftimag,mftimag), imag_ft
     +imag_im(mftimag,mftimag), 
     *     xaxis_ftimag(mftimag), yaxis_ftimag(mftimag)



c		declarations for stachan_sctlist_wfdisc common block
	parameter (mstachan = 1500, msegs = 20)
	character*6 sta_sctlist_wfdisc
	character*8 chan_sctlist_wfdisc
	integer numsctlist_wfdisc, ntuple_sctlist_wfdisc, nsegs_
     +sctlist_wfdisc
	real*8 time_sctlist_wfdisc, endtime_sctlist_wfdisc
	common/c_sctlist_wfdisc/sta_sctlist_wfdisc(mstachan), 
     *    chan_sctlist_wfdisc(mstachan),time_sctlist_wfdisc(mst
     +achan,msegs), 
     *    endtime_sctlist_wfdisc(mstachan, msegs),ntuple_sctlis
     +t_wfdisc(mstachan,msegs), 
     *    nsegs_sctlist_wfdisc(mstachan),icalled_sctlist_wfdisc
     +,numsctlist_wfdisc

c		declarations for stachan_sctlist_wfedit common block
	parameter (medits = 100)
	character*6 sta_sctlist_wfedit
	character*8 chan_sctlist_wfedit, probtype_sctlist_wfedit
     +, edtype_sctlist_wfedit
	integer numsctlist_wfedit, ntuple_sctlist_wfedit, nsegs_
     +sctlist_wfedit
	real*8 time_sctlist_wfedit, endtime_sctlist_wfedit
	common/c_sctlist_wfedit/sta_sctlist_wfedit(mstachan), 
     *    chan_sctlist_wfedit(mstachan),time_sctlist_wfedit(mst
     +achan,medits), 
     *    endtime_sctlist_wfedit(mstachan, medits),probtype_sct
     +list_wfedit(mstachan, medits),
     *	  edtype_sctlist_wfedit(mstachan, medits),ntuple_s
     +ctlist_wfedit(mstachan,medits), 
     *    nsegs_sctlist_wfedit(mstachan),icalled_sctlist_wfedit
     +,numsctlist_wfedit

c		waveform declarations
	parameter (mdata= 72000)
	common/c_data/t(mdata), d(mdata), t_plot(mdata), d_plot(
     +mdata), nlen_data, nlen_plot,
     *    t1(mdata), d1(mdata)

c		plotting declarations
	character*80 x_label, y_label, title
	character chr
	character*80 fg, bg
	common/mhr_nplot/itran,ipost,iwsize,ssize,xwin,ywin,
     *   xdim,ydim,xlow,ylow,init,chr,x_label,y_label,title,fg,
     +bg,iltype,thick

c		declarations for sta:chn sifting
	parameter (msc=1500)
	character*6 sta_plot
	character*8 chan_plot
	common/c_scplot/sta_plot(msc), chan_plot(msc), numplot

c		odds and ends
	character ifedit, ifinterp, overplot_type, gpvel_cmp, if
     +_centryd, if_auto_out
	character*80 ps_file, xlabel_t, xlabel_f, ylabel_t, ylab
     +el_f, notefile
	common/c_oande/icurrent, ifedit, ifinterp, ps_file, idis
     +p, ift_disc, istage, 
     *	inewfilt, xlabel_t, xlabel_f, ylabel_t, ylabel_f, 
     +nrownote, inote, 
     *  notefile, overplot_type, if_centryd, if_auto_out, gpvel
     +_cmp,
     *  t01_bp,tc1_bp,tc2_bp,t02_bp

c		source information from cmt relations (menu, print_cmt)
	character*24 region_src
	integer iy_src, jday_src, imo_src, id_src, ih_src, imin_
     +src, expo_src
	real sec_src, lat_src, lon_src, depth_src, smo_src, mzz_
     +src, mss_src, 
     *   mee_src, mzs_src, mze_src, mse_src, magb_src, mags_src
     +, dtt_src
	common/c_src/iy_src, jday_src, imo_src, id_src, ih_src, 
     +imin_src, 
     *   sec_src, expo_src, lat_src, lon_src, depth_src, smo_sr
     +c, mzz_src,
     *   mss_src, mee_src, mzs_src, mze_src, mse_src, magb_src,
     + mags_src, 
     *   region_src, dtt_src

c		waveform indices, etc.
	common/c_tw/time_display, endtime_display, ibeg_t_displa
     +y,iend_t_display,
     *    nlen_t_display

c		anatoli's common blocks
       	parameter (mperiod = 50, mgroup = 150, mphase = 1
     +5, mkeys = 15, nraz =  66000,
     *	nseis=72000)
       	character*4 order
	character*6 stnam
	character*8 nchan, nchanR, nchanT, nchanZ, nchanN, nchan
     +E
	character*1 symchan
       	character*60 wfout, dispout
       	character*80 infile, outfile, grvfile, phvfile, s
     +vafile, filtseis, in_file
       	logical TYP,clue
       	common/shmaxis/period(mperiod),group(mgroup)
       	common/int_param/n2pow, nbase, nhalf, m2pow, mdec
     +, ndec, nw, np, nflt,
     * 		nflt0, nlen, nskip, nfirst
       	common/re_param/distan, bazim, azie, t0, tratime,
     + tmax, tmin, tmin_save, tmax_save, 
     *	grmax, grmin, grmax_save, grmin_save, grstart, grs
     +tart_save, tdel, tinit, outdt, 
     *  dur, frstep, dt, vmin, vmax, tref,norb,k_mode,grcentr,w
     +idth
       	common/gauss/alpha(mperiod), nf(mperiod),alph
       	common/result/amp(mgroup,mperiod), phase(mgroup,m
     +period),ampmax,
     * 		phavel(mperiod,mphase),nphase, pervis(mper
     +iod), phmax(mperiod),
     * 		ammax(mperiod), grtime(mperiod),gr(mperiod
     +)
C	common/polar/ amp_temp(mgroup,mperiod,3), phase_temp(mgroup,mperiod,3) 
       	common/prelim/stnam, nchan, symchan, iyear, iday,
     + nchanZ, nchanN, nchanE,
     *    t0_Z, t0_N, t0_E, dt_Z, dt_N, dt_E, dZ(nseis), dN(nse
     +is), dE(nseis), 
     *    tZ(nseis), tN(nseis), tE(nseis), ierrZ, ierrN, ierrE,
     + nZ, nN, nE,
     *    icurrN, icurrE, icurrZ, itupleZ, itupleN, itupleE, ic
     +urr_tuple,
     *    calibN, calibE, calibZ, hangN, hangE, isegZ, isegRT, 
     +iseg
	common/rot/order, nchanT, nchanR, n_RT, t0_RT, dt_RT, dR
     +AD(nseis), dTRANS(nseis), t_RT(nseis)
       	common/logamp/bamp(mgroup,mperiod)
       	common/filenames/infile, outfile, grvfile, phvfil
     +e, svafile, filtseis, in_file
       	common/KEYS/TYP(mkeys),clue
       	common/inp_out/seis(nseis), seimax
	common/dbase/wfout,dispout
       	common/instr/ampins(nraz/2), phasins(nraz/2),cali
     +bnom
	parameter (nper_graph=100)
	common/raw_amp/nflt_raw,per_raw(50),amp_raw(50),am_r(npe
     +r_graph),
     *	amp_zold(nper_graph),amp_rold(nper_graph),amp_told
     +(nper_graph),amp_zold_dispdata(nper_graph),
     *  amp_rold_dispdata(nper_graph),amp_told_dispdata(nper_gr
     +aph),per_graph(nper_graph),
     *  per_graph_z(nper_graph),per_graph_r(nper_graph),per_gra
     +ph_t(nper_graph)
       	common/work/sre(nraz), sim(nraz), fre(nraz), fim(
     +nraz), smod(nraz),
     *    tmpre(nraz),tmpim(nraz),tm(nraz)

c		data, dispersion and image information stored for plotting and interaction
	common/c_clean/clean_rz(nraz), clean_rn(nraz), clean_re(
     +nraz), clean_tn(nraz), clean_te(nraz), clean_r(nraz),
     + clean_t(nraz), 
     *    tcl_z(nraz), tcl_h(nraz), ncl_z, ncl_h, ncl_R, ncl_T
	common/c_disp_ftan/groupvel_z(mperiod), groupvel_t(mperi
     +od), groupvel_r(mperiod), 
     *    phasevel_z(mperiod), phasevel_t(mperiod), phasevel_r(
     +mperiod), period_z(mperiod), period_t(mperiod),
     *    period_r(mperiod), amp_z(mperiod), amp_t(mperiod), am
     +p_r(mperiod), pol_z(mperiod), pol_t(mperiod), 
     *    pol_r(mperiod), tdisp_z(mperiod), tdisp_t(mperiod), t
     +disp_r(mperiod), ndisp_z, ndisp_t, ndisp_r, 
     *    istage_z, istage_t, istage_r, t01_z, t01_t, t01_r, tc
     +1_z, tc1_t, tc1_r, t02_z, t02_t, t02_r, tc2_z, 
     *    tc2_t, tc2_r
	common/c_images/ftimage_zraw(mgroup, mperiod), ftimage_z
     +cl(mgroup, mperiod),
     *    ftimage_traw(mgroup, mperiod), ftimage_tcl(mgroup, mp
     +eriod),
     *    ftimage_rraw(mgroup, mperiod), ftimage_rcl(mgroup, mp
     +eriod),
     *    xaxis_zraw(mperiod), yaxis_zraw(mgroup), xaxis_zcl(mp
     +eriod), yaxis_zcl(mgroup), 
     *    xaxis_traw(mperiod), yaxis_traw(mgroup), xaxis_tcl(mp
     +eriod), yaxis_tcl(mgroup),
     *    xaxis_rraw(mperiod), yaxis_rraw(mgroup), xaxis_rcl(mp
     +eriod), yaxis_rcl(mgroup),
     *    nper_zraw, ngroup_zraw, nper_zcl, ngroup_zcl, nper_tr
     +aw, ngroup_traw, nper_tcl, 
     *    ngroup_tcl, nper_rraw, ngroup_rraw, nper_rcl, ngroup_
     +rcl

c		saving input disp relation
	parameter (mdisp2 = 500)
	character*2 stage_disp_save
	character*6 sta_disp_save
	character*8 chan_disp_save, wavetype_disp_save
	character*16 model_disp_save
	character*17 lddate_disp_save
	character*32 dfile_disp_save, dfileerr_disp_save
	character*64 dir_disp_save
	integer dispid_disp_save, jdate_disp_save, orid_disp_sav
     +e, nfreq_disp_save,
     *     commid_disp_save
	real range_disp_save, backaz_disp_save, az_disp_save, t0
     +1_disp_save, tc1_disp_save, 
     *     tc2_disp_save, t02_disp_save
	real*8 time_disp_save
	common/c_disp_save/sta_disp_save(mdisp2), chan_disp_save
     +(mdisp2), 
     *     dispid_disp_save(mdisp2), wavetype_disp_save(mdisp2)
     +, jdate_disp_save(mdisp2),
     *     orid_disp_save(mdisp2), time_disp_save(mdisp2), rang
     +e_disp_save(mdisp2),
     *     backaz_disp_save(mdisp2), az_disp_save(mdisp2), nfre
     +q_disp_save(mdisp2),
     *     stage_disp_save(mdisp2), t01_disp_save(mdisp2), tc1_
     +disp_save(mdisp2),
     *     tc2_disp_save(mdisp2), t02_disp_save(mdisp2), model_
     +disp_save(mdisp2), 
     *	   dir_disp_save(mdisp2), dfile_disp_save(mdisp2),
     + dfileerr_disp_save(mdisp2), 
     *     commid_disp_save(mdisp2), lddate_disp_save(mdisp2), 
     +nrowdisp_save

c		saving input ftdisc relation
	parameter (mftdisc2 = 500)
	character*2 datatype_ftdisc_save, stage_ftdisc_save
	character*6 sta_ftdisc_save
	character*8 chan_ftdisc_save, wavetype_ftdisc_save, imag
     +efield_ftdisc_save
	character*16 imagetype_ftdisc_save, xaxistype_ftdisc_sav
     +e, yaxistype_ftdisc_save
	character*17 lddate_ftdisc_save
	character*32 dfile_ftdisc_save
	character*64 dir_ftdisc_save
	integer ftid_ftdisc_save, jdate_ftdisc_save, orid_ftdisc
     +_save, commid_ftdisc_save,
     *     numtot_ftdisc_save, numimage_ftdisc_save, ny_ftdisc_
     +save, nx_ftdisc_save
	real range_ftdisc_save
	real*8 time_ftdisc_save
	common/c_ftdisc_save/sta_ftdisc_save(mftdisc2), chan_ftd
     +isc_save(mftdisc2), 
     *     ftid_ftdisc_save(mftdisc2), wavetype_ftdisc_save(mft
     +disc2), jdate_ftdisc_save(mftdisc2), 
     *     orid_ftdisc_save(mftdisc2), time_ftdisc_save(mftdisc
     +2), range_ftdisc_save(mftdisc2), 
     *     stage_ftdisc_save(mftdisc2), imagetype_ftdisc_save(m
     +ftdisc2), 
     *     imagefield_ftdisc_save(mftdisc2), xaxistype_ftdisc_s
     +ave(mftdisc2), 
     *     yaxistype_ftdisc_save(mftdisc2), numtot_ftdisc_save(
     +mftdisc2), numimage_ftdisc_save(mftdisc2),
     *     ny_ftdisc_save(mftdisc2), nx_ftdisc_save(mftdisc2), 
     +datatype_ftdisc_save(mftdisc2), 
     *     dir_ftdisc_save(mftdisc2), dfile_ftdisc_save(mftdisc
     +2),  
     *	   commid_ftdisc_save(mftdisc2), lddate_ftdisc_sav
     +e(mftdisc2), nrowftdisc_save
c               quality measure
	common/c_quality/quality

	character*80 fmtx, fmty
	character*80 x_label_tmp

	xmarg=.5
	ymarg=1.0
	yinc=10.
	if(ncomp.gt.3) yinc=6
C--------x_scale-------------------------------------
	a=10     
1	nxmax=int(xmax/a)+1
	nxmin=int(xmin/a)-1
	if(nxmax-nxmin.lt.10) then
	a=a/2. 
	go to 1
			      end if
	xmax=a*nxmax
	xmin=a*nxmin
       	dxnumb=a
C      	dxnumb=(xmax-xmin)/yinc
       	dxsmal=dxnumb/2.0
C--------y_scale-------------------------------------
	a=1.E+06
2	nymax=int(ymax/a)
	nymin=int(ymin/a)
	ndif=nymax-nymin
	if(ndif.lt.6) then
	a=a/10.
	go to 2
			      end if
	ymax=a*nymax
	ymin=a*nymin
3       if(ndif.gt.10) then
	a=a*2.
	ndif=ndif/2
	go to 3
		       end if
	dynumb=a
C      	dynumb=(ymax-ymin)/yinc
       	dysmal=dynumb/2.0
        fmtx='(i10)'
	if(.not.TYP(14)) fmtx='(F6.3)'
        fmty='(E10.2)'
	iclear=1

c		shift bottom plot down if more than 1 to be plotted and set incremental
c		shift for each successive plot
	shift_lower=1.
	shift_next_up=0.
	if(ncomp.gt.1) 	 shift_lower=2.
	if(ncomp.gt.1.and.ncomp.le.3) then
	 shift_next_up=ydim/10.
	elseif(ncomp.gt.3) then
	 shift_next_up=ydim/20.
	endif

	call setbg(bg)
	call setfg('black')
	x_label_tmp = ''
	if(icomp.eq.1.and.time_centryd.ne.0.) then
	 x_label_tmp=x_label
	elseif(icomp.eq.1.and.time_centryd.eq.0.) then
	 x_label_tmp='time from beginning of waveform (sec)'
	endif

	ylow2=ylow/shift_lower + float(icomp - 1)*ydim/float(nco
     +mp) + float(icomp - 1)*shift_next_up
      	call axis (xdim, ydim/float(ncomp), xmarg, ymarg, 
     +xlow, ylow2,
     *           xmax, xmin, ymax, ymin, dxsmal, dxnumb,
     *           dysmal, dynumb, fmtx, fmty,
     *           x_label_tmp, title, ' ', iclear)
c		upper plot


	return
	end

	subroutine mhr_init(type)
c		niceplot initiation: determination of window type, size,
c		and if a postscript plot will be output.
c			itran = 0 ==> portrait, else landscape.
c			ipost = 1 ==> postscript output, else not.
c			iwsize = 1 ==> large, else small.
c		variable names are chosen to be identical to the CSS 3.0
c		attribute names with the relation name appended preceded
c		by an underscore (e.g., lat_centryd, lat_origin, sta_wfdisc, etc).
c
c		declarations and common blocks are included for the 
c		following relations:
c
c		  affiliation, arrival, assoc, centryd (hybrid 2.8), event, 
c		  gregion, instrument, network, moment (hybrid 2.8), origin,
c		  remark, sensor, site, sitechan, sregion, wfdisc
c
c		additional relations include: select, wfedit, spdisc, tape,
c			tapefile, tapedata, ftdisc, disp
c
c		in addition there are declarations for: db io and filter files.
c
c		the dimensions of all variables except those for the event 
c		relations are declared so that entire tables are stored.
c		the event relations are: 
c			centryd, event, origin, gregion, moment, sregion
c
c		order of variables in common blocks differ slightly from
c		in the definition of the relation in order to minimize 
c		misalignment complaints during compilation.


c	implicit integer(i-n), real(a-h,o-z)

c		data base io declarations (3.0)
	character*80 dbin, dbout, dbcmt, dbegn, dbwfdisc
	integer idbin, idbout, idbcmt, idbegn, idbwfdisc
	common/c_dbio/idbin,idbout,dbin,dbout,dbcmt,idbcmt,dbegn
     +,idbegn,
     *    dbwfdisc,idbwfdisc



c		centryd declarations (2.8 with modifications)
c			modifications are:
c			remark has been replaced with commid_centryd
c			lddate_centryd added at end
c			nrlpb interpreted as no. records of LP body waves
c			nrmw interpreted as no. records of mantle waves
	character*10 dused_centryd
	character*15 auth_centryd
	character*17 lddate_centryd
	integer orid_centryd, jdate_centryd, nslpb_centryd, nrlp
     +b_centryd,
     *    tmnlpb_centryd, nsmw_centryd, nrmw_centryd, tmnmw_cen
     +tryd, commid_centryd
	real lat_centryd, lon_centryd, depth_centryd, coterr_cen
     +tryd, claerr_centryd, 
     *    cloerr_centryd, cdperr_centryd, durat_centryd
	real*8 time_centryd
	common/c_centryd/orid_centryd, jdate_centryd, time_centr
     +yd,
     *    lat_centryd, lon_centryd, depth_centryd, coterr_centr
     +yd, claerr_centryd, 
     *    cloerr_centryd, cdperr_centryd, durat_centryd, nslpb_
     +centryd, nrlpb_centryd,
     *    tmnlpb_centryd, nsmw_centryd, nrmw_centryd, tmnmw_cen
     +tryd, commid_centryd, 
     *    dused_centryd, auth_centryd, lddate_centryd



c		event declarations (3.0)
	character*15 evname_event, auth_event
	character*17 lddate_event
	integer evid_event, prefor_event, commid_event
	common/c_event/evid_event, prefor_event, commid_event,
     *     auth_event, lddate_event, evname_event



c		filter declarations (3.0)
	parameter (mpz = 100, mfir = 500, mstages = 20)
	character*4 type_filter
	character*80 dfile_filter
	integer np_filter, nz_filter, nstages_filter
	real a0_filter, coefn_filter, coefd_filter, coefnerr_fil
     +ter, 
     *    coefderr_filter
	complex zero_filter, pole_filter, zererr_filter, polerr_
     +filter
	common/c_filter/a0_filter(mstages), nz_filter(mstages), 
     +np_filter(mstages), 
     *    zero_filter(mstages, mpz), zererr_filter(mstages, mpz
     +), 
     *    pole_filter(mstages, mpz), polerr_filter(mstages, mpz
     +), 
     *    nnum_filter(mstages), nden_filter(mstages), srate_fil
     +ter(mstages),
     *    coefn_filter(mstages, mfir), coefnerr_filter(mstages,
     + mfir), 
     *    coefd_filter(mstages, mfir), coefderr_filter(mstages,
     + mfir), 
     *    type_filter(mstages), nstages_filter, dfile_filter, i
     +resp_filter


c		geographical region (gregion) declarations (3.0)
	character*17 lddate_gregion
	character*40 grname_gregion
	integer grn_gregion
	common/c_gregion/grn_gregion, grname_gregion, lddate_gre
     +gion



c		instrument declarations (3.0)
	parameter (minstrument = 5500)
	character band_instrument, digital_instrument
	character*6 instype_instrument, rsptype_instrument
	character*17 lddate_instrument
	character*32 dfile_instrument
	character*50 insname_instrument
	character*64 dir_instrument
	integer inid_instrument
	real samprate_instrument, ncalib_instrument, ncalper_ins
     +trument
	common/c_instrument/inid_instrument(minstrument), 
     *     insname_instrument(minstrument), instype_instrument(
     +minstrument), 
     *     band_instrument(minstrument), digital_instrument(min
     +strument), 
     *     samprate_instrument(minstrument), ncalib_instrument(
     +minstrument), 
     *     ncalper_instrument(minstrument), dir_instrument(mins
     +trument), 
     *     dfile_instrument(minstrument), rsptype_instrument(mi
     +nstrument),
     *     lddate_instrument(minstrument), nrowinstrument





c		moment declarations (2.8 with modifications)
c			modifications are:
c			remark has been replaced with commid_moment
c			lddate_moment added at end
c			nslpb, nrlpb, tmnlpb, nsmw, nrmw, tmnmw have
c			   been left out since they're in centryd
c			slips have been replaced with rakes
	character*10 dused_moment
	character*15 auth_moment
	character*17 lddate_moment
	integer orid_moment, mexpon_moment, commid_moment
	real bestdc_moment, mrr_moment, mtt_moment, mff_moment, 
     +mrt_moment,
     *    mrf_moment, mtf_moment, mrrerr_moment, mtterr_moment,
     + mfferr_moment,
     *    mrterr_moment, mrferr_moment, mtferr_moment, paxval_m
     +oment, paxplg_moment, 
     *    paxazm_moment, naxval_moment, naxplg_moment, naxazm_m
     +oment, taxval_moment, 
     *    taxplg_moment, taxazm_moment, str1_moment, dip1_momen
     +t, rake1_moment, 
     *    str2_moment, dip2_moment, rake2_moment
	common/c_moment/orid_moment, mexpon_moment, bestdc_momen
     +t, 
     *    mrr_moment, mtt_moment, mff_moment, mrt_moment, mrf_m
     +oment, mtf_moment,
     *    mrrerr_moment, mtterr_moment, mfferr_moment, mrterr_m
     +oment, mrferr_moment,
     *    mtferr_moment, paxval_moment, paxplg_moment, paxazm_m
     +oment, naxval_moment, 
     *    naxplg_moment, naxazm_moment, taxval_moment, taxplg_m
     +oment, taxazm_moment, 
     *    str1_moment, dip1_moment, rake1_moment, str2_moment, 
     +dip2_moment, rake2_moment, 
     *    commid_moment, dused_moment, auth_moment, lddate_mome
     +nt


c		origin declarations (3.0)
	character dtype_origin
	character*7 etype_origin
	character*15 algorithm_origin, auth_origin 
	character*17 lddate_origin
	integer orid_origin, evid_origin, jdate_origin, nass_ori
     +gin,
     *    ndef_origin, ndp_origin, grn_origin, srn_origin, mbid
     +_origin, 
     *    msid_origin, mlid_origin, commid_origin
	real lat_origin, lon_origin, depth_origin, depdp_origin,
     + mb_origin,
     *    ms_origin, ml_origin
	real*8 time_origin
	common/c_origin/time_origin, lat_origin, lon_origin, dep
     +th_origin,
     *    orid_origin, evid_origin, jdate_origin, nass_origin, 
     +ndef_origin, 
     *    ndp_origin, grn_origin, srn_origin, depdp_origin, mb_
     +origin,
     *    mbid_origin, ms_origin, msid_origin, ml_origin, mlid_
     +origin, 
     *    commid_origin, algorithm_origin, auth_origin, lddate_
     +origin, 
     *    dtype_origin, etype_origin 



c		remark declarations (3.0)
	parameter (mremark = 10000)
	character*17 lddate_remark
	character*80 remark_remark
	integer commid_remark, lineno_remark
	common/c_remark/commid_remark(mremark), lineno_remark(mr
     +emark), 
     *      remark_remark(mremark), lddate_remark(mremark), nro
     +wremark

c		select declarations (mhr)
	parameter (mselect=5000)	
	integer selid_select, nmode_select, lmode_select, commid
     +_select
	character st_select
	character*6 sta_select
	character*8 chan_select
	character*15 author_select
	character*16 comment_select
	character*17 lddate_select
	character*32 dbwfdisc_select
	character*64 dir_select
	common/c_select/selid_select(mselect), sta_select(mselec
     +t), 
     *    chan_select(mselect), nmode_select(mselect), st_selec
     +t(mselect),
     *    lmode_select(mselect), comment_select(mselect), 
     *    dir_select(mselect), dbwfdisc_select(mselect), 
     *    author_select(mselect), commid_select(mselect), 
     *    lddate_select(mselect), nrowselect



c		sensor declarations (3.0)
	parameter(msensor=8000)
	character instant_sensor
	character*6 sta_sensor
	character*8 chan_sensor
	character*17 lddate_sensor
	integer inid_sensor, chanid_sensor, jdate_sensor
	real calratio_sensor, calper_sensor, tshift_sensor
	real*8 time_sensor, endtime_sensor
	common/c_sensor/sta_sensor(msensor), chan_sensor(msensor
     +),
     *      time_sensor(msensor), endtime_sensor(msensor),
     *      inid_sensor(msensor), chanid_sensor(msensor), jdate
     +_sensor(msensor),
     *      calratio_sensor(msensor), calper_sensor(msensor), t
     +shift_sensor(msensor),
     *      instant_sensor(msensor), lddate_sensor(msensor), nr
     +owsensor



c		site declarations (3.0)
	parameter (msite = 500)
	character*4 statype_site 
	character*6 sta_site, refsta_site
	character*17 lddate_site 
	character*50 staname_site
	integer ondate_site, offdate_site	
	real lat_site, lon_site, elev_site, deast_site, dnorth_s
     +ite
	common/csite/sta_site(msite), ondate_site(msite), offdat
     +e_site(msite),
     *     lat_site(msite), lon_site(msite), elev_site(msite), 
     +staname_site(msite), 
     *     statype_site(msite), refsta_site(msite), dnorth_site
     +(msite), 
     *     deast_site(msite), lddate_site(msite), nrowsite



c		sitechan declarations (3.0)
	parameter(msitechan=6500)
	character*4 ctype_sitechan
	character*6 sta_sitechan
	character*8 chan_sitechan
	character*17 lddate_sitechan
	character*50 descrip_sitechan
	integer ondate_sitechan, offdate_sitechan, chanid_sitech
     +an
	real edepth_sitechan, hang_sitechan, vang_sitechan
	common/csitechan/sta_sitechan(msitechan), chan_sitechan(
     +msitechan),
     *     ondate_sitechan(msitechan), chanid_sitechan(msitecha
     +n), 
     *     offdate_sitechan(msitechan), ctype_sitechan(msitecha
     +n), 
     *     edepth_sitechan(msitechan), hang_sitechan(msitechan)
     +, 
     *     vang_sitechan(msitechan), descrip_sitechan(msitechan
     +),
     *     lddate_sitechan(msitechan), nrowsitechan


c		seismic region (sregion) declarations (3.0)
	character*17 lddate_sregion
	character*40 srname_sregion
	integer srn_sregion
	common/c_sregion/srn_sregion, srname_sregion, lddate_sre
     +gion


c		wfdisc declarations (3.0)
	parameter(mwfdisc = 10000)
	character segtype_wfdisc, clip_wfdisc
	character*2 datatype_wfdisc
	character*6 sta_wfdisc, instype_wfdisc
	character*8 chan_wfdisc
	character*17 lddate_wfdisc
	character*32 dfile_wfdisc
	character*64 dir_wfdisc
	integer wfid_wfdisc, chanid_wfdisc, jdate_wfdisc, nsamp_
     +wfdisc, 
     *     foff_wfdisc, commid_wfdisc
	real samprate_wfdisc, calib_wfdisc, calper_wfdisc
	real*8 time_wfdisc, endtime_wfdisc
	common/c_wfdisc/sta_wfdisc(mwfdisc), chan_wfdisc(mwfdisc
     +), time_wfdisc(mwfdisc), 
     *     wfid_wfdisc(mwfdisc), chanid_wfdisc(mwfdisc), jdate_
     +wfdisc(mwfdisc),
     *     endtime_wfdisc(mwfdisc), nsamp_wfdisc(mwfdisc), samp
     +rate_wfdisc(mwfdisc),
     *     calib_wfdisc(mwfdisc), calper_wfdisc(mwfdisc), insty
     +pe_wfdisc(mwfdisc), 
     *     segtype_wfdisc(mwfdisc), datatype_wfdisc(mwfdisc), c
     +lip_wfdisc(mwfdisc), 
     *     dir_wfdisc(mwfdisc), dfile_wfdisc(mwfdisc), foff_wfd
     +isc(mwfdisc), 
     *     commid_wfdisc(mwfdisc), lddate_wfdisc(mwfdisc), nrow
     +wfdisc

c		wfedit declarations (mhr)
	parameter (mwfedit = 10000)
	character*6 sta_wfedit
	character*8 chan_wfedit,probtype_wfedit,edtype_wfedit
	character*15 auth_wfedit
	character*17 lddate_wfedit
	integer edid_wfedit, commid_wfedit
	real*8 time_wfedit, endtime_wfedit
	common/c_wfedit/sta_wfedit(mwfedit), chan_wfedit(mwfedit
     +),
     *     edid_wfedit(mwfedit), time_wfedit(mwfedit), endtime_
     +wfedit(mwfedit),  
     *     probtype_wfedit(mwfedit), edtype_wfedit(mwfedit), co
     +mmid_wfedit(mwfedit),
     *     auth_wfedit(mwfedit), lddate_wfedit(mwfedit), nrowwf
     +edit


c		disp, dispdata and disperr declarations (mhr)
c			disp
	parameter (mdisp = 500, mdispdata = 100)
	character*2 stage_disp
	character*6 sta_disp
	character*8 chan_disp, wavetype_disp
	character*16 model_disp
	character*17 lddate_disp
	character*32 dfile_disp, dfileerr_disp
	character*64 dir_disp
	integer dispid_disp, jdate_disp, orid_disp, nfreq_disp,
     *     commid_disp
	real range_disp, backaz_disp, az_disp, t01_disp, tc1_dis
     +p, 
     *     tc2_disp, t02_disp
	real*8 time_disp
	common/c_disp/sta_disp(mdisp), chan_disp(mdisp), 
     *     dispid_disp(mdisp), wavetype_disp(mdisp), jdate_disp
     +(mdisp),
     *     orid_disp(mdisp), time_disp(mdisp), range_disp(mdisp
     +),
     *     backaz_disp(mdisp), az_disp(mdisp), nfreq_disp(mdisp
     +),
     *     stage_disp(mdisp), t01_disp(mdisp), tc1_disp(mdisp),
     +
     *     tc2_disp(mdisp), t02_disp(mdisp), model_disp(mdisp),
     + 
     *	   dir_disp(mdisp), dfile_disp(mdisp), dfileerr_di
     +sp(mdisp), 
     *     commid_disp(mdisp), lddate_disp(mdisp), nrowdisp

c			dispdata
	integer nfreq_dispdata
	real f_dispdata, t_dispdata, groupvel_dispdata, 
     *     dgroupvel_dispdata, phasevel_dispdata, dphasevel_dis
     +pdata,
     *     amp_dispdata, damp_dispdata, pol_dispdata, dpol_disp
     +data,
     *     filt1_dispdata, filt2_dispdata
	common/c_dispdata/nfreq_dispdata, f_dispdata(mdispdata),
     + 
     *     filt1_dispdata(mdispdata), filt2_dispdata(mdispdata)
     +,
     *     t_dispdata(mdispdata), groupvel_dispdata(mdispdata),
     + 
     *     dgroupvel_dispdata(mdispdata),
     *     phasevel_dispdata(mdispdata), dphasevel_dispdata(mdi
     +spdata),
     *     amp_dispdata(mdispdata), damp_dispdata(mdispdata),
     *     pol_dispdata(mdispdata), dpol_dispdata(mdispdata)
c			disperr
	integer nfreq_disperr
	real f_disperr, t_disperr, groupvel_disperr, 
     *     dgroupvel_disperr, phasevel_disperr, dphasevel_dispe
     +rr,
     *     amp_disperr, damp_disperr, pol_disperr, dpol_disperr
     +
	common/c_disperr/nfreq_disperr, f_disperr(mdispdata), 
     *     t_disperr(mdispdata), groupvel_disperr(mdispdata), 
     *     dgroupvel_disperr(mdispdata),
     *     phasevel_disperr(mdispdata), dphasevel_disperr(mdisp
     +data),
     *     amp_disperr(mdispdata), damp_disperr(mdispdata),
     *     pol_disperr(mdispdata), dpol_disperr(mdispdata)

c			ftdisc and ftimag
	parameter (mftdisc = 500, mftimag = 250)
	character*2 datatype_ftdisc, stage_ftdisc
	character*6 sta_ftdisc
	character*8 chan_ftdisc, wavetype_ftdisc, imagefield_ftd
     +isc
	character*16 imagetype_ftdisc, xaxistype_ftdisc, yaxisty
     +pe_ftdisc
	character*17 lddate_ftdisc
	character*32 dfile_ftdisc
	character*64 dir_ftdisc
	integer ftid_ftdisc, jdate_ftdisc, orid_ftdisc, commid_f
     +tdisc,
     *     numtot_ftdisc, numimage_ftdisc, ny_ftdisc, nx_ftdisc
     +
	real range_ftdisc
	real*8 time_ftdisc
	common/c_ftdisc/sta_ftdisc(mftdisc), chan_ftdisc(mftdisc
     +), 
     *     ftid_ftdisc(mftdisc), wavetype_ftdisc(mftdisc), jdat
     +e_ftdisc(mftdisc), 
     *     orid_ftdisc(mftdisc), time_ftdisc(mftdisc), range_ft
     +disc(mftdisc), stage_ftdisc(mftdisc), 
     *     imagetype_ftdisc(mftdisc), imagefield_ftdisc(mftdisc
     +), xaxistype_ftdisc(mftdisc), 
     *     yaxistype_ftdisc(mftdisc), numtot_ftdisc(mftdisc), n
     +umimage_ftdisc(mftdisc),
     *     ny_ftdisc(mftdisc), nx_ftdisc(mftdisc), datatype_ftd
     +isc(mftdisc), 
     *     dir_ftdisc(mftdisc), dfile_ftdisc(mftdisc),  
     *	   commid_ftdisc(mftdisc), lddate_ftdisc(mftdisc),
     + nrowftdisc
	real imag_ftimag_re, imag_ftimag_im, xaxis_ftimag, yaxis
     +_ftimag
	common/c_ftimag/imag_ftimag_re(mftimag,mftimag), imag_ft
     +imag_im(mftimag,mftimag), 
     *     xaxis_ftimag(mftimag), yaxis_ftimag(mftimag)



c		declarations for stachan_sctlist_wfdisc common block
	parameter (mstachan = 1500, msegs = 20)
	character*6 sta_sctlist_wfdisc
	character*8 chan_sctlist_wfdisc
	integer numsctlist_wfdisc, ntuple_sctlist_wfdisc, nsegs_
     +sctlist_wfdisc
	real*8 time_sctlist_wfdisc, endtime_sctlist_wfdisc
	common/c_sctlist_wfdisc/sta_sctlist_wfdisc(mstachan), 
     *    chan_sctlist_wfdisc(mstachan),time_sctlist_wfdisc(mst
     +achan,msegs), 
     *    endtime_sctlist_wfdisc(mstachan, msegs),ntuple_sctlis
     +t_wfdisc(mstachan,msegs), 
     *    nsegs_sctlist_wfdisc(mstachan),icalled_sctlist_wfdisc
     +,numsctlist_wfdisc

c		declarations for stachan_sctlist_wfedit common block
	parameter (medits = 100)
	character*6 sta_sctlist_wfedit
	character*8 chan_sctlist_wfedit, probtype_sctlist_wfedit
     +, edtype_sctlist_wfedit
	integer numsctlist_wfedit, ntuple_sctlist_wfedit, nsegs_
     +sctlist_wfedit
	real*8 time_sctlist_wfedit, endtime_sctlist_wfedit
	common/c_sctlist_wfedit/sta_sctlist_wfedit(mstachan), 
     *    chan_sctlist_wfedit(mstachan),time_sctlist_wfedit(mst
     +achan,medits), 
     *    endtime_sctlist_wfedit(mstachan, medits),probtype_sct
     +list_wfedit(mstachan, medits),
     *	  edtype_sctlist_wfedit(mstachan, medits),ntuple_s
     +ctlist_wfedit(mstachan,medits), 
     *    nsegs_sctlist_wfedit(mstachan),icalled_sctlist_wfedit
     +,numsctlist_wfedit

c		waveform declarations
	parameter (mdata= 72000)
	common/c_data/t(mdata), d(mdata), t_plot(mdata), d_plot(
     +mdata), nlen_data, nlen_plot,
     *    t1(mdata), d1(mdata)

c		plotting declarations
	character*80 x_label, y_label, title
	character chr
	character*80 fg, bg
	common/mhr_nplot/itran,ipost,iwsize,ssize,xwin,ywin,
     *   xdim,ydim,xlow,ylow,init,chr,x_label,y_label,title,fg,
     +bg,iltype,thick

c		declarations for sta:chn sifting
	parameter (msc=1500)
	character*6 sta_plot
	character*8 chan_plot
	common/c_scplot/sta_plot(msc), chan_plot(msc), numplot

c		odds and ends
	character ifedit, ifinterp, overplot_type, gpvel_cmp, if
     +_centryd, if_auto_out
	character*80 ps_file, xlabel_t, xlabel_f, ylabel_t, ylab
     +el_f, notefile
	common/c_oande/icurrent, ifedit, ifinterp, ps_file, idis
     +p, ift_disc, istage, 
     *	inewfilt, xlabel_t, xlabel_f, ylabel_t, ylabel_f, 
     +nrownote, inote, 
     *  notefile, overplot_type, if_centryd, if_auto_out, gpvel
     +_cmp,
     *  t01_bp,tc1_bp,tc2_bp,t02_bp

c		source information from cmt relations (menu, print_cmt)
	character*24 region_src
	integer iy_src, jday_src, imo_src, id_src, ih_src, imin_
     +src, expo_src
	real sec_src, lat_src, lon_src, depth_src, smo_src, mzz_
     +src, mss_src, 
     *   mee_src, mzs_src, mze_src, mse_src, magb_src, mags_src
     +, dtt_src
	common/c_src/iy_src, jday_src, imo_src, id_src, ih_src, 
     +imin_src, 
     *   sec_src, expo_src, lat_src, lon_src, depth_src, smo_sr
     +c, mzz_src,
     *   mss_src, mee_src, mzs_src, mze_src, mse_src, magb_src,
     + mags_src, 
     *   region_src, dtt_src

c		waveform indices, etc.
	common/c_tw/time_display, endtime_display, ibeg_t_displa
     +y,iend_t_display,
     *    nlen_t_display

c		anatoli's common blocks
       	parameter (mperiod = 50, mgroup = 150, mphase = 1
     +5, mkeys = 15, nraz =  66000,
     *	nseis=72000)
       	character*4 order
	character*6 stnam
	character*8 nchan, nchanR, nchanT, nchanZ, nchanN, nchan
     +E
	character*1 symchan
       	character*60 wfout, dispout
       	character*80 infile, outfile, grvfile, phvfile, s
     +vafile, filtseis, in_file
       	logical TYP,clue
       	common/shmaxis/period(mperiod),group(mgroup)
       	common/int_param/n2pow, nbase, nhalf, m2pow, mdec
     +, ndec, nw, np, nflt,
     * 		nflt0, nlen, nskip, nfirst
       	common/re_param/distan, bazim, azie, t0, tratime,
     + tmax, tmin, tmin_save, tmax_save, 
     *	grmax, grmin, grmax_save, grmin_save, grstart, grs
     +tart_save, tdel, tinit, outdt, 
     *  dur, frstep, dt, vmin, vmax, tref,norb,k_mode,grcentr,w
     +idth
       	common/gauss/alpha(mperiod), nf(mperiod),alph
       	common/result/amp(mgroup,mperiod), phase(mgroup,m
     +period),ampmax,
     * 		phavel(mperiod,mphase),nphase, pervis(mper
     +iod), phmax(mperiod),
     * 		ammax(mperiod), grtime(mperiod),gr(mperiod
     +)
C	common/polar/ amp_temp(mgroup,mperiod,3), phase_temp(mgroup,mperiod,3) 
       	common/prelim/stnam, nchan, symchan, iyear, iday,
     + nchanZ, nchanN, nchanE,
     *    t0_Z, t0_N, t0_E, dt_Z, dt_N, dt_E, dZ(nseis), dN(nse
     +is), dE(nseis), 
     *    tZ(nseis), tN(nseis), tE(nseis), ierrZ, ierrN, ierrE,
     + nZ, nN, nE,
     *    icurrN, icurrE, icurrZ, itupleZ, itupleN, itupleE, ic
     +urr_tuple,
     *    calibN, calibE, calibZ, hangN, hangE, isegZ, isegRT, 
     +iseg
	common/rot/order, nchanT, nchanR, n_RT, t0_RT, dt_RT, dR
     +AD(nseis), dTRANS(nseis), t_RT(nseis)
       	common/logamp/bamp(mgroup,mperiod)
       	common/filenames/infile, outfile, grvfile, phvfil
     +e, svafile, filtseis, in_file
       	common/KEYS/TYP(mkeys),clue
       	common/inp_out/seis(nseis), seimax
	common/dbase/wfout,dispout
       	common/instr/ampins(nraz/2), phasins(nraz/2),cali
     +bnom
	parameter (nper_graph=100)
	common/raw_amp/nflt_raw,per_raw(50),amp_raw(50),am_r(npe
     +r_graph),
     *	amp_zold(nper_graph),amp_rold(nper_graph),amp_told
     +(nper_graph),amp_zold_dispdata(nper_graph),
     *  amp_rold_dispdata(nper_graph),amp_told_dispdata(nper_gr
     +aph),per_graph(nper_graph),
     *  per_graph_z(nper_graph),per_graph_r(nper_graph),per_gra
     +ph_t(nper_graph)
       	common/work/sre(nraz), sim(nraz), fre(nraz), fim(
     +nraz), smod(nraz),
     *    tmpre(nraz),tmpim(nraz),tm(nraz)

c		data, dispersion and image information stored for plotting and interaction
	common/c_clean/clean_rz(nraz), clean_rn(nraz), clean_re(
     +nraz), clean_tn(nraz), clean_te(nraz), clean_r(nraz),
     + clean_t(nraz), 
     *    tcl_z(nraz), tcl_h(nraz), ncl_z, ncl_h, ncl_R, ncl_T
	common/c_disp_ftan/groupvel_z(mperiod), groupvel_t(mperi
     +od), groupvel_r(mperiod), 
     *    phasevel_z(mperiod), phasevel_t(mperiod), phasevel_r(
     +mperiod), period_z(mperiod), period_t(mperiod),
     *    period_r(mperiod), amp_z(mperiod), amp_t(mperiod), am
     +p_r(mperiod), pol_z(mperiod), pol_t(mperiod), 
     *    pol_r(mperiod), tdisp_z(mperiod), tdisp_t(mperiod), t
     +disp_r(mperiod), ndisp_z, ndisp_t, ndisp_r, 
     *    istage_z, istage_t, istage_r, t01_z, t01_t, t01_r, tc
     +1_z, tc1_t, tc1_r, t02_z, t02_t, t02_r, tc2_z, 
     *    tc2_t, tc2_r
	common/c_images/ftimage_zraw(mgroup, mperiod), ftimage_z
     +cl(mgroup, mperiod),
     *    ftimage_traw(mgroup, mperiod), ftimage_tcl(mgroup, mp
     +eriod),
     *    ftimage_rraw(mgroup, mperiod), ftimage_rcl(mgroup, mp
     +eriod),
     *    xaxis_zraw(mperiod), yaxis_zraw(mgroup), xaxis_zcl(mp
     +eriod), yaxis_zcl(mgroup), 
     *    xaxis_traw(mperiod), yaxis_traw(mgroup), xaxis_tcl(mp
     +eriod), yaxis_tcl(mgroup),
     *    xaxis_rraw(mperiod), yaxis_rraw(mgroup), xaxis_rcl(mp
     +eriod), yaxis_rcl(mgroup),
     *    nper_zraw, ngroup_zraw, nper_zcl, ngroup_zcl, nper_tr
     +aw, ngroup_traw, nper_tcl, 
     *    ngroup_tcl, nper_rraw, ngroup_rraw, nper_rcl, ngroup_
     +rcl

c		saving input disp relation
	parameter (mdisp2 = 500)
	character*2 stage_disp_save
	character*6 sta_disp_save
	character*8 chan_disp_save, wavetype_disp_save
	character*16 model_disp_save
	character*17 lddate_disp_save
	character*32 dfile_disp_save, dfileerr_disp_save
	character*64 dir_disp_save
	integer dispid_disp_save, jdate_disp_save, orid_disp_sav
     +e, nfreq_disp_save,
     *     commid_disp_save
	real range_disp_save, backaz_disp_save, az_disp_save, t0
     +1_disp_save, tc1_disp_save, 
     *     tc2_disp_save, t02_disp_save
	real*8 time_disp_save
	common/c_disp_save/sta_disp_save(mdisp2), chan_disp_save
     +(mdisp2), 
     *     dispid_disp_save(mdisp2), wavetype_disp_save(mdisp2)
     +, jdate_disp_save(mdisp2),
     *     orid_disp_save(mdisp2), time_disp_save(mdisp2), rang
     +e_disp_save(mdisp2),
     *     backaz_disp_save(mdisp2), az_disp_save(mdisp2), nfre
     +q_disp_save(mdisp2),
     *     stage_disp_save(mdisp2), t01_disp_save(mdisp2), tc1_
     +disp_save(mdisp2),
     *     tc2_disp_save(mdisp2), t02_disp_save(mdisp2), model_
     +disp_save(mdisp2), 
     *	   dir_disp_save(mdisp2), dfile_disp_save(mdisp2),
     + dfileerr_disp_save(mdisp2), 
     *     commid_disp_save(mdisp2), lddate_disp_save(mdisp2), 
     +nrowdisp_save

c		saving input ftdisc relation
	parameter (mftdisc2 = 500)
	character*2 datatype_ftdisc_save, stage_ftdisc_save
	character*6 sta_ftdisc_save
	character*8 chan_ftdisc_save, wavetype_ftdisc_save, imag
     +efield_ftdisc_save
	character*16 imagetype_ftdisc_save, xaxistype_ftdisc_sav
     +e, yaxistype_ftdisc_save
	character*17 lddate_ftdisc_save
	character*32 dfile_ftdisc_save
	character*64 dir_ftdisc_save
	integer ftid_ftdisc_save, jdate_ftdisc_save, orid_ftdisc
     +_save, commid_ftdisc_save,
     *     numtot_ftdisc_save, numimage_ftdisc_save, ny_ftdisc_
     +save, nx_ftdisc_save
	real range_ftdisc_save
	real*8 time_ftdisc_save
	common/c_ftdisc_save/sta_ftdisc_save(mftdisc2), chan_ftd
     +isc_save(mftdisc2), 
     *     ftid_ftdisc_save(mftdisc2), wavetype_ftdisc_save(mft
     +disc2), jdate_ftdisc_save(mftdisc2), 
     *     orid_ftdisc_save(mftdisc2), time_ftdisc_save(mftdisc
     +2), range_ftdisc_save(mftdisc2), 
     *     stage_ftdisc_save(mftdisc2), imagetype_ftdisc_save(m
     +ftdisc2), 
     *     imagefield_ftdisc_save(mftdisc2), xaxistype_ftdisc_s
     +ave(mftdisc2), 
     *     yaxistype_ftdisc_save(mftdisc2), numtot_ftdisc_save(
     +mftdisc2), numimage_ftdisc_save(mftdisc2),
     *     ny_ftdisc_save(mftdisc2), nx_ftdisc_save(mftdisc2), 
     +datatype_ftdisc_save(mftdisc2), 
     *     dir_ftdisc_save(mftdisc2), dfile_ftdisc_save(mftdisc
     +2),  
     *	   commid_ftdisc_save(mftdisc2), lddate_ftdisc_sav
     +e(mftdisc2), nrowftdisc_save
c               quality measure
	common/c_quality/quality

c		declarations specific to this routine
	character*80 file
	character*6 sta
	character*(*) type

	if(sta_wfdisc(icurrZ).ne.'') then
	 sta=sta_wfdisc(icurrZ)
	elseif(sta_wfdisc(icurrN).ne.'') then
	 sta=sta_wfdisc(icurrN)
	elseif(sta_wfdisc(icurrE).ne.'') then
	 sta=sta_wfdisc(icurrE)	
	else
	 sta=''
	endif

c		graphics initiated if init=1
	init=1
	
c	print *,ipost
      	if(ipost.eq.1) then
	 file=ps_file(1:lnblnk(ps_file))//'_'//sta(1:lnblnk(sta)
     +)//'_'//type(1:lnblnk(type))//'.ps'
	else
	 file='none'//''
	 
      	endif
c	print *,file
	if(itran.eq.0) then
c		portrait
	  if(iwsize.eq.1) then
c			large window
	   ssize=.90
	   xwin=.88
	   ywin=0.
	  else
c			small window
	   ssize=.60
	   xwin=1.82
	   ywin=0.
	  endif
      	  call initt (itran, file, '','ftan', ssize, xwin,
     + ywin)
	else
c		landscape
	 if(iwsize.eq.1) then
c			large window
	  ssize=.80
	  xwin=.19
	  ywin=0.
	 else
c			small window (Anatoli's size)
	  ssize=.75
	  xwin=.27
	  ywin=0.
	 endif
      	 call initt (itran, file, '','ftan', ssize, xwin, 
     +ywin)
	endif

	if(itran.eq.0) then
c		portrait
         xdim=5.5
         ydim=5.5
         xlow=1.5
         ylow=2.
	else
c		landscape
         xdim=8.0
         ydim=5.5
         xlow=1.5
         ylow=1.25
	endif
       	call setdim(xdim,ydim,xlow,ylow)

c       call cfont(132)

	return
	end
	subroutine mhr_minmax(ndata,x,y,xmin,xmax,ymin,ymax)
c		returns min and max values of arrays x and y
	dimension x(*), y(*)
	xmin=x(1)
	xmax=x(1)
	ymin=y(1)
	ymax=y(1)
	do i=1,ndata
	 xmin=min(xmin,x(i))
	 ymin=min(ymin,y(i))
	 xmax=max(xmax,x(i))
	 ymax=max(ymax,y(i))
	enddo
	return
	end
