	subroutine mk_database
c		read in site, sitechan, sensor, and intrument tables
c		variable names are chosen to be identical to the CSS 3.0
c		attribute names with the relation name appended preceded
c		by an underscore (e.g., lat_centryd, lat_origin, sta_wfdisc, etc).
c
c		declarations and common blocks are included for the 
c		following relations:
c
c		  affiliation, arrival, assoc, centryd (hybrid 2.8), event, 
c		  gregion, instrument, network, moment (hybrid 2.8), origin,
c		  remark, sensor, site, sitechan, sregion, wfdisc
c
c		additional relations include: select, wfedit, spdisc, tape,
c			tapefile, tapedata, ftdisc, disp
c
c		in addition there are declarations for: db io and filter files.
c
c		the dimensions of all variables except those for the event 
c		relations are declared so that entire tables are stored.
c		the event relations are: 
c			centryd, event, origin, gregion, moment, sregion
c
c		order of variables in common blocks differ slightly from
c		in the definition of the relation in order to minimize 
c		misalignment complaints during compilation.


c	implicit integer(i-n), real(a-h,o-z)

c		data base io declarations (3.0)
	character*80 dbin, dbout, dbcmt, dbegn, dbwfdisc
	integer idbin, idbout, idbcmt, idbegn, idbwfdisc
	common/c_dbio/idbin,idbout,dbin,dbout,dbcmt,idbcmt,dbegn
     +,idbegn,
     *    dbwfdisc,idbwfdisc



c		centryd declarations (2.8 with modifications)
c			modifications are:
c			remark has been replaced with commid_centryd
c			lddate_centryd added at end
c			nrlpb interpreted as no. records of LP body waves
c			nrmw interpreted as no. records of mantle waves
	character*10 dused_centryd
	character*15 auth_centryd
	character*17 lddate_centryd
	integer orid_centryd, jdate_centryd, nslpb_centryd, nrlp
     +b_centryd,
     *    tmnlpb_centryd, nsmw_centryd, nrmw_centryd, tmnmw_cen
     +tryd, commid_centryd
	real lat_centryd, lon_centryd, depth_centryd, coterr_cen
     +tryd, claerr_centryd, 
     *    cloerr_centryd, cdperr_centryd, durat_centryd
	real*8 time_centryd
	common/c_centryd/orid_centryd, jdate_centryd, time_centr
     +yd,
     *    lat_centryd, lon_centryd, depth_centryd, coterr_centr
     +yd, claerr_centryd, 
     *    cloerr_centryd, cdperr_centryd, durat_centryd, nslpb_
     +centryd, nrlpb_centryd,
     *    tmnlpb_centryd, nsmw_centryd, nrmw_centryd, tmnmw_cen
     +tryd, commid_centryd, 
     *    dused_centryd, auth_centryd, lddate_centryd



c		event declarations (3.0)
	character*15 evname_event, auth_event
	character*17 lddate_event
	integer evid_event, prefor_event, commid_event
	common/c_event/evid_event, prefor_event, commid_event,
     *     auth_event, lddate_event, evname_event



c		filter declarations (3.0)
	parameter (mpz = 100, mfir = 500, mstages = 20)
	character*4 type_filter
	character*80 dfile_filter
	integer np_filter, nz_filter, nstages_filter
	real a0_filter, coefn_filter, coefd_filter, coefnerr_fil
     +ter, 
     *    coefderr_filter
	complex zero_filter, pole_filter, zererr_filter, polerr_
     +filter
	common/c_filter/a0_filter(mstages), nz_filter(mstages), 
     +np_filter(mstages), 
     *    zero_filter(mstages, mpz), zererr_filter(mstages, mpz
     +), 
     *    pole_filter(mstages, mpz), polerr_filter(mstages, mpz
     +), 
     *    nnum_filter(mstages), nden_filter(mstages), srate_fil
     +ter(mstages),
     *    coefn_filter(mstages, mfir), coefnerr_filter(mstages,
     + mfir), 
     *    coefd_filter(mstages, mfir), coefderr_filter(mstages,
     + mfir), 
     *    type_filter(mstages), nstages_filter, dfile_filter, i
     +resp_filter


c		geographical region (gregion) declarations (3.0)
	character*17 lddate_gregion
	character*40 grname_gregion
	integer grn_gregion
	common/c_gregion/grn_gregion, grname_gregion, lddate_gre
     +gion



c		instrument declarations (3.0)
	parameter (minstrument = 5500)
	character band_instrument, digital_instrument
	character*6 instype_instrument, rsptype_instrument
	character*17 lddate_instrument
	character*32 dfile_instrument
	character*50 insname_instrument
	character*64 dir_instrument
	integer inid_instrument
	real samprate_instrument, ncalib_instrument, ncalper_ins
     +trument
	common/c_instrument/inid_instrument(minstrument), 
     *     insname_instrument(minstrument), instype_instrument(
     +minstrument), 
     *     band_instrument(minstrument), digital_instrument(min
     +strument), 
     *     samprate_instrument(minstrument), ncalib_instrument(
     +minstrument), 
     *     ncalper_instrument(minstrument), dir_instrument(mins
     +trument), 
     *     dfile_instrument(minstrument), rsptype_instrument(mi
     +nstrument),
     *     lddate_instrument(minstrument), nrowinstrument





c		moment declarations (2.8 with modifications)
c			modifications are:
c			remark has been replaced with commid_moment
c			lddate_moment added at end
c			nslpb, nrlpb, tmnlpb, nsmw, nrmw, tmnmw have
c			   been left out since they're in centryd
c			slips have been replaced with rakes
	character*10 dused_moment
	character*15 auth_moment
	character*17 lddate_moment
	integer orid_moment, mexpon_moment, commid_moment
	real bestdc_moment, mrr_moment, mtt_moment, mff_moment, 
     +mrt_moment,
     *    mrf_moment, mtf_moment, mrrerr_moment, mtterr_moment,
     + mfferr_moment,
     *    mrterr_moment, mrferr_moment, mtferr_moment, paxval_m
     +oment, paxplg_moment, 
     *    paxazm_moment, naxval_moment, naxplg_moment, naxazm_m
     +oment, taxval_moment, 
     *    taxplg_moment, taxazm_moment, str1_moment, dip1_momen
     +t, rake1_moment, 
     *    str2_moment, dip2_moment, rake2_moment
	common/c_moment/orid_moment, mexpon_moment, bestdc_momen
     +t, 
     *    mrr_moment, mtt_moment, mff_moment, mrt_moment, mrf_m
     +oment, mtf_moment,
     *    mrrerr_moment, mtterr_moment, mfferr_moment, mrterr_m
     +oment, mrferr_moment,
     *    mtferr_moment, paxval_moment, paxplg_moment, paxazm_m
     +oment, naxval_moment, 
     *    naxplg_moment, naxazm_moment, taxval_moment, taxplg_m
     +oment, taxazm_moment, 
     *    str1_moment, dip1_moment, rake1_moment, str2_moment, 
     +dip2_moment, rake2_moment, 
     *    commid_moment, dused_moment, auth_moment, lddate_mome
     +nt


c		origin declarations (3.0)
	character dtype_origin
	character*7 etype_origin
	character*15 algorithm_origin, auth_origin 
	character*17 lddate_origin
	integer orid_origin, evid_origin, jdate_origin, nass_ori
     +gin,
     *    ndef_origin, ndp_origin, grn_origin, srn_origin, mbid
     +_origin, 
     *    msid_origin, mlid_origin, commid_origin
	real lat_origin, lon_origin, depth_origin, depdp_origin,
     + mb_origin,
     *    ms_origin, ml_origin
	real*8 time_origin
	common/c_origin/time_origin, lat_origin, lon_origin, dep
     +th_origin,
     *    orid_origin, evid_origin, jdate_origin, nass_origin, 
     +ndef_origin, 
     *    ndp_origin, grn_origin, srn_origin, depdp_origin, mb_
     +origin,
     *    mbid_origin, ms_origin, msid_origin, ml_origin, mlid_
     +origin, 
     *    commid_origin, algorithm_origin, auth_origin, lddate_
     +origin, 
     *    dtype_origin, etype_origin 



c		remark declarations (3.0)
	parameter (mremark = 10000)
	character*17 lddate_remark
	character*80 remark_remark
	integer commid_remark, lineno_remark
	common/c_remark/commid_remark(mremark), lineno_remark(mr
     +emark), 
     *      remark_remark(mremark), lddate_remark(mremark), nro
     +wremark

c		select declarations (mhr)
	parameter (mselect=5000)	
	integer selid_select, nmode_select, lmode_select, commid
     +_select
	character st_select
	character*6 sta_select
	character*8 chan_select
	character*15 author_select
	character*16 comment_select
	character*17 lddate_select
	character*32 dbwfdisc_select
	character*64 dir_select
	common/c_select/selid_select(mselect), sta_select(mselec
     +t), 
     *    chan_select(mselect), nmode_select(mselect), st_selec
     +t(mselect),
     *    lmode_select(mselect), comment_select(mselect), 
     *    dir_select(mselect), dbwfdisc_select(mselect), 
     *    author_select(mselect), commid_select(mselect), 
     *    lddate_select(mselect), nrowselect



c		sensor declarations (3.0)
	parameter(msensor=8000)
	character instant_sensor
	character*6 sta_sensor
	character*8 chan_sensor
	character*17 lddate_sensor
	integer inid_sensor, chanid_sensor, jdate_sensor
	real calratio_sensor, calper_sensor, tshift_sensor
	real*8 time_sensor, endtime_sensor
	common/c_sensor/sta_sensor(msensor), chan_sensor(msensor
     +),
     *      time_sensor(msensor), endtime_sensor(msensor),
     *      inid_sensor(msensor), chanid_sensor(msensor), jdate
     +_sensor(msensor),
     *      calratio_sensor(msensor), calper_sensor(msensor), t
     +shift_sensor(msensor),
     *      instant_sensor(msensor), lddate_sensor(msensor), nr
     +owsensor



c		site declarations (3.0)
	parameter (msite = 500)
	character*4 statype_site 
	character*6 sta_site, refsta_site
	character*17 lddate_site 
	character*50 staname_site
	integer ondate_site, offdate_site	
	real lat_site, lon_site, elev_site, deast_site, dnorth_s
     +ite
	common/csite/sta_site(msite), ondate_site(msite), offdat
     +e_site(msite),
     *     lat_site(msite), lon_site(msite), elev_site(msite), 
     +staname_site(msite), 
     *     statype_site(msite), refsta_site(msite), dnorth_site
     +(msite), 
     *     deast_site(msite), lddate_site(msite), nrowsite



c		sitechan declarations (3.0)
	parameter(msitechan=6500)
	character*4 ctype_sitechan
	character*6 sta_sitechan
	character*8 chan_sitechan
	character*17 lddate_sitechan
	character*50 descrip_sitechan
	integer ondate_sitechan, offdate_sitechan, chanid_sitech
     +an
	real edepth_sitechan, hang_sitechan, vang_sitechan
	common/csitechan/sta_sitechan(msitechan), chan_sitechan(
     +msitechan),
     *     ondate_sitechan(msitechan), chanid_sitechan(msitecha
     +n), 
     *     offdate_sitechan(msitechan), ctype_sitechan(msitecha
     +n), 
     *     edepth_sitechan(msitechan), hang_sitechan(msitechan)
     +, 
     *     vang_sitechan(msitechan), descrip_sitechan(msitechan
     +),
     *     lddate_sitechan(msitechan), nrowsitechan


c		seismic region (sregion) declarations (3.0)
	character*17 lddate_sregion
	character*40 srname_sregion
	integer srn_sregion
	common/c_sregion/srn_sregion, srname_sregion, lddate_sre
     +gion


c		wfdisc declarations (3.0)
	parameter(mwfdisc = 10000)
	character segtype_wfdisc, clip_wfdisc
	character*2 datatype_wfdisc
	character*6 sta_wfdisc, instype_wfdisc
	character*8 chan_wfdisc
	character*17 lddate_wfdisc
	character*32 dfile_wfdisc
	character*64 dir_wfdisc
	integer wfid_wfdisc, chanid_wfdisc, jdate_wfdisc, nsamp_
     +wfdisc, 
     *     foff_wfdisc, commid_wfdisc
	real samprate_wfdisc, calib_wfdisc, calper_wfdisc
	real*8 time_wfdisc, endtime_wfdisc
	common/c_wfdisc/sta_wfdisc(mwfdisc), chan_wfdisc(mwfdisc
     +), time_wfdisc(mwfdisc), 
     *     wfid_wfdisc(mwfdisc), chanid_wfdisc(mwfdisc), jdate_
     +wfdisc(mwfdisc),
     *     endtime_wfdisc(mwfdisc), nsamp_wfdisc(mwfdisc), samp
     +rate_wfdisc(mwfdisc),
     *     calib_wfdisc(mwfdisc), calper_wfdisc(mwfdisc), insty
     +pe_wfdisc(mwfdisc), 
     *     segtype_wfdisc(mwfdisc), datatype_wfdisc(mwfdisc), c
     +lip_wfdisc(mwfdisc), 
     *     dir_wfdisc(mwfdisc), dfile_wfdisc(mwfdisc), foff_wfd
     +isc(mwfdisc), 
     *     commid_wfdisc(mwfdisc), lddate_wfdisc(mwfdisc), nrow
     +wfdisc

c		wfedit declarations (mhr)
	parameter (mwfedit = 10000)
	character*6 sta_wfedit
	character*8 chan_wfedit,probtype_wfedit,edtype_wfedit
	character*15 auth_wfedit
	character*17 lddate_wfedit
	integer edid_wfedit, commid_wfedit
	real*8 time_wfedit, endtime_wfedit
	common/c_wfedit/sta_wfedit(mwfedit), chan_wfedit(mwfedit
     +),
     *     edid_wfedit(mwfedit), time_wfedit(mwfedit), endtime_
     +wfedit(mwfedit),  
     *     probtype_wfedit(mwfedit), edtype_wfedit(mwfedit), co
     +mmid_wfedit(mwfedit),
     *     auth_wfedit(mwfedit), lddate_wfedit(mwfedit), nrowwf
     +edit


c		disp, dispdata and disperr declarations (mhr)
c			disp
	parameter (mdisp = 500, mdispdata = 100)
	character*2 stage_disp
	character*6 sta_disp
	character*8 chan_disp, wavetype_disp
	character*16 model_disp
	character*17 lddate_disp
	character*32 dfile_disp, dfileerr_disp
	character*64 dir_disp
	integer dispid_disp, jdate_disp, orid_disp, nfreq_disp,
     *     commid_disp
	real range_disp, backaz_disp, az_disp, t01_disp, tc1_dis
     +p, 
     *     tc2_disp, t02_disp
	real*8 time_disp
	common/c_disp/sta_disp(mdisp), chan_disp(mdisp), 
     *     dispid_disp(mdisp), wavetype_disp(mdisp), jdate_disp
     +(mdisp),
     *     orid_disp(mdisp), time_disp(mdisp), range_disp(mdisp
     +),
     *     backaz_disp(mdisp), az_disp(mdisp), nfreq_disp(mdisp
     +),
     *     stage_disp(mdisp), t01_disp(mdisp), tc1_disp(mdisp),
     +
     *     tc2_disp(mdisp), t02_disp(mdisp), model_disp(mdisp),
     + 
     *	   dir_disp(mdisp), dfile_disp(mdisp), dfileerr_di
     +sp(mdisp), 
     *     commid_disp(mdisp), lddate_disp(mdisp), nrowdisp

c			dispdata
	integer nfreq_dispdata
	real f_dispdata, t_dispdata, groupvel_dispdata, 
     *     dgroupvel_dispdata, phasevel_dispdata, dphasevel_dis
     +pdata,
     *     amp_dispdata, damp_dispdata, pol_dispdata, dpol_disp
     +data,
     *     filt1_dispdata, filt2_dispdata
	common/c_dispdata/nfreq_dispdata, f_dispdata(mdispdata),
     + 
     *     filt1_dispdata(mdispdata), filt2_dispdata(mdispdata)
     +,
     *     t_dispdata(mdispdata), groupvel_dispdata(mdispdata),
     + 
     *     dgroupvel_dispdata(mdispdata),
     *     phasevel_dispdata(mdispdata), dphasevel_dispdata(mdi
     +spdata),
     *     amp_dispdata(mdispdata), damp_dispdata(mdispdata),
     *     pol_dispdata(mdispdata), dpol_dispdata(mdispdata)
c			disperr
	integer nfreq_disperr
	real f_disperr, t_disperr, groupvel_disperr, 
     *     dgroupvel_disperr, phasevel_disperr, dphasevel_dispe
     +rr,
     *     amp_disperr, damp_disperr, pol_disperr, dpol_disperr
     +
	common/c_disperr/nfreq_disperr, f_disperr(mdispdata), 
     *     t_disperr(mdispdata), groupvel_disperr(mdispdata), 
     *     dgroupvel_disperr(mdispdata),
     *     phasevel_disperr(mdispdata), dphasevel_disperr(mdisp
     +data),
     *     amp_disperr(mdispdata), damp_disperr(mdispdata),
     *     pol_disperr(mdispdata), dpol_disperr(mdispdata)

c			ftdisc and ftimag
	parameter (mftdisc = 500, mftimag = 250)
	character*2 datatype_ftdisc, stage_ftdisc
	character*6 sta_ftdisc
	character*8 chan_ftdisc, wavetype_ftdisc, imagefield_ftd
     +isc
	character*16 imagetype_ftdisc, xaxistype_ftdisc, yaxisty
     +pe_ftdisc
	character*17 lddate_ftdisc
	character*32 dfile_ftdisc
	character*64 dir_ftdisc
	integer ftid_ftdisc, jdate_ftdisc, orid_ftdisc, commid_f
     +tdisc,
     *     numtot_ftdisc, numimage_ftdisc, ny_ftdisc, nx_ftdisc
     +
	real range_ftdisc
	real*8 time_ftdisc
	common/c_ftdisc/sta_ftdisc(mftdisc), chan_ftdisc(mftdisc
     +), 
     *     ftid_ftdisc(mftdisc), wavetype_ftdisc(mftdisc), jdat
     +e_ftdisc(mftdisc), 
     *     orid_ftdisc(mftdisc), time_ftdisc(mftdisc), range_ft
     +disc(mftdisc), stage_ftdisc(mftdisc), 
     *     imagetype_ftdisc(mftdisc), imagefield_ftdisc(mftdisc
     +), xaxistype_ftdisc(mftdisc), 
     *     yaxistype_ftdisc(mftdisc), numtot_ftdisc(mftdisc), n
     +umimage_ftdisc(mftdisc),
     *     ny_ftdisc(mftdisc), nx_ftdisc(mftdisc), datatype_ftd
     +isc(mftdisc), 
     *     dir_ftdisc(mftdisc), dfile_ftdisc(mftdisc),  
     *	   commid_ftdisc(mftdisc), lddate_ftdisc(mftdisc),
     + nrowftdisc
	real imag_ftimag_re, imag_ftimag_im, xaxis_ftimag, yaxis
     +_ftimag
	common/c_ftimag/imag_ftimag_re(mftimag,mftimag), imag_ft
     +imag_im(mftimag,mftimag), 
     *     xaxis_ftimag(mftimag), yaxis_ftimag(mftimag)

c		declarations specific to this routine
	character*264 dir
	call create_dbin
	call read_site
	call read_sitechan
	call read_sensor
	call read_instrument
c			change directory name in instrument common block to complete path name
	do i=lnblnk(dbin),1,-1
	  if(dbin(i:i).eq.'/') then
	   ndbin=i-1
	   goto 102
	  endif
	enddo
 102	continue
	do ituple=1,nrowinstrument
	  dir=dir_instrument(ituple)
	dir_instrument(ituple)=dbin(1:ndbin)//'/'//dir(1:lnblnk(dir))
cccc	dir_instrument(ituple)=dir(1:lnblnk(dir))
C-------Anatoli: correction for local database name----------------------
	if(ndbin.eq.0)dir_instrument(ituple)=dir(1:lnblnk(dir))
C------------------------------------------------------------------------
	enddo
	return
	end



