
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>
#include "db.h"
int N_Records;
struct PDE {
	int year;
	int month;
	int day;
	int hour;
	int minute;
	double second;
	double latitude;
	double longitude;
	int depth;
	double mb;
	char flags_isoseismal[4];
	char flags_max_intensity[4];
	char flags_diastrophic[4];
	char flags_tsunami[4];
	char flags_seiche[4];
	char flags_volcanism[4];
	char flags_source[4];
	char flags_waves[4];
	int fe_region;
	double ms;
	char flags_cultural[4];
	double contrib_mag;
	char contrib_auth[4];
	char flags_ide[4];
	char flags_depth_qc[4];
	int hypo_np;
	char hypo_qc[4];
	double local_mag;
	char local_type[4];
	char local_auth[4];
	char hypo_contrib[8];
};

/*
 *  General purpose routines to add a null at the end of a string.
 */

#ifndef TRIM
#define TRIM(cptr,len)	{ register char *ptr, *end;\
end = cptr; ptr = end + len - 2;\
while(*ptr == ' ' && ptr >= end) ptr--;\
*(++ptr) = '\0'; }
#endif

#ifndef FPAD
#define FPAD(s,l) {int i;for(i=strlen(s);i<l;s[i++]=' ');}
#endif

#ifndef BFIL
#define BFIL(s,l) {int i;for(i=0;i<l;s[i++]=' ');}
#endif

int
read_pde_line ();
int
grnumber();
int
grname();

int main (argc, argv)

int argc;
char **argv;

{
	char *cat_file, *dbname;
	FILE *pdefile;
	static char line[512];
	struct PDE pde;
	Dbptr db;
	Dbvalue value;
	int doy, last_doy, orid;
	char algorithm[32];
	char etype[32];
	char dtype[32];
	char author[64];
        int mday2doy();
	double h2e();

/*
 *	Get command args.
 */

	if (argc < 3) {
		fprintf (stderr, "usage: Fmtcat2origin cat_file dbRootname [-auth author]\n");
		exit (1);
	}
	cat_file = argv[1];
	dbname = argv[2];
	strcpy (author, "Fmt");
	if (argc > 3) {
		if (strcmp(argv[3], "-auth")) {
			fprintf (stderr, "Fmtcat2origin: Unrecognized argument '%s'.\n", argv[3]);
			fprintf (stderr, "usage: Fmtcat2origin cat_file dbRootname [-auth author]\n");
			exit (1);
		}

		if (argc < 4) {
			fprintf (stderr, "Fmtcat2origin: Need argument for '-auth'.\n");
			fprintf (stderr, "usage: Fmtcat2origin catalog_file dbRootname [-auth author]\n");
			exit (1);
		}
		strcpy (author, argv[4]);
	}



/*
 *	Open pde file.
 */
	pdefile = fopen (cat_file, "r");
	if (pdefile == NULL) {
		fprintf (stderr, "Fmtcat2origin: Unable to open %s file.\n",cat_file);
		exit (1);
	}

/*
 *	Open database.
 */
	if (dbopen (dbname, "r+", &db) == dbINVALID) {
		fprintf (stderr, "Fmtcat2origin: Unable to open database.\n");
		exit (1);
	}
/*
 *	Set db pointer to origin table.
 */
	db = dblookup (db, 0, "origin", 0, 0);
/*
 *	See if origin already exists.
 */
	dbquery (db, dbRECORD_COUNT, &value);
	if (value.i > 0) {
		fprintf (stderr, "Fmtcat2origin: origin table already exists.\n");
		exit (1);
	}
	orid = -1;
	last_doy = -1;
/*
 *	Loop on lines from cat file.
 */
N_Records = 0;
	while (fgets (line, 512, pdefile)) {
/*
 *		Read pde line and fill in pde structure.
 */
		read_pde_line (line, &pde);
/*
 *		Initial scratch record with NULLs.
 */
		db.record = dbNULL;
		db.field = dbALL;
		dbget(db, 0);
		db.record = dbSCRATCH;
/*
 *		Get the day-of-year and set the orid for this record.
 */
		doy = mday2doy (pde.year, pde.month, pde.day);
		if (last_doy != doy) {
			orid = (pde.year-1900)*1000000+doy*1000+1;
		} else orid++;
		last_doy = doy;
/*
 *		Set the "algorithm", "dtype" and "etype" fields.
 */
		switch (pde.hypo_qc[0]) {
		case '&':	
			strcpy (algorithm, "furnished");
			break;
		case '%':	
			strcpy (algorithm, "single_network");
			break;
		case '*':	
			strcpy (algorithm, "less_reliable");
			break;
		case '?':	
			strcpy (algorithm, "poor_solution");
			break;
		default:
			strcpy (algorithm, "-");
			break;
		}
		switch (pde.flags_source[0]) {
		case 'E':
			strcpy (etype, "ex");
			break;
		default:
			strcpy (etype, "-");
			break;
		}
		switch (pde.flags_depth_qc[0]) {
		case 'N':
			strcpy (dtype, "r");
			break;
		case 'D':
			strcpy (dtype, "d");
			break;
		case 'G':
			strcpy (dtype, "g");
			break;
		case '*':
			strcpy (dtype, "F");
			break;
		case '?':
			strcpy (dtype, "P");
			break;
		default:
			strcpy (dtype, "f");
			break;
		}
/*
 *		Set magnitude NULL values.
 */
		if (pde.mb == 0.0) dbgetv (db, 0, "mb", &pde.mb, 0);
		if (pde.ms == 0.0) dbgetv (db, 0, "ms", &pde.ms, 0);
		if (pde.local_mag == 0.0) dbgetv (db, 0, "ml", &pde.local_mag, 0);
/*
 *		Fill in the origin scratch record.
 */
		dbputv (db, 0, 	"lat", pde.latitude,
				"lon", pde.longitude,
				"depth", (double) pde.depth,
				"time", h2e(pde.year, doy, pde.hour, pde.minute,
								pde.second),
				"orid", orid,
/*				"evid", evid,*/
				"jdate", pde.year*1000+doy,
/*				"nass", 0,*/
				"ndef", pde.hypo_np,
/*				"ndp", */
				"grn", pde.fe_region,
/*				"srn", */
				"etype", etype,
/*				"depdp", */
				"dtype", dtype,
				"mb", pde.mb,
/*				"mbid", */
				"ms", pde.ms,
/*				"msid", */
				"ml", pde.local_mag,
/*				"mlid", */
				"algorithm", algorithm,
				"auth", author,
				"commid", -1,
				"lddate", "-",
				0);
/*
 *		Add the scratch record to the database.
 */
		dbadd (db, 0);
	} 
return 0;
}

int
read_pde_line (line, pde)

char *line;
struct PDE *pde;

{
	static char string[512];
	char dummy[24];
			struct tm timet;
			struct tm *ttm;
                	long itime;
	int             grn;
	char            gname[128];


strcpy(string,line);
sscanf(string,"%d%s%d%s%d%d%s%d%s%le%le%le%d%le%le",
&pde->year,dummy,
&pde->month,dummy,
&pde->day,
&pde->hour,dummy,
&pde->minute,dummy,
&pde->second,
&pde->latitude,
&pde->longitude,
&pde->depth,
&pde->mb,
&pde->ms
);

pde->local_mag = 0.0;
pde->year += 1900;

		itime = time(NULL);
		ttm = &timet;
		ttm = localtime(&itime);


				grn = grnumber(pde->latitude, pde->longitude);
				grname(grn, gname);
				pde->fe_region = grn;


	
				
				
				
N_Records++;

fprintf(stderr,"%3d:> %2d/%2d/%4d  %2d:%2d:% 6.3f % 7.3f % 8.3f % 5.0f % 5.2f % 5.2f\n",
N_Records,
pde->month,
pde->day,
pde->year,
pde->hour,
pde->minute,
(float)pde->second,
(float)pde->latitude,
(float)pde->longitude,
(float)pde->depth,
(float)pde->mb,
(float)pde->ms);


return 0;
}

int
myatoi (string)

char *string;

{
	int i, l;

	l = strlen(string);
	for (i=0; i<l; i++) if (string[i] == ' ') string[i] = '0';
	return atoi(string);
}

