#include <QtGui>
#include "helpwindow.h"
#include "default.h"
HelpWindow::~HelpWindow()
{
searchList.clear();
}
HelpWindow::HelpWindow( const QString& home_,QWidget* parent)
    : QMainWindow( parent ),
      pathCombo( 0 )
{
    readBookmarks();
    browser = new QTextBrowser( this );
    searchList.append(searchHelpPath());
    browser->setSearchPaths(searchList );
    browser->setFrameStyle( QFrame::Panel | QFrame::Sunken );
    browser->setAcceptRichText(true);
    browser->setBackgroundRole(QPalette::Window);
   // browser->setAutoFormatting(QTextEdit::AutoAll);
	browser->setOpenExternalLinks ( true);
    connect( browser, SIGNAL( sourceChanged(const QUrl & ) ),
	     this, SLOT( sourceChanged( const QUrl &) ) );

    setCentralWidget( browser );

    if ( !home_.isEmpty() )
	browser->setSource( home_ );
    connect( browser, SIGNAL( highlighted( const QString&) ),
	     statusBar(), SLOT( message( const QString&)) );

    QMenu *file;
    file = menuBar()->addMenu(tr("& View"));

    QAction* newAct = new QAction(QIcon(":/images/new.png"), tr("&New File"),this);
    newAct->setShortcut(tr("Ctrl+N"));
    newAct->setStatusTip(tr("New file"));
    connect(newAct, SIGNAL(triggered()), this, SLOT(newWindow()));
   // file->addAction(newAct);

    QAction*     openAct = new QAction(QIcon(":/images/open.png"), tr("&Open File"),this);
    openAct->setShortcut(tr("Ctrl+O"));
    openAct->setStatusTip(tr("Open an existing file"));
    connect(openAct, SIGNAL(triggered()), this, SLOT(openFile()));
   // file->addAction(openAct);
//=============================================================================
    zoominAct = new QAction(QIcon(":/images/zoomin.png"), tr("Zoom &In"),this);
    zoominAct->setShortcut(tr("Ctrl++"));
    zoominAct->setStatusTip(tr("Zoom in"));
    connect(zoominAct, SIGNAL(triggered()),this, SLOT(zoomin()));



    zoomoutAct = new QAction(QIcon(":/images/zoomout.png"), tr("Zoom &Out"),this);
    zoomoutAct->setShortcut(tr("Ctrl+-"));
    zoomoutAct->setStatusTip(tr("Zoom out"));
    connect(zoomoutAct, SIGNAL(triggered()),this, SLOT(zoomout()));	
//=============================================================================
    QAction*     printAct = new QAction(QIcon(":/images/print.png"), tr("&Print"),this);
    printAct->setShortcut(tr("Ctrl+P"));
    printAct->setStatusTip(tr("Print file"));
    connect(printAct, SIGNAL(triggered()), this, SLOT(print()));
    file->addAction(printAct);
    file->addAction(zoominAct);
    file->addAction(zoomoutAct);

    file->addSeparator();

    QAction*     exitAct = new QAction(QIcon(":/images/exit.png"), tr("E&xit"),this);
    exitAct->setShortcut(tr("Ctrl+X"));
    exitAct->setStatusTip(tr("Print file"));
    connect(exitAct, SIGNAL(triggered()), this, SLOT(exit()));
    file->addAction(exitAct);


    QMenu *go;
    go = menuBar()->addMenu(tr("&Go"));

    backwardId = new QAction(QIcon(":/images/back.png"), tr("&Backward"),this);
    backwardId->setShortcut(tr("Alt+Left"));
    backwardId->setStatusTip(tr("Backward"));
    connect(backwardId, SIGNAL(triggered()), browser, SLOT(backward()));
    go->addAction(backwardId);

    forwardId = new QAction(QIcon(":/images/forward.png"), tr("&Forward"),this);
    forwardId->setShortcut(tr("Alt+Right"));
    forwardId->setStatusTip(tr("Forward"));
    connect(forwardId, SIGNAL(triggered()), browser, SLOT(forward()));
    go->addAction(forwardId);

    QAction*     homeAct = new QAction(QIcon(":/images/home.png"), tr("&Home"),this);
	homeAct->setShortcut(tr("Alt+Home"));
    homeAct->setStatusTip(tr("Home"));
    connect(homeAct, SIGNAL(triggered()), browser, SLOT(home()));
    go->addAction(homeAct);


    bookm = menuBar()->addMenu(tr("Bookmarks"));

    QAction*     addbookmAct = new QAction(tr("Add Bookmark"),this);
    addbookmAct->setShortcut(tr("Ctrl+A"));
    addbookmAct->setStatusTip(tr("Add bookmark"));
    connect(addbookmAct, SIGNAL(triggered()), this, SLOT(addBookmark()));
    bookm->addAction(addbookmAct);

    QAction*     manbookmAct = new QAction(tr("&Manage Bookmark..."),this);
    manbookmAct->setShortcut(tr("Ctrl+M"));
    manbookmAct->setStatusTip(tr("Manage Bookmarks..."));
    connect(manbookmAct, SIGNAL(triggered()), this, SLOT(manBookmark()));
    bookm->addAction(manbookmAct);

    bookm->addSeparator();

    bookmActs = new QActionGroup(this);

    CreateBookMarksMenu();

    menuBar()->addSeparator();

    QMenu *help;
    help = menuBar()->addMenu(tr("&Help"));

    QAction*     aboutAct = new QAction( tr("&About"),this);
    aboutAct->setStatusTip(tr("About"));
    connect(aboutAct, SIGNAL(triggered()), this, SLOT(about()));
    help->addAction(aboutAct);
 
    QAction*     aboutQtAct = new QAction( tr("&About Qt"),this);
    aboutQtAct->setStatusTip(tr("About Qt"));
    connect(aboutQtAct, SIGNAL(triggered()), this, SLOT(aboutQt()));
    help->addAction(aboutQtAct);


    forwardId->setEnabled(FALSE);
    backwardId->setEnabled( FALSE);
    connect( browser, SIGNAL( backwardAvailable( bool ) ),
	     this, SLOT( setBackwardAvailable( bool ) ) );
    connect( browser, SIGNAL( forwardAvailable( bool ) ),
	     this, SLOT( setForwardAvailable( bool ) ) );


   // QToolBar* toolbar = new QToolBar( this );
   // addToolBar( toolbar, "Toolbar");
    QToolBar *toolbar = addToolBar(tr("Toolbar"));

    connect( browser, SIGNAL( backwardAvailable(bool) ), backwardId, SLOT( setEnabled(bool) ) );
    toolbar->addAction(backwardId);

    connect( browser, SIGNAL( forwardAvailable(bool) ), forwardId, SLOT( setEnabled(bool) ) );
    toolbar->addAction(forwardId);
    toolbar->addAction(homeAct);

    toolbar->addSeparator();
    toolbar->addAction(zoominAct);
    toolbar->addAction(zoomoutAct);
    toolbar->addSeparator();

    pathCombo = new QComboBox(toolbar);
    pathCombo->setEditable(false);
    pathCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);
    connect( pathCombo, SIGNAL( activated( const QString & ) ),
	     this, SLOT( pathSelected( const QString & ) ) );
    pathCombo->addItem( home_ );
    toolbar->addWidget(pathCombo);
    toolbar->setAllowedAreas(Qt::TopToolBarArea);
    toolbar->setIconSize(QSize(22,22));
    browser->setFocus();

    toolbar->addSeparator();
    toolbar->addAction(printAct);
    toolbar->addAction(exitAct);

}
void HelpWindow::zoomin(){
   QFont f( font() );
    f.setPointSize( f.pointSize() + 1 );  
    setFont( f );
}
void HelpWindow::zoomout(){
    QFont f(font() );
    f.setPointSize( f.pointSize() - 1 );  
    setFont( f );
}

void HelpWindow::CreateBookMarksMenu() {
    QStringList::Iterator it2 = bookmarks.begin();
    for ( ; it2 != bookmarks.end(); ++it2 ) {
        QTextBrowser brows;
        brows.setSource(*it2);
        QString tmp = "";
    if ( brows.documentTitle().isNull() )
	tmp = *it2;
    else
	tmp = brows.documentTitle();
        QAction*    bookmAct = new QAction(tmp,this);
        bookmAct->setVisible(true);
        connect( bookmAct, SIGNAL( triggered() ),this, SLOT( bookmChosen() ) );
        bookmActs->addAction(bookmAct);
    }

    bookm->addActions(bookmActs->actions ());
}

void HelpWindow::setBackwardAvailable( bool b)
{
    backwardId->setEnabled( b);
}

void HelpWindow::setForwardAvailable( bool b)
{
    forwardId->setEnabled(b);
}

void HelpWindow::sourceChanged( const QUrl & url)
{

    if ( browser->documentTitle().isNull() ) 
	setWindowTitle( "Program edcat - Helpviewer - " + url.toString(QUrl::None) );
    else 
	setWindowTitle( "Program edcat - Helpviewer - " + browser->documentTitle() ) ;

    if ( !url.isEmpty() && pathCombo != 0 ) {
	bool exists = FALSE;
	int i;
	for ( i = 0; i < pathCombo->count(); ++i ) {
	    if ( pathCombo->itemText( i ) == url.toString(QUrl::None) ) {
		exists = TRUE;
		break;
	    }
	}
	if ( !exists ) {
            QStringList items; items.append(url.toString(QUrl::None));
            int maxSize = 0; if (pathCombo->count() > 9) maxSize = 9; else  maxSize = pathCombo->count();
            for (int i = 0; i < maxSize; ++i ) items.append(pathCombo->itemText(i));
            pathCombo->clear();
	    pathCombo->addItems(items);
	    pathCombo->setCurrentIndex( 0 );
	} else 
	    pathCombo->setCurrentIndex( i );

    }

}





void HelpWindow::about()
{
    QMessageBox::about( this, "Help Browser",
			"<p>This Help Browser is HTML-based program manual  "
			"using Qt's rich text capabilities</p>"
			);
}


void HelpWindow::aboutQt()
{
    QMessageBox::aboutQt( this, "HelpViewer" );
}

void HelpWindow::openFile()
{

    QString fn = QFileDialog::getOpenFileName( this,QString::null, QString::null );
    if ( !fn.isEmpty() )
	browser->setSource( fn );

}

void HelpWindow::newWindow()
{
    ( new HelpWindow(browser->source().toString(QUrl::None), this) )->show();
}

void HelpWindow::print()
{

    QPrinter printer(QPrinter::HighResolution);
    printer.setFullPage(true);
    QPrintDialog *dlg = new QPrintDialog(&printer, this);
    if (dlg->exec() == QDialog::Accepted) {
        browser->document()->print(&printer);
    }
    delete dlg;


}

void HelpWindow::pathSelected( const QString &_path )
{
    browser->setSource( _path );
}

void HelpWindow::exit(){
    close();
}
void HelpWindow::closeEvent(QCloseEvent *event)
{
    QSettings settings("mitp.ru", "EditCatalogHelp");
    settings.beginGroup("/Geometry");
    settings.setValue("/geometry/pos", pos());
    settings.setValue("/geometry/size", size());

    settings.endGroup();
    settings.beginGroup("/Bookmarks");
    settings.setValue("/List of bookmarks", bookmarks);
    settings.endGroup();
/*
    QFile f2( QDir::currentPath() + "/.bookmarks" );
    f2.open( QIODevice::WriteOnly );
    QDataStream s2( &f2 );
    s2 << bookmarks;
    f2.close();

*/ 

    event->accept();
}
void HelpWindow::readBookmarks()
{
    QSettings settings("mitp.ru", "EditCatalogHelp");
    settings.beginGroup("/Geometry");
    QPoint pos = settings.value("/geometry/pos", QPoint(200, 200)).toPoint();
    QSize size = settings.value("/geometry/size", QSize(640, 700)).toSize();
    resize(size);
    move(pos);
    settings.endGroup();
    settings.beginGroup("/Bookmarks");

    bookmarks = settings.value("/List of bookmarks",QVariant (QStringList())).toStringList ();
    settings.endGroup();
/*
 propPos = settings.value("/geometry/pos",QPoint(100, 100)).toPoint();
    if ( QFile::exists( QDir::currentPath() + "/.bookmarks" ) ) {
	QFile f( QDir::currentPath() + "/.bookmarks" );
	f.open( QIODevice::ReadOnly );
	QDataStream s( &f );
	s >> bookmarks;
	f.close();
    }
*/

}

void HelpWindow::bookmChosen( )
{
  QAction *action = qobject_cast<QAction *>(sender());
  if (!action) return;
  QString title = action->text();
  QString tmp = "";
  QStringList::Iterator it2 = bookmarks.begin();
  int i = 0; bool exists = FALSE;
  for ( ; it2 != bookmarks.end(); ++it2 ) {
       QTextBrowser brows;
       brows.setSource(*it2);

       if ( brows.documentTitle().isNull() )
	 tmp = *it2;
       else
	tmp = brows.documentTitle();
       if (tmp == title) {exists = TRUE;break;}
       i++;
  }
  if (exists) browser->setSource(*it2);

}

void HelpWindow::addBookmark()
{
   QString tmp = browser->source().toString(QUrl::None);
   for ( QStringList::Iterator it2 = bookmarks.begin(); it2 != bookmarks.end(); ++it2 )
       if (*it2 == tmp) return;
   bookmarks.append(tmp);
        if ( !browser->documentTitle().isNull() )
        tmp = browser->documentTitle();
        QAction*    bookmAct = new QAction(tmp,this);
        bookmAct->setVisible(true);
        bookm->addAction(bookmAct);
        bookmActs->addAction(bookmAct);
        connect( bookmAct, SIGNAL( triggered() ),
        this, SLOT( bookmChosen() ) );

}

void HelpWindow::manBookmark(){
  ManageBookmarkImpl *dlg = new ManageBookmarkImpl(this,bookmarks);
  if(  dlg->exec() == QDialog::Accepted) {
       if (dlg->title.empty()) SetEmptyBookMarks();
       else SetModifiedBookMarks(dlg->title,dlg->bookmarks);
    }
   delete dlg;

 } 
void HelpWindow::SetEmptyBookMarks(){
  QList<QAction *> listActions = bookmActs->actions();
  for (int i = 0; i < listActions.size(); ++i) {
    bookmActs-> removeAction(listActions.at(i));
    bookm->removeAction(listActions.at(i));
  }
    bookmarks.clear();
}
void HelpWindow::SetModifiedBookMarks(QStringList &,QStringList &bookmlist){
SetEmptyBookMarks();
for (int i = 0; i < bookmlist.size(); ++i) bookmarks.append(bookmlist.at(i));
delete bookmActs;
bookmActs = new QActionGroup(this);
CreateBookMarksMenu();
}
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------

ManageBookmarkImpl::ManageBookmarkImpl(QWidget *parent,QStringList &bookmlist)
    : QDialog(parent),bookmarks(bookmlist)
{

    setupUi(this);
    listWidget->clear();
    setWindowTitle("Manage Bookmarks");
    QStringList::Iterator it2 = bookmarks.begin();

    for ( ; it2 != bookmarks.end(); ++it2 ) {
        QTextBrowser brows;
        brows.setSource(*it2);
        QString tmp = "";
    if ( brows.documentTitle().isNull() )
	tmp = *it2;
    else
	tmp += brows.documentTitle();
        title.append(tmp);
    }

    listWidget->addItems (title);
    connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
    connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
    connect(buttonUp, SIGNAL(clicked()), this, SLOT(up()));
    connect(buttonDown, SIGNAL(clicked()), this, SLOT(down()));
    connect(buttonDel, SIGNAL(clicked()), this, SLOT(del()));
    connect(buttonDelAll, SIGNAL(clicked()), this, SLOT(delAll()));

}
void ManageBookmarkImpl::accept(){
title.clear();
QStringList tmpBookmarks(bookmarks);
bookmarks.clear();
if(listWidget->count() > 0){
    for (int i = 0; i < listWidget->count(); ++i){
    QString tmp = listWidget->item(i)->text();
    title.append(tmp);
    }

    QStringList::Iterator it1 = title.begin();
    for ( ; it1 != title.end(); ++it1 ) {
        QStringList::Iterator it2 = tmpBookmarks.begin();
        for ( ; it2 != tmpBookmarks.end(); ++it2 ) {
            QTextBrowser brows;
            brows.setSource(*it2);
            QString tmp = "";
        if ( brows.documentTitle().isNull() ) tmp = *it2;
        else tmp = brows.documentTitle();
        if(tmp == *it1) { bookmarks.append(*it2); break; }
       }
   }
}
done( Accepted );
}
void ManageBookmarkImpl::reject(){

done( Rejected );
}
void ManageBookmarkImpl::up(){
if (listWidget->currentRow() == 0 ) return;
int row = listWidget->currentRow() ;
QListWidgetItem * item = listWidget->currentItem ();

listWidget->takeItem ( row );
listWidget->insertItem(row-1,item);
listWidget->setCurrentRow(row-1);

}
void ManageBookmarkImpl::down(){
if (listWidget->currentRow() == listWidget->count () - 1 ) return;
int row = listWidget->currentRow() ;
QListWidgetItem * item = listWidget->currentItem ();
listWidget->takeItem ( row );
listWidget->insertItem(row+1,item);
listWidget->setCurrentRow(row+1);
}
void ManageBookmarkImpl::del(){
listWidget->takeItem ( listWidget->currentRow() );
}
void ManageBookmarkImpl::delAll(){
listWidget->clear();
}
