//
// C++ Implementation: projectwizard
//
// Description:
//
//
// Author: fmt <fmt@localhost.localdomain>, (C) 2008
//
// Copyright: See COPYING file that comes with this distribution
//
//

#include <QtGui>
#include <QMessageBox>
#include <QProcess>
#include "default.h"
#include "document.h"
#include "mainwindow.h"
#include "projectwizard.h"
#include "editline.h"

static bool firstWizardVisit  = true;
ProWizard *ProWizard::wizardSelf = 0;

ProWizard::~ProWizard() {

}
ProWizard::ProWizard(QWidget *parent,FDocument* doc,DocumentUsing documentUsing)
        : QWizard(parent),doc(doc),documentUsing(documentUsing) {
    setFont( parent->font() );
    wizardSelf = this;
    firstWizardVisit  = true;
    datPage  = new DataPage(this,doc,documentUsing);
    dirPage  = new DirectoriesPage(this,doc,documentUsing);
    oriPage  = new OriginPage(this,doc,documentUsing);
    hypoPage = new HypoPage(this,doc,documentUsing);

    addPage(datPage);
    addPage(dirPage);
    addPage(oriPage);
    addPage(hypoPage);

    if (doc->GetInputDataType()->GetValue() == "0")
        ProWizard::wizardSelf->oriPage->originPage->GetSpinBoxDuration()->setDisabled ( false ) ;
    else
        ProWizard::wizardSelf->oriPage->originPage->GetSpinBoxDuration()->setDisabled ( true ) ;

    if (documentUsing == ProWizard::ProjectNew)
        setWindowTitle(tr("Project Wizard - New Project"));
    if (documentUsing == ProWizard::ProjectEdit)
        setWindowTitle(QString("Project Wizard - Edit Project: %1").
                       arg(MainWindow::self->strippedName(MainWindow::self->GetCurFile())));


    if (documentUsing == ProWizard::ProjectRepair)
        setWindowTitle(QString("Project Wizard - Repair Project"));

    connect( button ( QWizard::FinishButton ), SIGNAL( clicked() ), this, SLOT(finishButton()));


}

void ProWizard::finishButton() {
//QMessageBox::critical(0,"","ProWizard::finishButton()");
    QList<int> listPages = visitedPages ();
    for (int i = 0; i < listPages.size(); ++i) {
        QWizardPage * pg  = page(listPages.at(i));
        if (WizardPage* wd = qobject_cast<WizardPage *>(pg)) wd->FinishWizard();
    }


    MainWindow::self->infoAct->setFont(font());
    MainWindow::self->infoAct->setText (doc->infoProgect());

}
///====================================================================================
DataPage::DataPage(QWidget *parent,FDocument* doc,ProWizard::DocumentUsing documentUsing)
        : WizardPage(parent) {
    setTitle(tr("DataPage Info"));
    setSubTitle(tr("Define an input type of data, browse data directory. Define output records will be decimated or will be leaved the original delta time."));

    if (documentUsing == ProWizard::ProjectNew)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardnew.png"));
    if (documentUsing == ProWizard::ProjectEdit)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardedit.png"));
    if (documentUsing == ProWizard::ProjectRepair)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardrepair.png"));

    dataPage = new DataPageImpl(this,doc);

    dataPage->setWindowFlags(Qt::SubWindow);
    dataPage->setSizeGripEnabled ( FALSE );
    dataPage->setModal (false);

    QGridLayout *layout = new QGridLayout;
    layout->addWidget(dataPage);
    setLayout(layout);
    if (documentUsing == ProWizard::ProjectNew)
        registerField("directory.DataName*", dataPage->GetLineEditSeedAhDirectory());
}

bool DataPage::validatePage() {
    return hasInputFiles(dataPage->inputDataDirectoryName,
                         dataPage->GetSeedRadioButton()->isChecked());
}
void DataPage::FinishWizard() {
    dataPage->FinishWizard();
}
DataPageImpl::DataPageImpl(QWidget *parent,FDocument* doc)
        : QDialog(parent),doc(doc) {
    setFont( parent->font() );
    setWindowIcon(QIcon(":/images/icon.png"));
    setupUi(this);
    connect( pushButtonSeedAhBrowse, SIGNAL( clicked() ), this, SLOT( browse() ) );

    connect( radioButtonDecim, SIGNAL( clicked(bool) ), this, SLOT( rdButtonDecim(bool) ) );

    connect( radioButtonOrigin, SIGNAL( clicked(bool) ), this, SLOT( rdButtonOrigin(bool) ) );
    InitDialog();
    SetDocumentToDialog();

}

void DataPageImpl::rdButtonDecim(bool checked) {
    if (checked) ProWizard::wizardSelf->oriPage->originPage->GetSpinBoxDuration()->setDisabled ( false ) ;
}
void DataPageImpl::rdButtonOrigin(bool checked) {
    if (checked) ProWizard::wizardSelf->oriPage->originPage->GetSpinBoxDuration()->setDisabled ( true ) ;
}
void DataPageImpl::browse() {
    QString dir = QFileDialog::getExistingDirectory(this, tr("Open Input Data Directory"),
                  MainWindow::self->openDataDirectory,
                  // QFileDialog::ShowDirsOnly |
                  QFileDialog::DontResolveSymlinks);
    if (!dir.isEmpty()) {
        if (!hasInputFiles(dir,radioButtonSeed->isChecked())) {
            lineEditSeedAhDirectory->setText(QString());
            return;
        }
        lineEditSeedAhDirectory->setText(QDir(dir).dirName ());
        MainWindow::self->openDataDirectory = dir;
        inputDataDirectoryName = dir;
    }


}
bool hasInputFiles(QString directory,bool isSeedFiles) {
    QDir dir(directory);
    if ( !dir.exists () ) {
        QMessageBox::warning ( 0, QString ( "SeedToDb Check Directory" ),
                               QString ( "Directory <%1> does not exist." )
                               .arg (directory));
        return false;
    }
    QStringList filters;
    QString tmp = "";
    if (isSeedFiles) {
        tmp = "\"seed volume\" files";
        filters << "*" + seedFilterLocator();
    } else {
        tmp = "\"ah binaries\" files";
        filters << "*" + ahFilterLocator();
    }
    dir.setNameFilters(filters);
    QStringList list = dir.entryList(filters,QDir::Files);
    if (list.isEmpty ()) {

        QMessageBox::warning ( 0, QString ( "SeedToDb Check Directory" ),
                               QString ( "Directory <%1> does not contain %2." )
                               .arg ( dir.dirName () )
                               .arg ( tmp ) );
        return false;
    } else return true;

}
void DataPageImpl::FinishWizard() {
    GetDocumentFromDialog();
    foreach (PropertyValue* val, values) val->SetValueToResetvalue();
}
void DataPageImpl::InitDialog() {
    values.append(doc->GetInputDataType ());
    values.append(doc->GetOutputDeltaTime ());
    values.append(doc->GetDataDirectoryName ());
    inputDataDirectoryName = QString();
    lineEditSeedAhDirectory->setReadOnly ( true );

}
void DataPageImpl::SetDocumentToDialog() {

    if (doc->GetInputDataType()->GetValue() == "0") {
        radioButtonSeed->setChecked (TRUE);
        radioButtonAh->setChecked (FALSE);

    }  else {
        radioButtonSeed->setChecked (FALSE);
        radioButtonAh->setChecked (TRUE);

    }

    if (doc->GetOutputDeltaTime()->GetValue() == "0") {
        radioButtonDecim->setChecked (TRUE);
        radioButtonOrigin->setChecked (FALSE);
    }  else {
        radioButtonDecim->setChecked (FALSE);
        radioButtonOrigin->setChecked (TRUE);
    }

    QString tmp = doc->GetDataDirectoryName()->GetValue();
    if (tmp != doc->GetDataDirectoryName()->GetDefaultvalue()) {
        lineEditSeedAhDirectory->setText(QDir(tmp).dirName ());
        inputDataDirectoryName = tmp;
    }

}
void DataPageImpl::GetDocumentFromDialog() {

    if (radioButtonSeed->isChecked()) doc->GetInputDataType()->SetValue("0");
    else doc->GetInputDataType()->SetValue("1");

    if (radioButtonDecim->isChecked()) doc->GetOutputDeltaTime()->SetValue("0");
    else doc->GetOutputDeltaTime()->SetValue("1");

    doc->GetDataDirectoryName()->SetValue(inputDataDirectoryName);

}
///====================================================================================
DirectoriesPage::DirectoriesPage(QWidget *parent,FDocument* doc,ProWizard::DocumentUsing documentUsing)
        : WizardPage(parent) {
    setTitle(tr("DirectoriesPage Info"));
    setSubTitle(tr("Type the data base name\nBrowse output data base directory."));

    if (documentUsing == ProWizard::ProjectNew)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardnew.png"));
    if (documentUsing == ProWizard::ProjectEdit)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardedit.png"));
    if (documentUsing == ProWizard::ProjectRepair)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardrepair.png"));

    directoriesPage = new DirectoriesImpl(this,doc);

    directoriesPage->setWindowFlags(Qt::SubWindow);
    directoriesPage->setSizeGripEnabled ( FALSE );
    directoriesPage->setModal (false);

    QGridLayout *layout = new QGridLayout;
    layout->addWidget(directoriesPage);
    setLayout(layout);

    if (documentUsing == ProWizard::ProjectNew) {
        registerField("directory.DbaseName*", directoriesPage->GetLineEditDbaseName());
        registerField("directory.DbaseDirectory*", directoriesPage->GetLineEditDbaseDirectory());
    }


}
void DirectoriesPage::cleanupPage () {
//QMessageBox::critical(0,"", QString("DirectoriesPage::cleanupPage"));
}

int isOutputDbaseDirectoryEmpty(QString dirName) {
    QDir dir(dirName);
    if ( !dir.exists () ) {
        QMessageBox::warning ( 0, QString( "Check Dbase directory" ),
                               QString ( "Directory <%1> does not exist." )
                               .arg (dirName));
        return 1; /// Directory does not exist
    }
    QStringList list = dir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot);

    if (list.isEmpty ()) return 0;
    int ret = QMessageBox::warning(0, "Check Dbase directory",
                                   QString("Output dbase directory  %1 does not empty.\n Do you want to remove all entries?")
                                   .arg(dirName),
                                   QMessageBox::Yes | QMessageBox::Default,
                                   QMessageBox::No | QMessageBox::Escape);
    if (ret == QMessageBox::No) return 2; ///  won't remove dir's entries

    if (!QDir::setCurrent(dirName)) {
        QMessageBox::warning ( 0, "Check Dbase directory" ,
                               QString("Can't change current working directory to path:\n   %1").arg(dirName));

        return 3; /// can't change directory
    }
    char sysStr[4096];
    strcpy(sysStr,"rm -f -r *");
    system(sysStr);

    return 0; /// directory is OK
}
bool DirectoriesPage::validatePage() {
    int ret =   isOutputDbaseDirectoryEmpty(directoriesPage->DbaseDirectoryName);
    if (ret == 0) return true;
    return false;
}
void DirectoriesPage::FinishWizard() {
    directoriesPage->FinishWizard();
}
DirectoriesImpl::DirectoriesImpl(QWidget *parent,FDocument* doc)
        : QDialog(parent),doc(doc) {
    setFont( parent->font() );
    setWindowIcon(QIcon(":/images/icon.png"));
    setupUi(this);
    pushButtonName->setVisible (false);
    connect( pushButtonDbaseBrowse, SIGNAL( clicked() ), this, SLOT( browse() ) );
    InitDialog();
    SetDocumentToDialog();

}
void DirectoriesImpl::browse() {
    QString dir = QFileDialog::getExistingDirectory(this, tr("Open Dbase Directory"),
                  MainWindow::self->openDbaseDirectory,
                  // QFileDialog::ShowDirsOnly |
                  QFileDialog::DontResolveSymlinks);
    if (!dir.isEmpty()) {
        lineEditDbaseDirectory->setText(QDir(dir).dirName ());
        MainWindow::self->openDbaseDirectory = dir;
        DbaseDirectoryName = dir;
    }


}
void DirectoriesImpl::FinishWizard() {
    GetDocumentFromDialog();
    foreach (PropertyValue* val, values) val->SetValueToResetvalue();
}
void DirectoriesImpl::InitDialog() {
    values.append(doc->GetDbaseName ());
    values.append(doc->GetDbaseDirectoryName ());
    DbaseDirectoryName = QString();
    lineEditDbaseDirectory->setReadOnly ( true );

}
void DirectoriesImpl::SetDocumentToDialog() {
    lineEditDbaseName->setText(doc->GetDbaseName()->GetValue());

    QString tmp = doc->GetDbaseDirectoryName()->GetValue();
    if (tmp != doc->GetDbaseDirectoryName()->GetDefaultvalue()) {
        lineEditDbaseDirectory->setText(QDir(tmp).dirName ());
        DbaseDirectoryName = tmp;
    }

}
void DirectoriesImpl::GetDocumentFromDialog() {
    doc->GetDbaseDirectoryName()->SetValue(DbaseDirectoryName);
    doc->GetDbaseName()->SetValue(lineEditDbaseName->text());
}
///====================================================================================
OriginPage::OriginPage(QWidget *parent,FDocument* doc,ProWizard::DocumentUsing documentUsing)
        : WizardPage(parent) {
    setTitle(tr("OriginPage Info"));
    setSubTitle(tr("Define the date and the time of the event and\nthe time duration of output records."));

    if (documentUsing == ProWizard::ProjectNew)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardnew.png"));
    if (documentUsing == ProWizard::ProjectEdit)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardedit.png"));
    if (documentUsing == ProWizard::ProjectRepair)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardrepair.png"));

    originPage = new OriginPageImpl(this,doc);

    originPage->setWindowFlags(Qt::SubWindow);
    originPage->setSizeGripEnabled ( FALSE );
    originPage->setModal (false);

    QGridLayout *layout = new QGridLayout;
    layout->addWidget(originPage);
    setLayout(layout);
}
void OriginPage::FinishWizard() {
    originPage->FinishWizard();
}

OriginPageImpl::OriginPageImpl(QWidget *parent,FDocument* doc)
        : QDialog(parent),doc(doc) {
    setFont( parent->font() );
    setWindowIcon(QIcon(":/images/icon.png"));
    setupUi(this);
    InitDialog();
    SetDocumentToDialog();
}
void OriginPageImpl::FinishWizard() {
    GetDocumentFromDialog();
    foreach (PropertyValue* val, values) val->SetValueToResetvalue();
}

void OriginPageImpl::InitDialog() {
    values.append(doc->GetOriginYear());
    values.append(doc->GetOriginMonth());
    values.append(doc->GetOriginDay());
    values.append(doc->GetOriginHour());
    values.append(doc->GetOriginMinute());
    values.append(doc->GetOriginSecond());
    values.append(doc->GetRecordDuration());
    propDocLine.append(new LineDocProperty(spinBoxYear,     doc->GetOriginYear()));
    propDocLine.append(new LineDocProperty(spinBoxMonth,    doc->GetOriginMonth()));
    propDocLine.append(new LineDocProperty(spinBoxDay,      doc->GetOriginDay()));
    propDocLine.append(new LineDocProperty(spinBoxHour,     doc->GetOriginHour()));
    propDocLine.append(new LineDocProperty(spinBoxMin,      doc->GetOriginMinute()));
    propDocLine.append(new LineDocProperty(lineEditSecond,  doc->GetOriginSecond()));
    propDocLine.append(new LineDocProperty(spinBoxDuration, doc->GetRecordDuration()));


}
void OriginPageImpl::SetDocumentToDialog() {
    foreach (LineDocProperty *docprop, propDocLine) docprop->SetValueFromDoc();
}
void OriginPageImpl::GetDocumentFromDialog() {
    doc->GetOriginYear()->SetValue(spinBoxYear->text());
    doc->GetOriginMonth()->SetValue(spinBoxMonth->text());
    doc->GetOriginDay()->SetValue(spinBoxDay->text());
    doc->GetOriginHour()->SetValue(spinBoxHour->text());
    doc->GetOriginMinute()->SetValue(spinBoxMin->text());
    doc->GetOriginSecond()->SetValue(lineEditSecond->text());
    doc->GetRecordDuration()->SetValue(spinBoxDuration->text());

}
///====================================================================================
HypoPage::HypoPage(QWidget *parent,FDocument* doc,ProWizard::DocumentUsing documentUsing)
        : WizardPage(parent) {
    setTitle(tr("HypoPage Info"));
    setSubTitle(tr("Define the hypocenter of the events and magnitudes."));

    if (documentUsing == ProWizard::ProjectNew)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardnew.png"));
    if (documentUsing == ProWizard::ProjectEdit)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardedit.png"));
    if (documentUsing == ProWizard::ProjectRepair)
        setPixmap(QWizard::LogoPixmap, QPixmap(":/images/wizardrepair.png"));

    hypoPage = new HypoPageImpl(this,doc);

    hypoPage->setWindowFlags(Qt::SubWindow);
    hypoPage->setSizeGripEnabled ( FALSE );
    hypoPage->setModal (false);

    QGridLayout *layout = new QGridLayout;
    layout->addWidget(hypoPage);
    setLayout(layout);

}

void HypoPage::FinishWizard() {
    hypoPage->FinishWizard();
}
HypoPageImpl::HypoPageImpl(QWidget *parent,FDocument* doc)
        : QDialog(parent),doc(doc) {
    setFont( parent->font() );
    setWindowIcon(QIcon(":/images/icon.png"));
    setupUi(this);
    InitDialog();
    SetDocumentToDialog();

}
void HypoPageImpl::FinishWizard() {
    GetDocumentFromDialog();
    foreach (PropertyValue* val, values) val->SetValueToResetvalue();
}
void HypoPageImpl::InitDialog() {
    values.append(doc->GetOriginLatitude());
    values.append(doc->GetOriginLongitude());
    values.append(doc->GetOriginDepth());
    values.append(doc->GetOriginMb());
    values.append(doc->GetOriginMs());
    values.append(doc->GetOriginMl());
    propDocLine.append(new LineDocProperty(lineEditLatitude,  doc->GetOriginLatitude()));
    propDocLine.append(new LineDocProperty(lineEditLongitude, doc->GetOriginLongitude()));
    propDocLine.append(new LineDocProperty(lineEditDepth,     doc->GetOriginDepth()));
    propDocLine.append(new LineDocProperty(lineEditMb,        doc->GetOriginMb()));
    propDocLine.append(new LineDocProperty(lineEditMs,        doc->GetOriginMs()));
    propDocLine.append(new LineDocProperty(lineEditMl,        doc->GetOriginMl()));
}
void HypoPageImpl::SetDocumentToDialog() {
    foreach (LineDocProperty *docprop, propDocLine) docprop->SetValueFromDoc();
}
void HypoPageImpl::GetDocumentFromDialog() {
    doc->GetOriginLatitude()->SetValue(lineEditLatitude->text());
    doc->GetOriginLongitude()->SetValue(lineEditLongitude->text());
    doc->GetOriginDepth()->SetValue(lineEditDepth->text());
    doc->GetOriginMb()->SetValue(lineEditMb->text());
    doc->GetOriginMs()->SetValue(lineEditMs->text());
    doc->GetOriginMl()->SetValue(lineEditMl->text());
}

