//
// C++ Implementation: stationlist
//
// Description:
//
//
// Author: fmt <fmt@localhost.localdomain>, (C) 2008
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include <QtGui>
#include "mainwindow.h"
#include "stationlist.h"
#include "fmt4cmdw.h"
#include "document.h"
#include "default.h"

ProfileTreeView::~ProfileTreeView() {
}
ProfileTreeView::ProfileTreeView(int numCol,QWidget* parent)
        : QTreeView(parent) {

    QFont f = parent->font();
    setFont( f );
    setAlternatingRowColors (TRUE);
    model = new TreePropertyModel(numCol,this);
    setModel(model);
    delegate = new TreeProfileDelegate;
    setItemDelegate(delegate);

    setSelectionMode (QAbstractItemView::NoSelection);
    connect(this,SIGNAL(clicked ( const QModelIndex & )),this, SLOT(clicked(const QModelIndex & )));


}
 
void ProfileTreeView::clicked(const QModelIndex & index) {
    model->clicked(index);
}
void ProfileTreeView::MarkDoubleStationName() {


    iconDouble = QIcon(":/images/double.png");
    QSize size (16,16) ;
    iconDouble.actualSize (size);

    int rows = model->rowCount(QModelIndex());
    for (int i = 1; i < rows; ++i) {
        QModelIndex staIndex = model->index(i, 0, QModelIndex());

        if (model->itemFromIndex(staIndex)->checkState () == Qt::Unchecked) continue;
        QString name = staIndex.data().toString();

        int indBeg = name.indexOf(':') + 1;
        int indFin = name.indexOf(':',indBeg);
        name = name.mid(indBeg+1, indFin - indBeg-1);

        for (int j = i+1; j < rows; ++j) {

            QModelIndex staIndexCur = model->index(j, 0, QModelIndex());
            if (model->itemFromIndex(staIndexCur)->checkState () == Qt::Unchecked) continue;
            QString nameCur = staIndexCur.data().toString();
            int jindBeg = nameCur.indexOf(':') + 1;
            int jindFin = nameCur.indexOf(':',jindBeg);
            nameCur = nameCur.mid(jindBeg+1, jindFin - jindBeg-1);
            if (name.contains(nameCur,Qt::CaseInsensitive)) {
                model->setData (staIndex, QVariant(iconDouble),Qt::DecorationRole);
                model->setData (staIndexCur, QVariant(iconDouble),Qt::DecorationRole);

            }
        }


    }



}
bool ProfileTreeView::CheckStationTree() {
    int rows = model->rowCount(QModelIndex());
    QString firstSta;
    QString findSta;
    bool find = false;
    QModelIndex findIndex;
    for (int i = 1; i < rows; ++i) {
        QModelIndex staIndex = model->index(i, 0, QModelIndex());

        if (model->itemFromIndex(staIndex)->checkState () == Qt::Unchecked) continue;
        QString name = staIndex.data().toString();

        int indBeg = name.indexOf(':') + 1;
        int indFin = name.indexOf(':',indBeg);
        name = name.mid(indBeg+1, indFin - indBeg-1);

        for (int j = i+1; j < rows; ++j) {

            QModelIndex staIndexCur = model->index(j, 0, QModelIndex());
            if (model->itemFromIndex(staIndexCur)->checkState () == Qt::Unchecked) continue;
            QString nameCur = staIndexCur.data().toString();

            int jindBeg = nameCur.indexOf(':') + 1;
            int jindFin = nameCur.indexOf(':',jindBeg);
            nameCur = nameCur.mid(jindBeg+1, jindFin - jindBeg-1);
            if (name.contains(nameCur,Qt::CaseInsensitive)) {
                find = true;
                findSta  = staIndexCur.data().toString();
                firstSta = staIndex.data().toString();
                findIndex = staIndexCur;
                break;
            }
        }

        if (find) break;

    }
    if (!find)    return true;

    QMessageBox::warning ( 0, "Set tree of stations" ,
                           tr("Data contains pair(s) of identical station names:\none of it is ( <%1> , <%2> )\nUncheck one station row of all pairs marked by 'blue circle'").
                           arg(firstSta).arg(findSta));
    setCurrentIndex(findIndex);


    return false;
}

void ProfileTreeView::SetStationTree(Ah4DbCmdWindow* ahStations,const QString &tempCurFileName) {
    ahsta = ahStations;
    itsStationList = ahsta->GetStaList();
    origin = &(ahsta->origin);
    InitTreeView(tempCurFileName);
}
void ProfileTreeView::SetMarkStationForDbase(FDocument* doc,QStringList &fmt2dbScriptlist) {

    QString ahDirectory = MainWindow::self->tempDirectoryPath + "/wfAh";
    if (doc->GetInputDataType()->GetValue() == "1")
        ahDirectory = doc->GetDataDirectoryName()->GetValue();
    QString dbaseDirectory = MainWindow::self->tempDirectoryPath;
    if (doc->GetOutputDeltaTime()->GetValue() == "1")
        dbaseDirectory = doc->GetDbaseDirectoryName()->GetValue();
    QString  dbaseName = doc->GetDbaseName()->GetValue();

    itrStation=itsStationList->begin();
    int rows = model->rowCount(QModelIndex());
    for (int i = 1; i < rows; ++i) {
        QModelIndex indexStation = model->index(i, 0, QModelIndex());
        QStandardItem* itemStation = model->itemFromIndex(indexStation);
        if (!itemStation->isCheckable ()) {itrStation++; continue;}
        if (itemStation->checkState () == Qt::Unchecked) {itrStation++; continue;}
//QMessageBox::warning ( 0, "" ,QString("SetMarkStationForDbase  1 %1").arg((*itrStation)->GetNameStation()));

        int rowsLoc = itemStation->rowCount ();
        list<Location *> pListLocation = (*itrStation)->GetLocationList();
        itrLocation=pListLocation.begin();

        for (int  i = 0; i < rowsLoc; ++i) {
            QStandardItem * itloc = itemStation->child ( i);
            int rowsChan = itloc->rowCount();
            if (!itloc->isCheckable ()) {itrLocation++; continue; }
            if (itloc->checkState () == Qt::Unchecked) {itrLocation++; continue;}

            list<Channel *> pListChannel = (*itrLocation)->GetChannelList();
            itrChannel=pListChannel.begin();
            for (int j = 0; j < rowsChan; ++j) {
                QStandardItem * itChan = itloc->child (j);
                int rowsComp = itChan->rowCount();
              if (!itChan->isCheckable ()) { itrChannel++; continue;}
                if (itChan->checkState () == Qt::Unchecked)  {itrChannel++; continue;}

                list<Comp *> pListComp = (*itrChannel)->GetCompList();
                itrComp=pListComp.begin();
                for (int k = 0; k < rowsComp; ++k) {
                    QStandardItem * itComp = itChan->child (k);
                    int rowsRec = itComp->rowCount();
                    if (!itComp->isCheckable ()) { itrComp++; continue; }
                    if (itComp->checkState () == Qt::Unchecked) { itrComp++; continue; }
                    list<Record *> pListRecord = (*itrComp)->GetRecordList();
                    itrRecord=pListRecord.begin();
                    for (int m = 0; m < rowsRec; ++m) {

//-----------------------------------------------------------------------------
                        QString sysString = QString("%1 %2/%3 %4 %5%6 %7 %8").
                                            arg(dbaseName).
                                            arg(ahDirectory).
                                            arg((*itrRecord)->GetNameFile()).
                                            //arg(dbaseDirectory).
                                            arg((*itrRecord)->GetNameOut()).
                                            arg((*itrChannel)->GetNameChannel()).
                                            arg((*itrComp)->GetNameComp()).
                                            arg((*itrComp)->GetHang()).
                                            arg((*itrComp)->GetVang());
                        fmt2dbScriptlist << sysString;

//-------------------------------------------------------------------------------
                        itrRecord++;
                    }

                    itrComp++;
                }
                itrChannel++;
            }
            itrLocation++;
        }
        itrStation++;
    }

}
void ProfileTreeView::InitTreeView(const QString &tempCurFileName) {
//QMessageBox::critical(0,"", QString("setTree %1").arg(tmp));
    model->removeRows( 0,model->rowCount());
    if (!itsStationList->empty() )  {
        iconAccept = QIcon(":/images/accept.png");
        QSize size (16,16) ;
        iconAccept.actualSize (size);
        iconReject = QIcon(":/images/reject.png");
        iconReject.actualSize (size);

        iconLocation = QIcon(":/images/location.png");
        iconLocation.actualSize (size);
        int i = 1;
        model->SetItem(0,"Project",tempCurFileName);
        for (itrStation=itsStationList->begin();
                itrStation!=itsStationList->end();
                itrStation++)  {

            int numberCheckableLocation = 0;
            list<Location *> pListLocation = (*itrStation)->GetLocationList();
///  setTree Station
            int isize = pListLocation.size();
            QString tmp;
            if ( (i) < 10) tmp  += QString("  %1:").arg(i);
            else tmp +=  QString("%1:").arg(i);

            tmp +=  QString(" %1:").
                    arg((*itrStation)->GetNameStation());
            QString col2 = QString("Loc: %1, Net: %2").
                           arg(isize).arg((*itrStation)->GetNameNet() );
            QModelIndex ind = model->SetItem(i,tmp,col2);


            if (i == 1) setExpanded(ind,true);
            int j = 0;
            model->SetColumns(i);
            if (!pListLocation.empty() )
                for (itrLocation=pListLocation.begin();
                        itrLocation!=pListLocation.end();
                        itrLocation++) {
                    list<Channel *> pListChannel = (*itrLocation)->GetChannelList();
                    int isize = pListChannel.size();

///  setTree Location
                    tmp =  QString("%1").
                           arg((*itrLocation)->GetNameLocation());
                    col2 = QString("Chan: %2").arg(isize);
                    QModelIndex ind = model->SetItem(i,j,tmp,col2);
                    if ((*itrLocation)->GetRemDefault() == 0) {
                        model->setData (ind, QVariant(iconAccept),Qt::DecorationRole);
                        model->itemFromIndex(ind)->setCheckable (true );
                        numberCheckableLocation++;
                        model->itemFromIndex(ind)->setEditable (false );
                        if (j == 0) model->itemFromIndex(ind)->setCheckState(Qt::Checked);
                    } else {
                        model->setData (ind, QVariant(iconReject),Qt::DecorationRole);
                        model->itemFromIndex(ind)->setCheckable (false );
                        model->itemFromIndex(ind)->setEditable (false );
                    }
                    if (i == 1 && j == 0) setExpanded(ind,true);
                    model->SetColumns(i,j);
                    int k = 0;

                    if (!pListChannel.empty() )
                        for (itrChannel=pListChannel.begin();
                                itrChannel!=pListChannel.end();
                                itrChannel++) {
                            list<Comp *> pListComp = (*itrChannel)->GetCompList();
                            int isize = pListComp.size();
///  setTree Channel
                            col2 = QString("Comp: %1  %2").arg(isize).
                                   arg((*itrChannel)->GetErrComent());
                            tmp =  QString("%1").
                                   arg((*itrChannel)->GetNameChannel());
                            QModelIndex ind = model->SetItem(i,j,k,tmp,col2);

                            if ((*itrChannel)->GetRemDefault() == 0) {
                                model->setData (ind, QVariant(iconAccept),Qt::DecorationRole);
                                model->itemFromIndex(ind)->setCheckable (true );
                                model->itemFromIndex(ind)->setEditable (false );
                                if (j == 0) model->itemFromIndex(ind)->setCheckState(Qt::Checked);
                            } else {
                                model->setData (ind, QVariant(iconReject),Qt::DecorationRole);
                                model->itemFromIndex(ind)->setCheckable (false );
                                model->itemFromIndex(ind)->setEditable (false );
                            }
                            if (i == 1 && j == 0 && k == 0) setExpanded(ind,true);

                            model->SetColumns(i,j,k);
                            int m = 0;

                            if (!pListComp.empty() )
                                for (itrComp=pListComp.begin();
                                        itrComp!=pListComp.end();
                                        itrComp++) {
                                    list<Record *> pListRecord = (*itrComp)->GetRecordList();
                                    int isize = pListRecord.size();
///  setTree Comp
                                    QString errstr = QString("Rec: %1, Hang: %2, Vang: %3").arg(isize).
                                                     arg((*itrComp)->GetHang()).arg((*itrComp)->GetVang());
                                    tmp =  QString("%1").
                                           arg((*itrComp)->GetNameComp());

//QMessageBox::critical(0,"", QString("setTree %1 %2").arg( tmp).arg(errstr));
                                    QModelIndex ind = model->SetItem(i,j,k,m,tmp,errstr);


                                    if ((*itrComp)->GetRemDefault() == 0) {
                                        model->setData (ind, QVariant(iconAccept),Qt::DecorationRole);
                                        model->itemFromIndex(ind)->setCheckable (true );
                                        model->itemFromIndex(ind)->setEditable (false );
                                        if (j == 0 )
                                            model->itemFromIndex(ind)->setCheckState(Qt::Checked);
                                    } else {
                                        model->setData (ind, QVariant(iconReject),Qt::DecorationRole);
                                        model->itemFromIndex(ind)->setCheckable (false );
                                        model->itemFromIndex(ind)->setEditable (false );
                                    }
                                    if (i == 1 && j == 0 && k == 0 && m == 0) setExpanded(ind,true);

                                    model->SetColumns(i,j,k,m);
                                    int n = 0;
                                    if (!pListRecord.empty() )

                                        for (itrRecord=pListRecord.begin();
                                                itrRecord!=pListRecord.end();
                                                itrRecord++) {
///  setTree
                                            ahsta->GetRecList (itrRecord, errstr);
                                            tmp =  QString("Rec: %1").arg(n+1);

//QMessageBox::critical(0,"", QString("setTree %1 %2").arg( tmp).arg(errstr));
                                            QModelIndex ind = model->SetItem(i,j,k,m,n,tmp,errstr);
                                            n++;
                                        }
                                    m++;
                                }

//                            fprintf (out,"\n");

                            k++;
                        }
//                    fprintf (out,"\n");
                    j++;
                }


            if ((*itrStation)->GetRemDefault() == 0) {
                if (numberCheckableLocation > 1 )
                    model->setData (ind, QVariant(iconLocation),Qt::DecorationRole);
                else
                    model->setData (ind, QVariant(iconAccept),Qt::DecorationRole);


                //QStandardItem* item = model->itemFromIndex(ind);
                model->itemFromIndex(ind)->setCheckable (true );
                model->itemFromIndex(ind)->setEditable (false );
                model->itemFromIndex(ind)->setCheckState(Qt::Checked);
            } else {
                model->setData (ind, QVariant(iconReject),Qt::DecorationRole);
                model->itemFromIndex(ind)->setCheckable (false );
                model->itemFromIndex(ind)->setEditable (false );
            }
//            fprintf (out,"\n");
            i++;
        }

    }
/// mark doubles station name
    MarkDoubleStationName();
    resizeColumnToContents(0);
    resizeColumnToContents(1);
}
///==========================================================================
void ProfileTreeView::drawBranches(QPainter *painter, const QRect &rect, const QModelIndex &index) const {
    QStyleOptionViewItem opt = viewOptions();
    QStyleOptionViewItem option = opt;

    if (selectionModel()->isSelected(index))
        painter->fillRect(option.rect, option.palette.brush(QPalette::Highlight));

    if (model->hasChildren(index)) {
        static const int size = 9;
        opt.state |= QStyle::State_Children;
        opt.rect.setRect(rect.width() - (indentation() + size) / 2,
                         rect.y() + (rect.height() - size) / 2, size, size);
        if (isExpanded(index))
            opt.state |= QStyle::State_Open;
        painter->fillRect(opt.rect, Qt::white);
        style()->drawPrimitive(QStyle::PE_IndicatorBranch, &opt, painter, this);
    }
    painter->drawLine(rect.x(), rect.bottom(), rect.right(), rect.bottom());
}
///========================================================================================
TreePropertyModel::~TreePropertyModel() {
}
TreePropertyModel::TreePropertyModel(int columns, QWidget * parent )
        : QStandardItemModel(0, columns,parent) {

    NumRows = 0;
    NumCols = columns;
    parentWindow = (ProfileTreeView*) parent;
    SetHorizontalHeader();
}

///-----------------------------------------------------------------------
void TreePropertyModel::SetHorizontalHeader() {
    setHeaderData(0, Qt::Horizontal,"Value");
    setHeaderData(1, Qt::Horizontal,"Property");
}
///-----------------------------------------------------------------------
void TreePropertyModel::SetColumns(int rowFirst) {
    QModelIndex indexParent = index(rowFirst, 0, QModelIndex());
    insertColumns( 0,NumCols, indexParent);
}
///-----------------------------------------------------------------------
void TreePropertyModel::SetColumns(int rowFirst,int rowSecond) {
    QModelIndex ind = index(rowFirst, 0, QModelIndex());
    QModelIndex indexParent = index(rowSecond, 0, ind);
    insertColumns( 0,NumCols, indexParent);
}

///-----------------------------------------------------------------------
void TreePropertyModel::SetColumns(int rowFirst,int rowSecond,int rowThird) {
    QModelIndex ind = index(rowFirst, 0, QModelIndex());
    QModelIndex indexParent = index(rowSecond, 0, ind);
    QModelIndex indexGrandParent = index(rowThird, 0, indexParent);
    insertColumns( 0,NumCols, indexGrandParent);
}

///-----------------------------------------------------------------------
void TreePropertyModel::SetColumns(int rowFirst,int rowSecond,int rowThird,int rowForth) {

    QModelIndex ind = index(rowFirst, 0, QModelIndex());
    QModelIndex indexParent = index(rowSecond, 0, ind);
    QModelIndex indexGrandParent = index(rowThird, 0, indexParent);
    QModelIndex indexGrandGrandParent = index(rowForth, 0, indexGrandParent);
    insertColumns( 0,NumCols, indexGrandGrandParent);
}
///-----------------------------------------------------------------------
QModelIndex TreePropertyModel::SetItem(int rowFirst,const QString value,QString value2) {
    QModelIndex rowIndex = index(rowFirst, 0, QModelIndex());
    int rows = rowCount(rowIndex);
    insertRow ( rows);
    QModelIndex rowNewIndex = index(rowFirst, 0, QModelIndex());
    if ( rowFirst > 0 ) setData(rowNewIndex, QVariant(false),Qt::CheckStateRole );
    setData(rowNewIndex, value);
    if (value2 != QString()) {
        QModelIndex rowIndexCol1 = index(rowFirst,1, QModelIndex());
        setData( rowIndexCol1,value2);
    }
    return rowNewIndex;
}
///-----------------------------------------------------------------------
QModelIndex TreePropertyModel::SetItem(int rowFirst,int rowSecond,
                                       const QString value,QString value2) {
    QModelIndex indexParent = index(rowFirst, 0, QModelIndex());
    int rows = rowCount(indexParent);
    insertRows ( rows ,1,indexParent);
    QModelIndex rowIndexSecond = index(rowSecond, 0, indexParent);
    setData(rowIndexSecond, QVariant(false),Qt::CheckStateRole );
    setData(rowIndexSecond, value);
    if (value2 != QString()) {
        QModelIndex rowIndexSecondCol1 = index(rowSecond, 1, indexParent);
        setData( rowIndexSecondCol1,value2);
    }
    return rowIndexSecond;
}
///-----------------------------------------------------------------------
QModelIndex TreePropertyModel::SetItem(int rowFirst,int rowSecond,int rowThird,const QString value,QString value2) {
    QModelIndex ind = index(rowFirst, 0, QModelIndex());
    QModelIndex indexParent = index(rowSecond, 0, ind);
    int rows = rowCount(indexParent);
    insertRows ( rows ,1,indexParent);
    QModelIndex rowIndexThirdCol0 = index(rowThird, 0, indexParent);
    setData(rowIndexThirdCol0, QVariant(false),Qt::CheckStateRole );
    setData(rowIndexThirdCol0 , value);
    if (value2 != QString() && NumCols == 2) {
        QModelIndex rowIndexThirdCol1 = index(rowThird, 1, indexParent);
        setData( rowIndexThirdCol1,value2);
    }
    return rowIndexThirdCol0;
}

///-----------------------------------------------------------------------
QModelIndex TreePropertyModel::SetItem(int rowFirst,int rowSecond,int rowThird,int rowForth,const QString value,QString value2) {
    QModelIndex ind = index(rowFirst, 0, QModelIndex());
    QModelIndex indexParent = index(rowSecond, 0, ind);
    QModelIndex indexGrandParent = index(rowThird, 0, indexParent);
    int rows = rowCount(indexGrandParent);
    insertRows ( rows ,1,indexGrandParent);
    QModelIndex rowIndexForthCol0 = index(rowForth, 0, indexGrandParent);
    setData(rowIndexForthCol0, QVariant(false),Qt::CheckStateRole );
    setData(rowIndexForthCol0 , value);
    if (value2 != QString()) {
        QModelIndex rowIndexForthCol1 = index(rowForth, 1, indexGrandParent);
        setData( rowIndexForthCol1,value2);
    }
    return rowIndexForthCol0;
}

///-----------------------------------------------------------------------
QModelIndex TreePropertyModel::SetItem(int rowFirst,int rowSecond,int rowThird,int rowForth,int rowFiveth,const QString value,QString value2) {
    QModelIndex ind = index(rowFirst, 0, QModelIndex());
    QModelIndex indexParent = index(rowSecond, 0, ind);
    QModelIndex indexGrandParent = index(rowThird, 0, indexParent);
    QModelIndex indexGrandGrandParent = index(rowForth, 0, indexGrandParent);
    int rows = rowCount(indexGrandGrandParent);
    insertRows ( rows ,1,indexGrandGrandParent);
    QModelIndex rowIndexFivethCol0 = index(rowFiveth, 0, indexGrandGrandParent);
    setData(rowIndexFivethCol0 , value);
    if (value2 != QString()) {
        QModelIndex rowIndexFivethCol1 = index(rowFiveth, 1, indexGrandGrandParent);
        setData( rowIndexFivethCol1,value2);
    }
    return rowIndexFivethCol0;
}
///-----------------------------------------------------------------------
void TreePropertyModel::CheckedStation(const QModelIndex & indexStation) {
    QStandardItem* itemStation = itemFromIndex(indexStation);
    int rowsLoc = itemStation->rowCount ();
    QStandardItem * loc0 = itemStation->child (0);
    loc0->setCheckState(Qt::Checked);
    QModelIndex ind = loc0->index();
    for (int  i = 0; i < rowsLoc; ++i) {
        QStandardItem * itloc = itemStation->child ( i);
        int rowsChan = itloc->rowCount();
        for (int j = 0; j < rowsChan; ++j) {
            QStandardItem * itChan = itloc->child (j);
            if (!itChan->isCheckable ()) continue;
            if (itloc->index() == ind ) itChan->setCheckState(Qt::Checked);
            else itChan->setCheckState(Qt::Unchecked);
            int rowsComp = itChan->rowCount();
            for (int k = 0; k < rowsComp; ++k) {
                QStandardItem * itComp = itChan->child (k);
                if (!itComp->isCheckable ()) continue;
                if (itloc->index() == ind) itComp->setCheckState(Qt::Checked);
                else itComp->setCheckState(Qt::Unchecked);
            }
        }
    }
    QModelIndex findIndex;
    QModelIndex staIndex = indexStation; //itemStation->index();
    int n = 0;
    if ((findIndex = hasStationDouble(staIndex,n) ) == QModelIndex()) return;
    setData (indexStation, QVariant(parentWindow->iconDouble),Qt::DecorationRole);
    setData (findIndex, QVariant(parentWindow->iconDouble),Qt::DecorationRole);
}
QModelIndex TreePropertyModel::hasStationDouble(QModelIndex & indexstation,int & numDouble) {
    int rows = rowCount(QModelIndex());
    QModelIndex staIndex = indexstation;
    QString name = staIndex.data().toString();
    QModelIndex findDoubleIndex = QModelIndex();
    int indBeg = name.indexOf(':') + 1;
    int indFin = name.indexOf(':',indBeg);
    name = name.mid(indBeg+1, indFin - indBeg-1);
    numDouble = 0;
    for (int j = 1; j < rows; ++j) {

        QModelIndex staIndexCur = index(j, 0, QModelIndex());
        if (itemFromIndex(staIndexCur)->checkState () == Qt::Unchecked) continue;
        if (staIndex == staIndexCur) continue;
        QString nameCur = staIndexCur.data().toString();

        int jindBeg = nameCur.indexOf(':') + 1;
        int jindFin = nameCur.indexOf(':',jindBeg);
        nameCur = nameCur.mid(jindBeg+1, jindFin - jindBeg-1);
        if (name.contains(nameCur,Qt::CaseInsensitive)) {
            if (numDouble == 0) findDoubleIndex = staIndexCur;
            numDouble++;

        }
    }


    return findDoubleIndex;

}
///-----------------------------------------------------------------------
void TreePropertyModel::UnCheckedStation(const QModelIndex & indexStation) {
    QStandardItem* itemStation = itemFromIndex(indexStation);
    int rowsLoc = itemStation->rowCount ();
    for (int  i = 0; i < rowsLoc; ++i) {
        QStandardItem * itloc = itemStation->child ( i);
        itloc->setCheckState(Qt::Unchecked);
        int rowsChan = itloc->rowCount();
        for (int j = 0; j < rowsChan; ++j) {
            QStandardItem * itChan = itloc->child (j);
            itChan->setCheckState(Qt::Unchecked);
            int rowsComp = itChan->rowCount();
            for (int k = 0; k < rowsComp; ++k) {
                QStandardItem * itComp = itChan->child (k);
                itComp->setCheckState(Qt::Unchecked);
            }
        }
    }

    QModelIndex findIndex;
    QModelIndex staIndex = itemStation->index();
    int numDouble = 0;
    if ((findIndex = hasStationDouble(staIndex,numDouble) ) == QModelIndex()) return;
    int numberCheckableLocation = 0;
    for (int  i = 0; i < rowsLoc; ++i)
        if (itemStation->child (i)->isCheckable ()) numberCheckableLocation++;
    if (numberCheckableLocation > 1) setData (indexStation, QVariant(parentWindow->iconLocation),Qt::DecorationRole);
    else setData (indexStation, QVariant(parentWindow->iconAccept),Qt::DecorationRole);

    if (numDouble == 1) {
        numberCheckableLocation = 0;
        itemStation = itemFromIndex(findIndex);
        rowsLoc = itemStation->rowCount ();
        for (int  i = 0; i < rowsLoc; ++i)
            if (itemStation->child (i)->isCheckable ()) numberCheckableLocation++;
        if (numberCheckableLocation > 1 )
            setData (findIndex, QVariant(parentWindow->iconLocation),Qt::DecorationRole);
        else
            setData (findIndex, QVariant(parentWindow->iconAccept),Qt::DecorationRole);
    }
}
///-----------------------------------------------------------------------
void TreePropertyModel::UnCheckedLocation(const QModelIndex & ind) {
    QModelIndex indexStation =  ind.parent ();
    QStandardItem* itemStation = itemFromIndex(indexStation);
    int rowsLoc = itemStation->rowCount ();

    bool unchecked = true;
    for (int  i = 0; i < rowsLoc; ++i) {
        QStandardItem * itloc = itemStation->child ( i);
        if (itloc->checkState () == Qt::Checked) unchecked = false;
        int rowsChan = itloc->rowCount();
        for (int j = 0; j < rowsChan; ++j) {
            QStandardItem * itChan = itloc->child (j);
            if (itloc->index() == ind) itChan->setCheckState(Qt::Unchecked);

            int rowsComp = itChan->rowCount();
            for (int k = 0; k < rowsComp; ++k) {
                QStandardItem * itComp = itChan->child (k);
                if (itloc->index() == ind) itComp->setCheckState(Qt::Unchecked);
            }


        }
    }
    if (unchecked) itemStation->setCheckState(Qt::Unchecked);

}
///-----------------------------------------------------------------------
void TreePropertyModel::CheckedLocation(const QModelIndex & ind) {
    QModelIndex indexStation =  ind.parent ();
    QStandardItem* itemStation = itemFromIndex(indexStation);
    int rowsLoc = itemStation->rowCount ();
    for (int  i = 0; i < rowsLoc; ++i) {
        QStandardItem * itloc = itemStation->child ( i);
        int rowsChan = itloc->rowCount();
        for (int j = 0; j < rowsChan; ++j) {
            QStandardItem * itChan = itloc->child (j);
            if (!itChan->isCheckable ()) continue;
            if (itloc->index() == ind ) itChan->setCheckState(Qt::Checked);
            else itChan->setCheckState(Qt::Unchecked);
            int rowsComp = itChan->rowCount();
            for (int k = 0; k < rowsComp; ++k) {
                QStandardItem * itComp = itChan->child (k);
                if (!itComp->isCheckable ()) continue;
                if (itloc->index() == ind) itComp->setCheckState(Qt::Checked);
                else itComp->setCheckState(Qt::Unchecked);
            }
        }
        if (itloc->index() != ind && itloc->isCheckable ()) itloc->setCheckState(Qt::Unchecked);
    }
    if (itemStation->checkState () == Qt::Unchecked  && itemStation->isCheckable ())
        itemStation->setCheckState(Qt::Checked);
}
///-----------------------------------------------------------------------

void TreePropertyModel::CheckedChannel(const QModelIndex & ind) {
    QModelIndex indexLocation =  ind.parent ();
    QStandardItem* itloc = itemFromIndex(indexLocation);
    int rowsChan = itloc->rowCount ();
    for (int i = 0; i < rowsChan; ++i) {
        QStandardItem * itChan = itloc->child (i);
        int rowsComp = itChan->rowCount();
        for (int j = 0; j < rowsComp; ++j) {
            QStandardItem * itComp = itChan->child (j);
            if (!itComp->isCheckable ()) continue;
            if (itChan->index() == ind) itComp->setCheckState(Qt::Checked );
        }
    }
    itloc->setCheckState(Qt::Checked );
    QModelIndex indexStation =  indexLocation.parent ();
    QStandardItem* itemStation = itemFromIndex(indexStation);
    int rowsLoc = itemStation->rowCount ();
    for (int  i = 0; i < rowsLoc; ++i) {
        itloc = itemStation->child ( i);
        if (indexLocation == itloc->index()) continue;
        if (!itloc->isCheckable ()) continue;
        itloc->setCheckState(Qt::Unchecked );
        int rowsChan = itloc->rowCount ();
        for (int i = 0; i < rowsChan; ++i) {
            QStandardItem * itChan = itloc->child (i);
            if (!itChan->isCheckable ()) continue;
            itChan->setCheckState(Qt::Unchecked );
            int rowsComp = itChan->rowCount();
            for (int j = 0; j < rowsComp; ++j) {
                QStandardItem * itComp = itChan->child (j);
                if (!itComp->isCheckable ()) continue;
                itComp->setCheckState(Qt::Unchecked );
            }
        }

    }

    itemStation->setCheckState(Qt::Checked );

}
///-----------------------------------------------------------------------

void TreePropertyModel::UnCheckedChannel(const QModelIndex & ind) {
    QModelIndex indexLocation =  ind.parent ();
    QStandardItem* itloc = itemFromIndex(indexLocation);
    int rowsChan = itloc->rowCount ();
    for (int i = 0; i < rowsChan; ++i) {
        QStandardItem * itChan = itloc->child (i);
        if (itChan->index() != ind) continue;
        int rowsComp = itChan->rowCount();
        for (int j = 0; j < rowsComp; ++j) {
            QStandardItem * itComp = itChan->child (j);
            if (!itComp->isCheckable ()) continue;
            itComp->setCheckState(Qt::Unchecked);
        }
    }

    bool allunchecked = true;
    for (int i = 0; i < rowsChan; ++i) {
        QStandardItem * itChan = itloc->child (i);
        if (itChan->checkState () == Qt::Checked) allunchecked = false;
    }
    if (allunchecked)
        itloc->setCheckState(Qt::Unchecked );

    allunchecked = true;
    QModelIndex indexLStation =  indexLocation.parent ();
    QStandardItem* itStation = itemFromIndex(indexLStation);
    int rowsSta = itStation->rowCount ();
    for (int i = 0; i < rowsSta; ++i) {
        itloc = itStation->child (i);
        if (itloc->checkState () == Qt::Checked) allunchecked = false;
    }
    if (allunchecked)
        itStation->setCheckState(Qt::Unchecked );
}
///-----------------------------------------------------------------------
void TreePropertyModel::CheckedComp(const QModelIndex & ind) {
    QModelIndex indexChannel =  ind.parent ();
    QStandardItem* itChan = itemFromIndex(indexChannel);
    QString nameComp = ind.data().toString();
    bool eComp = nameComp.contains('E');
    bool nComp = nameComp.contains('N');
    int rowsComp = itChan->rowCount ();
    for (int i = 0; i < rowsComp; ++i) {
        QStandardItem * itComp = itChan->child (i);
        if (!itComp->isCheckable ()) continue;
        QString nameCur = itComp->index().data().toString();
        if (nameCur.contains('E') && nComp) itComp->setCheckState(Qt::Checked );
        if (nameCur.contains('N') && eComp) itComp->setCheckState(Qt::Checked );
    }
    itChan->setCheckState(Qt::Checked );
    QModelIndex indexLocation =  indexChannel.parent ();
    QStandardItem* itloc = itemFromIndex(indexLocation);

    itloc->setCheckState(Qt::Checked );
    QModelIndex indexStation =  indexLocation.parent ();
    QStandardItem* itemStation = itemFromIndex(indexStation);
    int rowsLoc = itemStation->rowCount ();
    for (int  i = 0; i < rowsLoc; ++i) {
        itloc = itemStation->child ( i);
        if (indexLocation == itloc->index()) continue;
        if (!itloc->isCheckable ()) continue;
        itloc->setCheckState(Qt::Unchecked );
        int rowsChan = itloc->rowCount ();
        for (int i = 0; i < rowsChan; ++i) {
            QStandardItem * itChan = itloc->child (i);
            if (!itChan->isCheckable ()) continue;
            itChan->setCheckState(Qt::Unchecked );
            int rowsComp = itChan->rowCount();
            for (int j = 0; j < rowsComp; ++j) {
                QStandardItem * itComp = itChan->child (j);
                if (!itComp->isCheckable ()) continue;
                itComp->setCheckState(Qt::Unchecked );
            }
        }

    }

    itemStation->setCheckState(Qt::Checked );

}
///-----------------------------------------------------------------------
void TreePropertyModel::UnCheckedComp(const QModelIndex & ind) {
    QModelIndex indexChannel =  ind.parent ();
    QStandardItem* itChan = itemFromIndex(indexChannel);
    QString nameComp = ind.data().toString();
    bool eComp = nameComp.contains('E');
    bool nComp = nameComp.contains('N');
    int rowsComp = itChan->rowCount ();
    for (int i = 0; i < rowsComp; ++i) {
        QStandardItem * itComp = itChan->child (i);
        if (!itComp->isCheckable ()) continue;
        QString nameCur = itComp->index().data().toString();
        if (nameCur.contains('E') && nComp) itComp->setCheckState(Qt::Unchecked );
        if (nameCur.contains('N') && eComp) itComp->setCheckState(Qt::Unchecked );
    }
    bool allunchecked = true;
    for (int i = 0; i < rowsComp; ++i) {
        QStandardItem * itComp = itChan->child (i);
        if (!itComp->isCheckable ()) continue;
        if (itComp->checkState () == Qt::Checked) allunchecked = false;
    }
    if (allunchecked)
        itChan->setCheckState(Qt::Unchecked );
    QModelIndex indexLocation =  indexChannel.parent ();
    QStandardItem* itloc = itemFromIndex(indexLocation);
    allunchecked = true;
    int rowsChan = itloc->rowCount ();
    for (int i = 0; i < rowsChan; ++i) {
        QStandardItem * itChan = itloc->child (i);
        if (!itChan->isCheckable ()) continue;
        if (itChan->checkState () == Qt::Checked) allunchecked = false;
    }
    if (allunchecked) {
        itloc->setCheckState(Qt::Unchecked );
        QModelIndex indexStation =  indexLocation.parent ();
        QStandardItem* itemStation = itemFromIndex(indexStation);
        itemStation->setCheckState(Qt::Unchecked );
    }
}
///-----------------------------------------------------------------------
void TreePropertyModel::clicked(const QModelIndex & ind) {
    QStandardItem* item = itemFromIndex(ind);
    QModelIndex indexParentStation =  ind.parent ();
    if (indexParentStation == QModelIndex())  {/// station
        if (item->checkState () == Qt::Checked) CheckedStation(ind);
        else UnCheckedStation(ind);
        return;
    }
    QModelIndex indexParentLocation =   indexParentStation.parent();
    if (indexParentLocation == QModelIndex()) { /// location
        if (item->checkState () == Qt::Checked) CheckedLocation(ind);
        else UnCheckedLocation(ind);
        return;
    }
    QModelIndex indexParentChannel =   indexParentLocation.parent();
    if (indexParentChannel == QModelIndex()) { /// channel
        if (item->checkState () == Qt::Checked) CheckedChannel(ind);
        else UnCheckedChannel(ind);
        return;

    }

    QModelIndex indexParentComponent =   indexParentChannel.parent();
    if (indexParentComponent == QModelIndex()) { /// component
        if (item->checkState () == Qt::Checked) CheckedComp(ind);
        else UnCheckedComp(ind);
        return;

    }

}
///========================================================================================
TreeProfileDelegate::TreeProfileDelegate(QObject *parent)
        : QItemDelegate(parent) {

}
/*
//-----------------------------------------------------------------------
QWidget *TreeProfileDelegate::createEditor(QWidget *parent,
    const QStyleOptionViewItem &,
    const QModelIndex & index) const
{

    TreeProfileModel *mod = (TreeProfileModel *)index.model();
    if (mod->type == ProfileList::Normal) return 0;

    QList<QModelIndex> list = mod->rlist;
      if( list.indexOf(index) != -1){
       FindFileEditor *editor = new FindFileEditor(index,parent);
       return editor;

   } else return 0;

}
//=========================================================================
void TreeProfileDelegate::setEditorData(QWidget *editor,
                                    const QModelIndex &index) const
{

     QString value = index.model()->data(index, Qt::DisplayRole).toString();
      FindFileEditor *lineEdit = static_cast<FindFileEditor*>(editor);
      lineEdit->GetLineEditor()->setText(value);

}

void TreeProfileDelegate::setModelData(QWidget *editor, QAbstractItemModel *,
                                   const QModelIndex &index) const
{

       TreeProfileModel *mod = (TreeProfileModel *)index.model();
       QString value = "";
       FindFileEditor* lineEdit = static_cast<FindFileEditor *>(editor);
       value = lineEdit->GetLineEditor()->text();
       mod->setData(index, QVariant(value));

}

*/
//-----------------------------------------------------------------------

void TreeProfileDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt, const QModelIndex &index) const {
    QStyleOptionViewItem option = opt;
    option.displayAlignment =  Qt::AlignLeft|Qt::AlignVCenter;
    TreePropertyModel *mod = (TreePropertyModel *)index.model();
    QModelIndex parent  = mod->parent(index);
    /*
        if (mod->type == ProfileList::Normal) {
    	if(parent != QModelIndex() )
            if(executeAction && mod->data(parent).toString() == "Tasks:"){
    	//QMessageBox::warning(0, "",QString ("action %1").arg(mod->data(index).toString()));
             //option.font.setBold(true);
             option.palette.setColor(QPalette::Text,QColor("blue"));
           }
       }
       if (mod->type == ProfileList::Repair) {
          QStringList& listRepair = MainWindow::self->GetRepairFileName();
          QList<QModelIndex> list = mod->rlist;
              if( list.indexOf(index) != -1) {
              QString str = mod->data(index).toString();
                  if( !listRepair.contains(str) )
                      option.palette.setColor(QPalette::Text,QColor("blue"));
              }
      }
     */   //option.palette.setColor(QPalette::Highlight,QColor(70,120,220)); //QColor(80,132,166)    100,160,180

    QItemDelegate::paint(painter, option, index);

    if (index.column() == 0 || index.column() == 1) {
        painter->drawLine(option.rect.right(), option.rect.y(),
                          option.rect.right(), option.rect.bottom());
    }
    painter->drawLine(option.rect.x(), option.rect.bottom(),
                      option.rect.right(), option.rect.bottom());
}

