//
// C++ Implementation: document
//
// Description:
//
//
// Author: fmt <fmt@localhost.localdomain>, (C) 2008
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include <QtGui>
#include <stdlib.h>
#include <qmessagebox.h>
#include "mainwindow.h"
#include "document.h"
#include "default.h"

void delAndNullify(PropertyValue* &pPropVal) {
    delete  pPropVal;
    pPropVal = 0;
}
 
///////////////////// PropertyValue Implemenation ///////////////////////////////
PropertyValue::~PropertyValue() {
}
PropertyValue::PropertyValue( const int i,const QString defval,const QString name) :
        id(i),value(defval),initialvalue(defval),resetvalue(defval),defaultvalue(defval),name(name),changed(FALSE) {}
PropertyValue::PropertyValue(const int i, const QString resval,const QString defval,const QString name) :
        id(i),value(resval),initialvalue(resval),resetvalue(resval),defaultvalue(defval),name(name),changed(FALSE) {}
PropertyValue::PropertyValue( const int i,const  QString val, const QString resval,const QString defval,const QString name):
        id(i),value(val),initialvalue(val),resetvalue(resval),defaultvalue(defval),name(name),changed(FALSE) {}
void PropertyValue::setChanged( bool b) {
    if ( changed == b )
        return;
    changed = b;


}

bool PropertyValue::isChanged() const {
    return changed;
}
bool PropertyValue::isReseted() const {
    if (value == resetvalue) return FALSE;
    else return TRUE;
}
QDataStream &operator<< (QDataStream & out, const PropertyValue * prop) {

    out <<   prop->GetId() <<    prop->GetValue();
    return out;
}
QDataStream &operator>>(QDataStream & in, PropertyValue & prop) {
    QString v;
    int id;
    in >>   id  >>  v;
    prop.SetId(id);
    prop.SetResetvalue(v);
    return in;
}
///////////////////// <: inherits from PropertyValue :> //////////////////////////

///////////////////// PropertyBoolValue Implemenation ///////////////////////////
PropertyBoolValue::PropertyBoolValue(const int i, const QString defval,const QString name ) :
        PropertyValue(i,defval ,name) {
    kind = PropertyValue::Property_Bool;
}
PropertyBoolValue::PropertyBoolValue( const int i, const QString resval, const QString defval ,const QString name) :
        PropertyValue(i, resval,defval ,name) {
    kind = PropertyValue::Property_Bool;
}
PropertyBoolValue::PropertyBoolValue( const int i, const QString val,const  QString resval,const QString defval,const QString name) :
        PropertyValue(i, val,resval,defval,name ) {
    kind = PropertyValue::Property_Bool;
}
///////////////////// PropertyIntValue Implemenation ///////////////////////////
PropertyIntValue::PropertyIntValue( const int i,const QString defval ,const QString name,const int min,const int max, const bool s):
        PropertyValue(i,defval ,name),
        min(min),max(max), signedValue(s) {
    kind = PropertyValue::Property_Int;
}
PropertyIntValue::PropertyIntValue( const int i,const  QString resval,const QString defval ,const QString name,const int min,const int max, const bool s):
        PropertyValue( i,resval,defval ,name),
        min(min),max(max), signedValue(s) {
    kind = PropertyValue::Property_Int;
}

PropertyIntValue::PropertyIntValue( const int i, const  QString val, const  QString resval,const QString defval,const QString name,const int min,const int max, const bool s):
        PropertyValue( i,val,resval,defval,name ),
        min(min),max(max), signedValue(s) {
    kind = PropertyValue::Property_Int;
}

///////////////////// PropertyIntSpinValue Implemenation ///////////////////////////
PropertyIntSpinValue::PropertyIntSpinValue( const int i,const QString defval ,const QString name,const int min,const int max, const int s):
        PropertyValue(i,defval ,name),
        min(min),max(max), step(s) {
    kind = PropertyValue::Property_IntSpin;
}
PropertyIntSpinValue::PropertyIntSpinValue( const int i,const  QString resval,const QString defval ,const QString name,const int min,const int max, const int s):
        PropertyValue( i,resval,defval ,name),
        min(min),max(max), step(s) {
    kind = PropertyValue::Property_IntSpin;
}

PropertyIntSpinValue::PropertyIntSpinValue( const int i, const  QString val, const  QString resval,const QString defval,const QString name,const int min,const int max, const int s):
        PropertyValue( i,val,resval,defval,name ),
        min(min),max(max), step(s) {
    kind = PropertyValue::Property_IntSpin;
}
///////////////////// PropertyFloatValue Implemenation ///////////////////////////

PropertyFloatValue::PropertyFloatValue( const int i,  const QString defval ,const QString name,
                                        const float min,const float max, const int dec) :
        PropertyValue(i,defval ,name),
        min(min),max(max), decimal(dec) {
    kind = PropertyValue::Property_Float;
}

PropertyFloatValue::PropertyFloatValue(  const int i, const QString resval,const QString defval,
        const QString name,
        const float min,const float max, const int dec ) :
        PropertyValue(i, resval,defval ,name),
        min(min),max(max), decimal(dec) {
    kind = PropertyValue::Property_Float;
}

PropertyFloatValue::PropertyFloatValue( const int i, const  QString val,const  QString resval,
                                        const QString defval,const QString name,
                                        const float min,const float max, const int dec):
        PropertyValue( i,val,resval,defval,name ),
        min(min),max(max), decimal(dec) {
    kind = PropertyValue::Property_Float;
}

///////////////////// PropertyEnumValue Implemenation ///////////////////////////

PropertyEnumValue::PropertyEnumValue( const int i,  const QString defval ,const QString name,const QString lst) :
        PropertyValue(i,defval ,name) {
    list = lst.split ('@');
    kind = PropertyValue::Property_Enum;
}
PropertyEnumValue::PropertyEnumValue(  const int i,  const QString resval,const QString defval ,const QString name,const QString lst) :
        PropertyValue( i,resval,defval ,name) {
    list = lst.split ('@');
    kind = PropertyValue::Property_Enum;
}
PropertyEnumValue::PropertyEnumValue( const int i,  const  QString val, const QString resval,const QString defval,const QString name,const QString lst):
        PropertyValue( i,val,resval,defval,name ) {
    list = lst.split ('@');
    kind = PropertyValue::Property_Enum;
}
///////////////////// PropertyStringValue Implemenation ///////////////////////////

PropertyStringValue::PropertyStringValue( const int i,  const QString defval ,const QString name) :
        PropertyValue(i,defval ,name) {
    kind = PropertyValue::Property_String;
}
PropertyStringValue::PropertyStringValue(  const int i,  const QString resval,const QString defval ,const QString name) :
        PropertyValue( i,resval,defval ,name) {
    kind = PropertyValue::Property_String;
}
PropertyStringValue::PropertyStringValue( const int i,  const  QString val, const QString resval,const QString defval,const QString name):
        PropertyValue( i,val,resval,defval,name ) {
    kind = PropertyValue::Property_String;
}
///////////////////// PropertyStringListValue Implemenation ///////////////////////////

PropertyStringListValue::PropertyStringListValue( const int i,  const QString defval ,const QString name) :
        PropertyValue(i,defval ,name) {
    if (!value.isEmpty()) list = value.split ('*');
    else  list = QStringList();
    kind = PropertyValue::Property_StringList;
}
PropertyStringListValue::PropertyStringListValue(  const int i,  const QString resval,const QString defval ,const QString name) :
        PropertyValue( i,resval,defval ,name) {
    if (!value.isEmpty()) list = value.split ('*');
    else  list = QStringList();
    kind = PropertyValue::Property_StringList;
}
PropertyStringListValue::PropertyStringListValue( const int i,  const  QString val, const QString resval,const QString defval,const QString name):
        PropertyValue( i,val,resval,defval,name ) {
    if (!value.isEmpty()) list = value.split ('*');
    else  list = QStringList();
    kind = PropertyValue::Property_StringList;
}
void PropertyStringListValue::SetListToValue(QStringList &lst) {
    if (!lst.empty ()) {
        value = lst.join("*");
        list = lst;
    } else {
        value = QString();
        list = QStringList();
    }
}
void PropertyStringListValue::SetValue  (const QString val)  {
    if (!val.isEmpty()) {
        value = val;
        list = value.split ('*');
    } else {
        value = QString();
        list = QStringList();
    }
}
void PropertyStringListValue::SetResetvalueToValue       ()  {
    if (!resetvalue.isEmpty()) {
        value   =  resetvalue;
        list = value.split ('*');
    } else {
        value = QString();
        list = QStringList();
    }
}
void PropertyStringListValue::SetDefault                 ()  {
    if (!defaultvalue.isEmpty()) {
        value   =  defaultvalue;
        list = value.split ('*');
    } else {
        value = QString();
        list = QStringList();
    }
}
void PropertyStringListValue::SetInitial                 ()  {
    if (!initialvalue.isEmpty()) {
        value   =  initialvalue;
        list = value.split ('*');
    } else {
        value = QString();
        list = QStringList();
    }
}

FDocument::~FDocument() {
    for_each(values.begin(),values.end(),delAndNullify);

    values.erase(remove(values.begin(),values.end(),
                        static_cast<PropertyValue*>(0)),
                 values.end());
    /*
    PropValIterator it; int i = 0;
    for (it = values.begin(); it!= values.end(); it++) {
    qWarning(" i %d  id %d '%s'",i,(*it)->GetId(),(*it)->GetValue().toAscii().data());
    delete *it; i++;
    }
    values.clear();
    */


}
FDocument::FDocument() {

///========================== SeedToDb parameters ======================================

    SetPropertyEnumValue(InputDataType,idInputDataType(),
                         defaultInputDataType(),defaultInputDataType(),
                         nameInputDataType(),enumInputDataType());

    SetPropertyEnumValue(OutputDeltaTime,idOutputDeltaTime(),
                         defaultOutputDeltaTime(),defaultOutputDeltaTime(),
                         nameOutputDeltaTime(),enumOutputDeltaTime());

    SetPropertyStringValue(DataDirectoryName,idDataDirectoryName(),
                           defaultDataDirectoryName(),defaultDataDirectoryName(),
                           nameDataDirectoryName());

    SetPropertyStringValue(DbaseName,idDbaseName(),
                           defaultDbaseName(),defaultDbaseName(),
                           nameDbaseName());

    SetPropertyStringValue(DbaseDirectoryName,idDbaseDirectoryName(),
                           defaultDbaseDirectoryName(),defaultDbaseDirectoryName(),
                           nameDbaseDirectoryName());

    SetPropertyIntValue(OriginYear,idOriginYear(),
                        defaultOriginYear(),defaultOriginYear(),nameOriginYear(),
                        minOriginYear(),maxOriginYear(),signedOriginYear());

    SetPropertyIntValue(OriginMonth,idOriginMonth(),
                        defaultOriginMonth(),defaultOriginMonth(),nameOriginMonth(),
                        minOriginMonth(),maxOriginMonth(),signedOriginMonth());

    SetPropertyIntValue(OriginDay,idOriginDay(),
                        defaultOriginDay(),defaultOriginDay(),nameOriginDay(),
                        minOriginDay(),maxOriginDay(),signedOriginDay());

    SetPropertyIntValue(OriginHour,idOriginHour(),
                        defaultOriginHour(),defaultOriginHour(),nameOriginHour(),
                        minOriginHour(),maxOriginHour(),signedOriginHour());

    SetPropertyIntValue(OriginMinute,idOriginMinute(),
                        defaultOriginMinute(),defaultOriginMinute(),nameOriginMinute(),
                        minOriginMinute(),maxOriginMinute(),signedOriginMinute());

    SetPropertyFloatValue(OriginSecond,idOriginSecond(),
                          defaultOriginSecond(),defaultOriginSecond(),
                          nameOriginSecond(),minOriginSecond(),
                          maxOriginSecond(),decimalDOriginSecond());

    SetPropertyIntValue(RecordDuration,idRecordDuration(),
                        defaultRecordDuration(),defaultRecordDuration(),nameRecordDuration(),
                        minRecordDuration(),maxRecordDuration(),signedRecordDuration());

    SetPropertyFloatValue(OriginLatitude,idOriginLatitude(),
                          defaultOriginLatitude(),defaultOriginLatitude(),
                          nameOriginLatitude(),minOriginLatitude(),
                          maxOriginLatitude(),decimalDOriginLatitude());

    SetPropertyFloatValue(OriginLongitude,idOriginLongitude(),
                          defaultOriginLongitude(),defaultOriginLongitude(),
                          nameOriginLongitude(),minOriginLongitude(),
                          maxOriginLongitude(),decimalDOriginLongitude());

    SetPropertyFloatValue(OriginDepth,idOriginDepth(),
                          defaultOriginDepth(),defaultOriginDepth(),
                          nameOriginDepth(),minOriginDepth(),
                          maxOriginDepth(),decimalDOriginDepth());

    SetPropertyFloatValue(OriginMb,idOriginMb(),
                          defaultOriginMb(),defaultOriginMb(),
                          nameOriginMb(),minOriginMb(),
                          maxOriginMb(),decimalDOriginMb());

    SetPropertyFloatValue(OriginMs,idOriginMs(),
                          defaultOriginMs(),defaultOriginMs(),
                          nameOriginMs(),minOriginMs(),
                          maxOriginMs(),decimalDOriginMs());

    SetPropertyFloatValue(OriginMl,idOriginMl(),
                          defaultOriginMl(),defaultOriginMl(),
                          nameOriginMl(),minOriginMl(),
                          maxOriginMl(),decimalDOriginMl());

}
void FDocument::readFromStream(QDataStream &in) {
    PropertyValue prop;
    while (!in.atEnd()) {
        in >> prop;
///========================== SeedToDb parameters ======================================
        if ( prop.GetId() ==   idInputDataType())
            SetPropertyEnumValue(InputDataType,idInputDataType(),
                                 prop.GetResetvalue(),defaultInputDataType(),
                                 nameInputDataType(),enumInputDataType());

        if ( prop.GetId() ==   idOutputDeltaTime())
            SetPropertyEnumValue(OutputDeltaTime,idOutputDeltaTime(),
                                 prop.GetResetvalue(),defaultOutputDeltaTime(),
                                 nameOutputDeltaTime(),enumOutputDeltaTime());

        if ( prop.GetId() ==   idDataDirectoryName())
            SetPropertyStringValue(DataDirectoryName,idDataDirectoryName(),
                                   prop.GetResetvalue(),defaultDataDirectoryName(),
                                   nameDataDirectoryName());

        if ( prop.GetId() ==   idDbaseName())
            SetPropertyStringValue(DbaseName,idDbaseName(),
                                   prop.GetResetvalue(),defaultDbaseName(),
                                   nameDbaseName());

        if ( prop.GetId() ==   idDbaseDirectoryName())
            SetPropertyStringValue(DbaseDirectoryName,idDbaseDirectoryName(),
                                   prop.GetResetvalue(),defaultDbaseDirectoryName(),
                                   nameDbaseDirectoryName());

        if ( prop.GetId() ==   idOriginYear())
            SetPropertyIntValue(OriginYear,idOriginYear(),
                                prop.GetResetvalue(),defaultOriginYear(),nameOriginYear(),
                                minOriginYear(),maxOriginYear(),signedOriginYear());

        if ( prop.GetId() ==   idOriginMonth())
            SetPropertyIntValue(OriginMonth,idOriginMonth(),
                                prop.GetResetvalue(),defaultOriginMonth(),nameOriginMonth(),
                                minOriginMonth(),maxOriginMonth(),signedOriginMonth());

        if ( prop.GetId() ==   idOriginDay())
            SetPropertyIntValue(OriginDay,idOriginDay(),
                                prop.GetResetvalue(),defaultOriginDay(),nameOriginDay(),
                                minOriginDay(),maxOriginDay(),signedOriginDay());

        if ( prop.GetId() ==   idOriginHour())
            SetPropertyIntValue(OriginHour,idOriginHour(),
                                prop.GetResetvalue(),defaultOriginHour(),nameOriginHour(),
                                minOriginHour(),maxOriginHour(),signedOriginHour());

        if ( prop.GetId() ==   idOriginMinute())
            SetPropertyIntValue(OriginMinute,idOriginMinute(),
                                prop.GetResetvalue(),defaultOriginMinute(),nameOriginMinute(),
                                minOriginMinute(),maxOriginMinute(),signedOriginMinute());

        if ( prop.GetId() ==   idOriginSecond())
            SetPropertyFloatValue(OriginSecond,idOriginSecond(),
                                  prop.GetResetvalue(),defaultOriginSecond(),
                                  nameOriginSecond(),minOriginSecond(),
                                  maxOriginSecond(),decimalDOriginSecond());

        if ( prop.GetId() ==   idRecordDuration())
            SetPropertyIntValue(RecordDuration,idRecordDuration(),
                                prop.GetResetvalue(),defaultRecordDuration(),nameRecordDuration(),
                                minRecordDuration(),maxRecordDuration(),signedRecordDuration());

        if ( prop.GetId() ==   idOriginLatitude())
            SetPropertyFloatValue(OriginLatitude,idOriginLatitude(),
                                  prop.GetResetvalue(),defaultOriginLatitude(),
                                  nameOriginLatitude(),minOriginLatitude(),
                                  maxOriginLatitude(),decimalDOriginLatitude());

        if ( prop.GetId() ==   idOriginLongitude())
            SetPropertyFloatValue(OriginLongitude,idOriginLongitude(),
                                  prop.GetResetvalue(),defaultOriginLongitude(),
                                  nameOriginLongitude(),minOriginLongitude(),
                                  maxOriginLongitude(),decimalDOriginLongitude());

        if ( prop.GetId() ==   idOriginDepth())
            SetPropertyFloatValue(OriginDepth,idOriginDepth(),
                                  prop.GetResetvalue(),defaultOriginDepth(),
                                  nameOriginDepth(),minOriginDepth(),
                                  maxOriginDepth(),decimalDOriginDepth());

        if ( prop.GetId() ==   idOriginMb())
            SetPropertyFloatValue(OriginMb,idOriginMb(),
                                  prop.GetResetvalue(),defaultOriginMb(),
                                  nameOriginMb(),minOriginMb(),
                                  maxOriginMb(),decimalDOriginMb());

        if ( prop.GetId() ==   idOriginMs())
            SetPropertyFloatValue(OriginMs,idOriginMs(),
                                  prop.GetResetvalue(),defaultOriginMs(),
                                  nameOriginMs(),minOriginMs(),
                                  maxOriginMs(),decimalDOriginMs());

        if ( prop.GetId() ==   idOriginMl())
            SetPropertyFloatValue(OriginMl,idOriginMl(),
                                  prop.GetResetvalue(),defaultOriginMl(),
                                  nameOriginMl(),minOriginMl(),
                                  maxOriginMl(),decimalDOriginMl());

    }//while (!in.atEnd())
}
FDocument::FDocument(const QString &fileName) {

    projectFileGood = true;
    if (!loadBinary(fileName)) projectFileGood = false;

}
bool  FDocument::loadBinary(const QString &fileName) {

    QFile file(fileName);
    if (!file.open(QIODevice::ReadOnly)) {
        ioError(file,"Cannot open file %1 for reading") ;
        return false;
    }
    QDataStream in (&file);
    quint32 magic;
    in >>  magic;
    if (magic != MagicNumber) {
        error(file,"File %1 is not a project file. Bad Format.");
        return false;
    }
    int ecpVersion;

    in >>  ecpVersion;
    QString lst =  SeedToDbVersionsForQt4();
    QStringList words =  lst.split(" ");
    int minForQt4 =  words[0].toInt();
    int maxForQt4 =  words[1].toInt();

    if ( ecpVersion  >=  minForQt4 && ecpVersion  <=  maxForQt4 )
        in.setVersion(QDataStream::Qt_4_3);
// Here for next    VersionQDataStream

    readFromStream(in);

    if ( file.error() != QFile::NoError  ) {
        ioError(file,"Error reading from file %1") ;
        return false;
    }

    file.close() ;
    return true;
}
bool  FDocument::saveBinary(const QString &fileName) {
    QFile file(fileName);
    if (!file.open(QIODevice::WriteOnly)) {
        ioError(file,"Cannot open file %1 for writing") ;
        return false;
    }
    QDataStream out (&file);
    out  <<  (quint32)MagicNumber;
    int ecpVersion =  SeedToDbCurrentVersion().toInt();
    out  <<  ecpVersion;
    writeToStream(out);
    if ( file.error() != QFile::NoError  ) {
        ioError(file,"Error writing to file %1") ;
        return false;
    }

    file.close() ;
    return true;
}
void FDocument::error(const QFile &file ,const QString &message) {
    QMessageBox::warning(0,"Project Parameters",message.arg(file.fileName()));
}
void FDocument::ioError(const QFile &file ,const QString &message) {
    error(file, message + ": " + file.errorString());
}
void FDocument::writeToStream(QDataStream &out) {
    PropValIterator it = values.begin();
    while (it != values.end()) {
        out << *it;
        ++it;
    }
}

void FDocument::SetPropertyIntValue(PropertyIntValue* &p, int id,QString reset,QString defaultvalue,
                                    QString name,int min,int max,bool sign) {
    p = new PropertyIntValue(id,reset,defaultvalue,name,min,max,sign);
    values.push_back(p);
}
void FDocument::SetPropertyFloatValue(PropertyFloatValue* &p, int id,QString reset,QString defaultvalue,
                                      QString name,float min,float max,int decimal) {
    p = new PropertyFloatValue(id,reset,defaultvalue,name,min,max,decimal);
    values.push_back(p);
}

void FDocument::SetPropertyEnumValue(PropertyEnumValue* &p, int id,QString reset,QString defaultvalue,
                                     QString name,QString enumeration) {
    p = new PropertyEnumValue(id,reset,defaultvalue,name,enumeration);
    values.push_back(p);
}
void FDocument::SetPropertyStringValue(PropertyStringValue* &p, int id,QString reset,QString defaultvalue,
                                       QString name) {
    p = new PropertyStringValue(id,reset,defaultvalue,name);
    values.push_back(p);
}
void FDocument::SetPropertyStringListValue(PropertyStringListValue* &p, int id,QString reset,QString defaultvalue,
        QString name) {
    p = new PropertyStringListValue(id,reset,defaultvalue,name);
    values.push_back(p);
}
bool FDocument::CheckModified() {
    PropValIterator i = values.begin();
    while (i != values.end()) {
        (*i)->setChanged();
        i++;
    }
    return  isModified();
}
bool FDocument::isModified() {
    bool mod = false;
    PropValIterator i = values.begin();
    while (i != values.end()) {

        if ( (*i)->GetValue() != (*i)->GetInitialvalue()) {
            mod = true;
            (*i)->setChanged(true);
        } else (*i)->setChanged(false);
        i++;
    }
    return mod;
}
void FDocument::SetResetvalueToValue() {
    for_each(values.begin(),values.end(),mem_fun(&PropertyValue::SetResetvalueToValue));
}
void FDocument::SetValueToResetvalue() {
    for_each(values.begin(),values.end(),mem_fun(&PropertyValue::SetValueToResetvalue));
}
void FDocument::SetValueToInitialValue() {
    for_each(values.begin(),values.end(),mem_fun(&PropertyValue::SetValueToInitialValue));
}
void FDocument::SetDefault() {
    for_each(values.begin(),values.end(),mem_fun(&PropertyValue::SetDefault));
}
void FDocument::SetInitial() {
    for_each(values.begin(),values.end(),mem_fun(&PropertyValue::SetInitial));
}
QString FDocument::infoProgect() {

    QString tmp = QString();

    QDateTime dt =  QDateTime::currentDateTime ();
    QString date = QString("Info project created on %1\n").arg( dt.toString(Qt::ISODate));
    date.replace('-','/');
    date.replace('T',' ');
    tmp +=date;
    tmp += "\n--- Project File --- \n";
    QString projectName = MainWindow::self->GetCurFile();
    if (MainWindow::self->GetCurFile().isEmpty()) tmp += "untitled project";
    else {
        tmp += projectName;
        QFileInfo info(projectName);
        dt = info.created ();
        date  = QString("\ncreated on %1\n").arg(dt.toString(Qt::ISODate));
        date.replace('-','/');
        date.replace('T',' ');
        tmp +=date;


        dt = info.lastRead();
        date  = QString("last read on %1\n").arg(dt.toString(Qt::ISODate));
        date.replace('-','/');
        date.replace('T',' ');
        tmp +=date;

        dt = info.lastModified();
        date  = QString("last modified on %1\n").arg(dt.toString(Qt::ISODate));
        date.replace('-','/');
        date.replace('T',' ');
        tmp +=date;
    }

    tmp += "\n--- Input data ---\n";
    if (InputDataType->GetValue() == "0")
        tmp += "seed volumes form directory\n";
    else
        tmp += "ah files form directory\n";

    tmp += DataDirectoryName->GetValue();
    tmp += "\n\n--- Event data ---\n";

    tmp += QString("date: %1/%2/%3").arg(OriginYear->GetValue()).
           arg(OriginMonth->GetValue()).arg(OriginDay->GetValue());

    tmp += QString("  %1:%2:%3\n").arg(OriginHour->GetValue()).
           arg(OriginMinute->GetValue()).arg(OriginSecond->GetValue());

    tmp += QString("hipocenter:  %1 %2 %3\n").arg(OriginLatitude->GetValue()).
           arg(OriginLongitude->GetValue()).arg(OriginDepth->GetValue());

    tmp += QString("magitudes:  mb %1 ms %2 ml %3\n").arg(OriginMb->GetValue()).
           arg(OriginMs->GetValue()).arg(OriginMl->GetValue());


    tmp += "\n--- Output data ---\n";

    tmp += QString("dbase name: %1\n").arg(DbaseName->GetValue());


    tmp += QString("dbase directory:\n%1\n").arg(DbaseDirectoryName->GetValue());

    if (OutputDeltaTime->GetValue() == "0")  {
        tmp += "decimate dbase records to 10 and 1 sec.\n";
        tmp += QString("duration of each records: %1\n").arg(RecordDuration->GetValue());
    } else  tmp += "Dbase records keep origin dt.";




    return tmp;
}

