#ifndef _SED2DBASE_DOCUMENT_H
#define _SED2DBASE_DOCUMENT_H
#include <vector>
#include <iostream>
#include <fstream>
#include <functional>
#include <algorithm>

using namespace std;

class QDataStream;
class QFile;
class PropertyValue;

//---------------------------------------------------------------------------------------------
class PropertyValue {
    friend QDataStream &operator<< (QDataStream &, const PropertyValue &);
    friend QDataStream &operator >> (QDataStream &, PropertyValue &);

public:
    enum Kind {
        Property_Bool,
        Property_Int,
        Property_IntSpin,
        Property_Float,
        Property_Enum,
        Property_TransformFunction,
        Property_DateTime,
        Property_String,
        Property_StringList
    };
    PropertyValue() {};
    PropertyValue(const int id,const QString defval,const QString name);
    PropertyValue(const int id,const QString resval,const QString defval,const QString name);
    PropertyValue(const int id,const QString val,const QString resval,const QString defval,const QString name);
    virtual     ~PropertyValue();
    virtual void setChanged( bool b);
    PropertyValue::Kind GetKind() {
        return kind;
    }
    bool isChanged() const;
    bool isReseted() const;
    void SetValueToResetvalue       () {
        resetvalue = value;
    }

    void SetValueToInitialValue       () {
        initialvalue = value;
    }
    void SetInitial                 () {
        value         =  initialvalue;
    }
    void setChanged                 () {
        if (value  ==  initialvalue)   setChanged( FALSE);
        else setChanged( TRUE);
    }
    int GetId                 () const {
        return id;
    }
    const QString GetName           () const {
        return name;
    }
    const QString GetInitialvalue   () const {
        return initialvalue;
    }
    const QString GetDefaultvalue   () const {
        return defaultvalue;
    }
    const QString GetResetvalue     ()  const {
        return resetvalue;
    }
    const QString GetValue          ()  const {
        return value;
    }
    void SetId             (const int i      ) {
        id = i;
    }
    void SetName           (const QString val) {
        name = val;
    }
    void SetResetvalue     (const QString val) {
        resetvalue = val;
    }
//---------------------------------------------------------------------------------------
    virtual void SetIntialvalue    (const QString ) {}
    virtual void SetValue          (const QString ) {}
    virtual void SetResetvalueToValue       () {}
    virtual void SetDefault                 () {}
//----------------------------------------------------------------------------------------
protected:
    int id;
    QString value;
    QString initialvalue;
    QString resetvalue;
    QString defaultvalue;
    QString name;
    PropertyValue::Kind kind;
private:
    bool changed;

};
//---------------------------------------------------------------------------------------------
class PropertyBoolValue : public PropertyValue {

public:
    PropertyBoolValue( const int id,const QString defval ,const QString name);
    PropertyBoolValue(const int id,const  QString resval, const QString defval ,const QString name);
    PropertyBoolValue( const int id,const QString val,const  QString resval,const QString defval,const QString name);
    ~PropertyBoolValue() {};
    void SetIntialvalue    (const QString val) {
        initialvalue= val;
    }
    void SetValue          (const QString val) {
        value = val;
    }
    void SetResetvalueToValue       () {
        value         = resetvalue ;
    }
    void SetDefault                 () {
        value         =  defaultvalue ;
    }
private:

};
//---------------------------------------------------------------------------------------------
class PropertyIntValue : public PropertyValue {

public:
    PropertyIntValue( const int id,const QString defval ,const QString name,const int min,const int max, const bool s);
    PropertyIntValue( const int id,const  QString resval,const QString defval ,const QString name,const int min,const int max, const bool s);
    PropertyIntValue( const int id, const  QString val, const  QString resval,const QString defval,const QString name,const int min,const int max, const bool s);
    ~PropertyIntValue() {};
    int  GetMin()          const {
        return min;
    }
    int  GetMax()          const {
        return max;
    }
    bool GetSignedValue() const {
        return   signedValue;
    }

    void SetIntialvalue    (const QString val) {
        initialvalue= val;
    }
    void SetValue          (const QString val) {
        value = val;
    }
    void SetResetvalueToValue       () {
        value         = resetvalue ;
    }
    void SetDefault                 () {
        value         =  defaultvalue ;
    }
private:
    int min;
    int max;
    bool signedValue;
};
//---------------------------------------------------------------------------------------------
class PropertyIntSpinValue : public PropertyValue {

public:
    PropertyIntSpinValue( const int id,const QString defval ,const QString name,const int min,const int max, const int s);
    PropertyIntSpinValue( const int id,const  QString resval,const QString defval ,const QString name,const int min,const int max, const int s);
    PropertyIntSpinValue( const int id, const  QString val, const  QString resval,const QString defval,const QString name,const int min,const int max, const int s);
    ~PropertyIntSpinValue() {};
    int  GetMin()          const {
        return min;
    }
    int  GetMax()          const {
        return max;
    }
    int GetStep()         const {
        return  step;
    }
    void SetIntialvalue    (const QString val) {
        initialvalue= val;
    }
    void SetValue          (const QString val) {
        value = val;
    }
    void SetResetvalueToValue       () {
        value         = resetvalue ;
    }
    void SetDefault                 () {
        value         =  defaultvalue ;
    }

private:
    int min;
    int max;
    int step;
};
//---------------------------------------------------------------------------------------------
class PropertyFloatValue : public PropertyValue {

public:
    PropertyFloatValue(const int id, const QString defval ,const QString name,const float min,const float max, const int dec);
    PropertyFloatValue(const int id, const  QString resval,const QString defval ,const QString name,const float min,const float max, const int dec);
    PropertyFloatValue(const int id, const  QString val, const  QString resval,const QString defval,const QString name,const float min,const float max, const int dec);
    ~PropertyFloatValue() {};
    float GetMin()           const {
        return min;
    }
    float GetMax()          const {
        return max;
    }
    void SetMin(float val) {
        min = val;
    }
    void SetMax(float val) {
        max = val;
    }
    int GetDecimal()     const {
        return  decimal;
    }
    void SetIntialvalue    (const QString val) {
        initialvalue= val;
    }
    void SetValue          (const QString val) {
        value = val;
    }
    void SetResetvalueToValue       () {
        value         = resetvalue ;
    }
    void SetDefault                 () {
        value         =  defaultvalue ;
    }
    void SetDefault         (QString val) {
        defaultvalue  =  val;
    }
private:
    float min;
    float max;
    int decimal;
};
//---------------------------------------------------------------------------------------------
class PropertyStringListValue : public PropertyValue {
public:
    PropertyStringListValue(const int id, const QString defval ,const QString name);
    PropertyStringListValue(const int id, const  QString resval,const QString defval ,const QString name);
    PropertyStringListValue(const int id, const QString val,const QString resval,const QString defval,const QString name);
    ~PropertyStringListValue() {
        list.clear();
    }
    void SetValue  (const QString val);
    void SetResetvalueToValue       ();
    void SetDefault                 ();
    void SetInitial                 ();
    QStringList &GetList   () {
        return list;
    }
    QStringList GetStringList () {
        return list;
    }
    void SetListToValue(QStringList &list);
private:
    QStringList list;

};

//---------------------------------------------------------------------------------------------
class PropertyStringValue : public PropertyValue {
public:
    PropertyStringValue(const int id, const QString defval ,const QString name);
    PropertyStringValue(const int id, const  QString resval,const QString defval ,const QString name);
    PropertyStringValue(const int id, const QString val,const QString resval,const QString defval,const QString name);
    ~PropertyStringValue() {};

    void SetIntialvalue    (const QString val) {
        initialvalue= val;
    }
    void SetValue          (const QString val) {
        value = val;
    }
    void SetResetvalueToValue       () {
        value         = resetvalue ;
    }
    void SetDefault                 () {
        value         =  defaultvalue ;
    }
private:


};

//---------------------------------------------------------------------------------------------
class PropertyEnumValue : public PropertyValue {
public:
    PropertyEnumValue(const int id, const QString defval ,const QString name,const QString list);
    PropertyEnumValue(const int id, const  QString resval,const QString defval ,const QString name,const QString list);
    PropertyEnumValue(const int id, const QString val,const QString resval,const QString defval,const QString name,const QString list);
    ~PropertyEnumValue() {
        list.clear();
    }
    QStringList &GetList   () {
        return list;
    }
    QStringList GetStringList () {
        return list;
    }
    void SetIntialvalue    (const QString val) {
        initialvalue= val;
    }
    void SetValue          (const QString val) {
        value = val;
    }
    void SetResetvalueToValue       () {
        value         = resetvalue ;
    }
    void SetDefault                 () {
        value         =  defaultvalue ;
    }
private:
    QStringList list;

};

//============================================================================================
class FDocument {
    typedef std::vector<PropertyValue* > PropValVector;
    typedef std::vector<PropertyValue* >::iterator PropValIterator;
public:

    FDocument();
    FDocument(const QString &fileName);
    FDocument(FDocument *doc);
    ~FDocument();
    bool loadBinary(const QString &fileName);
    bool saveBinary(const QString &fileName);
    bool isModified();
    void SetResetvalueToValue();
    void SetValueToResetvalue();
    void SetValueToInitialValue();
    void SetDefault();
    void SetInitial();
    std::vector <PropertyValue* >  &GetValues() {
        return values;
    }
    bool GetProjectFileGood() {
        return projectFileGood;
    }
    bool isChanged() const;
    bool CheckModified();
    QString infoProgect();
//----------------------------------------------------------------------------------------
    void SetPropertyEnumValue(PropertyEnumValue* &p, int id,QString reset,QString defaultvalue,
                              QString name,QString enumeration);
    void SetPropertyIntValue(PropertyIntValue* &p, int id,QString reset,QString defaultvalue,
                             QString name,int min,int max,bool sign);
    void SetPropertyFloatValue(PropertyFloatValue* &p, int id,QString reset,QString defaultvalue,
                               QString name,float min,float max,int decimal);
    void SetPropertyStringValue(PropertyStringValue* &p, int id,
                                QString reset,QString defaultvalue, QString name);
    void SetPropertyStringListValue(PropertyStringListValue* &p, int id,
                                    QString reset,QString defaultvalue, QString name);

///========================== SeedToDb parameters ======================================
    PropertyEnumValue*  &GetInputDataType() {
        return  InputDataType;
    }
    PropertyEnumValue*  &GetOutputDeltaTime() {
        return  OutputDeltaTime;
    }

    PropertyStringValue* &GetDataDirectoryName() {
        return  DataDirectoryName;
    }
    PropertyStringValue* &GetDbaseName() {
        return  DbaseName;
    }
    PropertyStringValue* &GetDbaseDirectoryName() {
        return  DbaseDirectoryName;
    }
///---------------------------------- Origin Data -------------------------------------
    PropertyIntValue*    &GetOriginYear() {
        return  OriginYear;
    }
    PropertyIntValue*    &GetOriginMonth() {
        return  OriginMonth;
    }
    PropertyIntValue*    &GetOriginDay() {
        return  OriginDay;
    }
    PropertyIntValue*    &GetOriginHour() {
        return  OriginHour;
    }
    PropertyIntValue*    &GetOriginMinute() {
        return  OriginMinute;
    }
    PropertyFloatValue*  &GetOriginSecond() {
        return  OriginSecond;
    }

    PropertyIntValue*    &GetRecordDuration() {
        return  RecordDuration;
    }

    PropertyFloatValue*  &GetOriginLatitude() {
        return  OriginLatitude;
    }
    PropertyFloatValue*  &GetOriginLongitude() {
        return  OriginLongitude;
    }
    PropertyFloatValue*  &GetOriginDepth() {
        return  OriginDepth;
    }
    PropertyFloatValue*  &GetOriginMb() {
        return  OriginMb;
    }
    PropertyFloatValue*  &GetOriginMs() {
        return  OriginMs;
    }
    PropertyFloatValue*  &GetOriginMl() {
        return  OriginMl;
    }

    QString GetProtocolInfo();
private:
    bool projectFileGood;
    bool changed;
    enum { MagicNumber = 0x73b85c11 };
    void writeToStream(QDataStream &out);
    void readFromStream(QDataStream &in);
    void error(const QFile &file ,const QString &message);
    void ioError(const QFile &file ,const QString &message);

///========================== SeedToDb parameters ======================================

///----------------------------------- Input Data Type --------------------------------
    PropertyEnumValue*  InputDataType;
///----------------------------------- Output DeltA Time ------------------------------
    PropertyEnumValue*  OutputDeltaTime;
///----------------------------------- Data Directory Name ----------------------
    PropertyStringValue* DataDirectoryName;
///----------------------------------- DBase Name -------------------------------------
    PropertyStringValue* DbaseName;
///----------------------------------- DBase Directory Name ---------------------------
    PropertyStringValue* DbaseDirectoryName;
///---------------------------------- Origin Data -------------------------------------
    PropertyIntValue*    OriginYear;
    PropertyIntValue*    OriginMonth;
    PropertyIntValue*    OriginDay;
    PropertyIntValue*    OriginHour;
    PropertyIntValue*    OriginMinute;
    PropertyFloatValue*  OriginSecond;

    PropertyIntValue*    RecordDuration;

    PropertyFloatValue*  OriginLatitude;
    PropertyFloatValue*  OriginLongitude;
    PropertyFloatValue*  OriginDepth;
    PropertyFloatValue*  OriginMb;
    PropertyFloatValue*  OriginMs;
    PropertyFloatValue*  OriginMl;

    PropValVector values;

};
#endif
