#include <QtGui>
#include <QWhatsThis>
#include "mainwindow.h"
#include "document.h"
#include "default.h"
#include "stationlist.h"
#include "creationdb.h"
#include "projectwizard.h"
#include "helpwindow.h"
#include "fmt4cmdw.h"
MainWindow *MainWindow::self = 0;
MainWindow::~MainWindow () {
    if  (doc !=0) delete doc;
    if  (fmtAh4Db !=0) delete fmtAh4Db;
    if(help !=0) {delete help; help = 0;}
}
MainWindow::MainWindow() {
    self = this;
    fmtAh4Db = 0;
    doc = new FDocument();
    help = 0;
    splitter = new QSplitter(this);
    splitter->setOrientation(Qt::Vertical);
    staTree = new ProfileTreeView(2,this);
    konsole = new AppKonsole(this);
    splitter->addWidget(staTree);
    splitter->addWidget(konsole);
    setCentralWidget(splitter);
    setWindowIcon(QIcon(":/images/icon.png"));
    projectFileFilters = tr("Project files (*%1);;All Files (*)").
                         arg(projectFileFilterLocator());
    protocolFileFilters = tr("Protocol files (*%1);;All Files (*)").
                          arg(protocolFileFilterLocator());
    createActions();
    createWhatsThis();
    createMenus();
    createToolBars();
    createStatusBar();

    readSettings();
    setWindowIcon(QIcon(":/images/icon.png"));
    FileActsShowHide(false);
    setCurrentFile ( "" );
    MakeTempDirectory();
}

void MainWindow::RepaintAllFrames() {

    repaint();
    staTree->repaint(); //staTree->repaint();
    konsole->repaint();
}
void MainWindow::FileActsShowHide(bool b) {
    foreach (QAction *action, showHideFileActs)
    if (b) action->setEnabled ( TRUE );
    else action->setEnabled ( FALSE );
}
void  MainWindow::MakeTempDirectory() {
    QDate date = QDate::currentDate ();
    QTime time = QTime::currentTime ();
    QDateTime datetime ( date, time ) ;
    uint currentTime = datetime.toTime_t ();
    homeDirectoryPath = temporarySystemDirectoryPath();
    homeDirectoryPath =  QDir::toNativeSeparators ( homeDirectoryPath );
    QDir d ( temporarySystemDirectoryPath() );
    homeDirectory = d;
    tempDirectoryPath = temporarySystemDirectoryPath() +
                        QString ( "/%1%2" ).arg ( temporaryDirectoryPrifix() ).arg ( currentTime );
    tempDirectoryPath =  QDir::toNativeSeparators ( tempDirectoryPath );
    d.mkdir ( tempDirectoryPath );
    QDir dd ( tempDirectoryPath );
    tempDirectory = dd;
//QMessageBox::critical(0,"",QString("temp %1").arg(tempDirectoryPath));
}
void MainWindow::removeWorkingMaterials(QString & temporaryDirectory,bool removeTempDirectory) {
    if ( temporaryDirectory.isNull() ) return;
    QDir tempDir ( temporaryDirectory );
    QFileInfoList info = tempDir.entryInfoList ( QDir::Dirs | QDir::Files,QDir::Name );

//   QMessageBox::critical(0,"", QString("temporaryDirectory %1").arg(temporaryDirectory));

    for ( int i = 0; i < info.size(); ++i ) {
        QFileInfo  infoTemp = info.at ( i );
        QString itemName = infoTemp.filePath();
        if ( itemName.contains ( QDir::toNativeSeparators ("/.") ) ) continue;
        if ( itemName.contains ( QDir::toNativeSeparators ("/..") ) ) continue;
        if ( infoTemp.isDir ()) {
            QDir tempCurDir ( itemName );
            QFileInfoList infolist = tempCurDir.entryInfoList (  QDir::Dirs | QDir::Files,QDir::Name );
            for ( int j = 0; j < infolist.size(); ++j ) {
                QFileInfo  infoCurTemp = infolist.at ( j );
                QString fileName = infoCurTemp.filePath();
                if ( fileName.contains (QDir::toNativeSeparators ( "/." )) ) continue;
                if ( fileName.contains ( QDir::toNativeSeparators ("/.." )) ) continue;
                if ( infoCurTemp.isFile ()) {
                    if (!tempCurDir.remove ( fileName )) QMessageBox::critical(0,"",
                                QString("Can't remove file %1").arg(fileName));
                }
            }
        }

        if ( infoTemp.isDir ())
            if (!tempDir.rmdir ( itemName )) QMessageBox::critical(0,"",
                        QString("Can't remove directory %1").arg(itemName));

        if ( infoTemp.isFile ())
            if (!tempDir.remove ( itemName )) QMessageBox::critical(0,"",
                        QString("Can't remove file %1").arg(itemName));
    }
    if (removeTempDirectory) {
        QDir tempSys(temporarySystemDirectoryPath());
        if (!tempSys.rmdir ( temporaryDirectory )) QMessageBox::critical(0,"",
                    QString("Can't remove directory %1").arg(temporaryDirectory));
    }
}
void MainWindow::closeEvent ( QCloseEvent *event ) {
    if ( maybeSave() ) {

        QApplication::setOverrideCursor(Qt::WaitCursor);
        removeWorkingMaterials(tempDirectoryPath);
        writeSettings();
        QApplication::restoreOverrideCursor();
        event->accept();
    } else {
        event->ignore();
    }
}

void MainWindow::newFile() {
    if ( maybeSave() ) {
        FDocument* tmpDoc = doc;
        doc = new FDocument();
        ProWizard  dialog(this,doc,ProWizard::ProjectNew);
        dialog.resize(projectWizardSize);
        dialog.move(projectWizardPos);
        if (dialog.exec()) {
            if (!SetTreeView("unnamed")) {
                delete doc;
                doc = tmpDoc;
                return;
            }
konsole->textCursor().insertText(doc->infoProgect());
konsole->textCursor().insertText("\n");
            FileActsShowHide(true);
            delete tmpDoc;
            setCurrentFile ( "" );
        } else {
            delete doc;
            doc = tmpDoc;
        }
        projectWizardPos   =  dialog.pos();
        projectWizardSize  =  dialog.size();
    }
}
void MainWindow::openRecentFile() {
    if (maybeSave()) {
        QAction *action = qobject_cast<QAction *>(sender());
        if (action) {
            if (!loadFile(action->data().toString())) return;
            FileActsShowHide(true);
        }
    }

}
void MainWindow::open() {

    if (maybeSave()) {
        QString fileName =
            QFileDialog::getOpenFileName(this,"Open an existing project file",userHomePath(),projectFileFilters); //openUserProjectDirectory,
        if (!fileName.isEmpty()) {
            if (!loadFile(fileName)) return;
           // openUserProjectDirectory = QFileInfo(fileName).absolutePath ();
            FileActsShowHide(true);
        }
    }

}

bool MainWindow::loadFile(const QString &fileName) {
    FDocument* tmpDoc = doc;
    doc = new FDocument(fileName);
    if (!doc->GetProjectFileGood()) {
        delete doc;
        doc = tmpDoc;
        return false;
    }
    if ( !AreDirectoriesExist(fileName) )  {
        delete doc;
        doc = tmpDoc;
        return false;
    }



    if (!SetTreeView(fileName)) {
        delete doc;
        doc = tmpDoc;
        return false;
    }
    delete tmpDoc;


    setCurrentFile(fileName);
    infoAct->setFont(font());
    infoAct->setText (doc->infoProgect());
konsole->textCursor().insertText(doc->infoProgect());
konsole->textCursor().insertText("\n");
    statusBar()->showMessage(tr("File loaded"), 2000);
    return true;
}
///========================== Repair Project ========================================= 
bool MainWindow::AreDirectoriesExist(const QString &fileName) {

    bool dataDirIsExist = true;
    QString dataDirectoryName = doc->GetDataDirectoryName()->GetValue();
    bool isSeedFiles = false;
    if (doc->GetInputDataType()->GetValue() == "0") isSeedFiles = true;
    if (!hasInputFiles(dataDirectoryName,isSeedFiles)) dataDirIsExist = false;

    bool dbaseDirIsExist = true;
    QString dbaseDirectoryName = doc->GetDbaseDirectoryName()->GetValue();
    int ret = isOutputDbaseDirectoryEmpty(dbaseDirectoryName);
   if (ret == 1 ) dbaseDirIsExist = false;  /// dbaseDirectoryName does not exist

//    if (ret == 2 ) return false; ///  won't remove dbaseDirectoryName's entries


    if (ret == 3 ) return false; ///  can't change directory to dbaseDirectoryName


    if ( !dataDirIsExist || !dbaseDirIsExist) {
        QString tmp = QString("The project file is\n    '%1'\n").arg(QDir::toNativeSeparators(fileName));

        if (!dataDirIsExist) tmp += QString("Input  Data Directory does not exist or does not contains needed files\n     %1\n").arg( QDir::toNativeSeparators(dataDirectoryName));

        if (!dbaseDirIsExist) tmp += QString("Output Dbase Directory does not exist\n     %1\n").arg( QDir::toNativeSeparators(dbaseDirectoryName));


        tmp += "Try fixing the problem?";
        int ret = QMessageBox::warning(this, mainWindowCaption(),tmp,
                                       QMessageBox::Yes | QMessageBox::Default,
                                       QMessageBox::No | QMessageBox::Escape);
        if (ret == QMessageBox::No) return false;



        ProWizard  dialog(this,doc,ProWizard::ProjectRepair);
        dialog.resize(projectWizardSize);
        dialog.move(projectWizardPos);
        if (dialog.exec()) {
        } else {
            return false;
        }


        projectWizardPos   =  dialog.pos();
        projectWizardSize  =  dialog.size();
    }

    return true;
}
void MainWindow::edit() {

    ProWizard  dialog(this,doc,ProWizard::ProjectEdit);
    dialog.resize(projectWizardSize);
    dialog.move(projectWizardPos);
    if (dialog.exec()) {
        if (doc->isModified()) SetTreeView(curFile);

konsole->textCursor().insertText(doc->infoProgect());
konsole->textCursor().insertText("\n");
    }
    projectWizardPos   =  dialog.pos();
    projectWizardSize  =  dialog.size();
}

bool MainWindow::save() {
    if (curFile.isEmpty()) {
        return saveAs();
    } else {
        return saveFile(curFile);
    }
}
bool MainWindow::saveAs() {
    QString fileName =
        QFileDialog::getSaveFileName(this,"Save the Project file under a new name",userHomePath(),projectFileFilters); //saveUserProjectDirectory,
    if (fileName.isEmpty())
        return false;
    int ind = fileName.length () - projectFileFilterLocator().length ()-1;
    if (ind < 0) ind =0;
    if ( ( fileName.indexOf(projectFileFilterLocator(),ind)) == -1 && ( fileName.indexOf(projectFileFilterLocator().toUpper(),ind)) == -1) {
        fileName.append(projectFileFilterLocator());
        if (QFile::exists(fileName)) {
            int ret = QMessageBox::warning(this, mainWindowCaption(),
                                           QString("File %1 already exists.\n Do you want to overwrite it?")
                                           .arg(QDir::toNativeSeparators(fileName)),
                                           QMessageBox::Yes | QMessageBox::Default,
                                           QMessageBox::No | QMessageBox::Escape);
            if (ret == QMessageBox::No)
                return true;
        }
    }
    if (!fileName.isEmpty())
        saveFile(fileName);
 //   saveUserProjectDirectory = QFileInfo(fileName).absolutePath ();
    return true;
}
bool MainWindow::saveFile ( const QString &fileName ) {

    QApplication::setOverrideCursor(Qt::WaitCursor);
    if (doc->saveBinary(fileName)) {

        setCurrentFile(fileName);
        setDocumentModified ();
        statusBar()->showMessage(tr("Project file saved"), 2000);

    } else {
        QApplication::restoreOverrideCursor();
        statusBar()->showMessage(tr("Saving Project file canceled"), 2000);
        return false;
    }

    QApplication::restoreOverrideCursor();

    return true;
}


void MainWindow::mainHelp() {
    QString home = searchHelpPath() + "/Dbcreator_index.html";
    if(help !=0) {delete help; help =0;}
    help = new HelpWindow(home,this);
    if ( QApplication::desktop()->width() > 400
         && QApplication::desktop()->height() > 500 )
         help->show();
    else
        help->showMaximized();
}

void MainWindow::about() {
	QString text =  tr("<h2>DbCreator version 1.40.1</h2>"
     "<p>Copyright &copy; 2008 MITPAN."
     "<p><b>DbCreator</b> is a program for creating <b>Data base</b> of "
     "seismograms for further processing by <b>Frequency time analysis</b> program."
     "<p>It's interface is a <b>C++ code using Qt C++</b> tool kit for multiplatform Graphic User Interface and application development."
     "<p>See http://www.mitp.ru/en/soft/mainIndex.html "
     );
    QMessageBox::about ( this, tr ( "About Application" ),
                         text );

}
void MainWindow::setDocumentModified () {
    doc->SetValueToResetvalue();
    doc->SetValueToInitialValue();
}
void MainWindow::documentWasModified() {
//    setDocumentModified ( textEdit->document()->isModified() );
}

void MainWindow::createActions() {
    newAct = new QAction ( QIcon ( ":/images/project_new.png" ), tr ( "&New" ), this );
    newAct->setShortcut ( tr ( "Ctrl+N" ) );
    newAct->setStatusTip ( tr ( "Create a new project" ) );
    connect ( newAct, SIGNAL ( triggered() ), this, SLOT ( newFile() ) );

    openAct = new QAction ( QIcon ( ":/images/project_open.png" ), tr ( "&Open..." ), this );
    openAct->setShortcut ( tr ( "Ctrl+O" ) );
    openAct->setStatusTip ( tr ( "Open an existing project" ) );
    connect ( openAct, SIGNAL ( triggered() ), this, SLOT ( open() ) );


    editAct = new QAction ( QIcon ( ":/images/project_edit.png" ), tr ( "&Edit..." ), this );
    editAct->setShortcut ( tr ( "Ctrl+E" ) );
    editAct->setStatusTip ( tr ( "Edit an opened project" ) );
    connect ( editAct, SIGNAL ( triggered() ), this, SLOT ( edit() ) );
    showHideFileActs.append(editAct);

    runAct = new QAction ( QIcon ( ":/images/run.png" ), tr ( "&Run..." ), this );
    runAct->setShortcut ( tr ( "Ctrl+R" ) );
    runAct->setStatusTip ( tr ( "Transforming seed vols to dbase" ) );
    connect ( runAct, SIGNAL ( triggered() ), this, SLOT ( run() ) );
    showHideFileActs.append(runAct);

    saveAct = new QAction ( QIcon ( ":/images/project_save.png" ), tr ( "&Save" ), this );
    saveAct->setShortcut ( tr ( "Ctrl+S" ) );
    saveAct->setStatusTip ( tr ( "Save the project to disk" ) );
    connect ( saveAct, SIGNAL ( triggered() ), this, SLOT ( save() ) );
    showHideFileActs.append(saveAct);

    saveAsAct = new QAction ( QIcon ( ":/images/project_saveas.png" ), tr ( "Save &As..." ), this );
    saveAsAct->setStatusTip ( tr ( "Save the project under a new name" ) );
    connect ( saveAsAct, SIGNAL ( triggered() ), this, SLOT ( saveAs() ) );
    showHideFileActs.append(saveAsAct);


    for (int i = 0; i < MaxRecentFiles; ++i) {
        recentFileActs[i] = new QAction(this);
        recentFileActs[i]->setVisible(false);
        connect(recentFileActs[i], SIGNAL(triggered()),
                this, SLOT(openRecentFile()));
    }

    exitAct = new QAction ( QIcon ( ":/images/exit.png" ), tr ( "E&xit"  ), this );
    exitAct->setShortcut ( tr ( "Ctrl+Q" ) );
    exitAct->setStatusTip ( tr ( "Exit the application" ) );
    connect ( exitAct, SIGNAL ( triggered() ), this, SLOT ( close() ) );


    zoominAct = new QAction ( QIcon ( ":/images/zoomin.png" ), tr ( "Zoom &In" ), this );
    zoominAct->setShortcut ( tr ( "Ctrl++" ) );
    zoominAct->setStatusTip ( tr ( "Zoom in" ) );
    connect ( zoominAct, SIGNAL ( triggered() ), this, SLOT ( zoomin() ) );

    zoomoutAct = new QAction ( QIcon ( ":/images/zoomout.png" ), tr ( "Zoom &Out" ), this );
    zoomoutAct->setShortcut ( tr ( "Ctrl+-" ) );
    zoomoutAct->setStatusTip ( tr ( "Zoom out" ) );
    connect ( zoomoutAct, SIGNAL ( triggered() ), this, SLOT ( zoomout() ) );

    infoAct = new QAction ( QIcon ( ":/images/info.png" ), tr ( "&Info" ), this );
    infoAct->setShortcut ( tr ( "Ctrl+I" ) );
    infoAct->setStatusTip ( tr ( "View project parameters" ) );
    connect ( infoAct, SIGNAL ( triggered() ), this, SLOT ( info() ) );
    showHideFileActs.append(infoAct);

    contentAct = new QAction ( QIcon ( ":/images/help.png" ), tr ( "&Content" ), this );
    contentAct->setShortcut ( tr ( "F1" ) );
    contentAct->setStatusTip ( tr ("Show the content of manual") );
    connect ( contentAct, SIGNAL ( triggered() ), this, SLOT ( mainHelp() ) );


    aboutAct = new QAction ( tr ( "&About" ), this );
    aboutAct->setStatusTip ( tr ( "Show the application's About box" ) );
    connect ( aboutAct, SIGNAL ( triggered() ), this, SLOT ( about() ) );

    aboutQtAct = new QAction ( tr ( "About &Qt" ), this );
    aboutQtAct->setStatusTip ( tr ( "Show the Qt library's About box" ) );
    connect ( aboutQtAct, SIGNAL ( triggered() ), qApp, SLOT ( aboutQt() ) );

}
void MainWindow::createWhatsThis() {
    const char * openActText = "<p><img source=\":/images/project_open.png\"> "
                               "Click this button to open an <em>existing project</em>."
                               "You can also select the <b>Open project</b> command "
                               "from the <b>Project</b> menu. Keyboard shortcut is <b>(Ctrl+O)</b></p>";

    openAct->setWhatsThis(openActText);
}
void MainWindow::zoomin() {
    QFont f( font() );
    f.setPointSize( f.pointSize() + 1 );
    setFont( f );
}
void MainWindow::zoomout() {
    QFont f(font() );
    f.setPointSize( f.pointSize() - 1 );
    setFont( f );
}

void MainWindow::info() {
    QString tmp = doc->infoProgect();

    if (tmp != QString()) {
 //  QMessageBox::information(this,mainWindowCaption(),tmp)
	QMessageBox mb(mainWindowCaption(),tmp,
	QMessageBox::Information,
	QMessageBox::Ok | QMessageBox::Default,
	QMessageBox::NoButton,
	QMessageBox::NoButton,this);
	mb.setFont(font());
	mb.exec();
	}

}
void MainWindow::createMenus() {
    fileMenu = menuBar()->addMenu ( tr ( "&Project" ) );
    fileMenu->addAction ( newAct );
    fileMenu->addAction ( openAct );
    fileMenu->addAction ( editAct );
    fileMenu->addAction ( runAct );
    fileMenu->addAction ( saveAct );
    fileMenu->addAction ( saveAsAct );

    separatorAct = fileMenu->addSeparator();
    for (int i = 0; i < MaxRecentFiles; ++i)
        fileMenu->addAction(recentFileActs[i]);
    fileMenu->addSeparator();
    fileMenu->addAction ( exitAct );
    updateRecentFileActions();

    menuBar()->addSeparator();

    viewMenu = menuBar()->addMenu ( tr ( "&View" ) );
    viewMenu->addAction ( zoominAct );
    viewMenu->addAction ( zoomoutAct );
    //viewMenu->addAction ( infoAct );

    menuBar()->addSeparator();

    helpMenu = menuBar()->addMenu ( tr ( "&Help" ) );
    helpMenu->addAction ( contentAct );
    whatsThisAct = helpMenu->addAction(QIcon(":/images/whatis.png"), tr("&What's This?"),
                                       this, SLOT(onWhatsThis()));
    whatsThisAct->setWhatsThis(tr("Enter What's This? mode."));
    whatsThisAct->setShortcut(Qt::SHIFT + Qt::Key_F1);
    helpMenu->addAction ( aboutAct );
    helpMenu->addAction ( aboutQtAct );
}
void MainWindow::onWhatsThis() {
    QWhatsThis::enterWhatsThisMode();
}
void MainWindow::createToolBars() {
    fileToolBar = addToolBar ( tr ( "Project" ) );
    fileToolBar->setIconSize(QSize(22,22));
    fileToolBar->addAction ( newAct );
    fileToolBar->addAction ( openAct );
    fileToolBar->addAction ( editAct );
    fileToolBar->addAction ( runAct );
    fileToolBar->addAction ( saveAct );
    fileToolBar->addAction ( saveAsAct );

    editToolBar = addToolBar ( tr ( "View" ) );
    editToolBar->setIconSize(QSize(22,22));
    editToolBar->addAction ( zoominAct );
    editToolBar->addAction ( zoomoutAct );
    editToolBar->addAction ( infoAct );
    editToolBar->addAction ( whatsThisAct );
    editToolBar->addSeparator();
    editToolBar->addAction ( exitAct );
}

void MainWindow::createStatusBar() {
    statusBar()->showMessage ( tr ( "Ready" ) );
}

void MainWindow::readSettings() {
    QSettings settings ( "mitp.ru", "Seed to Dbase" );
    QPoint pos = settings.value ( "pos", QPoint ( 200, 200 ) ).toPoint();
    QSize size = settings.value ( "size", QSize ( 400, 400 ) ).toSize();
    resize ( size );
    move ( pos );
    int fontPointSize = settings.value("fontPointSize", 10).toInt();
    QFont f(font());
    f.setPointSize(fontPointSize );
    setFont( f );
    QByteArray splitterData = settings.value("mainSplitter").toByteArray();
    splitter->restoreState(splitterData);
    projectWizardPos  = settings.value("projectWizardPos",QPoint(100, 100)).toPoint();
    projectWizardSize = settings.value("projectWizardSize",QSize(500, 400)).toSize();

    openDataDirectory = settings.value("openDataDirectory",userHomePath()).toString();
    openDbaseDirectory = settings.value("openDbaseDirectory",userHomePath()).toString();

    saveUserProjectDirectory = settings.value("saveUserProjectDirectory",userHomePath()).toString();
    openUserProjectDirectory = settings.value("openUserProjectDirectory",userHomePath()).toString();


    openDataDirectory = QDir::toNativeSeparators(openDataDirectory);
    openDbaseDirectory = QDir::toNativeSeparators(openDbaseDirectory);
    saveUserProjectDirectory = QDir::toNativeSeparators(saveUserProjectDirectory);
    openUserProjectDirectory = QDir::toNativeSeparators(openUserProjectDirectory);
}

void MainWindow::writeSettings() {
    QSettings settings ( "mitp.ru", "Seed to Dbase" );
    settings.setValue  ( "pos", pos() );
    settings.setValue  ( "size", size() );
    settings.setValue  ("fontPointSize", font().pointSize());
    settings.setValue  ("mainSplitter",splitter->saveState());
    settings.setValue  ("projectWizardPos",projectWizardPos);
    settings.setValue  ("projectWizardSize",projectWizardSize);
    settings.setValue  ("openDataDirectory",openDataDirectory);
    settings.setValue  ("openDbaseDirectory",openDbaseDirectory);
    settings.setValue  ("saveUserProjectDirectory",saveUserProjectDirectory);
    settings.setValue  ("openUserProjectDirectory",openUserProjectDirectory);
}

bool MainWindow::maybeSave() {

    if (doc->isModified()) {
        int ret = QMessageBox::warning(this, mainWindowCaption(),
                                       "The project has been modified.\n"
                                       "Do you want to save your changes?",
                                       QMessageBox::Yes | QMessageBox::Default,
                                       QMessageBox::No,
                                       QMessageBox::Cancel | QMessageBox::Escape);
        if (ret == QMessageBox::Yes)
            return save();
        else if (ret == QMessageBox::Cancel)
            return false;
    }
    return true;
}


void MainWindow::setCurrentFile ( const QString &fileName ) {
    curFile = fileName;
    QString shownName;
    if ( curFile.isEmpty() ) {
        shownName = "untitled";
        setWindowTitle(tr("%1[*] - %2").arg(shownName).arg(mainWindowCaption()));
        return;
    }

    shownName = strippedName ( curFile );

    setWindowTitle ( tr ( "%1[*] - %2" ).arg ( shownName ).arg (mainWindowCaption()));


    QSettings settings("mitp.ru", "Seed to Dbase" );
    QStringList files = settings.value("recentFileList").toStringList();
    files.removeAll(fileName);
    files.prepend(fileName);
    while (files.size() > MaxRecentFiles)
        files.removeLast();

    settings.setValue("recentFileList", files);

    foreach (QWidget *widget, QApplication::topLevelWidgets()) {
        MainWindow *mainWin = qobject_cast<MainWindow *>(widget);
        if (mainWin)
            mainWin->updateRecentFileActions();
    }


}
void MainWindow::updateRecentFileActions() {
    QSettings settings("mitp.ru", "Seed to Dbase" );
    QStringList files = settings.value("recentFileList").toStringList();

    int numRecentFiles = qMin(files.size(), (int)MaxRecentFiles);

    for (int i = 0; i < numRecentFiles; ++i) {
        QString text = tr("&%1 %2").arg(i + 1).arg(strippedName(files[i]));
        recentFileActs[i]->setText(text);
        recentFileActs[i]->setData(files[i]);
        recentFileActs[i]->setVisible(true);
    }
    for (int j = numRecentFiles; j < MaxRecentFiles; ++j)
        recentFileActs[j]->setVisible(false);

    separatorAct->setVisible(numRecentFiles > 0);
}
QString MainWindow::strippedName ( const QString &fullFileName ) {
    return QFileInfo ( fullFileName ).fileName();
}

void MainWindow::SetErrLogFileToKonsole(QString & name) {
    konsole->SetErrLogFileToKonsole(name);
}

bool MainWindow::SetTreeView(const QString &tempCurFileName) {

    RepaintAllFrames();
    konsole->SetDateTimeKonsole();
    QApplication::setOverrideCursor(Qt::WaitCursor);
    removeWorkingMaterials(tempDirectoryPath,false);
    QString ahDirectory = tempDirectoryPath + "/wfAh";
    if (doc->GetInputDataType()->GetValue() == "0") {
        if (!konsole->SeedToAh(doc)) {
            QApplication::restoreOverrideCursor();
            return false;
        }

    } else {
        ahDirectory = doc->GetDataDirectoryName()->GetValue();

        /*
                if (!konsole->AhCopyToTempDirectory(doc)) {
                    QApplication::restoreOverrideCursor();
                    return false;
                }
        */
    }

    if  (fmtAh4Db !=0) delete fmtAh4Db;
    fmtAh4Db = new  Ah4DbCmdWindow(doc);
    char *OutErr = new char[2000];
    if (fmtAh4Db->GetListOfAhRecords(ahDirectory.toAscii().data(),OutErr)) {

        QApplication::restoreOverrideCursor();
        QMessageBox::warning ( 0, "Create station info structure" ,
                               OutErr);

        return false;
    }
    QString rootBinDirectory = rootPath() + "/bin";
    rootBinDirectory = QDir::toNativeSeparators(rootBinDirectory);

    if (!QDir::setCurrent(rootBinDirectory)) {
        QMessageBox::warning ( 0, "Create station info structure" ,
                               tr("Can't change current working directory to path:\n   %1").arg(rootBinDirectory));

        QApplication::restoreOverrideCursor();

        return false;
    }
    staTree->SetStationTree(fmtAh4Db,tempCurFileName);

    QApplication::restoreOverrideCursor();

    return true;
}

void MainWindow::run() {

    QString dbaseDirectoryName = doc->GetDbaseDirectoryName()->GetValue();
    int ret = isOutputDbaseDirectoryEmpty(dbaseDirectoryName);
//  
   if (ret == 2 ) return; ///  won't remove dbaseDirectoryName's entries


    if (ret == 3 ) return; ///  can't change directory to dbaseDirectoryName


    if (!staTree->CheckStationTree()) {

        return;
    }

    QApplication::setOverrideCursor(Qt::WaitCursor);

    if (!konsole->MakeOriginTable(doc,fmtAh4Db)) {
        QApplication::restoreOverrideCursor();

        return ;
    }


    QStringList fmt2dbScriptlist;
    staTree->SetMarkStationForDbase(doc,fmt2dbScriptlist);

    if (!konsole->MakeDbaseFromAhFiles(doc,fmt2dbScriptlist)) {
        QApplication::restoreOverrideCursor();

        return ;
    }

    if (doc->GetOutputDeltaTime()->GetValue() == "1") {
        QApplication::restoreOverrideCursor();
        return ;
    }

    if (!konsole->DecimateDbase(doc,fmtAh4Db)) {
        QApplication::restoreOverrideCursor();
        return ;
    }

    QString rootBinDirectory = rootPath() + "/bin";
    rootBinDirectory = QDir::toNativeSeparators(rootBinDirectory);
    if (!QDir::setCurrent(rootBinDirectory)) {
        QMessageBox::warning ( 0, "Data base creation" ,
                               tr("Can't change current working directory to path:\n   %1").arg(rootBinDirectory));

        QApplication::restoreOverrideCursor();

        return;
    }
//    progress->cancel ();
    QApplication::restoreOverrideCursor();

}

