#ifndef MAINWINDOW_H
#define MAINWINDOW_H
#include <QMainWindow>
#include <QDir>
#include <QStringList>
class QAction;
class QMenu;
class QTextEdit;
class QSplitter;
class QTreeView;
class QProgressDialog;
class QTimer;
class ProfileTreeView;
class FDocument;
class AppKonsole;
class Ah4DbCmdWindow;
class HelpWindow;
class MainWindow : public QMainWindow {
    Q_OBJECT

public:
    MainWindow();
    ~MainWindow();
    FDocument* &GetDocument() {
        return doc;
    }
    AppKonsole * GetKonsole() {
        return konsole;
    }
    static MainWindow *self;
    void removeWorkingMaterials(QString & temporaryDirectory,bool removeTempDirectory = true);
    QString strippedName ( const QString &fullFileName );
    void SetErrLogFileToKonsole(QString & name);
    bool SetTreeView(const QString &tempCurFileName);
    QDir homeDirectory;
    QDir tempDirectory;
    QString    tempDirectoryPath;
    QString &GetCurFile() {
        return curFile;
    }
    QPoint projectWizardPos;
    QSize  projectWizardSize;
    QString openDataDirectory;
    QString openDbaseDirectory;
    QString saveUserProjectDirectory,openUserProjectDirectory;
    QString projectFileFilters;
    QString protocolFileFilters;
    QMenu *GetFileMenu () {
        return fileMenu;
    }
    void RepaintAllFrames();
    QAction *infoAct;
protected:
    void closeEvent ( QCloseEvent *event );
private slots:
    void newFile();
    void open();
    void edit();
    void run();
    bool save();
    bool saveAs();
    void zoomin();
    void zoomout();
    void info();
    void mainHelp();
    void about();
    void onWhatsThis();
    void documentWasModified();
    void setDocumentModified ();
    void openRecentFile();
private:
    QProgressDialog* progress;
    int numMaxProgress;
    int numCurProgress;
    FDocument* doc;
    Ah4DbCmdWindow* fmtAh4Db;
    QSplitter* splitter;
    QString  homeDirectoryPath;
    void createActions();
    void createMenus();
    void createToolBars();
    void createStatusBar();
    void readSettings();
    void writeSettings();
    bool maybeSave();
    bool loadFile ( const QString &fileName );
    bool saveFile ( const QString &fileName );
    void FileActsShowHide(bool b);
    void setCurrentFile ( const QString &fileName );
    void MakeTempDirectory();
    void createWhatsThis();
    bool AreDirectoriesExist(const QString &fileName);
    AppKonsole *konsole;
    ProfileTreeView* staTree;
    QList<QAction *> showHideFileActs;
    void updateRecentFileActions();
    QString curFile;
    QMenu *fileMenu;
    QMenu *viewMenu;
    QMenu *helpMenu;
    QToolBar *fileToolBar;
    QToolBar *editToolBar;
    QAction *newAct;
    QAction *openAct;
    QAction *editAct;
    QAction *runAct;
    QAction *saveAct;
    QAction *saveAsAct;
    QAction *exitAct;

    QAction *zoominAct;
    QAction *zoomoutAct;

    QAction *contentAct;
    QAction *whatsThisAct;
    QAction *aboutAct;
    QAction *aboutQtAct;

    QAction *separatorAct;
    enum { MaxRecentFiles = 5 };
    QAction *recentFileActs[MaxRecentFiles];
    HelpWindow* help;
};

#endif
