//
// C++ Interface: projectwizard
//
// Description:
//
//
// Author: fmt <fmt@localhost.localdomain>, (C) 2008
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef PROJECT_WIZARD_H
#define PROJECT_WIZARD_H
#include <QWizard>
#include "ui_database.h"
#include "ui_directoriesbase.h"
#include "ui_originbase.h"
#include "ui_hypobase.h"
class WizardPage;
class LineDocProperty;
class PropertyValue;
class DataPage;
class DataPageImpl;
class DirectoriesPage;
class DirectoriesImpl;
class OriginPage;
class OriginPageImpl;
class HypoPage;
class HypoPageImpl;
class FDocument;
bool hasInputFiles(QString dir,bool isSeedFiles);
int isOutputDbaseDirectoryEmpty(QString dir);
class ProWizard : public QWizard {
    Q_OBJECT

public:
    enum DocumentUsing {
        ProjectNew,
        ProjectEdit,
        ProjectRepair
    };
    ProWizard(QWidget *parent,FDocument* doc,DocumentUsing documentUsing);
    ~ProWizard();
    static ProWizard *wizardSelf;
    DataPage* datPage;
    DirectoriesPage* dirPage;
    OriginPage* oriPage;
    HypoPage* hypoPage;
    DocumentUsing GetDocumentUsing() {
        return documentUsing;
    }
private slots:
    void finishButton();
private:
    FDocument* doc;
    DocumentUsing documentUsing;
};
class WizardPage : public QWizardPage
{
	
    Q_OBJECT

 public:
    WizardPage(QWidget * ){};
virtual     ~WizardPage(){}
virtual void FinishWizard() = 0;
private:
};
class DataPage : public WizardPage
{
    Q_OBJECT

public:
    DataPage(QWidget *parent,FDocument* doc,ProWizard::DocumentUsing documentUsing);
    DataPageImpl* dataPage;
    void FinishWizard();
    bool validatePage();

private:
};
class DataPageImpl : public QDialog, private Ui::DataPageBase
{
    Q_OBJECT

public:
    DataPageImpl(QWidget *parent,FDocument* doc);
    void FinishWizard();
    QLineEdit *GetLineEditSeedAhDirectory(){return lineEditSeedAhDirectory;}
    QRadioButton *GetSeedRadioButton(){return radioButtonSeed;}
    QRadioButton *GetRadioButtonOrigin(){return radioButtonOrigin;}


    
    QString inputDataDirectoryName;
private slots:
    void browse();
    void rdButtonDecim(bool);
    void rdButtonOrigin(bool);
private:
    FDocument* doc;
    void InitDialog();
    void SetDocumentToDialog();
    void GetDocumentFromDialog();
    QList<PropertyValue* > values;
};
///=====================================================================
class DirectoriesPage : public WizardPage
{
    Q_OBJECT

public:
    DirectoriesPage(QWidget *parent,FDocument* doc,ProWizard::DocumentUsing documentUsing);
    DirectoriesImpl* directoriesPage;
    void FinishWizard();
    bool validatePage();
    void cleanupPage ();

private:
};

class DirectoriesImpl : public QDialog, private Ui::DirectoriesPageBase
{
    Q_OBJECT

public:
    DirectoriesImpl(QWidget *parent,FDocument* doc);
    QLineEdit *GetLineEditDbaseName(){return lineEditDbaseName;}
    QLineEdit *GetLineEditDbaseDirectory(){return lineEditDbaseDirectory;}
    void FinishWizard();
    QString DbaseDirectoryName;
private slots:
    void browse();
private:
    FDocument* doc;	
    void InitDialog();
    void SetDocumentToDialog();
    void GetDocumentFromDialog();
    QList<PropertyValue* > values;
    QList<LineDocProperty* > propDocLine;
};
///=====================================================================
class OriginPage : public WizardPage
{
    Q_OBJECT

public:
    OriginPage(QWidget *parent,FDocument* doc,ProWizard::DocumentUsing documentUsing);
    OriginPageImpl* originPage;
    void FinishWizard();

private:
};
class OriginPageImpl : public QDialog, private Ui::OriginPageBase
{
    Q_OBJECT

public:
    OriginPageImpl(QWidget *parent,FDocument* doc);
    void FinishWizard();
    QSpinBox  *GetSpinBoxYear()     {return spinBoxYear;}
    QSpinBox  *GetSpinBoxMonth()    {return spinBoxMonth;}
    QSpinBox  *GetSpinBoxDay()      {return spinBoxDay;}
    QSpinBox  *GetSpinBoxHour()     {return spinBoxHour;}
    QSpinBox  *GetSpinBoxMin()      {return spinBoxMin;}
    QLineEdit *GetLineEditSecond()  {return lineEditSecond;}
    QSpinBox  *GetSpinBoxDuration() {return spinBoxDuration;}
private:
    FDocument* doc;	
    void InitDialog();
    void SetDocumentToDialog();
    void GetDocumentFromDialog();
    QList<PropertyValue* > values;
    QList<LineDocProperty* > propDocLine;
};
///=====================================================================
class HypoPage : public WizardPage
{
    Q_OBJECT

public:
    HypoPage(QWidget *parent,FDocument* doc,ProWizard::DocumentUsing documentUsing);
    HypoPageImpl* hypoPage;
    void FinishWizard();

private:
};
class HypoPageImpl : public QDialog, private Ui::HypoPageBase
{
    Q_OBJECT

public:
    HypoPageImpl(QWidget *parent,FDocument* doc);
    void FinishWizard();
private:
    FDocument* doc;	
    void InitDialog();
    void SetDocumentToDialog();
    void GetDocumentFromDialog();
    QList<PropertyValue* > values;
    QList<LineDocProperty* > propDocLine;
};
#endif
