	subroutine decfactor(sratein,srateout,idecseq,nseq)

c		outputs a recommended decimation sequence in
c		array idecseq to come as close as possible to
c		the desired output sampling rate from the input
c		sampling rate.
c		note: assumes sratein>srateout, if not it complains
c		and returns nseq = 0.
c		
c			sratein -- input sampling rate (e.g. 20 sps)
c			srateout -- output sampling rate (e.g. 1 sps)
c			idecseq -- array of length nseq containing the
c				sequence of decimations.
c				e.g. 20 --> 1; sequence would be 5, 4.
c			nseq -- number of decimations needed to go from
c				sratein sps to srateout sps
c				e.g. 20 --> 1; nseq = 2
	real sratein, srateout
	integer idecseq, nseq
	dimension idecseq(*)
C      eps introduced by Levshin to escape bad round-up
	data eps/0.001/
C--------------------------------------------------------
	nseq=0

	if(sratein.le.srateout) then
	 print *,'ERROR: your input sampling rate > ouput rate'
	 print *,'Do not call decfactor if this is the case'
	 print *,'Catch this problem in your code!!!'
	 return
	endif

	ifail=0

C      eps introduced by Levshin to escape bad round-up
	idecfac = int(sratein/srateout+eps)
C--------------------------------------------------------
	idectmp=idecfac

 1	ifac=idectmp
c	 print *,ifac

c			divide by two's
	 call factor(ifac,2,ntwo)
c			divide by five's
	 call factor(ifac,5,nfive)
c			combine 2's into 4's
	 nfac=2**(ntwo)
	 callfactor(nfac,4,nfour)
	 ntwo=0
	 if(nfac.eq.2) ntwo=1

c		test to see if successfully factored
c			if not try again: first increment down, then up
	 if(ifac.ne.1) then
c		 		failure
	  ifail=ifail+1
	  if(mod(ifail,2).ne.0) then
c				increment idecfac down 
	   idectmp=idecfac-(ifail+1)/2
	  else
c				increment idecfac up
	   idectmp=idecfac+(ifail/2)
	  endif
	  goto 1
	 endif

c		success: store decimation sequency for output
	k=0
	do i=1,nfive
	 k=k+1
	 idecseq(k)=5
	enddo
	do i=1,nfour
	 k=k+1
	 idecseq(k)=4
	enddo
	do i=1,ntwo
	 k=k+1
	 idecseq(k)=2
	enddo
	nseq=k

	return
	end


	subroutine factor(ifac,n,nfac)
c		factors the number ifac as far as possible by
c		the factor n.
c		ifac - input number to factor; modified on output
c		n - number to factor by
c		nfac - number of times factored by n
c		
	nfac=0
 1 	 continue
	 if(mod(ifac,n).eq.0) then
	  nfac=nfac+1
	  ifac=ifac/n
	 else
	  return
	 endif
	 goto 1
	end
