C       Extracts a set of waveforms for  given stations, given  channels
c               and  given zooming times from initial database to 
c               a new database, and creates a new wfdisc file.
c
c		Order of Execution:
c		  (1) subroutine 'readall' reads a complete wfdisc file 
c		    into common block all,
c		  (2) loops back over the rows of the wfdisc, outputting
c		    a new wfdisc with selected data, and
c		  (3) reads in waveform and outputs the waveform data 
c	
c Usage: dbextract dbin dbout dirout [-s stnam1 ...stnam?] [-c chan1...chan?]
c		 [-t timein timend] 
c			where
c		 dbin = input data base name 
c		    (e.g. /install_dir/NRDC/data/proc/1987078/1987078)	
c		 dbout = output data base name (user's choice)
c		 dirout = output directory for waveforms
c		    (note: directory must exist before program is
c		    run, unless dirout is . on the command line)
c                stnam1, stnam2, etc = station codes
c                chan1, chan2, etc = channel type codes
c                timein,timend are zooming times as a string 
c                year day hour min sec   e.g.: 
c dbextract 1987078 temp . -s ARU OBN GAR  -c LHZ -t 1989 171 11 30 0.0 1989 171 14 35 0.0
c                                        
c               Any option may be absent ; then it will be taken as in source
c               data base; order of options is not important
C-ATTENTION!---Output start and end times may be slightly different from
C--------------requested ones due to properties of getwf subroutine! 


c Copyright (c) 1993-1996 University of Colorado 
c All rights reserved 


c Copyright (c) 1993-1996 University of Colorado 
c All rights reserved 


      integer dbINVALID
      parameter (dbINVALID = -102)
      integer dbCOUNT
      parameter (dbCOUNT = -301)
      integer dbDATABASE_COUNT
      parameter (dbDATABASE_COUNT = -302	       )
      integer dbTABLE_COUNT
      parameter (dbTABLE_COUNT = -303	      )
      integer dbFIELD_COUNT
      parameter (dbFIELD_COUNT = -304	       )
      integer dbRECORD_COUNT
      parameter (dbRECORD_COUNT = -305	      )
      integer dbDESCRIPTION
      parameter (dbDESCRIPTION = -306)
      integer dbSCHEMA_DESCRIPTION
      parameter (dbSCHEMA_DESCRIPTION = -307    )
      integer dbDATABASE_DESCRIPTION
      parameter (dbDATABASE_DESCRIPTION = -308 )
      integer dbTABLE_DESCRIPTION
      parameter (dbTABLE_DESCRIPTION = -309   )
      integer dbFIELD_DESCRIPTION
      parameter (dbFIELD_DESCRIPTION = -310  )
      integer dbDETAIL
      parameter (dbDETAIL = -311)
      integer dbSCHEMA_DETAIL
      parameter (dbSCHEMA_DETAIL = -312	       )
      integer dbDATABASE_DETAIL
      parameter (dbDATABASE_DETAIL = -313	      )
      integer dbTABLE_DETAIL
      parameter (dbTABLE_DETAIL = -314	     )
      integer dbFIELD_DETAIL
      parameter (dbFIELD_DETAIL = -315	    )
      integer dbNAME
      parameter (dbNAME = -316)
      integer dbSCHEMA_NAME
      parameter (dbSCHEMA_NAME = -317	       )
      integer dbDATABASE_NAME
      parameter (dbDATABASE_NAME = -318	      )
      integer dbTABLE_NAME
      parameter (dbTABLE_NAME = -319	     )
      integer dbFIELD_NAME
      parameter (dbFIELD_NAME = -320	    )
      integer dbTABLE_PRESENT
      parameter (dbTABLE_PRESENT = -321)
      integer dbSIZE
      parameter (dbSIZE = -322)
      integer dbTABLE_SIZE
      parameter (dbTABLE_SIZE = -323	   )
      integer dbFIELD_SIZE
      parameter (dbFIELD_SIZE = -324	  )
      integer dbFIELD_TYPE
      parameter (dbFIELD_TYPE = -328	  )
      integer dbTABLE_FILENAME
      parameter (dbTABLE_FILENAME = -329)
      integer dbDBPATH
      parameter (dbDBPATH = -330)
      integer dbTABLE_DIRNAME
      parameter (dbTABLE_DIRNAME = -331)
      integer dbPRIMARY_KEY
      parameter (dbPRIMARY_KEY = -332)
      integer dbALTERNATE_KEY
      parameter (dbALTERNATE_KEY = -333)
      integer dbFOREIGN_KEYS
      parameter (dbFOREIGN_KEYS = -334)
      integer dbUNIQUE_ID
      parameter (dbUNIQUE_ID = -335)
      integer dbUNIQUE_ID_NAME
      parameter (dbUNIQUE_ID_NAME = -336)
      integer dbSINGLE
      parameter (dbSINGLE = -337)
      integer dbSCHEMA_DEFAULT
      parameter (dbSCHEMA_DEFAULT = -338)
      integer dbDBPATH_DEFAULT
      parameter (dbDBPATH_DEFAULT = -339)
      integer dbLOAD_DATE
      parameter (dbLOAD_DATE = -340)
      integer dbTYPE
      parameter (dbTYPE = -325)
      integer dbFORMAT
      parameter (dbFORMAT = -326)
      integer dbUNITS
      parameter (dbUNITS = -327)
      integer dbDATABASE
      parameter (dbDATABASE = -401)
      integer dbVIEW
      parameter (dbVIEW = -402)
      integer dbTABLE
      parameter (dbTABLE = -403)
      integer dbFIELD
      parameter (dbFIELD = -404)
      integer dbRECORD
      parameter (dbRECORD = -405)
      integer dbMERGE
      parameter (dbMERGE = -406)
      integer dbALL
      parameter (dbALL = -501)
      integer dbPRIMARY
      parameter (dbPRIMARY = -502)
      integer dbALTERNATE
      parameter (dbALTERNATE = -503)
      integer dbSCRATCH
      parameter (dbSCRATCH = -504)
      integer dbNULL
      parameter (dbNULL = -505)
      integer dbBOOLEAN
      parameter (dbBOOLEAN = 1)
      integer dbINTEGER
      parameter (dbINTEGER = 2)
      integer dbREAL
      parameter (dbREAL = 3)
      integer dbTIME
      parameter (dbTIME = 4)
      integer dbYEARDAY
      parameter (dbYEARDAY = 5)
      integer dbSTRING
      parameter (dbSTRING = 6)
      integer dbDATE
      parameter (dbDATE = 7)
      integer dbWAVEFORM
      parameter (dbWAVEFORM = 136)
      integer dbRESPONSE
      parameter (dbRESPONSE = 137)
      integer dbBFLOAT
      parameter (dbBFLOAT = 138)
      integer dbBDOUBLE
      parameter (dbBDOUBLE = 139)
      integer dbBSHORT
      parameter (dbBSHORT = 140)
      integer dbBINT
      parameter (dbBINT = 141)
      integer dbDBPTR
      parameter (dbDBPTR = 142)
      integer dbUNIQUE
      parameter (dbUNIQUE = 1)
      integer dbOUTER_JOIN
      parameter (dbOUTER_JOIN = 2)
      integer dbadd
      integer dbaddnull
      integer dbadd_remark
      integer dbaddv
      integer dbcompile
      integer dbcreate
      integer dbcrunch
      integer dbdelete
      integer dbdestroy
      integer dbex_compile
      integer dbex_eval
      integer dbex_free
      integer dbextfile
      integer dbfilename
      integer dbfind_join_keys
      integer dbget
      integer dbget_remark
      integer dbgetv
      integer dbis_expression
      integer dbmark
      integer dbnextid
      integer dbopen
      integer dbopen_database
      integer dbopen_table
      integer dbput
      integer dbputv
      integer dbputx
      integer dbread_view
      integer dbsave_view
      integer dbset
      integer dbtruncate
      integer dbunjoin
      integer dbwrite_view
      character *(*) ATTRID_ADATE
      character *(*) ATTRID_ALGID
      character *(*) ATTRID_ALGORITHM
      character *(*) ATTRID_AMP
      character *(*) ATTRID_ARID
      character *(*) ATTRID_ARRAY
      character *(*) ATTRID_ATTRIB
      character *(*) ATTRID_ATYPE
      character *(*) ATTRID_AUTH
      character *(*) ATTRID_AZDEF
      character *(*) ATTRID_AZIMUTH
      character *(*) ATTRID_AZRES
      character *(*) ATTRID_BAND
      character *(*) ATTRID_BANDW
      character *(*) ATTRID_BAZIM
      character *(*) ATTRID_BEAMID
      character *(*) ATTRID_BELIEF
      character *(*) ATTRID_BESTDC
      character *(*) ATTRID_BLKFAC
      character *(*) ATTRID_BMTYP
      character *(*) ATTRID_BSLOW
      character *(*) ATTRID_CALIB
      character *(*) ATTRID_CALPER
      character *(*) ATTRID_CALRATIO
      character *(*) ATTRID_CDATE
      character *(*) ATTRID_CDPERR
      character *(*) ATTRID_CFREQ
      character *(*) ATTRID_CHAN
      character *(*) ATTRID_CHANA
      character *(*) ATTRID_CHANID
      character *(*) ATTRID_CHANO
      character *(*) ATTRID_CHID
      character *(*) ATTRID_CLAERR
      character *(*) ATTRID_CLIP
      character *(*) ATTRID_CLOERR
      character *(*) ATTRID_CMPX
      character *(*) ATTRID_CODA
      character *(*) ATTRID_CODDES
      character *(*) ATTRID_CODE
      character *(*) ATTRID_COLDEP
      character *(*) ATTRID_COLDIA
      character *(*) ATTRID_COLINT
      character *(*) ATTRID_COLVOL
      character *(*) ATTRID_COMM
      character *(*) ATTRID_COMMID
      character *(*) ATTRID_COMPA
      character *(*) ATTRID_CONF
      character *(*) ATTRID_COTERR
      character *(*) ATTRID_CTYPE
      character *(*) ATTRID_CUREV
      character *(*) ATTRID_CUROR
      character *(*) ATTRID_DATATYPE
      character *(*) ATTRID_DATE
      character *(*) ATTRID_DATSW
      character *(*) ATTRID_DATTYP
      character *(*) ATTRID_DAY
      character *(*) ATTRID_DEAST
      character *(*) ATTRID_DELAZ
      character *(*) ATTRID_DELSLO
      character *(*) ATTRID_DELTA
      character *(*) ATTRID_DELTIM
      character *(*) ATTRID_DEPDP
      character *(*) ATTRID_DEPTH
      character *(*) ATTRID_DESCR
      character *(*) ATTRID_DESCRIP
      character *(*) ATTRID_DFILE
      character *(*) ATTRID_DIG
      character *(*) ATTRID_DIGITAL
      character *(*) ATTRID_DIP1
      character *(*) ATTRID_DIP2
      character *(*) ATTRID_DIR
      character *(*) ATTRID_DIST
      character *(*) ATTRID_DLID
      character *(*) ATTRID_DNORTH
      character *(*) ATTRID_DOY
      character *(*) ATTRID_DTYPE
      character *(*) ATTRID_DURAT
      character *(*) ATTRID_DUSED
      character *(*) ATTRID_EDATE
      character *(*) ATTRID_EDEPTH
      character *(*) ATTRID_ELEV
      character *(*) ATTRID_EMA
      character *(*) ATTRID_EMARES
      character *(*) ATTRID_ENDTIME
      character *(*) ATTRID_ESAZ
      character *(*) ATTRID_ETYPE
      character *(*) ATTRID_EVID
      character *(*) ATTRID_EVNAME
      character *(*) ATTRID_EXLAT
      character *(*) ATTRID_EXLON
      character *(*) ATTRID_EXPTYP
      character *(*) ATTRID_FILE
      character *(*) ATTRID_FILES
      character *(*) ATTRID_FILTID
      character *(*) ATTRID_FILTYP
      character *(*) ATTRID_FKID
      character *(*) ATTRID_FKQUAL
      character *(*) ATTRID_FKRID
      character *(*) ATTRID_FKTYP
      character *(*) ATTRID_FM
      character *(*) ATTRID_FNORM
      character *(*) ATTRID_FOFF
      character *(*) ATTRID_FSID
      character *(*) ATTRID_FSRID
      character *(*) ATTRID_FSTAT
      character *(*) ATTRID_FSTYP
      character *(*) ATTRID_FTID
      character *(*) ATTRID_GNORM
      character *(*) ATTRID_GRN
      character *(*) ATTRID_GRNAME
      character *(*) ATTRID_HANG
      character *(*) ATTRID_HICUT
      character *(*) ATTRID_HSLOPE
      character *(*) ATTRID_IDTYPE
      character *(*) ATTRID_IDVALUE
      character *(*) ATTRID_IMB
      character *(*) ATTRID_IML
      character *(*) ATTRID_IMS
      character *(*) ATTRID_INID
      character *(*) ATTRID_INSNAME
      character *(*) ATTRID_INSTANT
      character *(*) ATTRID_INSTYP
      character *(*) ATTRID_INSTYPE
      character *(*) ATTRID_INTSCL
      character *(*) ATTRID_IPHASE
      character *(*) ATTRID_JDATE
      character *(*) ATTRID_LAT
      character *(*) ATTRID_LDATE
      character *(*) ATTRID_LDDATE
      character *(*) ATTRID_LEAP
      character *(*) ATTRID_LINENO
      character *(*) ATTRID_LOCATION
      character *(*) ATTRID_LOCUT
      character *(*) ATTRID_LOGAT
      character *(*) ATTRID_LON
      character *(*) ATTRID_LSLOPE
      character *(*) ATTRID_LTYPE
      character *(*) ATTRID_MAG
      character *(*) ATTRID_MAGB
      character *(*) ATTRID_MAGID
      character *(*) ATTRID_MAGLR
      character *(*) ATTRID_MAGNITUDE
      character *(*) ATTRID_MAGSH
      character *(*) ATTRID_MAGTYPE
      character *(*) ATTRID_MAXBLK
      character *(*) ATTRID_MAXF
      character *(*) ATTRID_MAXINT
      character *(*) ATTRID_MAXKX
      character *(*) ATTRID_MAXKY
      character *(*) ATTRID_MAXSX
      character *(*) ATTRID_MAXSY
      character *(*) ATTRID_MB
      character *(*) ATTRID_MBID
      character *(*) ATTRID_MEDIUM
      character *(*) ATTRID_MEXPON
      character *(*) ATTRID_MFF
      character *(*) ATTRID_MFFERR
      character *(*) ATTRID_MINBLK
      character *(*) ATTRID_ML
      character *(*) ATTRID_MLID
      character *(*) ATTRID_MNAME
      character *(*) ATTRID_MO
      character *(*) ATTRID_MOAUTH
      character *(*) ATTRID_MOIST
      character *(*) ATTRID_MON
      character *(*) ATTRID_MRF
      character *(*) ATTRID_MRFERR
      character *(*) ATTRID_MRR
      character *(*) ATTRID_MRRERR
      character *(*) ATTRID_MRT
      character *(*) ATTRID_MRTERR
      character *(*) ATTRID_MS
      character *(*) ATTRID_MSID
      character *(*) ATTRID_MTF
      character *(*) ATTRID_MTFERR
      character *(*) ATTRID_MTT
      character *(*) ATTRID_MTTERR
      character *(*) ATTRID_NAME
      character *(*) ATTRID_NASS
      character *(*) ATTRID_NAXAZM
      character *(*) ATTRID_NAXPLG
      character *(*) ATTRID_NAXVAL
      character *(*) ATTRID_NBYTE
      character *(*) ATTRID_NCALIB
      character *(*) ATTRID_NCALPER
      character *(*) ATTRID_NDEF
      character *(*) ATTRID_NDLID
      character *(*) ATTRID_NDP
      character *(*) ATTRID_NET
      character *(*) ATTRID_NETNAME
      character *(*) ATTRID_NETTYPE
      character *(*) ATTRID_NETWRK
      character *(*) ATTRID_NF
      character *(*) ATTRID_NMB
      character *(*) ATTRID_NMO
      character *(*) ATTRID_NMS
      character *(*) ATTRID_NORID
      character *(*) ATTRID_NOWFT
      character *(*) ATTRID_NRLPB
      character *(*) ATTRID_NRMW
      character *(*) ATTRID_NSAMP
      character *(*) ATTRID_NSLPB
      character *(*) ATTRID_NSMW
      character *(*) ATTRID_NSTA
      character *(*) ATTRID_NX
      character *(*) ATTRID_NXALG
      character *(*) ATTRID_NXARID
      character *(*) ATTRID_NXCHID
      character *(*) ATTRID_NXCOMM
      character *(*) ATTRID_NXDLID
      character *(*) ATTRID_NXEVID
      character *(*) ATTRID_NXFILT
      character *(*) ATTRID_NXFK
      character *(*) ATTRID_NXFKR
      character *(*) ATTRID_NXFS
      character *(*) ATTRID_NXFSR
      character *(*) ATTRID_NXFTID
      character *(*) ATTRID_NXINID
      character *(*) ATTRID_NXORID
      character *(*) ATTRID_NXSENS
      character *(*) ATTRID_NXSITE
      character *(*) ATTRID_NXSPRO
      character *(*) ATTRID_NXWFID
      character *(*) ATTRID_NY
      character *(*) ATTRID_OFFDAT
      character *(*) ATTRID_OFFDATE
      character *(*) ATTRID_ONDATE
      character *(*) ATTRID_OPSW
      character *(*) ATTRID_OPTYP
      character *(*) ATTRID_ORID
      character *(*) ATTRID_PALDEP
      character *(*) ATTRID_PAXAZM
      character *(*) ATTRID_PAXPLG
      character *(*) ATTRID_PAXVAL
      character *(*) ATTRID_PCHID
      character *(*) ATTRID_PDLID
      character *(*) ATTRID_PER
      character *(*) ATTRID_PHASE
      character *(*) ATTRID_PLPREF
      character *(*) ATTRID_PNAME
      character *(*) ATTRID_PORID
      character *(*) ATTRID_PREFOR
      character *(*) ATTRID_PVALUE
      character *(*) ATTRID_QUAL
      character *(*) ATTRID_RECT
      character *(*) ATTRID_REELSZ
      character *(*) ATTRID_REFSTA
      character *(*) ATTRID_REGION
      character *(*) ATTRID_REL
      character *(*) ATTRID_REMARK
      character *(*) ATTRID_RESID
      character *(*) ATTRID_RIPPLE
      character *(*) ATTRID_RSPTYP
      character *(*) ATTRID_RSPTYPE
      character *(*) ATTRID_SAMPRATE
      character *(*) ATTRID_SDDP
      character *(*) ATTRID_SDEPTH
      character *(*) ATTRID_SDMB
      character *(*) ATTRID_SDMO
      character *(*) ATTRID_SDMS
      character *(*) ATTRID_SDOBS
      character *(*) ATTRID_SDZDP
      character *(*) ATTRID_SEAZ
      character *(*) ATTRID_SEGTYP
      character *(*) ATTRID_SEGTYPE
      character *(*) ATTRID_SENSID
      character *(*) ATTRID_SITEID
      character *(*) ATTRID_SLIP1
      character *(*) ATTRID_SLIP2
      character *(*) ATTRID_SLODEF
      character *(*) ATTRID_SLORES
      character *(*) ATTRID_SLOW
      character *(*) ATTRID_SMAJAX
      character *(*) ATTRID_SMINAX
      character *(*) ATTRID_SMPRAT
      character *(*) ATTRID_SNAME
      character *(*) ATTRID_SNR
      character *(*) ATTRID_SPAUTH
      character *(*) ATTRID_SPMM
      character *(*) ATTRID_SPROID
      character *(*) ATTRID_SPRT
      character *(*) ATTRID_SPVT
      character *(*) ATTRID_SRN
      character *(*) ATTRID_SRNAME
      character *(*) ATTRID_STA
      character *(*) ATTRID_STAA
      character *(*) ATTRID_STANAM
      character *(*) ATTRID_STANAME
      character *(*) ATTRID_STAO
      character *(*) ATTRID_STASSID
      character *(*) ATTRID_STATYPE
      character *(*) ATTRID_STAV
      character *(*) ATTRID_STID
      character *(*) ATTRID_STIME
      character *(*) ATTRID_STR1
      character *(*) ATTRID_STR2
      character *(*) ATTRID_STRIKE
      character *(*) ATTRID_STRING
      character *(*) ATTRID_STT
      character *(*) ATTRID_STX
      character *(*) ATTRID_STY
      character *(*) ATTRID_STYPE
      character *(*) ATTRID_STZ
      character *(*) ATTRID_SXX
      character *(*) ATTRID_SXY
      character *(*) ATTRID_SXZ
      character *(*) ATTRID_SYY
      character *(*) ATTRID_SYZ
      character *(*) ATTRID_SZZ
      character *(*) ATTRID_TAGID
      character *(*) ATTRID_TAGNAME
      character *(*) ATTRID_TAPEBLOCK
      character *(*) ATTRID_TAPEFILE
      character *(*) ATTRID_TARNAM
      character *(*) ATTRID_TAXAZM
      character *(*) ATTRID_TAXPLG
      character *(*) ATTRID_TAXVAL
      character *(*) ATTRID_TCALIB
      character *(*) ATTRID_TDENSE
      character *(*) ATTRID_TEXT
      character *(*) ATTRID_TFILE
      character *(*) ATTRID_TIME
      character *(*) ATTRID_TIMEDEF
      character *(*) ATTRID_TIMERES
      character *(*) ATTRID_TLEN
      character *(*) ATTRID_TMFC
      character *(*) ATTRID_TMFI
      character *(*) ATTRID_TMNLPB
      character *(*) ATTRID_TMNMW
      character *(*) ATTRID_TPBLCK
      character *(*) ATTRID_TPFILE
      character *(*) ATTRID_TPTYPE
      character *(*) ATTRID_TRATBL
      character *(*) ATTRID_TSHIFT
      character *(*) ATTRID_TSITE
      character *(*) ATTRID_TUPID
      character *(*) ATTRID_UNCERTAINTY
      character *(*) ATTRID_USEDFT
      character *(*) ATTRID_VANG
      character *(*) ATTRID_VELID
      character *(*) ATTRID_VMODEL
      character *(*) ATTRID_VOLNAM
      character *(*) ATTRID_VOLNAME
      character *(*) ATTRID_WATDEP
      character *(*) ATTRID_WFID
      character *(*) ATTRID_WGT
      character *(*) ATTRID_YEAR
      character *(*) ATTRID_YIELD
      character *(*) ATTRID_YLDMAX
      character *(*) RELID_AFFILIATION
      character *(*) RELID_ALIAS
      character *(*) RELID_ARRIVAL
      character *(*) RELID_ASSOC
      character *(*) RELID_BEAM
      character *(*) RELID_CENTRYD
      character *(*) RELID_CHANNEL
      character *(*) RELID_CHOPER
      character *(*) RELID_CODE
      character *(*) RELID_COMMENT
      character *(*) RELID_COUNTER
      character *(*) RELID_DATE
      character *(*) RELID_DAY
      character *(*) RELID_DETECTION
      character *(*) RELID_DETLOC
      character *(*) RELID_EVENT
      character *(*) RELID_EVWF
      character *(*) RELID_EXPLO
      character *(*) RELID_EXTRA
      character *(*) RELID_FEATURE
      character *(*) RELID_FILTER
      character *(*) RELID_FKDISC
      character *(*) RELID_FKREC
      character *(*) RELID_FPLANE
      character *(*) RELID_FSDISC
      character *(*) RELID_FSREC
      character *(*) RELID_GREGION
      character *(*) RELID_INSTRUMENT
      character *(*) RELID_LASTID
      character *(*) RELID_LOC
      character *(*) RELID_MOMENT
      character *(*) RELID_NETMAG
      character *(*) RELID_NETWORK
      character *(*) RELID_ORIGERR
      character *(*) RELID_ORIGIN
      character *(*) RELID_REMARK
      character *(*) RELID_SENSOR
      character *(*) RELID_SIGPRO
      character *(*) RELID_SITE
      character *(*) RELID_SITECHAN
      character *(*) RELID_SREGION
      character *(*) RELID_STALOG
      character *(*) RELID_STAMAG
      character *(*) RELID_STASSOC
      character *(*) RELID_STATION
      character *(*) RELID_TAPE
      character *(*) RELID_WFDISC
      character *(*) RELID_WFTAG
      character *(*) RELID_WFTAPE
      character *(*) RELID_WFTAR
      character *(*) RELID_XPARAM
      integer DBL_ASCII
      integer DBL_BINARY
      integer DBL_DBL
      integer DBL_FLT
      integer DBL_INT
      integer DBL_STR
      integer NUMBER_RELS30
      integer NUMBER_ATTRS
      integer NUMBER_ATTRS30
      parameter (ATTRID_ADATE = "adate"		)
      parameter (ATTRID_ALGID = "algid"		)
      parameter (ATTRID_ALGORITHM = "algorithm"	)
      parameter (ATTRID_AMP = "amp"		)
      parameter (ATTRID_ARID = "arid"		)
      parameter (ATTRID_ARRAY = "array"		)
      parameter (ATTRID_ATTRIB = "attrib"	)
      parameter (ATTRID_ATYPE = "atype"		)
      parameter (ATTRID_AUTH = "auth"		)
      parameter (ATTRID_AZDEF = "azdef"		)
      parameter (ATTRID_AZIMUTH = "azimuth"	)
      parameter (ATTRID_AZRES = "azres"		)
      parameter (ATTRID_BAND = "band"		)
      parameter (ATTRID_BANDW = "bandw"		)
      parameter (ATTRID_BAZIM = "bazim"		)
      parameter (ATTRID_BEAMID = "beamid"	)
      parameter (ATTRID_BELIEF = "belief"	)
      parameter (ATTRID_BESTDC = "bestdc"	)
      parameter (ATTRID_BLKFAC = "blkfac"	)
      parameter (ATTRID_BMTYP = "bmtyp"		)
      parameter (ATTRID_BSLOW = "bslow"		)
      parameter (ATTRID_CALIB = "calib"		)
      parameter (ATTRID_CALPER = "calper"	)
      parameter (ATTRID_CALRATIO = "calratio"	)
      parameter (ATTRID_CDATE = "cdate"		)
      parameter (ATTRID_CDPERR = "cdperr"	)
      parameter (ATTRID_CFREQ = "cfreq"		)
      parameter (ATTRID_CHAN = "chan"		)
      parameter (ATTRID_CHANA = "chana"		)
      parameter (ATTRID_CHANID = "chanid"	)
      parameter (ATTRID_CHANO = "chano"		)
      parameter (ATTRID_CHID = "chid"		)
      parameter (ATTRID_CLAERR = "claerr"	)
      parameter (ATTRID_CLIP = "clip"		)
      parameter (ATTRID_CLOERR = "cloerr"	)
      parameter (ATTRID_CMPX = "cmpx"		)
      parameter (ATTRID_CODA = "coda"		)
      parameter (ATTRID_CODDES = "coddes"	)
      parameter (ATTRID_CODE = "code"		)
      parameter (ATTRID_COLDEP = "coldep"	)
      parameter (ATTRID_COLDIA = "coldia"	)
      parameter (ATTRID_COLINT = "colint"	)
      parameter (ATTRID_COLVOL = "colvol"	)
      parameter (ATTRID_COMM = "comm"		)
      parameter (ATTRID_COMMID = "commid"	)
      parameter (ATTRID_COMPA = "compa"		)
      parameter (ATTRID_CONF = "conf"		)
      parameter (ATTRID_COTERR = "coterr"	)
      parameter (ATTRID_CTYPE = "ctype"		)
      parameter (ATTRID_CUREV = "curev"		)
      parameter (ATTRID_CUROR = "curor"		)
      parameter (ATTRID_DATATYPE = "datatype"	)
      parameter (ATTRID_DATE = "date"		)
      parameter (ATTRID_DATSW = "datsw"		)
      parameter (ATTRID_DATTYP = "dattyp"	)
      parameter (ATTRID_DAY = "day"		)
      parameter (ATTRID_DEAST = "deast"		)
      parameter (ATTRID_DELAZ = "delaz"		)
      parameter (ATTRID_DELSLO = "delslo"	)
      parameter (ATTRID_DELTA = "delta"		)
      parameter (ATTRID_DELTIM = "deltim"	)
      parameter (ATTRID_DEPDP = "depdp"		)
      parameter (ATTRID_DEPTH = "depth"		)
      parameter (ATTRID_DESCR = "descr"		)
      parameter (ATTRID_DESCRIP = "descrip"	)
      parameter (ATTRID_DFILE = "dfile"		)
      parameter (ATTRID_DIG = "dig"		)
      parameter (ATTRID_DIGITAL = "digital"	)
      parameter (ATTRID_DIP1 = "dip1"		)
      parameter (ATTRID_DIP2 = "dip2"		)
      parameter (ATTRID_DIR = "dir"		)
      parameter (ATTRID_DIST = "dist"		)
      parameter (ATTRID_DLID = "dlid"		)
      parameter (ATTRID_DNORTH = "dnorth"	)
      parameter (ATTRID_DOY = "doy"		)
      parameter (ATTRID_DTYPE = "dtype"		)
      parameter (ATTRID_DURAT = "durat"		)
      parameter (ATTRID_DUSED = "dused"		)
      parameter (ATTRID_EDATE = "edate"		)
      parameter (ATTRID_EDEPTH = "edepth"	)
      parameter (ATTRID_ELEV = "elev"		)
      parameter (ATTRID_EMA = "ema"		)
      parameter (ATTRID_EMARES = "emares"	)
      parameter (ATTRID_ENDTIME = "endtime"	)
      parameter (ATTRID_ESAZ = "esaz"		)
      parameter (ATTRID_ETYPE = "etype"		)
      parameter (ATTRID_EVID = "evid"		)
      parameter (ATTRID_EVNAME = "evname"	)
      parameter (ATTRID_EXLAT = "exlat"		)
      parameter (ATTRID_EXLON = "exlon"		)
      parameter (ATTRID_EXPTYP = "exptyp"	)
      parameter (ATTRID_FILE = "file"		)
      parameter (ATTRID_FILES = "files"		)
      parameter (ATTRID_FILTID = "filtid"	)
      parameter (ATTRID_FILTYP = "filtyp"	)
      parameter (ATTRID_FKID = "fkid"		)
      parameter (ATTRID_FKQUAL = "fkqual"	)
      parameter (ATTRID_FKRID = "fkrid"		)
      parameter (ATTRID_FKTYP = "fktyp"		)
      parameter (ATTRID_FM = "fm"		)
      parameter (ATTRID_FNORM = "fnorm"		)
      parameter (ATTRID_FOFF = "foff"		)
      parameter (ATTRID_FSID = "fsid"		)
      parameter (ATTRID_FSRID = "fsrid"		)
      parameter (ATTRID_FSTAT = "fstat"		)
      parameter (ATTRID_FSTYP = "fstyp"		)
      parameter (ATTRID_FTID = "ftid"		)
      parameter (ATTRID_GNORM = "gnorm"		)
      parameter (ATTRID_GRN = "grn"		)
      parameter (ATTRID_GRNAME = "grname"	)
      parameter (ATTRID_HANG = "hang"		)
      parameter (ATTRID_HICUT = "hicut"		)
      parameter (ATTRID_HSLOPE = "hslope"	)
      parameter (ATTRID_IDTYPE = "idtype"	)
      parameter (ATTRID_IDVALUE = "idvalue"	)
      parameter (ATTRID_IMB = "imb"		)
      parameter (ATTRID_IML = "iml"		)
      parameter (ATTRID_IMS = "ims"		)
      parameter (ATTRID_INID = "inid"		)
      parameter (ATTRID_INSNAME = "insname"	)
      parameter (ATTRID_INSTANT = "instant"	)
      parameter (ATTRID_INSTYP = "instyp"	)
      parameter (ATTRID_INSTYPE = "instype"	)
      parameter (ATTRID_INTSCL = "intscl"	)
      parameter (ATTRID_IPHASE = "iphase"	)
      parameter (ATTRID_JDATE = "jdate"		)
      parameter (ATTRID_LAT = "lat"		)
      parameter (ATTRID_LDATE = "ldate"		)
      parameter (ATTRID_LDDATE = "lddate"	)
      parameter (ATTRID_LEAP = "leap"		)
      parameter (ATTRID_LINENO = "lineno"	)
      parameter (ATTRID_LOCATION = "location"	)
      parameter (ATTRID_LOCUT = "locut"		)
      parameter (ATTRID_LOGAT = "logat"		)
      parameter (ATTRID_LON = "lon"		)
      parameter (ATTRID_LSLOPE = "lslope"	)
      parameter (ATTRID_LTYPE = "ltype"		)
      parameter (ATTRID_MAG = "mag"		)
      parameter (ATTRID_MAGB = "magb"		)
      parameter (ATTRID_MAGID = "magid"		)
      parameter (ATTRID_MAGLR = "maglr"		)
      parameter (ATTRID_MAGNITUDE = "magnitude"	)
      parameter (ATTRID_MAGSH = "magsh"		)
      parameter (ATTRID_MAGTYPE = "magtype"	)
      parameter (ATTRID_MAXBLK = "maxblk"	)
      parameter (ATTRID_MAXF = "maxf"		)
      parameter (ATTRID_MAXINT = "maxint"	)
      parameter (ATTRID_MAXKX = "maxkx"		)
      parameter (ATTRID_MAXKY = "maxky"		)
      parameter (ATTRID_MAXSX = "maxsx"		)
      parameter (ATTRID_MAXSY = "maxsy"		)
      parameter (ATTRID_MB = "mb"		)
      parameter (ATTRID_MBID = "mbid"		)
      parameter (ATTRID_MEDIUM = "medium"	)
      parameter (ATTRID_MEXPON = "mexpon"	)
      parameter (ATTRID_MFF = "mff"		)
      parameter (ATTRID_MFFERR = "mfferr"	)
      parameter (ATTRID_MINBLK = "minblk"	)
      parameter (ATTRID_ML = "ml"		)
      parameter (ATTRID_MLID = "mlid"		)
      parameter (ATTRID_MNAME = "mname"		)
      parameter (ATTRID_MO = "mo"		)
      parameter (ATTRID_MOAUTH = "moauth"	)
      parameter (ATTRID_MOIST = "moist"		)
      parameter (ATTRID_MON = "mon"		)
      parameter (ATTRID_MRF = "mrf"		)
      parameter (ATTRID_MRFERR = "mrferr"	)
      parameter (ATTRID_MRR = "mrr"		)
      parameter (ATTRID_MRRERR = "mrrerr"	)
      parameter (ATTRID_MRT = "mrt"		)
      parameter (ATTRID_MRTERR = "mrterr"	)
      parameter (ATTRID_MS = "ms"		)
      parameter (ATTRID_MSID = "msid"		)
      parameter (ATTRID_MTF = "mtf"		)
      parameter (ATTRID_MTFERR = "mtferr"	)
      parameter (ATTRID_MTT = "mtt"		)
      parameter (ATTRID_MTTERR = "mtterr"	)
      parameter (ATTRID_NAME = "name"		)
      parameter (ATTRID_NASS = "nass"		)
      parameter (ATTRID_NAXAZM = "naxazm"	)
      parameter (ATTRID_NAXPLG = "naxplg"	)
      parameter (ATTRID_NAXVAL = "naxval"	)
      parameter (ATTRID_NBYTE = "nbyte"		)
      parameter (ATTRID_NCALIB = "ncalib"	)
      parameter (ATTRID_NCALPER = "ncalper"	)
      parameter (ATTRID_NDEF = "ndef"		)
      parameter (ATTRID_NDLID = "ndlid"		)
      parameter (ATTRID_NDP = "ndp"		)
      parameter (ATTRID_NET = "net"		)
      parameter (ATTRID_NETNAME = "netname"	)
      parameter (ATTRID_NETTYPE = "nettype"	)
      parameter (ATTRID_NETWRK = "netwrk"	)
      parameter (ATTRID_NF = "nf"		)
      parameter (ATTRID_NMB = "nmb"		)
      parameter (ATTRID_NMO = "nmo"		)
      parameter (ATTRID_NMS = "nms"		)
      parameter (ATTRID_NORID = "norid"		)
      parameter (ATTRID_NOWFT = "nowft"		)
      parameter (ATTRID_NRLPB = "nrlpb"		)
      parameter (ATTRID_NRMW = "nrmw"		)
      parameter (ATTRID_NSAMP = "nsamp"		)
      parameter (ATTRID_NSLPB = "nslpb"		)
      parameter (ATTRID_NSMW = "nsmw"		)
      parameter (ATTRID_NSTA = "nsta"		)
      parameter (ATTRID_NX = "nx"		)
      parameter (ATTRID_NXALG = "nxalg"		)
      parameter (ATTRID_NXARID = "nxarid"	)
      parameter (ATTRID_NXCHID = "nxchid"	)
      parameter (ATTRID_NXCOMM = "nxcomm"	)
      parameter (ATTRID_NXDLID = "nxdlid"	)
      parameter (ATTRID_NXEVID = "nxevid"	)
      parameter (ATTRID_NXFILT = "nxfilt"	)
      parameter (ATTRID_NXFK = "nxfk"		)
      parameter (ATTRID_NXFKR = "nxfkr"		)
      parameter (ATTRID_NXFS = "nxfs"		)
      parameter (ATTRID_NXFSR = "nxfsr"		)
      parameter (ATTRID_NXFTID = "nxftid"	)
      parameter (ATTRID_NXINID = "nxinid"	)
      parameter (ATTRID_NXORID = "nxorid"	)
      parameter (ATTRID_NXSENS = "nxsens"	)
      parameter (ATTRID_NXSITE = "nxsite"	)
      parameter (ATTRID_NXSPRO = "nxspro"	)
      parameter (ATTRID_NXWFID = "nxwfid"	)
      parameter (ATTRID_NY = "ny"		)
      parameter (ATTRID_OFFDAT = "offdat"	)
      parameter (ATTRID_OFFDATE = "offdate"	)
      parameter (ATTRID_ONDATE = "ondate"	)
      parameter (ATTRID_OPSW = "opsw"		)
      parameter (ATTRID_OPTYP = "optyp"		)
      parameter (ATTRID_ORID = "orid"		)
      parameter (ATTRID_PALDEP = "paldep"	)
      parameter (ATTRID_PAXAZM = "paxazm"	)
      parameter (ATTRID_PAXPLG = "paxplg"	)
      parameter (ATTRID_PAXVAL = "paxval"	)
      parameter (ATTRID_PCHID = "pchid"		)
      parameter (ATTRID_PDLID = "pdlid"		)
      parameter (ATTRID_PER = "per"		)
      parameter (ATTRID_PHASE = "phase"		)
      parameter (ATTRID_PLPREF = "plpref"	)
      parameter (ATTRID_PNAME = "pname"		)
      parameter (ATTRID_PORID = "porid"		)
      parameter (ATTRID_PREFOR = "prefor"	)
      parameter (ATTRID_PVALUE = "pvalue"	)
      parameter (ATTRID_QUAL = "qual"		)
      parameter (ATTRID_RECT = "rect"		)
      parameter (ATTRID_REELSZ = "reelsz"	)
      parameter (ATTRID_REFSTA = "refsta"	)
      parameter (ATTRID_REGION = "region"	)
      parameter (ATTRID_REL = "rel"		)
      parameter (ATTRID_REMARK = "remark"	)
      parameter (ATTRID_RESID = "resid"		)
      parameter (ATTRID_RIPPLE = "ripple"	)
      parameter (ATTRID_RSPTYP = "rsptyp"	)
      parameter (ATTRID_RSPTYPE = "rsptype"	)
      parameter (ATTRID_SAMPRATE = "samprate"	)
      parameter (ATTRID_SDDP = "sddp"		)
      parameter (ATTRID_SDEPTH = "sdepth"	)
      parameter (ATTRID_SDMB = "sdmb"		)
      parameter (ATTRID_SDMO = "sdmo"		)
      parameter (ATTRID_SDMS = "sdms"		)
      parameter (ATTRID_SDOBS = "sdobs"		)
      parameter (ATTRID_SDZDP = "sdzdp"		)
      parameter (ATTRID_SEAZ = "seaz"		)
      parameter (ATTRID_SEGTYP = "segtyp"	)
      parameter (ATTRID_SEGTYPE = "segtype"	)
      parameter (ATTRID_SENSID = "sensid"	)
      parameter (ATTRID_SITEID = "siteid"	)
      parameter (ATTRID_SLIP1 = "slip1"		)
      parameter (ATTRID_SLIP2 = "slip2"		)
      parameter (ATTRID_SLODEF = "slodef"	)
      parameter (ATTRID_SLORES = "slores"	)
      parameter (ATTRID_SLOW = "slow"		)
      parameter (ATTRID_SMAJAX = "smajax"	)
      parameter (ATTRID_SMINAX = "sminax"	)
      parameter (ATTRID_SMPRAT = "smprat"	)
      parameter (ATTRID_SNAME = "sname"		)
      parameter (ATTRID_SNR = "snr"		)
      parameter (ATTRID_SPAUTH = "spauth"	)
      parameter (ATTRID_SPMM = "spmm"		)
      parameter (ATTRID_SPROID = "sproid"	)
      parameter (ATTRID_SPRT = "sprt"		)
      parameter (ATTRID_SPVT = "spvt"		)
      parameter (ATTRID_SRN = "srn"		)
      parameter (ATTRID_SRNAME = "srname"	)
      parameter (ATTRID_STA = "sta"		)
      parameter (ATTRID_STAA = "staa"		)
      parameter (ATTRID_STANAM = "stanam"	)
      parameter (ATTRID_STANAME = "staname"	)
      parameter (ATTRID_STAO = "stao"		)
      parameter (ATTRID_STASSID = "stassid"	)
      parameter (ATTRID_STATYPE = "statype"	)
      parameter (ATTRID_STAV = "stav"		)
      parameter (ATTRID_STID = "stid"		)
      parameter (ATTRID_STIME = "stime"		)
      parameter (ATTRID_STR1 = "str1"		)
      parameter (ATTRID_STR2 = "str2"		)
      parameter (ATTRID_STRIKE = "strike"	)
      parameter (ATTRID_STRING = "string"	)
      parameter (ATTRID_STT = "stt"		)
      parameter (ATTRID_STX = "stx"		)
      parameter (ATTRID_STY = "sty"		)
      parameter (ATTRID_STYPE = "stype"		)
      parameter (ATTRID_STZ = "stz"		)
      parameter (ATTRID_SXX = "sxx"		)
      parameter (ATTRID_SXY = "sxy"		)
      parameter (ATTRID_SXZ = "sxz"		)
      parameter (ATTRID_SYY = "syy"		)
      parameter (ATTRID_SYZ = "syz"		)
      parameter (ATTRID_SZZ = "szz"		)
      parameter (ATTRID_TAGID = "tagid"		)
      parameter (ATTRID_TAGNAME = "tagname"	)
      parameter (ATTRID_TAPEBLOCK = "tapeblock"	)
      parameter (ATTRID_TAPEFILE = "tapefile"	)
      parameter (ATTRID_TARNAM = "tarnam"	)
      parameter (ATTRID_TAXAZM = "taxazm"	)
      parameter (ATTRID_TAXPLG = "taxplg"	)
      parameter (ATTRID_TAXVAL = "taxval"	)
      parameter (ATTRID_TCALIB = "tcalib"	)
      parameter (ATTRID_TDENSE = "tdense"	)
      parameter (ATTRID_TEXT = "text"		)
      parameter (ATTRID_TFILE = "tfile"		)
      parameter (ATTRID_TIME = "time"		)
      parameter (ATTRID_TIMEDEF = "timedef"	)
      parameter (ATTRID_TIMERES = "timeres"	)
      parameter (ATTRID_TLEN = "tlen"		)
      parameter (ATTRID_TMFC = "tmfc"		)
      parameter (ATTRID_TMFI = "tmfi"		)
      parameter (ATTRID_TMNLPB = "tmnlpb"	)
      parameter (ATTRID_TMNMW = "tmnmw"		)
      parameter (ATTRID_TPBLCK = "tpblck"	)
      parameter (ATTRID_TPFILE = "tpfile"	)
      parameter (ATTRID_TPTYPE = "tptype"	)
      parameter (ATTRID_TRATBL = "tratbl"	)
      parameter (ATTRID_TSHIFT = "tshift"	)
      parameter (ATTRID_TSITE = "tsite"		)
      parameter (ATTRID_TUPID = "tupid"		)
      parameter (ATTRID_UNCERTAINTY = "uncertainty"	)
      parameter (ATTRID_USEDFT = "usedft"	)
      parameter (ATTRID_VANG = "vang"		)
      parameter (ATTRID_VELID = "velid"		)
      parameter (ATTRID_VMODEL = "vmodel"	)
      parameter (ATTRID_VOLNAM = "volnam"	)
      parameter (ATTRID_VOLNAME = "volname"	)
      parameter (ATTRID_WATDEP = "watdep"	)
      parameter (ATTRID_WFID = "wfid"		)
      parameter (ATTRID_WGT = "wgt"		)
      parameter (ATTRID_YEAR = "year"		)
      parameter (ATTRID_YIELD = "yield"		)
      parameter (ATTRID_YLDMAX = "yldmax"	)
      parameter (DBL_ASCII = 0	)
      parameter (DBL_BINARY = 1	)
      parameter (DBL_DBL = 2	)
      parameter (DBL_FLT = 1	)
      parameter (DBL_INT = 0	)
      parameter (DBL_STR = 3	)
      parameter (NUMBER_ATTRS = 282		)
      parameter (NUMBER_ATTRS30 = 152		)
      parameter (NUMBER_RELS30 = 23	)
      parameter (RELID_AFFILIATION = "affiliation"	)
      parameter (RELID_ALIAS = "alias"	)
      parameter (RELID_ARRIVAL = "arrival"	)
      parameter (RELID_ASSOC = "assoc"	)
      parameter (RELID_BEAM = "beam"		)
      parameter (RELID_CENTRYD = "centryd"	)
      parameter (RELID_CHANNEL = "channel"	)
      parameter (RELID_CHOPER = "choper"	)
      parameter (RELID_CODE = "code"		)
      parameter (RELID_COMMENT = "comment"	)
      parameter (RELID_COUNTER = "counter"	)
      parameter (RELID_DATE = "date"		)
      parameter (RELID_DAY = "day"		)
      parameter (RELID_DETECTION = "detection"	)
      parameter (RELID_DETLOC = "detloc"	)
      parameter (RELID_EVENT = "event"	)
      parameter (RELID_EVWF = "evwf"		)
      parameter (RELID_EXPLO = "explo"		)
      parameter (RELID_EXTRA = "extra"		)
      parameter (RELID_FEATURE = "feature"	)
      parameter (RELID_FILTER = "filter"	)
      parameter (RELID_FKDISC = "fkdisc"	)
      parameter (RELID_FKREC = "fkrec"		)
      parameter (RELID_FPLANE = "fplane"	)
      parameter (RELID_FSDISC = "fsdisc"	)
      parameter (RELID_FSREC = "fsrec"		)
      parameter (RELID_GREGION = "gregion"	)
      parameter (RELID_INSTRUMENT = "instrument"	)
      parameter (RELID_LASTID = "lastid"	)
      parameter (RELID_LOC = "loc"		)
      parameter (RELID_MOMENT = "moment"	)
      parameter (RELID_NETMAG = "netmag"	)
      parameter (RELID_NETWORK = "network"	)
      parameter (RELID_ORIGERR = "origerr"	)
      parameter (RELID_ORIGIN = "origin"	)
      parameter (RELID_REMARK = "remark"	)
      parameter (RELID_SENSOR = "sensor"	)
      parameter (RELID_SIGPRO = "sigpro"	)
      parameter (RELID_SITE = "site"	)
      parameter (RELID_SITECHAN = "sitechan"	)
      parameter (RELID_SREGION = "sregion"	)
      parameter (RELID_STALOG = "stalog"	)
      parameter (RELID_STAMAG = "stamag"	)
      parameter (RELID_STASSOC = "stassoc"	)
      parameter (RELID_STATION = "station"	)
      parameter (RELID_TAPE = "tape"		)
      parameter (RELID_WFDISC = "wfdisc"	)
      parameter (RELID_WFTAG = "wftag"	)
      parameter (RELID_WFTAPE = "wftape"	)
      parameter (RELID_WFTAR = "wftar"	)
      parameter (RELID_XPARAM = "xparam"	)

c		nr = max number of rows in the wfdisc file
c		npts = max number of points in the waveform data
	parameter(nr=10000,npts=2000000)

c		the following declarations are for the wfdisc attributes
	character segtype,clip
	character*2 datatype
	character*6 sta,instype
	character*8 chan
	character*17 lddate
	character*32 dfile
	character*64 dir
	character*8 chaty(20)
	character*8 name(80)
	logical tf
	real*4 samprate,calib,calper
	integer wfid,chanid,jdate,nsamp,foff,commid

c		the following common block contains all the wfdisc
c		attributes
	common/all/sta(nr),chan(nr),time(nr),wfid(nr),chanid(nr),
     +   jdate(nr),endtime(nr),nsamp(nr),samprate(nr),calib(nr),
     +   calper(nr),instype(nr),segtype(nr),datatype(nr),clip(nr),
     +   dir(nr),dfile(nr),foff(nr),commid(nr),lddate(nr)

c		declarations for the time series
        real*8 tstart,dt,sec,tdif,tendnew
	real*8 time,endtime,timein,timend,timl,tin,tend,tiz,tez
        real*4 data(npts),DSE

c		declarations for input command line arguments
       	character*80 dbin,dbout
	character*64 dirout

c		other declarations
	character*2 dtype_out
	character*6 stnam(20)
c	character*8 chaty(20)
	character*60 namedir,namef
	integer foff_out
	data const/2000000000.0/

c		grab command line arguments
        narg=iargc()	
	if(narg.lt.4) then
	print *,  'USAGE: dbextract dbin dbout dirout' 
	print *, '[-s stnam1 ...stnam?] [-c chan1...chan?]'
	print *,' [-t styear stday sthour stmin stsec '
	print *,'     endyear endday endhour endmin endsec]'
	STOP
	endif
	call getarg(1,dbin)
	call getarg(2,dbout)
	call getarg(3,dirout)
	nn=narg-3
c most	print * , 'NUMBER OF ARGUMENTS=', nn
	do i=1,nn
	call getarg(i+3,name(i))
        end do

c       interpret comand line arguments
	call anarg(nn,name,stnam,nst,chaty,nch,it,timein,timend)
c most	print*,'NUMBER OF STATIONS=',nst,'    NUMBER OF CHANNELS',nch

c		create input (dbin) and output (dbout) databases
        call db30create (dbin,idbin)
        if (idbin.eq.0) then
	 print *, 'db30create error 1'
	 stop
        end if
	call db30create(dbout,idbout)
        if (idbout.eq.0) then
	 print *, 'db30create error 2'
	 stop
        end if

c		read in data base and store in common all.
	call dbgetntuples(idbin,RELID_WFDISC,ntuples)
	call readall(idbin,ntuples)
	print *,'number of rows in input wfdisc file:',ntuples

c       to initiate loops' parameters if necessary 
        iout=0
        ncha=nch
	nsta=nst
        if (ncha.eq.0) ncha=1
        if (nsta.eq.0) nsta=1
        foff_out=0
c       start selection of  desired tuples from wfdisc-file

C------------------------loop by tuples----------------------------------

	do 1 ituple=1,ntuples
c--------to check if data exist--------------------------------------
           namedir=dir(ituple)
	   lnd=lnblnk(namedir)
	   namef=dfile(ituple)
	   lnf=lnblnk(namef)
	INQUIRE (file=namedir(1:lnd)//'/'//namef(1:lnf),
     +    exist=tf)
	  if (.not.tf) then
        INQUIRE (file=namedir(1:lnd)//'/'//namef(1:lnf)//'.Z',
     +    exist=tf)
	  end if
	  if (.not.tf) then
	  print'((a),(a),(a))','no file ',dfile(ituple),'exists'
	  go to 1
	  end if
c		add a null row to the output wfdisc
c		note: itupleout is returned from dbaddtuple

c		write attributes from input wfdisc to output wfdisc,
c		note: if input data is a sac file, foff = 632 (sac hdr),
c		 so we set foff_out = 0 for output.

C--------------------loop by channels------------------------------- 

	 do 2 k=1,ncha
	 if (nch.eq.0) chaty(k)=chan(ituple)
c--------------------loop by stations-------------------------------

	 do 3 j=1,nsta
	 if (nst.eq.0) stnam(j)=sta(ituple)
	 if (sta(ituple).eq.stnam(j).and.chan(ituple).
     +    eq.chaty(k)) then
             tiz=time(ituple)
	     tez=endtime(ituple)
c--------to zoom or not to zoom-------------------------------------
	 if(it.eq.0) then
c     no zooming, times are left as they are
	     tin=tiz
             tend=tez
	     go to 4
	      end if
c--------to zoom-----------------------------------------------
		 if (timein.gt.tez) go to 3
		 if (timend.lt.tiz) go to 3
                 tin=timein
                 tend=timend
4	  continue 
	    timl=tend-tin
	    if (timl.lt.0.0) go to 3
c------------------DESIRED WAVE FORM IS FOUND------------------
C-------to correct file name using a new starttime-----------
	 iout=iout+1
c	read in waveform for tuple ituple into array data
c       note: real*8 declaration on tstrt,tend,tstart,dt,tendnew,tdif
        if(calib(ituple).ne.0.) then
	    dnorm=1./calib(ituple)
		       else
		   dnorm=1.
	      endif

         call getwf(idbin,ituple,tin,tend,-100,nbad,tstart,
     +    dt,ns,
     +         npts,data)
	sum=0.0
	isum=0.0
C-------finding the mean value-------------------------S
	do idata=1,ns
	dat_pr=data(idata)*dnorm
	if(abs(dat_pr).lt.const)then
	sum=sum+dat_pr
	isum=isum+1
			       endif
	enddo
	dmean=0.0
	if(isum.ne.0)dmean=sum/float(isum)
	PRINT*,' MEAN VALUE=',dmean,' NUMBER OF GOOD VALUES=',
     +    isum
C-------finding the mean value-------------------------E
C-------killing gaps and glitches----------------------S
	do idata=1,ns
	dat_pr=data(idata)*dnorm
	if(abs(dat_pr).ge.const) data(idata)=dmean
	enddo
C-------killing gaps and glitches----------------------E


	 tendnew=tstart+dt*(ns-1)
C------to correct for differences of tin and tstart----------------
	     tdif=tin-tstart
	     ni=0
	if(tdif.gt.0)then
C-------There are extra points at the beginning; cutting them-----
	ni=int(tdif/dt)+1
	     tstart=ni*dt+tstart
	   end if
C------to correct for differences of tend and tendnew-------------
        tdif=tendnew-tend
	ne=0
	     if(tdif.gt.0)then
C-------There are extra points at the tail; cutting them----------
                    ne=int(tdif/dt)+1
	            tend=tendnew-ne*dt 
	                  else
	            tend=tendnew
	                 end if
c------to find  human times of beginning and end of record------
 	 call e2h(tstart,iyear,iday,ihour,min,sec)
C------to correct file name using a new starttime-----------
       call namfile(ituple,dfile(ituple),iyear,iday,ihour,
     +    min,sec,
     * sta(ituple),chan(ituple),iq)
c most       print 1002,iyear,iday,ihour, min,sec
       call e2h(tend,iyear,iday,ihour,min,sec)
c most	    print 1003,iyear,iday,ihour,min,sec
	 timl=tend-tstart
	 nss=ns-ni-ne
c most            print 1004,timl,nss
C------to move waveform to the true start-------------------------
	    do  jj=1,nss
	    data(jj)=data(jj+ni)
	    end do
c-------------to start writing of output wfdisc---------------
	 call dbaddtuple(idbout,RELID_WFDISC,itupleout)
	 call dbputattrs(idbout,RELID_WFDISC,itupleout,
     +    ATTRID_STA,sta(ituple),ATTRID_CHAN,chan(ituple),
     +    ATTRID_TIME,tstart,  ATTRID_WFID,iout,
     +    ATTRID_CHANID,chanid(ituple),
     +    ATTRID_JDATE,jdate(ituple),
     +    ATTRID_ENDTIME,tend,
     +    ATTRID_NSAMP,nss,
     +    ATTRID_SAMPRATE,samprate(ituple),
     +    ATTRID_CALIB,calib(ituple),
     +    ATTRID_CALPER,calper(ituple),	
     +    ATTRID_INSTYPE,instype(ituple),
     +    ATTRID_SEGTYPE,segtype(ituple),
     +    ATTRID_DATATYPE,datatype(ituple),
     +    ATTRID_CLIP,clip(ituple),ATTRID_DIR,dirout,
     +    ATTRID_DFILE,dfile(ituple)(1:iq),ATTRID_FOFF,foff_out,
     +    ATTRID_COMMID,commid(ituple),	0)

c--------------to write out waveform data for tuple itupleout
 	  call putwf(idbout,itupleout,data)
	  endif
3         continue
c---------------end of station loop------------------
2         continue
c---------------end of channel loop------------------
1         continue
c---------------end of tuples loop------------------

	print *,'number of rows in output wfdisc file:',iout
1000    format(4a10)
1001    format(' REQUESTED TIME LENGTH IS ', f17.5,
     +    ';   NSAMPLES  ' ,i8)
1002    format(  ' OUTPUT START TIME: ',4I4,1X,F9.5)
1003    format(' OUTPUT  END  TIME: ',4I4,1X,F9.5)
1004    format(' OUTPUT TIME LENGTH IS    ', f17.5,
     +    ';   NSAMPLES  ' ,i8)
        stop
        end
C###########################################################################
	subroutine readall(idbin,ntuples)
c		reads all the tuples from a wfdisc file.
c		puts all variables in common block all.


c Copyright (c) 1993-1996 University of Colorado 
c All rights reserved 


c Copyright (c) 1993-1996 University of Colorado 
c All rights reserved 


      integer dbINVALID
      parameter (dbINVALID = -102)
      integer dbCOUNT
      parameter (dbCOUNT = -301)
      integer dbDATABASE_COUNT
      parameter (dbDATABASE_COUNT = -302	       )
      integer dbTABLE_COUNT
      parameter (dbTABLE_COUNT = -303	      )
      integer dbFIELD_COUNT
      parameter (dbFIELD_COUNT = -304	       )
      integer dbRECORD_COUNT
      parameter (dbRECORD_COUNT = -305	      )
      integer dbDESCRIPTION
      parameter (dbDESCRIPTION = -306)
      integer dbSCHEMA_DESCRIPTION
      parameter (dbSCHEMA_DESCRIPTION = -307    )
      integer dbDATABASE_DESCRIPTION
      parameter (dbDATABASE_DESCRIPTION = -308 )
      integer dbTABLE_DESCRIPTION
      parameter (dbTABLE_DESCRIPTION = -309   )
      integer dbFIELD_DESCRIPTION
      parameter (dbFIELD_DESCRIPTION = -310  )
      integer dbDETAIL
      parameter (dbDETAIL = -311)
      integer dbSCHEMA_DETAIL
      parameter (dbSCHEMA_DETAIL = -312	       )
      integer dbDATABASE_DETAIL
      parameter (dbDATABASE_DETAIL = -313	      )
      integer dbTABLE_DETAIL
      parameter (dbTABLE_DETAIL = -314	     )
      integer dbFIELD_DETAIL
      parameter (dbFIELD_DETAIL = -315	    )
      integer dbNAME
      parameter (dbNAME = -316)
      integer dbSCHEMA_NAME
      parameter (dbSCHEMA_NAME = -317	       )
      integer dbDATABASE_NAME
      parameter (dbDATABASE_NAME = -318	      )
      integer dbTABLE_NAME
      parameter (dbTABLE_NAME = -319	     )
      integer dbFIELD_NAME
      parameter (dbFIELD_NAME = -320	    )
      integer dbTABLE_PRESENT
      parameter (dbTABLE_PRESENT = -321)
      integer dbSIZE
      parameter (dbSIZE = -322)
      integer dbTABLE_SIZE
      parameter (dbTABLE_SIZE = -323	   )
      integer dbFIELD_SIZE
      parameter (dbFIELD_SIZE = -324	  )
      integer dbFIELD_TYPE
      parameter (dbFIELD_TYPE = -328	  )
      integer dbTABLE_FILENAME
      parameter (dbTABLE_FILENAME = -329)
      integer dbDBPATH
      parameter (dbDBPATH = -330)
      integer dbTABLE_DIRNAME
      parameter (dbTABLE_DIRNAME = -331)
      integer dbPRIMARY_KEY
      parameter (dbPRIMARY_KEY = -332)
      integer dbALTERNATE_KEY
      parameter (dbALTERNATE_KEY = -333)
      integer dbFOREIGN_KEYS
      parameter (dbFOREIGN_KEYS = -334)
      integer dbUNIQUE_ID
      parameter (dbUNIQUE_ID = -335)
      integer dbUNIQUE_ID_NAME
      parameter (dbUNIQUE_ID_NAME = -336)
      integer dbSINGLE
      parameter (dbSINGLE = -337)
      integer dbSCHEMA_DEFAULT
      parameter (dbSCHEMA_DEFAULT = -338)
      integer dbDBPATH_DEFAULT
      parameter (dbDBPATH_DEFAULT = -339)
      integer dbLOAD_DATE
      parameter (dbLOAD_DATE = -340)
      integer dbTYPE
      parameter (dbTYPE = -325)
      integer dbFORMAT
      parameter (dbFORMAT = -326)
      integer dbUNITS
      parameter (dbUNITS = -327)
      integer dbDATABASE
      parameter (dbDATABASE = -401)
      integer dbVIEW
      parameter (dbVIEW = -402)
      integer dbTABLE
      parameter (dbTABLE = -403)
      integer dbFIELD
      parameter (dbFIELD = -404)
      integer dbRECORD
      parameter (dbRECORD = -405)
      integer dbMERGE
      parameter (dbMERGE = -406)
      integer dbALL
      parameter (dbALL = -501)
      integer dbPRIMARY
      parameter (dbPRIMARY = -502)
      integer dbALTERNATE
      parameter (dbALTERNATE = -503)
      integer dbSCRATCH
      parameter (dbSCRATCH = -504)
      integer dbNULL
      parameter (dbNULL = -505)
      integer dbBOOLEAN
      parameter (dbBOOLEAN = 1)
      integer dbINTEGER
      parameter (dbINTEGER = 2)
      integer dbREAL
      parameter (dbREAL = 3)
      integer dbTIME
      parameter (dbTIME = 4)
      integer dbYEARDAY
      parameter (dbYEARDAY = 5)
      integer dbSTRING
      parameter (dbSTRING = 6)
      integer dbDATE
      parameter (dbDATE = 7)
      integer dbWAVEFORM
      parameter (dbWAVEFORM = 136)
      integer dbRESPONSE
      parameter (dbRESPONSE = 137)
      integer dbBFLOAT
      parameter (dbBFLOAT = 138)
      integer dbBDOUBLE
      parameter (dbBDOUBLE = 139)
      integer dbBSHORT
      parameter (dbBSHORT = 140)
      integer dbBINT
      parameter (dbBINT = 141)
      integer dbDBPTR
      parameter (dbDBPTR = 142)
      integer dbUNIQUE
      parameter (dbUNIQUE = 1)
      integer dbOUTER_JOIN
      parameter (dbOUTER_JOIN = 2)
      integer dbadd
      integer dbaddnull
      integer dbadd_remark
      integer dbaddv
      integer dbcompile
      integer dbcreate
      integer dbcrunch
      integer dbdelete
      integer dbdestroy
      integer dbex_compile
      integer dbex_eval
      integer dbex_free
      integer dbextfile
      integer dbfilename
      integer dbfind_join_keys
      integer dbget
      integer dbget_remark
      integer dbgetv
      integer dbis_expression
      integer dbmark
      integer dbnextid
      integer dbopen
      integer dbopen_database
      integer dbopen_table
      integer dbput
      integer dbputv
      integer dbputx
      integer dbread_view
      integer dbsave_view
      integer dbset
      integer dbtruncate
      integer dbunjoin
      integer dbwrite_view
      character *(*) ATTRID_ADATE
      character *(*) ATTRID_ALGID
      character *(*) ATTRID_ALGORITHM
      character *(*) ATTRID_AMP
      character *(*) ATTRID_ARID
      character *(*) ATTRID_ARRAY
      character *(*) ATTRID_ATTRIB
      character *(*) ATTRID_ATYPE
      character *(*) ATTRID_AUTH
      character *(*) ATTRID_AZDEF
      character *(*) ATTRID_AZIMUTH
      character *(*) ATTRID_AZRES
      character *(*) ATTRID_BAND
      character *(*) ATTRID_BANDW
      character *(*) ATTRID_BAZIM
      character *(*) ATTRID_BEAMID
      character *(*) ATTRID_BELIEF
      character *(*) ATTRID_BESTDC
      character *(*) ATTRID_BLKFAC
      character *(*) ATTRID_BMTYP
      character *(*) ATTRID_BSLOW
      character *(*) ATTRID_CALIB
      character *(*) ATTRID_CALPER
      character *(*) ATTRID_CALRATIO
      character *(*) ATTRID_CDATE
      character *(*) ATTRID_CDPERR
      character *(*) ATTRID_CFREQ
      character *(*) ATTRID_CHAN
      character *(*) ATTRID_CHANA
      character *(*) ATTRID_CHANID
      character *(*) ATTRID_CHANO
      character *(*) ATTRID_CHID
      character *(*) ATTRID_CLAERR
      character *(*) ATTRID_CLIP
      character *(*) ATTRID_CLOERR
      character *(*) ATTRID_CMPX
      character *(*) ATTRID_CODA
      character *(*) ATTRID_CODDES
      character *(*) ATTRID_CODE
      character *(*) ATTRID_COLDEP
      character *(*) ATTRID_COLDIA
      character *(*) ATTRID_COLINT
      character *(*) ATTRID_COLVOL
      character *(*) ATTRID_COMM
      character *(*) ATTRID_COMMID
      character *(*) ATTRID_COMPA
      character *(*) ATTRID_CONF
      character *(*) ATTRID_COTERR
      character *(*) ATTRID_CTYPE
      character *(*) ATTRID_CUREV
      character *(*) ATTRID_CUROR
      character *(*) ATTRID_DATATYPE
      character *(*) ATTRID_DATE
      character *(*) ATTRID_DATSW
      character *(*) ATTRID_DATTYP
      character *(*) ATTRID_DAY
      character *(*) ATTRID_DEAST
      character *(*) ATTRID_DELAZ
      character *(*) ATTRID_DELSLO
      character *(*) ATTRID_DELTA
      character *(*) ATTRID_DELTIM
      character *(*) ATTRID_DEPDP
      character *(*) ATTRID_DEPTH
      character *(*) ATTRID_DESCR
      character *(*) ATTRID_DESCRIP
      character *(*) ATTRID_DFILE
      character *(*) ATTRID_DIG
      character *(*) ATTRID_DIGITAL
      character *(*) ATTRID_DIP1
      character *(*) ATTRID_DIP2
      character *(*) ATTRID_DIR
      character *(*) ATTRID_DIST
      character *(*) ATTRID_DLID
      character *(*) ATTRID_DNORTH
      character *(*) ATTRID_DOY
      character *(*) ATTRID_DTYPE
      character *(*) ATTRID_DURAT
      character *(*) ATTRID_DUSED
      character *(*) ATTRID_EDATE
      character *(*) ATTRID_EDEPTH
      character *(*) ATTRID_ELEV
      character *(*) ATTRID_EMA
      character *(*) ATTRID_EMARES
      character *(*) ATTRID_ENDTIME
      character *(*) ATTRID_ESAZ
      character *(*) ATTRID_ETYPE
      character *(*) ATTRID_EVID
      character *(*) ATTRID_EVNAME
      character *(*) ATTRID_EXLAT
      character *(*) ATTRID_EXLON
      character *(*) ATTRID_EXPTYP
      character *(*) ATTRID_FILE
      character *(*) ATTRID_FILES
      character *(*) ATTRID_FILTID
      character *(*) ATTRID_FILTYP
      character *(*) ATTRID_FKID
      character *(*) ATTRID_FKQUAL
      character *(*) ATTRID_FKRID
      character *(*) ATTRID_FKTYP
      character *(*) ATTRID_FM
      character *(*) ATTRID_FNORM
      character *(*) ATTRID_FOFF
      character *(*) ATTRID_FSID
      character *(*) ATTRID_FSRID
      character *(*) ATTRID_FSTAT
      character *(*) ATTRID_FSTYP
      character *(*) ATTRID_FTID
      character *(*) ATTRID_GNORM
      character *(*) ATTRID_GRN
      character *(*) ATTRID_GRNAME
      character *(*) ATTRID_HANG
      character *(*) ATTRID_HICUT
      character *(*) ATTRID_HSLOPE
      character *(*) ATTRID_IDTYPE
      character *(*) ATTRID_IDVALUE
      character *(*) ATTRID_IMB
      character *(*) ATTRID_IML
      character *(*) ATTRID_IMS
      character *(*) ATTRID_INID
      character *(*) ATTRID_INSNAME
      character *(*) ATTRID_INSTANT
      character *(*) ATTRID_INSTYP
      character *(*) ATTRID_INSTYPE
      character *(*) ATTRID_INTSCL
      character *(*) ATTRID_IPHASE
      character *(*) ATTRID_JDATE
      character *(*) ATTRID_LAT
      character *(*) ATTRID_LDATE
      character *(*) ATTRID_LDDATE
      character *(*) ATTRID_LEAP
      character *(*) ATTRID_LINENO
      character *(*) ATTRID_LOCATION
      character *(*) ATTRID_LOCUT
      character *(*) ATTRID_LOGAT
      character *(*) ATTRID_LON
      character *(*) ATTRID_LSLOPE
      character *(*) ATTRID_LTYPE
      character *(*) ATTRID_MAG
      character *(*) ATTRID_MAGB
      character *(*) ATTRID_MAGID
      character *(*) ATTRID_MAGLR
      character *(*) ATTRID_MAGNITUDE
      character *(*) ATTRID_MAGSH
      character *(*) ATTRID_MAGTYPE
      character *(*) ATTRID_MAXBLK
      character *(*) ATTRID_MAXF
      character *(*) ATTRID_MAXINT
      character *(*) ATTRID_MAXKX
      character *(*) ATTRID_MAXKY
      character *(*) ATTRID_MAXSX
      character *(*) ATTRID_MAXSY
      character *(*) ATTRID_MB
      character *(*) ATTRID_MBID
      character *(*) ATTRID_MEDIUM
      character *(*) ATTRID_MEXPON
      character *(*) ATTRID_MFF
      character *(*) ATTRID_MFFERR
      character *(*) ATTRID_MINBLK
      character *(*) ATTRID_ML
      character *(*) ATTRID_MLID
      character *(*) ATTRID_MNAME
      character *(*) ATTRID_MO
      character *(*) ATTRID_MOAUTH
      character *(*) ATTRID_MOIST
      character *(*) ATTRID_MON
      character *(*) ATTRID_MRF
      character *(*) ATTRID_MRFERR
      character *(*) ATTRID_MRR
      character *(*) ATTRID_MRRERR
      character *(*) ATTRID_MRT
      character *(*) ATTRID_MRTERR
      character *(*) ATTRID_MS
      character *(*) ATTRID_MSID
      character *(*) ATTRID_MTF
      character *(*) ATTRID_MTFERR
      character *(*) ATTRID_MTT
      character *(*) ATTRID_MTTERR
      character *(*) ATTRID_NAME
      character *(*) ATTRID_NASS
      character *(*) ATTRID_NAXAZM
      character *(*) ATTRID_NAXPLG
      character *(*) ATTRID_NAXVAL
      character *(*) ATTRID_NBYTE
      character *(*) ATTRID_NCALIB
      character *(*) ATTRID_NCALPER
      character *(*) ATTRID_NDEF
      character *(*) ATTRID_NDLID
      character *(*) ATTRID_NDP
      character *(*) ATTRID_NET
      character *(*) ATTRID_NETNAME
      character *(*) ATTRID_NETTYPE
      character *(*) ATTRID_NETWRK
      character *(*) ATTRID_NF
      character *(*) ATTRID_NMB
      character *(*) ATTRID_NMO
      character *(*) ATTRID_NMS
      character *(*) ATTRID_NORID
      character *(*) ATTRID_NOWFT
      character *(*) ATTRID_NRLPB
      character *(*) ATTRID_NRMW
      character *(*) ATTRID_NSAMP
      character *(*) ATTRID_NSLPB
      character *(*) ATTRID_NSMW
      character *(*) ATTRID_NSTA
      character *(*) ATTRID_NX
      character *(*) ATTRID_NXALG
      character *(*) ATTRID_NXARID
      character *(*) ATTRID_NXCHID
      character *(*) ATTRID_NXCOMM
      character *(*) ATTRID_NXDLID
      character *(*) ATTRID_NXEVID
      character *(*) ATTRID_NXFILT
      character *(*) ATTRID_NXFK
      character *(*) ATTRID_NXFKR
      character *(*) ATTRID_NXFS
      character *(*) ATTRID_NXFSR
      character *(*) ATTRID_NXFTID
      character *(*) ATTRID_NXINID
      character *(*) ATTRID_NXORID
      character *(*) ATTRID_NXSENS
      character *(*) ATTRID_NXSITE
      character *(*) ATTRID_NXSPRO
      character *(*) ATTRID_NXWFID
      character *(*) ATTRID_NY
      character *(*) ATTRID_OFFDAT
      character *(*) ATTRID_OFFDATE
      character *(*) ATTRID_ONDATE
      character *(*) ATTRID_OPSW
      character *(*) ATTRID_OPTYP
      character *(*) ATTRID_ORID
      character *(*) ATTRID_PALDEP
      character *(*) ATTRID_PAXAZM
      character *(*) ATTRID_PAXPLG
      character *(*) ATTRID_PAXVAL
      character *(*) ATTRID_PCHID
      character *(*) ATTRID_PDLID
      character *(*) ATTRID_PER
      character *(*) ATTRID_PHASE
      character *(*) ATTRID_PLPREF
      character *(*) ATTRID_PNAME
      character *(*) ATTRID_PORID
      character *(*) ATTRID_PREFOR
      character *(*) ATTRID_PVALUE
      character *(*) ATTRID_QUAL
      character *(*) ATTRID_RECT
      character *(*) ATTRID_REELSZ
      character *(*) ATTRID_REFSTA
      character *(*) ATTRID_REGION
      character *(*) ATTRID_REL
      character *(*) ATTRID_REMARK
      character *(*) ATTRID_RESID
      character *(*) ATTRID_RIPPLE
      character *(*) ATTRID_RSPTYP
      character *(*) ATTRID_RSPTYPE
      character *(*) ATTRID_SAMPRATE
      character *(*) ATTRID_SDDP
      character *(*) ATTRID_SDEPTH
      character *(*) ATTRID_SDMB
      character *(*) ATTRID_SDMO
      character *(*) ATTRID_SDMS
      character *(*) ATTRID_SDOBS
      character *(*) ATTRID_SDZDP
      character *(*) ATTRID_SEAZ
      character *(*) ATTRID_SEGTYP
      character *(*) ATTRID_SEGTYPE
      character *(*) ATTRID_SENSID
      character *(*) ATTRID_SITEID
      character *(*) ATTRID_SLIP1
      character *(*) ATTRID_SLIP2
      character *(*) ATTRID_SLODEF
      character *(*) ATTRID_SLORES
      character *(*) ATTRID_SLOW
      character *(*) ATTRID_SMAJAX
      character *(*) ATTRID_SMINAX
      character *(*) ATTRID_SMPRAT
      character *(*) ATTRID_SNAME
      character *(*) ATTRID_SNR
      character *(*) ATTRID_SPAUTH
      character *(*) ATTRID_SPMM
      character *(*) ATTRID_SPROID
      character *(*) ATTRID_SPRT
      character *(*) ATTRID_SPVT
      character *(*) ATTRID_SRN
      character *(*) ATTRID_SRNAME
      character *(*) ATTRID_STA
      character *(*) ATTRID_STAA
      character *(*) ATTRID_STANAM
      character *(*) ATTRID_STANAME
      character *(*) ATTRID_STAO
      character *(*) ATTRID_STASSID
      character *(*) ATTRID_STATYPE
      character *(*) ATTRID_STAV
      character *(*) ATTRID_STID
      character *(*) ATTRID_STIME
      character *(*) ATTRID_STR1
      character *(*) ATTRID_STR2
      character *(*) ATTRID_STRIKE
      character *(*) ATTRID_STRING
      character *(*) ATTRID_STT
      character *(*) ATTRID_STX
      character *(*) ATTRID_STY
      character *(*) ATTRID_STYPE
      character *(*) ATTRID_STZ
      character *(*) ATTRID_SXX
      character *(*) ATTRID_SXY
      character *(*) ATTRID_SXZ
      character *(*) ATTRID_SYY
      character *(*) ATTRID_SYZ
      character *(*) ATTRID_SZZ
      character *(*) ATTRID_TAGID
      character *(*) ATTRID_TAGNAME
      character *(*) ATTRID_TAPEBLOCK
      character *(*) ATTRID_TAPEFILE
      character *(*) ATTRID_TARNAM
      character *(*) ATTRID_TAXAZM
      character *(*) ATTRID_TAXPLG
      character *(*) ATTRID_TAXVAL
      character *(*) ATTRID_TCALIB
      character *(*) ATTRID_TDENSE
      character *(*) ATTRID_TEXT
      character *(*) ATTRID_TFILE
      character *(*) ATTRID_TIME
      character *(*) ATTRID_TIMEDEF
      character *(*) ATTRID_TIMERES
      character *(*) ATTRID_TLEN
      character *(*) ATTRID_TMFC
      character *(*) ATTRID_TMFI
      character *(*) ATTRID_TMNLPB
      character *(*) ATTRID_TMNMW
      character *(*) ATTRID_TPBLCK
      character *(*) ATTRID_TPFILE
      character *(*) ATTRID_TPTYPE
      character *(*) ATTRID_TRATBL
      character *(*) ATTRID_TSHIFT
      character *(*) ATTRID_TSITE
      character *(*) ATTRID_TUPID
      character *(*) ATTRID_UNCERTAINTY
      character *(*) ATTRID_USEDFT
      character *(*) ATTRID_VANG
      character *(*) ATTRID_VELID
      character *(*) ATTRID_VMODEL
      character *(*) ATTRID_VOLNAM
      character *(*) ATTRID_VOLNAME
      character *(*) ATTRID_WATDEP
      character *(*) ATTRID_WFID
      character *(*) ATTRID_WGT
      character *(*) ATTRID_YEAR
      character *(*) ATTRID_YIELD
      character *(*) ATTRID_YLDMAX
      character *(*) RELID_AFFILIATION
      character *(*) RELID_ALIAS
      character *(*) RELID_ARRIVAL
      character *(*) RELID_ASSOC
      character *(*) RELID_BEAM
      character *(*) RELID_CENTRYD
      character *(*) RELID_CHANNEL
      character *(*) RELID_CHOPER
      character *(*) RELID_CODE
      character *(*) RELID_COMMENT
      character *(*) RELID_COUNTER
      character *(*) RELID_DATE
      character *(*) RELID_DAY
      character *(*) RELID_DETECTION
      character *(*) RELID_DETLOC
      character *(*) RELID_EVENT
      character *(*) RELID_EVWF
      character *(*) RELID_EXPLO
      character *(*) RELID_EXTRA
      character *(*) RELID_FEATURE
      character *(*) RELID_FILTER
      character *(*) RELID_FKDISC
      character *(*) RELID_FKREC
      character *(*) RELID_FPLANE
      character *(*) RELID_FSDISC
      character *(*) RELID_FSREC
      character *(*) RELID_GREGION
      character *(*) RELID_INSTRUMENT
      character *(*) RELID_LASTID
      character *(*) RELID_LOC
      character *(*) RELID_MOMENT
      character *(*) RELID_NETMAG
      character *(*) RELID_NETWORK
      character *(*) RELID_ORIGERR
      character *(*) RELID_ORIGIN
      character *(*) RELID_REMARK
      character *(*) RELID_SENSOR
      character *(*) RELID_SIGPRO
      character *(*) RELID_SITE
      character *(*) RELID_SITECHAN
      character *(*) RELID_SREGION
      character *(*) RELID_STALOG
      character *(*) RELID_STAMAG
      character *(*) RELID_STASSOC
      character *(*) RELID_STATION
      character *(*) RELID_TAPE
      character *(*) RELID_WFDISC
      character *(*) RELID_WFTAG
      character *(*) RELID_WFTAPE
      character *(*) RELID_WFTAR
      character *(*) RELID_XPARAM
      integer DBL_ASCII
      integer DBL_BINARY
      integer DBL_DBL
      integer DBL_FLT
      integer DBL_INT
      integer DBL_STR
      integer NUMBER_RELS30
      integer NUMBER_ATTRS
      integer NUMBER_ATTRS30
      parameter (ATTRID_ADATE = "adate"		)
      parameter (ATTRID_ALGID = "algid"		)
      parameter (ATTRID_ALGORITHM = "algorithm"	)
      parameter (ATTRID_AMP = "amp"		)
      parameter (ATTRID_ARID = "arid"		)
      parameter (ATTRID_ARRAY = "array"		)
      parameter (ATTRID_ATTRIB = "attrib"	)
      parameter (ATTRID_ATYPE = "atype"		)
      parameter (ATTRID_AUTH = "auth"		)
      parameter (ATTRID_AZDEF = "azdef"		)
      parameter (ATTRID_AZIMUTH = "azimuth"	)
      parameter (ATTRID_AZRES = "azres"		)
      parameter (ATTRID_BAND = "band"		)
      parameter (ATTRID_BANDW = "bandw"		)
      parameter (ATTRID_BAZIM = "bazim"		)
      parameter (ATTRID_BEAMID = "beamid"	)
      parameter (ATTRID_BELIEF = "belief"	)
      parameter (ATTRID_BESTDC = "bestdc"	)
      parameter (ATTRID_BLKFAC = "blkfac"	)
      parameter (ATTRID_BMTYP = "bmtyp"		)
      parameter (ATTRID_BSLOW = "bslow"		)
      parameter (ATTRID_CALIB = "calib"		)
      parameter (ATTRID_CALPER = "calper"	)
      parameter (ATTRID_CALRATIO = "calratio"	)
      parameter (ATTRID_CDATE = "cdate"		)
      parameter (ATTRID_CDPERR = "cdperr"	)
      parameter (ATTRID_CFREQ = "cfreq"		)
      parameter (ATTRID_CHAN = "chan"		)
      parameter (ATTRID_CHANA = "chana"		)
      parameter (ATTRID_CHANID = "chanid"	)
      parameter (ATTRID_CHANO = "chano"		)
      parameter (ATTRID_CHID = "chid"		)
      parameter (ATTRID_CLAERR = "claerr"	)
      parameter (ATTRID_CLIP = "clip"		)
      parameter (ATTRID_CLOERR = "cloerr"	)
      parameter (ATTRID_CMPX = "cmpx"		)
      parameter (ATTRID_CODA = "coda"		)
      parameter (ATTRID_CODDES = "coddes"	)
      parameter (ATTRID_CODE = "code"		)
      parameter (ATTRID_COLDEP = "coldep"	)
      parameter (ATTRID_COLDIA = "coldia"	)
      parameter (ATTRID_COLINT = "colint"	)
      parameter (ATTRID_COLVOL = "colvol"	)
      parameter (ATTRID_COMM = "comm"		)
      parameter (ATTRID_COMMID = "commid"	)
      parameter (ATTRID_COMPA = "compa"		)
      parameter (ATTRID_CONF = "conf"		)
      parameter (ATTRID_COTERR = "coterr"	)
      parameter (ATTRID_CTYPE = "ctype"		)
      parameter (ATTRID_CUREV = "curev"		)
      parameter (ATTRID_CUROR = "curor"		)
      parameter (ATTRID_DATATYPE = "datatype"	)
      parameter (ATTRID_DATE = "date"		)
      parameter (ATTRID_DATSW = "datsw"		)
      parameter (ATTRID_DATTYP = "dattyp"	)
      parameter (ATTRID_DAY = "day"		)
      parameter (ATTRID_DEAST = "deast"		)
      parameter (ATTRID_DELAZ = "delaz"		)
      parameter (ATTRID_DELSLO = "delslo"	)
      parameter (ATTRID_DELTA = "delta"		)
      parameter (ATTRID_DELTIM = "deltim"	)
      parameter (ATTRID_DEPDP = "depdp"		)
      parameter (ATTRID_DEPTH = "depth"		)
      parameter (ATTRID_DESCR = "descr"		)
      parameter (ATTRID_DESCRIP = "descrip"	)
      parameter (ATTRID_DFILE = "dfile"		)
      parameter (ATTRID_DIG = "dig"		)
      parameter (ATTRID_DIGITAL = "digital"	)
      parameter (ATTRID_DIP1 = "dip1"		)
      parameter (ATTRID_DIP2 = "dip2"		)
      parameter (ATTRID_DIR = "dir"		)
      parameter (ATTRID_DIST = "dist"		)
      parameter (ATTRID_DLID = "dlid"		)
      parameter (ATTRID_DNORTH = "dnorth"	)
      parameter (ATTRID_DOY = "doy"		)
      parameter (ATTRID_DTYPE = "dtype"		)
      parameter (ATTRID_DURAT = "durat"		)
      parameter (ATTRID_DUSED = "dused"		)
      parameter (ATTRID_EDATE = "edate"		)
      parameter (ATTRID_EDEPTH = "edepth"	)
      parameter (ATTRID_ELEV = "elev"		)
      parameter (ATTRID_EMA = "ema"		)
      parameter (ATTRID_EMARES = "emares"	)
      parameter (ATTRID_ENDTIME = "endtime"	)
      parameter (ATTRID_ESAZ = "esaz"		)
      parameter (ATTRID_ETYPE = "etype"		)
      parameter (ATTRID_EVID = "evid"		)
      parameter (ATTRID_EVNAME = "evname"	)
      parameter (ATTRID_EXLAT = "exlat"		)
      parameter (ATTRID_EXLON = "exlon"		)
      parameter (ATTRID_EXPTYP = "exptyp"	)
      parameter (ATTRID_FILE = "file"		)
      parameter (ATTRID_FILES = "files"		)
      parameter (ATTRID_FILTID = "filtid"	)
      parameter (ATTRID_FILTYP = "filtyp"	)
      parameter (ATTRID_FKID = "fkid"		)
      parameter (ATTRID_FKQUAL = "fkqual"	)
      parameter (ATTRID_FKRID = "fkrid"		)
      parameter (ATTRID_FKTYP = "fktyp"		)
      parameter (ATTRID_FM = "fm"		)
      parameter (ATTRID_FNORM = "fnorm"		)
      parameter (ATTRID_FOFF = "foff"		)
      parameter (ATTRID_FSID = "fsid"		)
      parameter (ATTRID_FSRID = "fsrid"		)
      parameter (ATTRID_FSTAT = "fstat"		)
      parameter (ATTRID_FSTYP = "fstyp"		)
      parameter (ATTRID_FTID = "ftid"		)
      parameter (ATTRID_GNORM = "gnorm"		)
      parameter (ATTRID_GRN = "grn"		)
      parameter (ATTRID_GRNAME = "grname"	)
      parameter (ATTRID_HANG = "hang"		)
      parameter (ATTRID_HICUT = "hicut"		)
      parameter (ATTRID_HSLOPE = "hslope"	)
      parameter (ATTRID_IDTYPE = "idtype"	)
      parameter (ATTRID_IDVALUE = "idvalue"	)
      parameter (ATTRID_IMB = "imb"		)
      parameter (ATTRID_IML = "iml"		)
      parameter (ATTRID_IMS = "ims"		)
      parameter (ATTRID_INID = "inid"		)
      parameter (ATTRID_INSNAME = "insname"	)
      parameter (ATTRID_INSTANT = "instant"	)
      parameter (ATTRID_INSTYP = "instyp"	)
      parameter (ATTRID_INSTYPE = "instype"	)
      parameter (ATTRID_INTSCL = "intscl"	)
      parameter (ATTRID_IPHASE = "iphase"	)
      parameter (ATTRID_JDATE = "jdate"		)
      parameter (ATTRID_LAT = "lat"		)
      parameter (ATTRID_LDATE = "ldate"		)
      parameter (ATTRID_LDDATE = "lddate"	)
      parameter (ATTRID_LEAP = "leap"		)
      parameter (ATTRID_LINENO = "lineno"	)
      parameter (ATTRID_LOCATION = "location"	)
      parameter (ATTRID_LOCUT = "locut"		)
      parameter (ATTRID_LOGAT = "logat"		)
      parameter (ATTRID_LON = "lon"		)
      parameter (ATTRID_LSLOPE = "lslope"	)
      parameter (ATTRID_LTYPE = "ltype"		)
      parameter (ATTRID_MAG = "mag"		)
      parameter (ATTRID_MAGB = "magb"		)
      parameter (ATTRID_MAGID = "magid"		)
      parameter (ATTRID_MAGLR = "maglr"		)
      parameter (ATTRID_MAGNITUDE = "magnitude"	)
      parameter (ATTRID_MAGSH = "magsh"		)
      parameter (ATTRID_MAGTYPE = "magtype"	)
      parameter (ATTRID_MAXBLK = "maxblk"	)
      parameter (ATTRID_MAXF = "maxf"		)
      parameter (ATTRID_MAXINT = "maxint"	)
      parameter (ATTRID_MAXKX = "maxkx"		)
      parameter (ATTRID_MAXKY = "maxky"		)
      parameter (ATTRID_MAXSX = "maxsx"		)
      parameter (ATTRID_MAXSY = "maxsy"		)
      parameter (ATTRID_MB = "mb"		)
      parameter (ATTRID_MBID = "mbid"		)
      parameter (ATTRID_MEDIUM = "medium"	)
      parameter (ATTRID_MEXPON = "mexpon"	)
      parameter (ATTRID_MFF = "mff"		)
      parameter (ATTRID_MFFERR = "mfferr"	)
      parameter (ATTRID_MINBLK = "minblk"	)
      parameter (ATTRID_ML = "ml"		)
      parameter (ATTRID_MLID = "mlid"		)
      parameter (ATTRID_MNAME = "mname"		)
      parameter (ATTRID_MO = "mo"		)
      parameter (ATTRID_MOAUTH = "moauth"	)
      parameter (ATTRID_MOIST = "moist"		)
      parameter (ATTRID_MON = "mon"		)
      parameter (ATTRID_MRF = "mrf"		)
      parameter (ATTRID_MRFERR = "mrferr"	)
      parameter (ATTRID_MRR = "mrr"		)
      parameter (ATTRID_MRRERR = "mrrerr"	)
      parameter (ATTRID_MRT = "mrt"		)
      parameter (ATTRID_MRTERR = "mrterr"	)
      parameter (ATTRID_MS = "ms"		)
      parameter (ATTRID_MSID = "msid"		)
      parameter (ATTRID_MTF = "mtf"		)
      parameter (ATTRID_MTFERR = "mtferr"	)
      parameter (ATTRID_MTT = "mtt"		)
      parameter (ATTRID_MTTERR = "mtterr"	)
      parameter (ATTRID_NAME = "name"		)
      parameter (ATTRID_NASS = "nass"		)
      parameter (ATTRID_NAXAZM = "naxazm"	)
      parameter (ATTRID_NAXPLG = "naxplg"	)
      parameter (ATTRID_NAXVAL = "naxval"	)
      parameter (ATTRID_NBYTE = "nbyte"		)
      parameter (ATTRID_NCALIB = "ncalib"	)
      parameter (ATTRID_NCALPER = "ncalper"	)
      parameter (ATTRID_NDEF = "ndef"		)
      parameter (ATTRID_NDLID = "ndlid"		)
      parameter (ATTRID_NDP = "ndp"		)
      parameter (ATTRID_NET = "net"		)
      parameter (ATTRID_NETNAME = "netname"	)
      parameter (ATTRID_NETTYPE = "nettype"	)
      parameter (ATTRID_NETWRK = "netwrk"	)
      parameter (ATTRID_NF = "nf"		)
      parameter (ATTRID_NMB = "nmb"		)
      parameter (ATTRID_NMO = "nmo"		)
      parameter (ATTRID_NMS = "nms"		)
      parameter (ATTRID_NORID = "norid"		)
      parameter (ATTRID_NOWFT = "nowft"		)
      parameter (ATTRID_NRLPB = "nrlpb"		)
      parameter (ATTRID_NRMW = "nrmw"		)
      parameter (ATTRID_NSAMP = "nsamp"		)
      parameter (ATTRID_NSLPB = "nslpb"		)
      parameter (ATTRID_NSMW = "nsmw"		)
      parameter (ATTRID_NSTA = "nsta"		)
      parameter (ATTRID_NX = "nx"		)
      parameter (ATTRID_NXALG = "nxalg"		)
      parameter (ATTRID_NXARID = "nxarid"	)
      parameter (ATTRID_NXCHID = "nxchid"	)
      parameter (ATTRID_NXCOMM = "nxcomm"	)
      parameter (ATTRID_NXDLID = "nxdlid"	)
      parameter (ATTRID_NXEVID = "nxevid"	)
      parameter (ATTRID_NXFILT = "nxfilt"	)
      parameter (ATTRID_NXFK = "nxfk"		)
      parameter (ATTRID_NXFKR = "nxfkr"		)
      parameter (ATTRID_NXFS = "nxfs"		)
      parameter (ATTRID_NXFSR = "nxfsr"		)
      parameter (ATTRID_NXFTID = "nxftid"	)
      parameter (ATTRID_NXINID = "nxinid"	)
      parameter (ATTRID_NXORID = "nxorid"	)
      parameter (ATTRID_NXSENS = "nxsens"	)
      parameter (ATTRID_NXSITE = "nxsite"	)
      parameter (ATTRID_NXSPRO = "nxspro"	)
      parameter (ATTRID_NXWFID = "nxwfid"	)
      parameter (ATTRID_NY = "ny"		)
      parameter (ATTRID_OFFDAT = "offdat"	)
      parameter (ATTRID_OFFDATE = "offdate"	)
      parameter (ATTRID_ONDATE = "ondate"	)
      parameter (ATTRID_OPSW = "opsw"		)
      parameter (ATTRID_OPTYP = "optyp"		)
      parameter (ATTRID_ORID = "orid"		)
      parameter (ATTRID_PALDEP = "paldep"	)
      parameter (ATTRID_PAXAZM = "paxazm"	)
      parameter (ATTRID_PAXPLG = "paxplg"	)
      parameter (ATTRID_PAXVAL = "paxval"	)
      parameter (ATTRID_PCHID = "pchid"		)
      parameter (ATTRID_PDLID = "pdlid"		)
      parameter (ATTRID_PER = "per"		)
      parameter (ATTRID_PHASE = "phase"		)
      parameter (ATTRID_PLPREF = "plpref"	)
      parameter (ATTRID_PNAME = "pname"		)
      parameter (ATTRID_PORID = "porid"		)
      parameter (ATTRID_PREFOR = "prefor"	)
      parameter (ATTRID_PVALUE = "pvalue"	)
      parameter (ATTRID_QUAL = "qual"		)
      parameter (ATTRID_RECT = "rect"		)
      parameter (ATTRID_REELSZ = "reelsz"	)
      parameter (ATTRID_REFSTA = "refsta"	)
      parameter (ATTRID_REGION = "region"	)
      parameter (ATTRID_REL = "rel"		)
      parameter (ATTRID_REMARK = "remark"	)
      parameter (ATTRID_RESID = "resid"		)
      parameter (ATTRID_RIPPLE = "ripple"	)
      parameter (ATTRID_RSPTYP = "rsptyp"	)
      parameter (ATTRID_RSPTYPE = "rsptype"	)
      parameter (ATTRID_SAMPRATE = "samprate"	)
      parameter (ATTRID_SDDP = "sddp"		)
      parameter (ATTRID_SDEPTH = "sdepth"	)
      parameter (ATTRID_SDMB = "sdmb"		)
      parameter (ATTRID_SDMO = "sdmo"		)
      parameter (ATTRID_SDMS = "sdms"		)
      parameter (ATTRID_SDOBS = "sdobs"		)
      parameter (ATTRID_SDZDP = "sdzdp"		)
      parameter (ATTRID_SEAZ = "seaz"		)
      parameter (ATTRID_SEGTYP = "segtyp"	)
      parameter (ATTRID_SEGTYPE = "segtype"	)
      parameter (ATTRID_SENSID = "sensid"	)
      parameter (ATTRID_SITEID = "siteid"	)
      parameter (ATTRID_SLIP1 = "slip1"		)
      parameter (ATTRID_SLIP2 = "slip2"		)
      parameter (ATTRID_SLODEF = "slodef"	)
      parameter (ATTRID_SLORES = "slores"	)
      parameter (ATTRID_SLOW = "slow"		)
      parameter (ATTRID_SMAJAX = "smajax"	)
      parameter (ATTRID_SMINAX = "sminax"	)
      parameter (ATTRID_SMPRAT = "smprat"	)
      parameter (ATTRID_SNAME = "sname"		)
      parameter (ATTRID_SNR = "snr"		)
      parameter (ATTRID_SPAUTH = "spauth"	)
      parameter (ATTRID_SPMM = "spmm"		)
      parameter (ATTRID_SPROID = "sproid"	)
      parameter (ATTRID_SPRT = "sprt"		)
      parameter (ATTRID_SPVT = "spvt"		)
      parameter (ATTRID_SRN = "srn"		)
      parameter (ATTRID_SRNAME = "srname"	)
      parameter (ATTRID_STA = "sta"		)
      parameter (ATTRID_STAA = "staa"		)
      parameter (ATTRID_STANAM = "stanam"	)
      parameter (ATTRID_STANAME = "staname"	)
      parameter (ATTRID_STAO = "stao"		)
      parameter (ATTRID_STASSID = "stassid"	)
      parameter (ATTRID_STATYPE = "statype"	)
      parameter (ATTRID_STAV = "stav"		)
      parameter (ATTRID_STID = "stid"		)
      parameter (ATTRID_STIME = "stime"		)
      parameter (ATTRID_STR1 = "str1"		)
      parameter (ATTRID_STR2 = "str2"		)
      parameter (ATTRID_STRIKE = "strike"	)
      parameter (ATTRID_STRING = "string"	)
      parameter (ATTRID_STT = "stt"		)
      parameter (ATTRID_STX = "stx"		)
      parameter (ATTRID_STY = "sty"		)
      parameter (ATTRID_STYPE = "stype"		)
      parameter (ATTRID_STZ = "stz"		)
      parameter (ATTRID_SXX = "sxx"		)
      parameter (ATTRID_SXY = "sxy"		)
      parameter (ATTRID_SXZ = "sxz"		)
      parameter (ATTRID_SYY = "syy"		)
      parameter (ATTRID_SYZ = "syz"		)
      parameter (ATTRID_SZZ = "szz"		)
      parameter (ATTRID_TAGID = "tagid"		)
      parameter (ATTRID_TAGNAME = "tagname"	)
      parameter (ATTRID_TAPEBLOCK = "tapeblock"	)
      parameter (ATTRID_TAPEFILE = "tapefile"	)
      parameter (ATTRID_TARNAM = "tarnam"	)
      parameter (ATTRID_TAXAZM = "taxazm"	)
      parameter (ATTRID_TAXPLG = "taxplg"	)
      parameter (ATTRID_TAXVAL = "taxval"	)
      parameter (ATTRID_TCALIB = "tcalib"	)
      parameter (ATTRID_TDENSE = "tdense"	)
      parameter (ATTRID_TEXT = "text"		)
      parameter (ATTRID_TFILE = "tfile"		)
      parameter (ATTRID_TIME = "time"		)
      parameter (ATTRID_TIMEDEF = "timedef"	)
      parameter (ATTRID_TIMERES = "timeres"	)
      parameter (ATTRID_TLEN = "tlen"		)
      parameter (ATTRID_TMFC = "tmfc"		)
      parameter (ATTRID_TMFI = "tmfi"		)
      parameter (ATTRID_TMNLPB = "tmnlpb"	)
      parameter (ATTRID_TMNMW = "tmnmw"		)
      parameter (ATTRID_TPBLCK = "tpblck"	)
      parameter (ATTRID_TPFILE = "tpfile"	)
      parameter (ATTRID_TPTYPE = "tptype"	)
      parameter (ATTRID_TRATBL = "tratbl"	)
      parameter (ATTRID_TSHIFT = "tshift"	)
      parameter (ATTRID_TSITE = "tsite"		)
      parameter (ATTRID_TUPID = "tupid"		)
      parameter (ATTRID_UNCERTAINTY = "uncertainty"	)
      parameter (ATTRID_USEDFT = "usedft"	)
      parameter (ATTRID_VANG = "vang"		)
      parameter (ATTRID_VELID = "velid"		)
      parameter (ATTRID_VMODEL = "vmodel"	)
      parameter (ATTRID_VOLNAM = "volnam"	)
      parameter (ATTRID_VOLNAME = "volname"	)
      parameter (ATTRID_WATDEP = "watdep"	)
      parameter (ATTRID_WFID = "wfid"		)
      parameter (ATTRID_WGT = "wgt"		)
      parameter (ATTRID_YEAR = "year"		)
      parameter (ATTRID_YIELD = "yield"		)
      parameter (ATTRID_YLDMAX = "yldmax"	)
      parameter (DBL_ASCII = 0	)
      parameter (DBL_BINARY = 1	)
      parameter (DBL_DBL = 2	)
      parameter (DBL_FLT = 1	)
      parameter (DBL_INT = 0	)
      parameter (DBL_STR = 3	)
      parameter (NUMBER_ATTRS = 282		)
      parameter (NUMBER_ATTRS30 = 152		)
      parameter (NUMBER_RELS30 = 23	)
      parameter (RELID_AFFILIATION = "affiliation"	)
      parameter (RELID_ALIAS = "alias"	)
      parameter (RELID_ARRIVAL = "arrival"	)
      parameter (RELID_ASSOC = "assoc"	)
      parameter (RELID_BEAM = "beam"		)
      parameter (RELID_CENTRYD = "centryd"	)
      parameter (RELID_CHANNEL = "channel"	)
      parameter (RELID_CHOPER = "choper"	)
      parameter (RELID_CODE = "code"		)
      parameter (RELID_COMMENT = "comment"	)
      parameter (RELID_COUNTER = "counter"	)
      parameter (RELID_DATE = "date"		)
      parameter (RELID_DAY = "day"		)
      parameter (RELID_DETECTION = "detection"	)
      parameter (RELID_DETLOC = "detloc"	)
      parameter (RELID_EVENT = "event"	)
      parameter (RELID_EVWF = "evwf"		)
      parameter (RELID_EXPLO = "explo"		)
      parameter (RELID_EXTRA = "extra"		)
      parameter (RELID_FEATURE = "feature"	)
      parameter (RELID_FILTER = "filter"	)
      parameter (RELID_FKDISC = "fkdisc"	)
      parameter (RELID_FKREC = "fkrec"		)
      parameter (RELID_FPLANE = "fplane"	)
      parameter (RELID_FSDISC = "fsdisc"	)
      parameter (RELID_FSREC = "fsrec"		)
      parameter (RELID_GREGION = "gregion"	)
      parameter (RELID_INSTRUMENT = "instrument"	)
      parameter (RELID_LASTID = "lastid"	)
      parameter (RELID_LOC = "loc"		)
      parameter (RELID_MOMENT = "moment"	)
      parameter (RELID_NETMAG = "netmag"	)
      parameter (RELID_NETWORK = "network"	)
      parameter (RELID_ORIGERR = "origerr"	)
      parameter (RELID_ORIGIN = "origin"	)
      parameter (RELID_REMARK = "remark"	)
      parameter (RELID_SENSOR = "sensor"	)
      parameter (RELID_SIGPRO = "sigpro"	)
      parameter (RELID_SITE = "site"	)
      parameter (RELID_SITECHAN = "sitechan"	)
      parameter (RELID_SREGION = "sregion"	)
      parameter (RELID_STALOG = "stalog"	)
      parameter (RELID_STAMAG = "stamag"	)
      parameter (RELID_STASSOC = "stassoc"	)
      parameter (RELID_STATION = "station"	)
      parameter (RELID_TAPE = "tape"		)
      parameter (RELID_WFDISC = "wfdisc"	)
      parameter (RELID_WFTAG = "wftag"	)
      parameter (RELID_WFTAPE = "wftape"	)
      parameter (RELID_WFTAR = "wftar"	)
      parameter (RELID_XPARAM = "xparam"	)

	parameter(nr=10000)

	character segtype,clip
	character*2 datatype
	character*6 sta,instype
	character*8 chan
	character*17 lddate
	character*32 dfile
	character*64 dir

	real*4 samprate,calib,calper
	real*8 time,endtime

	integer wfid,chanid,jdate,nsamp,foff,commid

	common/all/sta(nr),chan(nr),time(nr),wfid(nr),chanid(nr),
     +   jdate(nr),endtime(nr),nsamp(nr),samprate(nr),calib(nr),
     +   calper(nr),instype(nr),segtype(nr),datatype(nr),clip(nr),
     +   dir(nr),dfile(nr),foff(nr),commid(nr),lddate(nr)


	do i=1,ntuples
c		get wfdisc row and store in common all
	 call dbgetattrs(idbin,RELID_WFDISC,i,
     +    ATTRID_STA,sta(i),		ATTRID_CHAN,chan(i),
     +    ATTRID_TIME,time(i),		ATTRID_WFID,wfid(i),
     +    ATTRID_CHANID,chanid(i),	ATTRID_JDATE,jdate(i),
     +    ATTRID_ENDTIME,endtime(i),	ATTRID_NSAMP,nsamp(i),
     +    ATTRID_SAMPRATE,samprate(i),	ATTRID_CALIB,calib(i),
     +    ATTRID_CALPER,calper(i),	ATTRID_INSTYPE,instype(i),
     +    ATTRID_SEGTYPE,segtype(i),	ATTRID_DATATYPE,datatype(i),
     +    ATTRID_CLIP,clip(i),		ATTRID_DIR,dir(i),
     +    ATTRID_DFILE,dfile(i),	ATTRID_FOFF,foff(i),
     +    ATTRID_COMMID,commid(i),	    0)
	 if(i.eq.1) print *, jdate(i)
	enddo

	return
	end
C###########################################################################
       subroutine anarg(narg,name,stanam,nst,chan,nch,it,t,endt)
c---------to interpret the line of optional arguments-----------------
c      option -s - selection of stations
c      arguments: at least one station code
c      option -c - selection of channels 
c      arguments: at least one channel code
c      option -t - zooming
c      arguments: two strings of numbers for beginning and end of record
c      year, jday, hour, min (integer*4) and sec (real*4)
c      if there is no -t option, it=0
c      no changes of times at wfdisc
c      if there is -t option, it=1
c      times at wfdisc may be changed.
c      t is a start time, endt is an end time g
c      using  real*8 function h2e(year, day, hour, min, sec)
c----------------------------------------------------------------------
       character*8 name(1)
       character*6 stanam(1)
       character*8 chan(1)
       character*2 si(3)
       character*1 iq
       real*8 endt,t,sec1,sec2,dt,h2e 
       integer iname(3)
       data si/'-s','-c','-t'/
       iq(k)=name(k)(1:1)
c----------------------------------------------------------------------
       nst=0
       nch=0
       it=0
       do j=1,3
       iname(j)=0
       do 4 i=1,narg
       if (name(i)(1:2).eq.si(j)) iname(j)=i  
4       continue
	end do 
       do 3 j=1,2
       if (iname(j).eq.0) go to 3 
	     do 1 k=iname(j)+1,narg
	  if (iq(k).eq.'-') go to 3 
	if (j.eq.1) then
		    stanam(k-iname(1))= name(k)(1:6)
		    nst=nst+1
		    end if
	if (j.eq.2) then
		    chan(k-iname(2))= name(k)(1:8)
		    nch=nch+1
		    end if
1       continue
3       continue
        if(iname(1).ne.0) print 1000,(stanam(i),i=1,nst)
        if(iname(2).ne.0) print 1001,(chan(i),i=1,nch)
	   il=iname(3)
	if (il.ne.0) then
	       do i=1,10
        if(iq(il+i).eq.'-'.or.il+i.gt.narg) 	go to 2
	       end do
	       read(name(il+1),*)iyear1
	       read(name(il+2),*)iday1
	       read(name(il+3),*)ihour1
	       read(name(il+4),*)min1
	       read(name(il+5),*)sec1
	       s1=sec1
	       read(name(il+6),*)iyear2
	       read(name(il+7),*)iday2
	       read(name(il+8),*)ihour2
	       read(name(il+9),*)min2
	       read(name(il+10),*)sec2
	       s2=sec2
c most	       print 1002,iyear1,iday1,ihour1,min1,s1
c most	       print 1003,iyear2,iday2,ihour2,min2,s2
	       t=h2e(iyear1,iday1,ihour1,min1,sec1) 
	       endt=h2e(iyear2,iday2,ihour2,min2,sec2) 
	       dt= endt-t
	       ddt=dt
c most	       print 1004 , ddt
	       if (dt.le.0.0) go to 2
	       it=1
	 end if
	       return
2       STOP ' WRONG TIME INTERVAL'
1000  format(' REQUESTED STATIONS ARE: ',20(a6,1X))
1001  format(' REQUESTED CHANNELS ARE: ',20(a8,1X))
1002  format(' REQUESTED START TIME: ',4I4,1X,F5.2)
1003  format(' REQUESTED  END  TIME: ',4I4,1X,F5.2)
1004  format(' REQUESTED TIME LENGTH IS ',F15.3, ' SEC') 
        END  
C####################################################################
       SUBROUTINE namfile(ituple,dfile,iyear,iday,ihour,min,sec,
     * sta,chan,iq)
C--------to get a new filename according the filename convention--------
       character*32 dfile
       character*8 nm1,chan
       character*6 sta 
       real*8 sec
	 nst=lnblnk(sta)
	 nch=lnblnk(chan)
	 iq=19+nst+nch
         dfile(5:iq)='.000.00.00.00.'//sta(1:nst)//'.'//chan(1:nch)
         write(nm1(1:4),'(i4)') iyear
	 dfile(1:4)=nm1(1:4)
	 if(iday.lt.10) then
	 write(nm1(1:1),'(i1)')iday
	  dfile(8:8)=nm1(1:1)
	  goto 66
	       endif
	 if(iday.lt.100) then
	 write(nm1(1:2),'(i2)')iday
	  dfile(7:8)=nm1(1:2)
	       else
	 write(nm1(1:3),'(i3)')iday
	  dfile(6:8)=nm1(1:3)
	       endif
66        if(ihour.lt.10) then
          write(nm1(1:1),'(i1)')ihour
	 dfile(11:11)=nm1(1:1)
	   else   
          write(nm1(1:2),'(i2)')ihour
         dfile(10:11)=nm1(1:2)
	   end if
         if(min.lt.10)then
	 write(nm1(1:1),'(i1)') min
	 dfile(14:14)=nm1(1:1)
	      else
	 write(nm1(1:2),'(i2)') min
	 dfile(13:14)=nm1(1:2)
	  end if
          isec=int(sec)
	  if(isec.lt.10) then
	  write(nm1(1:1),'(i1)') isec
	  dfile(17:17)=nm1(1:1)
	  else
	  write(nm1(1:2),'(i2)') isec
	  dfile(16:17)=nm1(1:2)
	  endif
111      print 1000,ituple,sta,chan,dfile(1:iq)
1000     format(i3,2x,a6,2x,a8,2x,a32)
	 return
	 end
