/* Copyright (c) 1993-1996 University of Colorado */
/* All rights reserved */

#include <stdio.h>
#include <string.h>

#include "db.h"
#include "stock.h"

int usage()
{
    fprintf(stderr, "Usage: %s database id [idstart]\n", Program_Name);
    exit(1);
    
}

Tbl            *
remap_deftable(dbdef, deftable, idname, idstart, new_lastid)
Dbptr           dbdef;
char           *deftable,
               *idname;
int             idstart;
int		*new_lastid ;
{
    Tbl            *oldids;
    int             nrecords;
    int             require_unique;
    int             id,
                    newid,
                    replacement;
    Tbl            *primary,
                   *alternate;

    dbquery(dbdef, dbRECORD_COUNT, &nrecords);
    oldids = newtbl(nrecords);

    dbquery(dbdef, dbPRIMARY_KEY, &primary);
    dbquery(dbdef, dbALTERNATE_KEY, &alternate);
    if ((maxtbl(primary) == 1 && strcmp(idname, gettbl(primary, 0)) == 0)
    || (maxtbl(alternate) == 1 && strcmp(idname, gettbl(alternate, 0)) == 0))
	require_unique = 1;
    else
	require_unique = 0;

    for (dbdef.record = 0; dbdef.record < nrecords; dbdef.record++)
      {
	dbgetv(dbdef, 0, idname, &id, 0);
	if (idstart > 0)
	  {
	    newid = dbdef.record + idstart;
	    dbputv(dbdef, 0, idname, newid, 0);
	    if (id > 0)
	      {
		if ((replacement = (int) gettbl(oldids, id)) != 0)
		  {
		    if (require_unique)
			complain(0, "Id #%d was repeated in defining table '%s' at record #%d\n\
\tThe new id for the first instance is %d\n\
\tThe new id for this record is %d\n",
			    id, deftable, dbdef.record, replacement, newid);
		    else
			dbputv(dbdef, 0, idname, replacement, 0);
		  }
		else
		    settbl(oldids, id, newid);
	      }
	  }
	else if (id >= 0)
	    dbputv(dbdef, 0, idname, -1, 0);
      }
    *new_lastid = nrecords + idstart - 1;
    return oldids;
}

int
remap_reftable(oldids, db, atable, idname)
Tbl            *oldids;
Dbptr           db;
char           *atable,
               *idname;
{
    int             n,
                    id,
                    newid;

    db = dblookup(db, 0, atable, 0, 0);
    dbquery(db, dbRECORD_COUNT, &n);
    if (n > 0)
      {
	for (db.record = 0; db.record < n; db.record++)
	  {
	    dbgetv(db, 0, idname, &id, 0);
	    if (id > 0)
	      {
		if (oldids)
		  {
		    newid = (int) gettbl(oldids, id);
		    if (newid > 0)
			dbputv(db, 0, idname, newid, 0);
		    else
		      {
			complain(0, "Unrecognized id #%d at record #%d in table '%s' -- set to -1\n",
				 id, db.record, atable);
			dbputv(db, 0, idname, -1, 0);
		      }
		  }
		else
		    dbputv(db, 0, idname, -1, 0);
	      }
	  }
      }
return 0;
}

int
remap_wftag(oldids, db, idname)
Tbl            *oldids;
Dbptr           db;
char           *idname;
{
    int             n,
                    id,
                    newid;
    char            tagname[25];

    db = dblookup(db, 0, "wftag", 0, 0);
    dbquery(db, dbRECORD_COUNT, &n);
    if (n > 0)
      {
	for (db.record = 0; db.record < n; db.record++)
	  {
	    dbgetv(db, 0, "tagname", tagname, "tagid", &id, 0);
	    if (strcmp(tagname, idname) == 0)
	      {
		if (id > 0)
		  {
		    if (oldids)
		      {
			newid = (int) gettbl(oldids, id);
			if (newid > 0)
			    dbputv(db, 0, "tagid", newid, 0);
			else
			  {
			    complain(0, "Unrecognized id #%d at record #%d in table '%s' -- set to -1\n",
				     id, db.record, "wftag");
			    dbputv(db, 0, "tagid", -1, 0);
			  }
		      }
		    else
			dbputv(db, 0, "tagid", -1, 0);
		  }
	      }
	  }
      }
return 0;
}

int
patch_lastid(new_lastid, db, idname)
int		new_lastid ;
Dbptr           db;
char           *idname;
{
    int             n;
    char            keyname[25];

    db = dblookup(db, 0, "lastid", 0, 0);
    dbquery(db, dbRECORD_COUNT, &n);
    if (n > 0)
      {
	for (db.record = 0; db.record < n; db.record++)
	  {
	    dbgetv(db, 0, "keyname", keyname, 0);
	    if (strcmp(keyname, idname) == 0) {
		dbputv ( db, 0, "keyvalue", new_lastid, 0 ) ; 
		break ;
	    }
	      
	  }
      }
return 0;
}

int
main(argc, argv)
int             argc;
char          **argv;
{
    char           *database,
                   *idname;
    int             idstart = 1;
    Dbptr           db,
                    dbdef;
    char           *deftable,
                   *atable,
                   *schema;
    Tbl            *tables,
                   *oldids;
    Arr            *links;
    int             i,
                    j,
                    nrecords,
                    ntables,
                    naliases;
    int             writeable,
                    nowrite = 0;
    Pf             *pf,
                   *pfschema,
                   *pfaliases ;
    char           *alias_list,
                   *analias;
    Tbl            *aliases;
    int		    new_lastid ;

    Program_Name = argv[0];

    if (argc > 1 && strcmp(argv[1], "-V") == 0 ) {
	banner ( Program_Name, "Version 1.5 11/14/96\n" ) ; 
	exit(0) ; 
    }

    if (argc != 3 && argc != 4)
	usage();

    database = argv[1];
    idname = argv[2];
    if (argc > 3)
	idstart = atoi(argv[3]);

    if (dbopen(database, "r+", &db))
	die(1, "Can't open database %s'\n", database);

    if (pfread(Program_Name, &pf) != 0)
	die(0, "Can't read parameter file\n");

    dbquery(db, dbSCHEMA_NAME, &schema);

    dbquery(db, dbLINK_FIELDS, &links);
    deftable = getarr(links, idname);
    if (deftable == 0)
      {
	die(0, "'%s' does not appear to be an id field in the schema '%s'.\n",
	    idname, schema);
      }

    dbdef = dblookup(db, 0, deftable, 0, 0);
    dbquery(dbdef, dbRECORD_COUNT, &nrecords);
    if (idstart > 0 && nrecords < 1)
	die(0, "Table '%s' defines id field '%s', but has no records.\n",
	    deftable, idname);

    aliases = newtbl(0);
    /*                    (void **) - Mostinski corections */          
    if (pfget(pf, schema, (void **)&pfschema) == PFARR    
	&& pfget(pfschema, "aliases", (void **)&pfaliases) == PFARR	
	&& pfget(pfaliases, idname,(void **) &alias_list) == PFSTRING)
      {
	alias_list = strdup(alias_list);
	while ( (analias = strtok(alias_list, " \t") ) )
	  {
	    alias_list = 0 ; 
	    pushtbl(aliases, analias);
	    tables = dbtables(db, analias);
	    ntables = maxtbl(tables);
	    for (i = 0; i < ntables; i++)
	      {
		atable = gettbl(tables, i);
		db = dblookup(db, 0, atable, 0, 0);
		dbquery(db, dbRECORD_COUNT, &nrecords);
		if (nrecords > 0)
		  {
		    dbquery(db, dbTABLE_IS_WRITEABLE, &writeable);
		    if (!writeable)
		      {
			complain(0, "Can't write to table '%s'\n", atable);
			nowrite = 1;
		      }
		  }
	      }
	  }
      }

    tables = dbtables(db, idname);
    ntables = maxtbl(tables);
    for (i = 0; i < ntables; i++)
      {
	atable = gettbl(tables, i);
	db = dblookup(db, 0, atable, 0, 0);
	dbquery(db, dbRECORD_COUNT, &nrecords);
	if (nrecords > 0)
	  {
	    dbquery(db, dbTABLE_IS_WRITEABLE, &writeable);
	    if (!writeable)
	      {
		complain(0, "Can't write to table '%s'\n", atable);
		nowrite = 1;
	      }
	  }
      }
    if (nowrite)
	die(0, "Can't update id field -- no ids were changed\n");

    oldids = remap_deftable(dbdef, deftable, idname, idstart, &new_lastid);

    for (i = 0; i < ntables; i++)
      {
	atable = gettbl(tables, i);
	if (strcmp(atable, deftable) == 0)
	    continue;
	remap_reftable(oldids, db, atable, idname);
      }

    naliases = maxtbl(aliases);
    for (j = 0; j < naliases; j++)
      {
	analias = gettbl(aliases, j);
	tables = dbtables(db, analias);
	ntables = maxtbl(tables);
	for (i = 0; i < ntables; i++)
	  {
	    atable = gettbl(tables, i);
	    remap_reftable(oldids, db, atable, analias);
	  }
      }

    remap_wftag(oldids, db, idname);
    patch_lastid(new_lastid, db, idname) ; 

    return 0;
}
