#include <qapplication.h>
#include <qdatastream.h>
#include <qfile.h>
#include <qdir.h>
#include <qiodevice.h>
#include <qmessagebox.h>
#include "mainwindow.h"
#include "document.h"
#include "stationlistimpl.h"
#include "defaults.h"
 
bool findItChanel(vector<ChanValue* >* chan,QString &name,QString &state,
                  vector<ChanValue* >::iterator &itChan) {
    vector<ChanValue* >::iterator it;
    for (it = chan->begin() ; it != chan->end(); ++it) {
        if ( (*it)->GetName() == name &&  (*it)->GetTextCol1() == state) {
            itChan = it;
            return true;
        }
    }
    return false;
}

void delAndNullify(PropertyValue* &pPropVal) {
    delete  pPropVal;
    pPropVal = 0;
}
void deleteChannelAndNullify( ChanValue* &chanVal) {
    delete  chanVal;
    chanVal = 0;
}
void deleteStationAndNullify( StaValue* &staVal) {
    delete  staVal;
    staVal = 0;
}
StaValue::~StaValue() { 
    for_each(chans.begin(),chans.end(),deleteChannelAndNullify);

    chans.erase(remove(chans.begin(),chans.end(),
                       static_cast<ChanValue*>(0)),
                chans.end());
}
StaValue::StaValue(QString name) : RowValue(0,name) {}
ChanValue::~ChanValue() {
}

ChanValue::ChanValue(int id,QString name): RowValue(id,name) {}
ChanValue::ChanValue(int id,QString name,QString textcol1,QString dfile): RowValue(id,name,textcol1,dfile) {}
RowValue::~RowValue() {}
RowValue::RowValue(int id,QString name):id(id),name( name) {
    markDelete=false;
    minperiod = QString();
    maxperiod = QString();
    comment = QString();
    accept = false;
}
RowValue::RowValue(int id,QString name,QString textcol1,QString dfile):id(id),name( name),
        textCol1(textcol1),dfile(dfile) {
    markDelete = false;
    QString minperiod;
    QString maxperiod;
    QString comment;
    accept = false;
}
///////////////////// PropertyValue Implemenation ///////////////////////////////
PropertyValue::PropertyValue( const int i,const QString defval,const QString name) :
        id(i),value(defval),initialvalue(defval),resetvalue(defval),defaultvalue(defval),name(name),changed(FALSE) {}
PropertyValue::PropertyValue(const int i, const QString resval,const QString defval,const QString name) :
        id(i),value(resval),initialvalue(resval),resetvalue(resval),defaultvalue(defval),name(name),changed(FALSE) {}
PropertyValue::PropertyValue( const int i,const  QString val, const QString resval,const QString defval,const QString name):
        id(i),value(val),initialvalue(val),resetvalue(resval),defaultvalue(defval),name(name),changed(FALSE) {}
void PropertyValue::setChanged( bool b) {
    if ( changed == b )
        return;
    changed = b;
    //repaint();

}

bool PropertyValue::isChanged() const {
    return changed;
}
bool PropertyValue::isReseted() const {
    if (value == resetvalue) return FALSE;
    else return TRUE;
}
QDataStream &operator<< (QDataStream & out, const PropertyValue * prop) {

    out <<   prop->GetId() <<    prop->GetValue();
    return out;
}
QDataStream &operator>>(QDataStream & in, PropertyValue & prop) {
    QString v;
    int id;
    in >>   id  >>  v;
    prop.SetId(id);
    prop.SetResetvalue(v);
    return in;
}
///////////////////// <: inherits from PropertyValue :> //////////////////////////

///////////////////// PropertyBoolValue Implemenation ///////////////////////////
PropertyBoolValue::PropertyBoolValue(const int i, const QString defval,const QString name ) :
        PropertyValue(i,defval ,name) {
    kind = PropertyValue::Property_Bool;
}
PropertyBoolValue::PropertyBoolValue( const int i, const QString resval, const QString defval ,const QString name) :
        PropertyValue(i, resval,defval ,name) {
    kind = PropertyValue::Property_Bool;
}
PropertyBoolValue::PropertyBoolValue( const int i, const QString val,const  QString resval,const QString defval,const QString name) :
        PropertyValue(i, val,resval,defval,name ) {
    kind = PropertyValue::Property_Bool;
}
///////////////////// PropertyIntValue Implemenation ///////////////////////////
PropertyIntValue::PropertyIntValue( const int i,const QString defval ,const QString name,const int min,const int max, const bool s):
        PropertyValue(i,defval ,name),
        min(min),max(max), signedValue(s) {
    kind = PropertyValue::Property_Int;
}
PropertyIntValue::PropertyIntValue( const int i,const  QString resval,const QString defval ,const QString name,const int min,const int max, const bool s):
        PropertyValue( i,resval,defval ,name),
        min(min),max(max), signedValue(s) {
    kind = PropertyValue::Property_Int;
}

PropertyIntValue::PropertyIntValue( const int i, const  QString val, const  QString resval,const QString defval,const QString name,const int min,const int max, const bool s):
        PropertyValue( i,val,resval,defval,name ),
        min(min),max(max), signedValue(s) {
    kind = PropertyValue::Property_Int;
}
///////////////////// PropertyFloatValue Implemenation ///////////////////////////

PropertyFloatValue::PropertyFloatValue( const int i,  const QString defval ,const QString name,
                                        const float min,const float max, const int dec) :
        PropertyValue(i,defval ,name),
        min(min),max(max), decimal(dec) {
    kind = PropertyValue::Property_Float;
}

PropertyFloatValue::PropertyFloatValue(  const int i, const QString resval,const QString defval,
        const QString name,
        const float min,const float max, const int dec ) :
        PropertyValue(i, resval,defval ,name),
        min(min),max(max), decimal(dec) {
    kind = PropertyValue::Property_Float;
}

PropertyFloatValue::PropertyFloatValue( const int i, const  QString val,const  QString resval,
                                        const QString defval,const QString name,
                                        const float min,const float max, const int dec):
        PropertyValue( i,val,resval,defval,name ),
        min(min),max(max), decimal(dec) {
    kind = PropertyValue::Property_Float;
}

///////////////////// PropertyEnumValue Implemenation ///////////////////////////

PropertyEnumValue::PropertyEnumValue( const int i,  const QString defval ,const QString name,const QString lst) :
        PropertyValue(i,defval ,name) {
    kind = PropertyValue::Property_Enum;
    list = QStringList::split (' ',lst);
}
PropertyEnumValue::PropertyEnumValue(  const int i,  const QString resval,const QString defval ,const QString name,const QString lst) :
        PropertyValue( i,resval,defval ,name) {
    kind = PropertyValue::Property_Enum;
    list = QStringList::split (' ',lst);
}
PropertyEnumValue::PropertyEnumValue( const int i,  const  QString val, const QString resval,const QString defval,const QString name,const QString lst):
        PropertyValue( i,val,resval,defval,name ) {
    kind = PropertyValue::Property_Enum;
    list = QStringList::split (' ',lst);
}


///////////////////// PropertyStringValue Implemenation ///////////////////////////

PropertyStringValue::PropertyStringValue( const int i,  const QString defval ,const QString name) :
        PropertyValue(i,defval ,name) {
    kind = PropertyValue::Property_String;
}
PropertyStringValue::PropertyStringValue(  const int i,  const QString resval,const QString defval ,const QString name) :
        PropertyValue( i,resval,defval ,name) {
    kind = PropertyValue::Property_String;
}
PropertyStringValue::PropertyStringValue( const int i,  const  QString val, const QString resval,const QString defval,const QString name):
        PropertyValue( i,val,resval,defval,name ) {
    kind = PropertyValue::Property_String;
}
///////////////////// PropertyStringListValue Implemenation ///////////////////////////
void FDocument::SetPropertyIntValue(PropertyIntValue* &p, int id,QString reset,QString defaultvalue,
                                    QString name,int min,int max,bool sign) {
    p = new PropertyIntValue(id,reset,defaultvalue,name,min,max,sign);
    values.push_back(p);
}
void FDocument::SetPropertyFloatValue(PropertyFloatValue* &p, int id,QString reset,QString defaultvalue,
                                      QString name,float min,float max,int decimal) {
    p = new PropertyFloatValue(id,reset,defaultvalue,name,min,max,decimal);
    values.push_back(p);
}

void FDocument::SetPropertyEnumValue(PropertyEnumValue* &p, int id,QString reset,QString defaultvalue,
                                     QString name,QString enumeration) {
    p = new PropertyEnumValue(id,reset,defaultvalue,name,enumeration);
    values.push_back(p);
}
void FDocument::SetPropertyStringValue(PropertyStringValue* &p, int id,QString reset,QString defaultvalue,
                                       QString name) {
    p = new PropertyStringValue(id,reset,defaultvalue,name);
    values.push_back(p);
}



///////////////////// FDocument class implementation ////////////////////////////

FDocument::~FDocument() {

    for_each(values.begin(),values.end(),delAndNullify);

    values.erase(remove(values.begin(),values.end(),
                        static_cast<PropertyValue*>(0)),
                 values.end());

    for_each(stations.begin(),stations.end(),deleteStationAndNullify);
    stations.erase(remove(stations.begin(),stations.end(),
                          static_cast<StaValue*>(0)),
                   stations.end());
    for_each(staouts.begin(),staouts.end(),deleteStationAndNullify);
    staouts.erase(remove(staouts.begin(),staouts.end(),
                         static_cast<StaValue*>(0)),
                  staouts.end());
}
vector<StaValue* >::iterator FDocument::GetStaIterator(QString sta,vector<StaValue* >* lst) {
    vStaIt itSta;
    if (! lst->empty())
        for  ( itSta = lst->begin();  itSta != lst->end(); itSta++)
            if ((*itSta)->GetName() == sta) {
                return itSta;
            }
    return  lst->end();
}

bool FDocument::ReadFileListCtachan() {
    QFile file(  "list_stachan" );
    if ( !file.open( QIODevice::ReadOnly ) ) {
        QMessageBox::warning(0,mainWindowCaption(),"Can't open file 'list_stachan'");
        return false;
    }
    Q3TextStream stream( &file );  // read the data serialized from the file
    QString tmp,str = "";
    while (!file.atEnd()) {
        tmp = stream.readLine ();
        str += tmp + ";";
    }
    file.close();
    QFile fil(  "list_stachan" );
    if ( fil.exists())
        if (!fil.remove()) {
            QMessageBox::warning(0,mainWindowCaption(),"Can't remove file 'list_stachan'");
            return false;
        }

    QStringList valuelist = QStringList::split (';', str);
    QStringList::iterator it;
    int i = 0;
    for (i = 0, it = valuelist.begin() ; it != valuelist.end(); ++it ,i++) {
        int j;
        QString sta,chan;

        j = valuelist[i].left(valuelist[i].findRev(' ') ).toInt();

        QString tmp = valuelist[i].right(valuelist[i].length()  - valuelist[i].findRev(" ") - 1);
        sta = tmp.section( ':', 0,0 );
        chan = tmp.section( ':', 1,1 );
        chan.remove(chan.length() -1,1);

        vStaIt itSta;
        if ( (itSta = GetStaIterator(sta,&stations)) != stations.end() )
            (*itSta)->GetChans().push_back(new ChanValue(j,chan));
        else {
            stations.push_back(new StaValue(sta));
            itSta = stations.end();
            itSta--;
            (*itSta)->GetChans().push_back(new ChanValue(j,chan));
        }

    }
    sortStationList(&stations);
    return true;
}
void FDocument::sortStationList(vector<StaValue* >* lst) {
    if (lst->empty()) return;
    vStaIt itSta;
    sort(lst->begin(),lst->end(),sta_Comp());
    itSta = lst->begin();
    while (itSta != lst->end()) {
        vChan Chan = (*itSta)->GetChans();
        sort(Chan.begin(),Chan.end(),chan_Comp());
        itSta++;
    }
}
void FDocument::initEmptyStationList(vector<StaValue* > &lst) {

    if (lst.empty()) {
        qWarning("Nothing to print ");
        return;
    }
    vStaIt itSta;
    vChanIt itChan;
    vChan Chan;
    itSta = lst.begin();
    while (itSta != lst.end()) {
        if ((*itSta)->GetTextCol1().isEmpty()) (*itSta)->SetTextCol1("XX");
        Chan = (*itSta)->GetChans();
        itChan = Chan.begin();
        for  ( itChan = Chan.begin();  itChan != Chan.end(); itChan++)
            if ((*itChan )->GetTextCol1().isEmpty()) (*itChan )->SetTextCol1("ZZ");
        itSta++;
    }
}
void FDocument::printStationList(vector<StaValue* > &lst) {

    if (lst.empty()) {
        qWarning("Nothing to print ");
        return;
    }
    qWarning("List of Stations(%d) and Channels",lst.size());
    vStaIt itSta;
    vChanIt itChan;
    vChan Chan;
    itSta = lst.begin();
    while (itSta != lst.end()) {
        QString tmp = "";
        if ((*itSta)->GetMarkDelete()) tmp = "Exclude";
        else  tmp = "Include";
        qWarning("sta:  '%s'  state  '%s'  %s", (*itSta)->GetName().ascii(),(*itSta)->GetTextCol1().ascii(),tmp.ascii());
        Chan = (*itSta)->GetChans();
        itChan = Chan.begin();
        qWarning("       chan(%d): ",Chan.size());
        int i = 0;
        for  ( itChan = Chan.begin();  itChan != Chan.end(); itChan++) {
            if ((*itChan )->GetMarkDelete()) tmp = "Exclude";
            else  tmp = "Include";
            qWarning("            %d: '%s'  id(%d)  state  '%s' %s", ++i,(*itChan )->GetName().ascii(),(*itChan )->GetId(),(*itChan )->GetTextCol1().ascii(),tmp.ascii());

        }
        itSta++;
    }
}
FDocument::FDocument(QString wFile,QString rFile,QString oFile,QString eInfo,QString numOriginRow):
        wfdiscAbsPath(wFile),rootAbsPath(rFile),originAbsPath(oFile),eventInfo(eInfo),numOriginRow(numOriginRow) {
///-----------------------------------------  Window characteristic: -----------------------------------------
    widowSize              = new PropertyEnumValue(idWindowSize(),defaultWindowSize(),nameWindowSize(),enumWindowSize());
    values.push_back(widowSize);
    widowMode              = new PropertyEnumValue( idWindowMode(),defaultWindowMode(),nameWindowMode(),enumWindowMode());
    values.push_back(widowMode);
    postscript              = new PropertyEnumValue(idPostscript(),defaultPostscript(),namePostscript(),enumPostscript());
    values.push_back(postscript);
///----------------------------------------- Plot characteristic:  ----------------------------------------
    ftaWaveTypeOverPlot              = new PropertyEnumValue( idFtaWaveTypeOverPlot(),defaultFtaWaveTypeOverPlot(),
            nameFtaWaveTypeOverPlot(),enumFtaWaveTypeOverPlot());
    values.push_back(ftaWaveTypeOverPlot);
    ftaGroupVelocityPlot              = new PropertyEnumValue(idFtaGroupVelocityPlot(),defaultFtaGroupVelocityPlot(),
            nameFtaGroupVelocityPlot(),enumFtaGroupVelocityPlot());
    values.push_back(ftaGroupVelocityPlot);
    xaxisScaling             = new PropertyEnumValue(idXaxisScaling(),defaultXaxisScaling(),
            nameXaxisScaling(),enumXaxisScaling());
    values.push_back(xaxisScaling);
///-----------------------------------------Edit handling:  ----------------------------------------
    editApplied              = new PropertyEnumValue( idEditApplied(),defaultEditApplied(),
            nameEditApplied(),enumEditApplied());
    values.push_back(editApplied);
    interpolateNominalGrid              = new PropertyEnumValue( idInterpolateNominalGrid(),defaultInterpolateNominalGrid(),
            nameInterpolateNominalGrid(),enumInterpolateNominalGrid());
    values.push_back(interpolateNominalGrid);
///-----------------------------------------Waveform:  ----------------------------------------
    plotCompt          = new PropertyEnumValue( idPlotCompts(),defaultPlotCompts(),namePlotCompts(),
            enumPlotCompts());
    values.push_back(plotCompt);

    shortPeriodZero    = new PropertyFloatValue( idShortPeriodZero(),defaultShortPeriodZero(),nameShortPeriodZero(),minShortPeriodZero(),maxShortPeriodZero(),decimalShortPeriodZero());
    values.push_back(shortPeriodZero);

    shortPeriodCorner  = new PropertyFloatValue( idShortPeriodCorner(),defaultShortPeriodCorner(),nameShortPeriodCorner(),minShortPeriodCorner(),maxShortPeriodCorner(),decimalShortPeriodCorner());
    values.push_back(shortPeriodCorner);

    longPeriodCorner   = new PropertyFloatValue(idLongPeriodCorner(),defaultLongPeriodCorner(),nameLongPeriodCorner(),minLongPeriodCorner(),maxLongPeriodCorner(),decimalLongPeriodCorner());
    values.push_back(longPeriodCorner);

    longPeriodZero     = new PropertyFloatValue( idLongPeriodZero(),defaultLongPeriodZero(),nameLongPeriodZero(),minLongPeriodZero(),maxLongPeriodZero(),decimalLongPeriodZero());
    values.push_back(longPeriodZero);

///-----------------------------------------Measurement specification:  ----------------------------------------
    outPutImagePhase           = new PropertyEnumValue( idOutPutImagePhase(),defaultOutPutImagePhase(),
            nameOutPutImagePhase(),enumOutPutImagePhase());
    values.push_back(outPutImagePhase);
    instrumentResponse           = new PropertyEnumValue( idInstrumentResponse(),defaultInstrumentResponse(),nameInstrumentResponse(),
            enumInstrumentResponse());
    values.push_back(instrumentResponse);
    changeAlphaFilter           = new PropertyEnumValue( idChangeAlphaFilter(),defaultChangeAlphaFilter(),nameChangeAlphaFilter(),
            enumChangeAlphaFilter());
    values.push_back(changeAlphaFilter);
    ftaCompt           = new PropertyEnumValue( idFtaCompts(),defaultFtaCompts(),nameFtaCompts(),
            enumFtaCompts());
    values.push_back(ftaCompt);
    polar              = new PropertyEnumValue( idPolar(),defaultPolar(),namePolar(),enumPolar());
    values.push_back(polar);
///-----------------------------------------Phase velocity information:  ----------------------------------------
    phaseVelocityMeasurement           = new PropertyEnumValue( idPhaseVelocityMeasurement(),
            defaultPhaseVelocityMeasurement(),
            namePhaseVelocityMeasurement(),
            enumPhaseVelocityMeasurement());
    values.push_back(phaseVelocityMeasurement);
    phaseVelBoundMinimum     = new PropertyFloatValue( idPhaseVelBoundMinimum(),
            defaultPhaseVelBoundMinimum(),
            namePhaseVelBoundMinimum(),
            minPhaseVelBoundMinimum(),
            maxPhaseVelBoundMinimum(),
            decimalPhaseVelBoundMinimum());
    values.push_back(phaseVelBoundMinimum);
    phaseVelBoundMaximum     = new PropertyFloatValue(idPhaseVelBoundMaximum(),
            defaultPhaseVelBoundMaximum(),
            namePhaseVelBoundMaximum(),
            minPhaseVelBoundMaximum(),
            maxPhaseVelBoundMaximum(),
            decimalPhaseVelBoundMaximum());
    values.push_back(phaseVelBoundMaximum);
    phaseVelRefPeriod     = new PropertyFloatValue( idPhaseVelRefPeriod(),
            defaultPhaseVelRefPeriod(),
            namePhaseVelRefPeriod(),
            minPhaseVelRefPeriod(),
            maxPhaseVelRefPeriod(),
            decimalPhaseVelRefPeriod());
    values.push_back(phaseVelRefPeriod);
///-----------------------------------------Analysis limits:  ----------------------------------------
    groupVelBoundMinimum     = new PropertyFloatValue(idGroupVelBoundMinimum(),
            defaultGroupVelBoundMinimum(),
            nameGroupVelBoundMinimum(),
            minGroupVelBoundMinimum(),
            maxGroupVelBoundMinimum(),
            decimalGroupVelBoundMinimum());
    values.push_back(groupVelBoundMinimum);

    groupVelBoundMaximum     = new PropertyFloatValue(idGroupVelBoundMaximum(),
            defaultGroupVelBoundMaximum(),
            nameGroupVelBoundMaximum(),
            minGroupVelBoundMaximum(),
            maxGroupVelBoundMaximum(),
            decimalGroupVelBoundMaximum());
    values.push_back(groupVelBoundMaximum);
    periodBoundMinimum     = new PropertyFloatValue(idPeriodBoundMinimum(),
            defaultPeriodBoundMinimum(),
            namePeriodBoundMinimum(),
            minPeriodBoundMinimum(),
            maxPeriodBoundMinimum(),
            decimalPeriodBoundMinimum());
    values.push_back(periodBoundMinimum);
    periodBoundMaximum     = new PropertyFloatValue( idPeriodBoundMaximum(),
            defaultPeriodBoundMaximum(),
            namePeriodBoundMaximum(),
            minPeriodBoundMaximum(),
            maxPeriodBoundMaximum(),
            decimalPeriodBoundMaximum());
    values.push_back(periodBoundMaximum);
    ftaOrbit    =    new     PropertyIntValue(idOrbit(),defaultOrbit(),nameOrbit(),minOrbit(),maxOrbit(),signedOrbit());
    values.push_back(ftaOrbit);
    ftaMode   =    new     PropertyIntValue(idMode(),defaultMode(),nameMode(),minMode(),maxMode(),signedMode());
    values.push_back(ftaMode);
    rowSpectrumGroupVelocity     = new PropertyFloatValue(idRowSpectrumGroupVelocity(),
            defaultRowSpectrumGroupVelocity(),
            nameRowSpectrumGroupVelocity(),
            minRowSpectrumGroupVelocity(),
            maxRowSpectrumGroupVelocity(),
            decimalRowSpectrumGroupVelocity());
    values.push_back(rowSpectrumGroupVelocity);
    rowSpectrumWidth     = new PropertyFloatValue( idRowSpectrumWidth(),
            defaultRowSpectrumWidth(),
            nameRowSpectrumWidth(),
            minRowSpectrumWidth(),
            maxRowSpectrumWidth(),
            decimalRowSpectrumWidth());
    values.push_back(rowSpectrumWidth);
///-----------------------------------------Event information:  ----------------------------------------
    readCentridMomentRelation              = new PropertyEnumValue( idReadCentridMomentRelation(),
            defaultReadCentridMomentRelation(),
            nameReadCentridMomentRelation(),
            enumReadCentridMomentRelation());
    values.push_back(readCentridMomentRelation);

}
bool FDocument::isModified() {
    PropValIterator i = find_if(values.begin(),values.end(),mem_fun(&PropertyValue::isChanged));
    if (i!=values.end()) return true;
    else return false;

}
/*
void    FDocument::printFDocument(){
    PrintDocument<PropValVector> P =
	    for_each(values.begin(),values.end(),
		     PrintDocument<PropValVector>(cout));
    cout << "-------------  "<< P.count << " parameters are in document  -------------" << endl<< endl;
    cout << "-------------  "<<  " In Station List  -------------" << endl<< endl;
    printStationList(stations);
    cout << "-------------  "<<  " Out Station List  -------------" << endl<< endl;
    printStationList(staouts);

    cout << "AbsPath wfdisc:  '"<< wfdiscAbsPath <<"'"<<endl;
    cout << "AbsPath root:      '" <<  rootAbsPath << "'"<<endl;
    cout << "AbsPath origin:   '" << originAbsPath <<"'"<<endl;
    cout << "eventInfo:  '"               << eventInfo<< "\""<<endl<<endl;
    cout << "-------------  End of print document  ----------------" << endl<<endl;
}
*/
FDocument::FDocument(const QString &fileName) {

    projectFileGood = true;
    if (!loadBinary(fileName)) projectFileGood = false;

}



bool  FDocument::loadBinary(const QString &fileName) {

    QFile file(fileName);
    if (!file.open(QIODevice::ReadOnly)) {
        ioError(file,"Cannot open file %1 for reading") ;
        return false;
    }
    QDataStream in (&file);
    Q_UINT32 magic;
    in >>  magic;
    if (magic != MagicNumber) {
        error(file,"File %1 is not a Ftan file. Bad Format.");
        return false;
    }
    Q_INT32 ftanVersion;

    in >>  ftanVersion;
    ftanincurrentversion = ftanVersion;
    QStringList words =  QStringList::split(" ",FtanVersionsForQt6());
    int minForQt6 =  words[0].toInt();
    int maxForQt6 =  words[1].toInt();

    if ( ftanVersion  >=  minForQt6 && ftanVersion  <=  maxForQt6 )
        in.setVersion(VersionQDataStreamQt332().toInt());

    words =  QStringList::split(" ",FtanVersionsForQt433());
    int minForQt =  words[0].toInt();
    int maxForQt =  words[1].toInt();

    if ( ftanVersion  >=  minForQt && ftanVersion  <=  maxForQt )
        in.setVersion(QDataStream::Qt_4_3);

// Here for next    VersionQDataStream
    in >>  wfdiscAbsPath;
    in >>  rootAbsPath;
    in >>  originAbsPath;
    in >> eventInfo;
    if (ftanVersion > (Q_INT32) 110)
        in >> numOriginRow;
    else numOriginRow = "1";
    readFromStream(in);

    if ( file.status() != (uint)IO_Ok  ) {
        ioError(file,"Error reading from file %1") ;
        return false;
    }

    file.close() ;
    return true;
}
void FDocument::readStationList( vector<StaValue* > &stat,QDataStream &in,int ind) {
    vStaIt itSta;
    int nSta;
    in >> nSta;
    for (int i = 0; i< nSta; i++) {
        int idSta;
        in >> idSta;
        QString nameSta;
        in >> nameSta;
        QString text1;
        in >>text1;
        stat.push_back(new StaValue(nameSta));
        itSta = stat.end();
        itSta--;
        (*itSta)->SetTextCol1(text1);
        QStringList words;
        if (ind == 1)   {
            words =  QStringList::split(" ",FtanVersionsForQt433());
            int minForQt =  words[0].toInt();
            int maxForQt =  words[1].toInt();

            if ( ftanincurrentversion  >=  minForQt && ftanincurrentversion  <=  maxForQt ) {
                QString minperiod;
                in >>minperiod;
                (*itSta)->SetMinPeriod(minperiod);
                QString maxperiod;
                in >>maxperiod;
                (*itSta)->SetMaxPeriod(maxperiod);
                QString comment;
                in >>comment;
                (*itSta)->SetComment(comment);
            }
            words =  QStringList::split(" ",FtanVersionsForQt6());
            int minForQt6 =  words[0].toInt();
            int maxForQt6 =  words[1].toInt();

            if ( ftanincurrentversion  >=  minForQt6 && ftanincurrentversion  <=  maxForQt6 ) {
                (*itSta)->SetMinPeriod("0.0");
                (*itSta)->SetMaxPeriod("1000.0");
                (*itSta)->SetComment(QString());
            }
        }
        int nChan;
        in >> nChan;
        for (int j = 0;j<nChan;j++) {
            int idChan;
            in >> idChan;
            QString nameChan;
            in >> nameChan;
            in >> text1;
            QString  dfile;
            in >> dfile;
            (*itSta)->GetChans().push_back(new ChanValue(idChan,nameChan,text1,dfile));

            if (ind == 1)   {
                vChanIt vChan = (*itSta)->GetChans().end();
                vChan--;
                words =  QStringList::split(" ",FtanVersionsForQt433());
                int minForQt =  words[0].toInt();
                int maxForQt =  words[1].toInt();

                if ( ftanincurrentversion  >=  minForQt && ftanincurrentversion  <=  maxForQt ) {
                    QString minperiod;
                    in >>minperiod;
                    (*vChan)->SetMinPeriod(minperiod);
                    QString maxperiod;
                    in >>maxperiod;
                    (*vChan)->SetMaxPeriod(maxperiod);
                    int accept;
                    in >>accept;
                    if (accept == 1)
                        (*vChan)->SetAccept(true);
                    else
                        (*vChan)->SetAccept(false);

                    QString comment;
                    in >>comment;
                    (*vChan)->SetComment(comment);
                }
                words =  QStringList::split(" ",FtanVersionsForQt6());
                int minForQt6 =  words[0].toInt();
                int maxForQt6 =  words[1].toInt();

                if ( ftanincurrentversion  >=  minForQt6 && ftanincurrentversion  <=  maxForQt6 ) {
                    (*vChan)->SetMinPeriod(QString());
                    (*vChan)->SetMaxPeriod(QString());
                    (*vChan)->SetAccept(false);
                    (*vChan)->SetComment(QString());
                }
            }
        }
    }

}
void FDocument::writeStationList( vector<StaValue* > *stat,QDataStream &out,int ind) {

//   printStationList(*stat);

//                     QMessageBox::warning(0,mainWindowCaption(),"POINT0 writeStationList");
    QString periodListFileName = parameterProjectSaveFileName;
    periodListFileName.replace(".bin",".periodlist");

    QFile file(periodListFileName);
    QTextStream period(&file);
    if (ind == 1) if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {

            ioError(periodListFileName,"Can't open for writing file %1") ;
            return;
        }

    vStaIt itSta;
    vChanIt itChan;
    vChan Chan;
    itSta = stat->begin();

    uint sizeStat = 0;
    for  ( itSta = stat->begin();  itSta != stat->end(); itSta++)
        if (!(*itSta)->GetMarkDelete()) sizeStat++;
    out  << sizeStat;

    for  ( itSta = stat->begin();  itSta != stat->end(); itSta++)  {
        if ((*itSta)->GetMarkDelete()) continue;
        out  <<   (*itSta)->GetId();
        out  <<  (*itSta)->GetName();
        out  <<  (*itSta)->GetTextCol1();

        if (ind == 1)   {
            out  <<   (*itSta)->GetMinPeriod();
            out  <<  (*itSta)->GetMaxPeriod();
            out  <<  (*itSta)->GetComment();
        }
        Chan = (*itSta)->GetChans();
        uint sizeChan = 0;
        for  ( itChan = Chan.begin();  itChan != Chan.end(); itChan++)
            if (!(*itChan)->GetMarkDelete()) sizeChan++;

        out  << sizeChan;
        itChan = Chan.begin();
        for  ( itChan = Chan.begin();  itChan != Chan.end(); itChan++)  {
            if ((*itChan)->GetMarkDelete()) continue;
            out  <<   (*itChan)->GetId();
            out  <<  (*itChan)->GetName();
            out  <<   (*itChan)->GetTextCol1();
            out  <<   (*itChan)->GetDfile();

            if (ind == 1)   {
                period  <<  (*itSta)->GetName()<<"@";
                period  <<  (*itChan)->GetName() << "@";
                period  <<   (*itChan)->GetTextCol1()<< "@";
                period  <<  (*itChan)->GetMinPeriod() << "@";
                period  <<  (*itChan)->GetMaxPeriod() << "\n";
                out  <<   (*itChan)->GetMinPeriod();
                out  <<  (*itChan)->GetMaxPeriod();
                int accy = 1;
                int accn = 0;
                if ((*itChan)->GetAccept()) out  << accy;
                else out  << accn;
                out  <<  (*itChan)->GetComment();
            }
        }
    }
file.close();
}
bool  FDocument::saveBinary(const QString &fileName) {
    parameterProjectSaveFileName = fileName;
    QFile file(fileName);
    if (!file.open(QIODevice::WriteOnly)) {
        ioError(file,"Cannot open file %1 for writing") ;
        return false;
    }
    QDataStream out (&file);
    out  <<  (Q_UINT32)MagicNumber;
    Q_INT32 ftanVersion =  (Q_INT32) FtanCurrentVersion().toInt();
    out  <<  ftanVersion;
    out  << wfdiscAbsPath;
    out  << rootAbsPath;
    out  << originAbsPath;
    out  << eventInfo;
    out  << numOriginRow;
    writeToStream(out);
    if ( file.status() != (uint)IO_Ok  ) {
        ioError(file,"Error writing to file %1") ;
        return false;
    }

    if (staouts.empty() ) {
        out  << idIndicatorReadStation();
        out  << nameIndicatorReadStationNo();
        file.close() ;
        return true;
    }

    out  <<  idIndicatorReadStation();
    out  << nameIndicatorReadStationYes();
    writeStationList(&stations ,out,0);
    writeStationList(&staouts,out,1);
    file.close() ;
    return true;
}

void FDocument::error(const QFile &file ,const QString &message) {
    QMessageBox::warning(0,"FtanDocument",message.arg(file.name()));
}
void FDocument::ioError(const QFile &file ,const QString &message) {
    error(file, message + ": " + file.errorString());
}
void FDocument::writeToStream(QDataStream &out) {
    PropValIterator it = values.begin();
    while (it != values.end()) {
        out << *it;
        ++it;
    }
}
void FDocument::readFromStream(QDataStream &in) {
    PropertyValue prop;
    while (!in.atEnd()) {
        in >> prop;
///-----------------------------------------  Window characteristic: -----------------------------------------
        if ( prop.GetId() ==  idWindowSize()) {
            widowSize   =  new  PropertyEnumValue(prop.GetId(),
                                                  prop.GetResetvalue(),
                                                  defaultWindowSize(),
                                                  nameWindowSize(),
                                                  enumWindowSize());
            values.push_back(widowSize);
        }
        if ( prop.GetId() ==  idWindowMode()) {
            widowMode   =  new  PropertyEnumValue(prop.GetId(),
                                                  prop.GetResetvalue(),
                                                  defaultWindowMode(),
                                                  nameWindowMode(),
                                                  enumWindowMode());
            values.push_back(widowMode);
        }
        if ( prop.GetId() ==  idPostscript()) {
            postscript    =  new  PropertyEnumValue(prop.GetId(),
                                                    prop.GetResetvalue(),
                                                    defaultPostscript(),
                                                    namePostscript(),
                                                    enumPostscript());
            values.push_back(postscript);
        }
///----------------------------------------- Plot characteristic:  ----------------------------------------
        if ( prop.GetId() ==  idFtaWaveTypeOverPlot()) {
            ftaWaveTypeOverPlot    =  new  PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultFtaWaveTypeOverPlot(),
                    nameFtaWaveTypeOverPlot(),
                    enumFtaWaveTypeOverPlot());
            values.push_back(ftaWaveTypeOverPlot);
        }
        if ( prop.GetId() ==  idFtaGroupVelocityPlot()) {
            ftaGroupVelocityPlot    =  new  PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultFtaGroupVelocityPlot(),
                    nameFtaGroupVelocityPlot(),
                    enumFtaGroupVelocityPlot());
            values.push_back(ftaGroupVelocityPlot);
        }

        if ( prop.GetId() ==  idXaxisScaling()) {
            xaxisScaling    =  new  PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultXaxisScaling(),
                    nameXaxisScaling(),
                    enumXaxisScaling());
            values.push_back(xaxisScaling);
        }
///-----------------------------------------Edit handling:  ----------------------------------------
        if ( prop.GetId() ==  idEditApplied()) {
            editApplied    =  new  PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultEditApplied(),
                    nameEditApplied(),
                    enumEditApplied());
            values.push_back(editApplied);
        }
        if ( prop.GetId() ==  idInterpolateNominalGrid()) {
            interpolateNominalGrid    =  new  PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultInterpolateNominalGrid(),
                    nameInterpolateNominalGrid(),
                    enumInterpolateNominalGrid());
            values.push_back(interpolateNominalGrid);
        }
///-----------------------------------------Waveform:  ----------------------------------------
        if ( prop.GetId() ==   idPlotCompts()) {
            plotCompt    =  new  PropertyEnumValue(prop.GetId(),
                                                   prop.GetResetvalue(),
                                                   defaultPlotCompts(),
                                                   namePlotCompts(),
                                                   enumPlotCompts());
            values.push_back(plotCompt);
        }
        if ( prop.GetId() ==   idShortPeriodZero()) {
            shortPeriodZero    = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultShortPeriodZero(),
                    nameShortPeriodZero(),
                    minShortPeriodZero(),
                    maxShortPeriodZero(),
                    decimalShortPeriodZero());
            values.push_back(shortPeriodZero);
        }
        if ( prop.GetId() ==   idShortPeriodCorner()) {
            shortPeriodCorner  = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultShortPeriodCorner(),
                    nameShortPeriodCorner(),
                    minShortPeriodCorner(),
                    maxShortPeriodCorner(),
                    decimalShortPeriodCorner());
            values.push_back(shortPeriodCorner);
        }
        if ( prop.GetId() ==   idLongPeriodCorner()) {
            longPeriodCorner   = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultLongPeriodCorner(),
                    nameLongPeriodCorner(),
                    minLongPeriodCorner(),
                    maxLongPeriodCorner(),
                    decimalLongPeriodCorner());
            values.push_back(longPeriodCorner);
        }
        if ( prop.GetId() ==   idLongPeriodZero()) {
            longPeriodZero     = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultLongPeriodZero(),
                    nameLongPeriodZero(),
                    minLongPeriodZero(),
                    maxLongPeriodZero(),
                    decimalLongPeriodZero());
            values.push_back(longPeriodZero);
        }

///-----------------------------------------Measurement specification:  ----------------------------------------
        if ( prop.GetId() ==   idOutPutImagePhase()) {
            outPutImagePhase           = new PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultOutPutImagePhase(),
                    nameOutPutImagePhase(),
                    enumOutPutImagePhase());
            values.push_back(outPutImagePhase);
        }
        if ( prop.GetId() ==   idInstrumentResponse()) {
            instrumentResponse           = new PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultInstrumentResponse(),
                    nameInstrumentResponse(),
                    enumInstrumentResponse());
            values.push_back(instrumentResponse);
        }
        if ( prop.GetId() ==   idChangeAlphaFilter()) {
            changeAlphaFilter           = new PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultChangeAlphaFilter(),
                    nameChangeAlphaFilter(),
                    enumChangeAlphaFilter());
            values.push_back(changeAlphaFilter);
        }
        if ( prop.GetId() ==   idFtaCompts()) {
            ftaCompt           = new PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultFtaCompts(),
                    nameFtaCompts(),
                    enumFtaCompts());
            values.push_back(ftaCompt);
        }
        if ( prop.GetId() ==   idPolar()) {
            polar              = new PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultPolar(),
                    namePolar(),
                    enumPolar());
            values.push_back(polar);
        }

///-----------------------------------------Phase velocity information:  ----------------------------------------
        if ( prop.GetId() ==  idPhaseVelocityMeasurement()) {
            phaseVelocityMeasurement           = new PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultPhaseVelocityMeasurement(),
                    namePhaseVelocityMeasurement(),
                    enumPhaseVelocityMeasurement());
            values.push_back(phaseVelocityMeasurement);
        }
        if ( prop.GetId() ==  idPhaseVelBoundMinimum()) {
            phaseVelBoundMinimum     = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultPhaseVelBoundMinimum(),
                    namePhaseVelBoundMinimum(),
                    minPhaseVelBoundMinimum(),
                    maxPhaseVelBoundMinimum(),
                    decimalPhaseVelBoundMinimum());
            values.push_back(phaseVelBoundMinimum);
        }
        if ( prop.GetId() ==  idPhaseVelBoundMaximum()) {
            phaseVelBoundMaximum     = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultPhaseVelBoundMaximum(),
                    namePhaseVelBoundMaximum(),
                    minPhaseVelBoundMaximum(),
                    maxPhaseVelBoundMaximum(),
                    decimalPhaseVelBoundMaximum());
            values.push_back(phaseVelBoundMaximum);
        }

        if ( prop.GetId() ==  idPhaseVelRefPeriod()) {
            phaseVelRefPeriod     = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultPhaseVelRefPeriod(),
                    namePhaseVelRefPeriod(),
                    minPhaseVelRefPeriod(),
                    maxPhaseVelRefPeriod(),
                    decimalPhaseVelRefPeriod());
            values.push_back(phaseVelRefPeriod);
        }
///-----------------------------------------Analysis limits:  ----------------------------------------
        if ( prop.GetId() ==  idGroupVelBoundMinimum()) {
            groupVelBoundMinimum     = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultGroupVelBoundMinimum(),
                    nameGroupVelBoundMinimum(),
                    minGroupVelBoundMinimum(),
                    maxGroupVelBoundMinimum(),
                    decimalGroupVelBoundMinimum());
            values.push_back(groupVelBoundMinimum);
        }
        if ( prop.GetId() ==  idGroupVelBoundMaximum()) {
            groupVelBoundMaximum     = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultGroupVelBoundMaximum(),
                    nameGroupVelBoundMaximum(),
                    minGroupVelBoundMaximum(),
                    maxGroupVelBoundMaximum(),
                    decimalGroupVelBoundMaximum());
            values.push_back(groupVelBoundMaximum);
        }
        if ( prop.GetId() ==  idPeriodBoundMinimum()) {
            periodBoundMinimum     = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultPeriodBoundMinimum(),
                    namePeriodBoundMinimum(),
                    minPeriodBoundMinimum(),
                    maxPeriodBoundMinimum(),
                    decimalPeriodBoundMinimum());
            values.push_back(periodBoundMinimum);
        }
        if ( prop.GetId() ==  idPeriodBoundMaximum()) {
            periodBoundMaximum     = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultPeriodBoundMaximum(),
                    namePeriodBoundMaximum(),
                    minPeriodBoundMaximum(),
                    maxPeriodBoundMaximum(),
                    decimalPeriodBoundMaximum());
            values.push_back(periodBoundMaximum);
        }

        if ( prop.GetId() ==  idOrbit()) {
            ftaOrbit    =    new     PropertyIntValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultOrbit(),
                    nameOrbit(),
                    minOrbit(),
                    maxOrbit(),
                    signedOrbit());
            values.push_back(ftaOrbit);
        }
        if ( prop.GetId() ==  idMode()) {
            ftaMode   =    new     PropertyIntValue(prop.GetId(),
                                                    prop.GetResetvalue(),
                                                    defaultMode(),
                                                    nameMode(),
                                                    minMode(),
                                                    maxMode(),
                                                    signedMode());
            values.push_back(ftaMode);
        }
        if ( prop.GetId() ==  idRowSpectrumGroupVelocity()) {
            rowSpectrumGroupVelocity     = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultRowSpectrumGroupVelocity(),
                    nameRowSpectrumGroupVelocity(),
                    minRowSpectrumGroupVelocity(),
                    maxRowSpectrumGroupVelocity(),
                    decimalRowSpectrumGroupVelocity());
            values.push_back(rowSpectrumGroupVelocity);
        }
        if ( prop.GetId() ==  idRowSpectrumWidth()) {
            rowSpectrumWidth     = new PropertyFloatValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultRowSpectrumWidth(),
                    nameRowSpectrumWidth(),
                    minRowSpectrumWidth(),
                    maxRowSpectrumWidth(),
                    decimalRowSpectrumWidth());
            values.push_back(rowSpectrumWidth);
        }

///-----------------------------------------Event information:  ----------------------------------------
        if ( prop.GetId() ==  idReadCentridMomentRelation()) {
            readCentridMomentRelation              = new PropertyEnumValue(prop.GetId(),
                    prop.GetResetvalue(),
                    defaultReadCentridMomentRelation(),
                    nameReadCentridMomentRelation(),
                    enumReadCentridMomentRelation());
            values.push_back(readCentridMomentRelation);

        }

        if ( prop.GetId() ==  idIndicatorReadStation()) {
            projectFileGood = true;
            if (prop.GetResetvalue() != nameIndicatorReadStationNo()) {

                readStationList(stations,in,0);
                readStationList(staouts,in,1);

            } else projectFileGood = false;

        }
    }

}
void FDocument::SetResetvalueToValue() {
    for_each(values.begin(),values.end(),mem_fun(&PropertyValue::SetResetvalueToValue));
}
void FDocument::SetValueToResetvalue() {
    for_each(values.begin(),values.end(),mem_fun(&PropertyValue::SetValueToResetvalue));
}
void FDocument::SetDefault() {
    for_each(values.begin(),values.end(),mem_fun(&PropertyValue::SetDefault));
}
void FDocument::SetInitial() {
    for_each(values.begin(),values.end(),mem_fun(&PropertyValue::SetInitial));
}
