#ifndef _FTAN_CONFIG_H
#define _FTAN_CONFIG_H
#include <qstring.h>
#include <qstringlist.h>
#include <q3valuelist.h>
#include <list>
#include <string>
#include <vector>
#include <map>
#include <set>
#include <iostream>
#include <fstream>
#include <functional>
#include <algorithm>
using namespace std;

class QDataStream;
class  QFile;
class RowValue {
   
public:
    RowValue();
    RowValue(int id,QString name);
    RowValue(int id,QString name,QString textcol1,QString df);
    virtual     ~RowValue();
    int GetId                               () const        {
        return id;
    }
    bool GetMarkDelete          () const        {
        return markDelete;
    }
    const QString GetName              () const        {
        return name;
    }
    const QString GetTextCol1         () const        {
        return textCol1;
    }
    const QString GetDfile                 () const        {
        return  dfile;
    }
    void SetId                      (const int i              )     {
        id = i;
    }
    void SetMarkDelete     (const bool i              )     {
        markDelete = i;
    }
    void SetName               (const QString val)     {
        name = val;
    }
    void SetTextCol1           (const QString val)    {
        textCol1 = val;
    }
    void SetDfile                  (const QString val)     {
        dfile = val;
    }
    void SetMinPeriod(const QString &val) {
        minperiod = val;
    }
    void SetMaxPeriod(const QString &val) {
        maxperiod = val;
    }
    QString GetMinPeriod() {
        return minperiod;
    }
    QString GetMaxPeriod() {
        return maxperiod;
    }
    void SetAccept(bool on){ accept = on;}
    bool GetAccept(){return accept;}
    void SetComment(const QString &val){ comment = val;}
    QString GetComment(){ return comment;}
private:
    int id;
    QString name;
    QString textCol1;
    QString dfile;
    bool    markDelete; // false - Include   true- Exclude
    QString minperiod;
    QString maxperiod;
    QString comment;
    bool accept;
};
class ChanValue : public RowValue {

public:
    ChanValue();
    ChanValue(int id,QString name);
    ChanValue(int id,QString name,QString textcol1,QString df);
    virtual     ~ChanValue();
private:

};

class StaValue : public RowValue {
    typedef vector<ChanValue* > vChan;
    typedef vector<ChanValue* >::iterator vChanIt;

public:
    StaValue();
    StaValue(QString name);
    virtual     ~StaValue();
    vector<ChanValue* >  &GetChans() {
        return chans;
    }
private:
    vector<ChanValue* > chans;

};
class PropertyValue {
    friend QDataStream &operator<< (QDataStream &, const PropertyValue &);
    friend QDataStream &operator >> (QDataStream &, PropertyValue &);
public:
    enum Kind {
        Property_Bool,
        Property_Int,
        Property_IntSpin,
        Property_Float,
        Property_Enum,
        Property_TransformFunction,
        Property_DateTime,
        Property_String,
        Property_StringList
    };
    PropertyValue() {};
    PropertyValue(const int id,const QString defval,const QString name);
    PropertyValue(const int id,const QString resval,const QString defval,const QString name);
    PropertyValue(const int id,const QString val,const QString resval,const QString defval,const QString name);
    virtual     ~PropertyValue() {}
    virtual void setChanged( bool b);
    PropertyValue::Kind GetKind() {
        return kind;
    }
    bool isChanged() const ;
    bool isReseted() const;
    void SetValueToResetvalue()  {
        resetvalue = value;
    }
    void SetResetvalueToValue()  {
        value         = resetvalue ;
    }
    void SetDefault                       ()  {
        value         =  defaultvalue ;
    }
    void SetInitial                          ()  {
        value         =  initialvalue;
    }
    void setChanged                   ()  {
        if (value  ==  initialvalue)   setChanged( FALSE);
        else setChanged( TRUE);
    }
    int GetId                               () const        {
        return id;
    }
    const QString GetName              () const        {
        return name;
    }
    const QString GetInitialvalue      () const        {
        return initialvalue;
    }
    const QString GetDefaultvalue   () const       {
        return defaultvalue;
    }
    const QString GetResetvalue     ()  const       {
        return resetvalue;
    }
    const QString GetValue               ()  const       {
        return value;
    }
    void SetId                      (const int i              )     {
        id = i;
    }
    void SetName               (const QString val)     {
        name = val;
    }
    void SetIntialvalue        (const QString val)     {
        initialvalue= val;
    }
    void SetValue               (const QString val)      {
        value = val;
    }
    void SetResetvalue     (const QString val)      {
        resetvalue = val;
    }

protected:
    int id;
    QString value;
    QString initialvalue;
    QString resetvalue;
    QString defaultvalue;
    QString name;
    PropertyValue::Kind kind;
private:
    bool changed;

};

class PropertyBoolValue : public PropertyValue {

public:
    PropertyBoolValue( const int id,const QString defval ,const QString name);
    PropertyBoolValue(const int id,const  QString resval, const QString defval ,const QString name);
    PropertyBoolValue( const int id,const QString val,const  QString resval,const QString defval,const QString name);
    ~PropertyBoolValue() {};
private:

};
class PropertyIntValue : public PropertyValue {

public:
    PropertyIntValue( const int id,const QString defval ,const QString name,const int min,const int max, const bool s);
    PropertyIntValue( const int id,const  QString resval,const QString defval ,const QString name,const int min,const int max, const bool s);
    PropertyIntValue( const int id, const  QString val, const  QString resval,const QString defval,const QString name,const int min,const int max, const bool s);
    ~PropertyIntValue() {};
    int GetMin()          const     {
        return min;
    }
    int GetMax()          const     {
        return max;
    }
    bool GetSignedValuel()   const     {
        return   signedValue;
    }
private:
    int min;
    int max;
    bool signedValue;
};
class PropertyFloatValue : public PropertyValue {

public:
    PropertyFloatValue(const int id, const QString defval ,const QString name,const float min,const float max, const int dec);
    PropertyFloatValue(const int id, const  QString resval,const QString defval ,const QString name,const float min,const float max, const int dec);
    PropertyFloatValue(const int id, const  QString val, const  QString resval,const QString defval,const QString name,const float min,const float max, const int dec);
    ~PropertyFloatValue() {};
    float GetMin()           const     {
        return min;
    }
    float GetMax()          const     {
        return max;
    }

    void SetMin(float val) {
        min = val;
    }
    void SetMax(float val) {
        max = val;
    }
    int GetDecimal()     const     {
        return  decimal;
    }
private:
    float min;
    float max;
    int decimal;
};

class PropertyEnumValue : public PropertyValue {
public:
    PropertyEnumValue(const int id, const QString defval ,const QString name,const QString list);
    PropertyEnumValue(const int id, const  QString resval,const QString defval ,const QString name,const QString list);
    PropertyEnumValue(const int id, const QString val,const QString resval,const QString defval,const QString name,const QString list);
    ~PropertyEnumValue() {};
    QStringList &GetList   ()       {
        return list;
    }

private:
    QStringList list;

};
//---------------------------------------------------------------------------------------------
class PropertyStringValue : public PropertyValue {
public:
    PropertyStringValue(const int id, const QString defval ,const QString name);
    PropertyStringValue(const int id, const  QString resval,const QString defval ,const QString name);
    PropertyStringValue(const int id, const QString val,const QString resval,const QString defval,const QString name);
    ~PropertyStringValue() {};

    void SetIntialvalue    (const QString val)     {
        initialvalue= val;
    }
    void SetValue          (const QString val)     {
        value = val;
    }
    void SetResetvalueToValue       ()  {
        value         = resetvalue ;
    }
    void SetDefault                 ()  {
        value         =  defaultvalue ;
    }
private:


};

//---------------------------------------------------------------------------------------------
class FDocument {
    typedef vector<PropertyValue* > PropValVector;
    typedef vector<PropertyValue* >::iterator PropValIterator;

    typedef vector<StaValue* > vSta;
    typedef vector<StaValue* >::iterator vStaIt;
    typedef vector<ChanValue* > vChan;
    typedef vector<ChanValue* >::iterator vChanIt;

public:
    FDocument(QString wFile,QString rFile,QString oFile,QString eInfo,QString numOriginRow);
    FDocument(const QString &fileName);
    ~FDocument();
    bool loadBinary(const QString &fileName);
    bool saveBinary(const QString &fileName);
    bool ReadFileListCtachan();
    void sortStationList(vector<StaValue* >* lst);
    void printStationList( vector<StaValue* > &lst);
    void initEmptyStationList( vector<StaValue* > &lst);
    void writeStationList( vector<StaValue* >* lst,QDataStream &out,int ind); // ind=0 stalist ind =1 outstalist
    void readStationList( vector<StaValue* > &lst,QDataStream &in,int ind);
    vector<StaValue* >::iterator GetStaIterator(QString sta,vector<StaValue* >* lst);
    bool isModified();
    void SetResetvalueToValue();
    void SetValueToResetvalue();
    void SetDefault();
    void SetInitial();
    void SetPropertyEnumValue(PropertyEnumValue* &p, int id,QString reset,QString defaultvalue,
                              QString name,QString enumeration);
    void SetPropertyIntValue(PropertyIntValue* &p, int id,QString reset,QString defaultvalue,
                             QString name,int min,int max,bool sign);
    void SetPropertyFloatValue(PropertyFloatValue* &p, int id,QString reset,QString defaultvalue,
                               QString name,float min,float max,int decimal);
    void SetPropertyStringValue(PropertyStringValue* &p, int id,
                                QString reset,QString defaultvalue, QString name);
///-----------------------------------------  Window characteristic: -----------------------------------------
    PropertyEnumValue*   &GetWidowSize                       ()  {
        return widowSize;
    }
    PropertyEnumValue*   &GetWidowMode                     ()  {
        return widowMode;
    }
    PropertyEnumValue*   &GetPostScript                         ()  {
        return postscript;
    }
///----------------------------------------- Plot characteristic:  ----------------------------------------
    PropertyEnumValue*   &GetFtaWaveTypeOverPlot ()  {
        return   ftaWaveTypeOverPlot;
    }
    PropertyEnumValue*   &GetFtaGroupVelocityPlot   ()  {
        return   ftaGroupVelocityPlot;
    }
    PropertyEnumValue*   &GetXaxisScaling                  ()  {
        return   xaxisScaling;
    }
///-----------------------------------------Edit handling:  ----------------------------------------
    PropertyEnumValue*   &GetEditApplied                       ()  {
        return   editApplied;
    }
    PropertyEnumValue*   &GetInterpolateNominalGrid   ()  {
        return   interpolateNominalGrid;
    }
///-----------------------------------------Waveform:  ----------------------------------------
    PropertyEnumValue*   &GetPlotCompt                         ()  {
        return plotCompt;
    }
    PropertyFloatValue*  &GetShortPeriodZero                 ()  {
        return shortPeriodZero;
    }
    PropertyFloatValue*  &GetShortPeriodCorner             ()  {
        return shortPeriodCorner;
    }
    PropertyFloatValue*  &GetLongPeriodZero                  ()  {
        return longPeriodZero;
    }
    PropertyFloatValue*  &GetLongPeriodCorner              ()  {
        return longPeriodCorner;
    }
///-----------------------------------------Measurement specification:  ----------------------------------------
    PropertyEnumValue*  &GetOutPutImagePhase               ()  {
        return outPutImagePhase;
    }
    PropertyEnumValue*  &GetInstrumentResponse             ()  {
        return instrumentResponse;
    }
    PropertyEnumValue*  &GetChangeAlphaFilter                ()  {
        return changeAlphaFilter;
    }
    PropertyEnumValue*  &GetFtaCompt                                ()  {
        return ftaCompt ;
    }
    PropertyEnumValue*  &GetPolar                                        ()   {
        return polar;
    }
///-----------------------------------------Phase velocity information:  ----------------------------------------
    PropertyEnumValue*  &GetPhaseVelocityMeasurement    ()  {
        return phaseVelocityMeasurement;
    }
    PropertyFloatValue*  &GetPhaseVelBoundMinimum          ()  {
        return phaseVelBoundMinimum;
    }
    PropertyFloatValue*  &GetPhaseVelBoundMaximum          ()  {
        return phaseVelBoundMaximum;
    }
    PropertyFloatValue*  &GetPhaseVelRefPeriod                     ()  {
        return phaseVelRefPeriod;
    }
///-----------------------------------------Analysis limits:  ---------------------------------------------------------
    PropertyFloatValue*  &GetGroupVelBoundMinimum          ()  {
        return groupVelBoundMinimum;
    }
    PropertyFloatValue*  &GetGroupVelBoundMaximum         ()  {
        return groupVelBoundMaximum;
    }
    PropertyFloatValue*  &GetPeriodBoundMinimum               ()  {
        return periodBoundMinimum;
    }
    PropertyFloatValue*  &GetPeriodBoundMaximum              ()  {
        return periodBoundMaximum;
    }
    PropertyIntValue*          &GetFtaOrbit                                     ()  {
        return  ftaOrbit;
    }
    PropertyIntValue*          &GetFtaMode                                    ()  {
        return  ftaMode;
    }
    PropertyFloatValue*  &GetRowSpectrumGroupVelocity     ()  {
        return rowSpectrumGroupVelocity;
    }
    PropertyFloatValue*  &GetRowSpectrumWidth                   ()  {
        return rowSpectrumWidth;
    }
///-----------------------------------------Event information:  ----------------------------------------
    PropertyEnumValue*  &GetReadCentridMomentRelation   ()   {
        return  readCentridMomentRelation;
    }

    vector <PropertyValue* >  &GetValues() {
        return values;
    }
    vector<StaValue* >* GetStaIn() {
        return &stations;
    }
    vector<StaValue* >* GetStaOut() {
        return &staouts;
    }

    QString    &GetWfdiscAbsPath()  {
        return wfdiscAbsPath;
    }
    QString    &GetRootAbsPath()      {
        return rootAbsPath;
    }
    QString    &GetOriginAbsPath()    {
        return originAbsPath;
    }
    QString    &GetEventInfo()             {
        return eventInfo;
    }
    QString    &GetNumOriginRow()   {
        return numOriginRow;
    }
    bool GetProjectFileGood()  {
        return projectFileGood;
    }
    // void printFDocument();
    bool isChanged() const;
private:
    bool projectFileGood;
    bool changed;
    enum { MagicNumber = 0x98c58f10 };
    void writeToStream(QDataStream &out);
    void readFromStream(QDataStream &in);
    void error(const QFile &file ,const QString &message);
    void ioError(const QFile &file ,const QString &message);
    QString parameterProjectSaveFileName;
    QString wfdiscAbsPath;
    QString rootAbsPath;
    QString originAbsPath;
    QString eventInfo;
    QString numOriginRow;
///-----------------------------------------  Window characteristic: -----------------------------------------
    PropertyEnumValue* widowSize;
    PropertyEnumValue* widowMode;
    PropertyEnumValue* postscript;
///----------------------------------------- Plot characteristic:  ----------------------------------------
    PropertyEnumValue* ftaWaveTypeOverPlot;
    PropertyEnumValue* ftaGroupVelocityPlot;
    PropertyEnumValue*  xaxisScaling;
///-----------------------------------------Edit handling:  ----------------------------------------
    PropertyEnumValue*  editApplied;
    PropertyEnumValue*  interpolateNominalGrid;
///-----------------------------------------Waveform:  ----------------------------------------
    PropertyEnumValue*  plotCompt;
    PropertyFloatValue* shortPeriodZero;
    PropertyFloatValue* shortPeriodCorner;
    PropertyFloatValue* longPeriodZero;
    PropertyFloatValue* longPeriodCorner;
///-----------------------------------------Measurement specification:  ----------------------------------------
    PropertyEnumValue*  outPutImagePhase;
    PropertyEnumValue*  instrumentResponse;
    PropertyEnumValue*  changeAlphaFilter;
    PropertyEnumValue*  ftaCompt;
    PropertyEnumValue*  polar;
///-----------------------------------------Phase velocity information:  ----------------------------------------
    PropertyEnumValue*  phaseVelocityMeasurement;
    PropertyFloatValue*   phaseVelBoundMinimum;
    PropertyFloatValue*   phaseVelBoundMaximum;
    PropertyFloatValue*   phaseVelRefPeriod;
///-----------------------------------------Analysis limits:  ----------------------------------------
    PropertyFloatValue*  groupVelBoundMinimum;
    PropertyFloatValue*  groupVelBoundMaximum;
    PropertyFloatValue*  periodBoundMinimum;
    PropertyFloatValue*  periodBoundMaximum;
    PropertyIntValue*      ftaOrbit;
    PropertyIntValue*      ftaMode;
    PropertyFloatValue* rowSpectrumGroupVelocity;
    PropertyFloatValue* rowSpectrumWidth;
///-----------------------------------------Event information:  ----------------------------------------
    PropertyEnumValue* readCentridMomentRelation;

    PropValVector values;
    vector<StaValue* > stations;
    vector<StaValue* > staouts;
   Q_INT32  ftanincurrentversion; 
};///////////////////// STL classes & functions /////////////////////////////
struct sta_Comp : public binary_function < StaValue * const & , StaValue *  const &, bool> {
    bool operator()(StaValue *  const & x, StaValue *  const & y) {
        if (x->GetName() > y->GetName())
            return false;
        else return true;
    }
};
struct chan_Comp : public binary_function < ChanValue * const & , ChanValue * const &, bool> {
    bool operator()(ChanValue * const & x, ChanValue * const & y) {
        if (x->GetName() > y->GetName())
            return false;
        else return true;
    }
};

    typedef vector<ChanValue* > vChan;
    typedef vector<ChanValue* >::iterator vChanIt;
bool findItChanel(vector<ChanValue* >* chan,QString &name,QString &state,
     vector<ChanValue* >::iterator &itChan);
#endif
