#ifndef _PROPERTY_LIST_VIEW_H
#define _PROPERTY_LIST_VIEW_H
#include <QItemDelegate>
#include <QModelIndex>
#include <QObject>
#include <QSize>
#include <QPointer>
#include <QStandardItemModel>
#include <QDateTimeEdit>
#include <QLineEdit>
#include <QLabel>
#include <QSpinBox>
#include <QToolButton>
#include <vector>
using namespace std;
class PropertyValue;
class PropertyValue;
class LineEditor;
class LineDocProperty;
class QGridLayout;
class SettingProperty;
class StaValue;
class ChanValue;
class ItemProperty
{
public:
    inline ItemProperty(QModelIndex ind,const QString &initStr,const QString &defStr,PropertyValue* p)
        : invalid(FALSE),
          changed(FALSE),
          initString(initStr),
          defaultString(defStr),
          property(p)
          { index = ind; edited=false;}
inline ItemProperty(QModelIndex ind,const QString &str)
        : invalid(FALSE),
          changed(FALSE),
          initString(str),
          defaultString(str) {index = ind; edited=false; property=0;}
    virtual ~ItemProperty() {}
    QModelIndex index;
    void SetIndex(QModelIndex ind){index = ind;};
    void SetInvalid(bool inv){invalid = inv;}
    bool GetInvalid(){return invalid;}
    void SetChanged(bool ch){changed = ch;}
    bool GetChanged(){return changed;}
    void SetInitStr(const QString &initStr ) {initString = initStr;}
    QString GetInitStr(){return initString;}

    QString GetDefaultStr(){return defaultString;}
    void SetDefaultStr(const QString &defStr ) {defaultString = defStr;}
    bool    edited;
    PropertyValue* GetPropertyValue(){ return property;}

protected:
    bool invalid;
    bool changed;
    QString initString;
    QString defaultString;
    PropertyValue* property;
};
//-----------------------------------------------------------------------------------------------------
class PropertyInt : public ItemProperty
{


public:
    PropertyInt(QModelIndex ind,const QString &initStr,const QString &defStr,PropertyValue* p,int min,int max, bool s );
    ~PropertyInt() {};

    int minimum;
    int maximum;
    bool signedValue;

};
//-----------------------------------------------------------------------------------------------------

//-----------------------------------------------------------------------------------------------------
class PropertyIntSpin : public ItemProperty
{


public:
    PropertyIntSpin(QModelIndex ind,const QString &initStr,const QString &defStr,PropertyValue* p,int min,int max, int s );
    ~PropertyIntSpin() {};

    int minimum;
    int maximum;
    int step;
};
//-----------------------------------------------------------------------------------------------------
class PropertyNotEdit : public ItemProperty
{
public:
    PropertyNotEdit(QModelIndex ind,const QString &initStr,const QString &defStr,PropertyValue* p);
    ~PropertyNotEdit() {};

};
//-----------------------------------------------------------------------------------------------------
class PropertyString : public ItemProperty
{
public:
    PropertyString(QModelIndex ind,const QString &initStr,const QString &defStr,PropertyValue* p);
    ~PropertyString() {};
};
//-----------------------------------------------------------------------------------------------------
class PropertyTittle : public ItemProperty
{
public:
    PropertyTittle(QModelIndex ind,const QString &title);
    ~PropertyTittle() {};
};
//-----------------------------------------------------------------------------------------------------
class PropertyDouble : public ItemProperty
{


public:
    PropertyDouble(QModelIndex ind,const QString &initStr,const QString &defStr,PropertyValue* p,double min,double max,int dec);
    ~PropertyDouble(){};

    double minimum;
    double maximum;
    int decimals;
};
//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
class PropertyDateTime : public ItemProperty
{
public:
    PropertyDateTime(QModelIndex ind,const QString &initStr,const QString &defStr,PropertyValue* p);
    ~PropertyDateTime() {};
};
//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

class ResetLineEdit : public QWidget
{
    Q_OBJECT
public:
    ResetLineEdit(PropertyDouble* ipmin,PropertyDouble* ipmax,const QModelIndex & index,QWidget *parent = 0);
    ~ResetLineEdit();
    void setLine(const QString &label);
    LineEditor  *GetLineEditorMin() {return linmin;}
    LineEditor  *GetLineEditorMax() {return linmax;}
    QLabel *labelmin;
    QLabel *labelmax;
    LineEditor *linmin;
    LineEditor *linmax;
    PropertyDouble* ipmin;
    PropertyDouble* ipmax;
    bool edited() {return m_edited;}
    void setEdited(bool on) {m_edited = on;}
signals:
    void changed(QWidget *widget);
private slots:
    void emitResetProperty();
private:
    QModelIndex index;
    bool    m_edited;
};
//-----------------------------------------------------------------------------
class TreePropertyModel : public QStandardItemModel
{
    Q_OBJECT
    typedef vector<StaValue* > vSta;
    typedef vector<StaValue* >::iterator vStaIt;
    typedef vector<ChanValue* > vChan;
    typedef vector<ChanValue* >::iterator vChanIt;

public:
    TreePropertyModel(int columns, QObject * parent = 0);
    ~TreePropertyModel();
   QMap<QModelIndex,PropertyDouble*> minMap;
   QMap<QModelIndex,PropertyDouble*> maxMap;
   QMap<QModelIndex,bool> redStaMap; // true draw red color
   void SetNumRow(int v) {NumRows = v;}

///====================================================================================
    void SetItem(vStaIt itSta);
    void SetItem(int nsta,int nchan,PropertyValue* p,PropertyValue* pmin,PropertyValue* pmax,PropertyValue* pcheck,PropertyValue* pcomment);
///====================================================================================

SettingProperty* parent;
private:
    void SetHorizontalHeader();
    int NumRows;
    int NumCols;
};
class TreePropertyDelegate : public QItemDelegate
{
    Q_OBJECT

public:
    TreePropertyDelegate(QObject *parent = 0);

   QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
                         const QModelIndex &index) const;

   void setEditorData(QWidget *editor, const QModelIndex &index) const;
    void setModelData(QWidget *editor, QAbstractItemModel *model,
                      const QModelIndex &index) const;
    void paint(QPainter *painter, const QStyleOptionViewItem &option,
                       const QModelIndex &index) const;

private slots:

private:
    
};
#endif 
