#include <qaction.h>
#include <qapplication.h>
#include <qtoolbutton.h>
#include <qcombobox.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qmenubar.h>
#include <qmessagebox.h>
#include <q3popupmenu.h>
#include <qsettings.h>
#include <qstatusbar.h>
#include <q3whatsthis.h>
#include <qfont.h>
#include <qtabwidget.h>
#include <qdatetime.h>
#include <qdir.h>
#include <qpushbutton.h>
#include <QDesktopWidget>
#include <QProcess>
#include <Q3Process>
//Added by qt3to4:
#include <QPixmap>
#include <QCloseEvent>
#include "stationlistimpl.h"
#include "mainwindow.h"
#include "helpwindow.h"
#include "newdialogimpl.h"
#include "document.h"
#include "defaults.h"

#include "setting.h"

MainWindow *MainWindow::self = 0;
AhFileDialog::AhFileDialog ( QWidget* parent,const char* name ) :
        Q3FileDialog ( QString::null, "Catalogs (*.dat *.DAT);;All Files (*)",
                       parent,name,
                       ( const char* ) "Choose a catalog and it's format" ) {
    setCaption ( "Choose a catalog and it's format" );
    setMode ( Q3FileDialog::DirectoryOnly );
    setDir ( QDir::currentDirPath () );
    label      = new QLabel ( "Format    :",this,"Label" );
    combobox   = new QComboBox ( FALSE, this, "read-onlycombobox" );
    combobox->insertItem ( "AH records" );
    combobox->insertItem ( "ASCII records" );
    combobox->insertItem ( "ASCII disp. curves" );
    combobox->setCurrentText ( "AH records" );
    addWidgets ( label, combobox, 0 );

}
void AhFileDialog::accept () {
    QString DirectoryName = selectedFile();
    QDir d ( DirectoryName );
    uint count = d.count ();
    if ( count >2 ) {
        //	   qWarning("Choosen directory '%s is not empty'",DirectoryName.ascii() );
        QString temp =DirectoryName.right ( DirectoryName.length()  - DirectoryName.findRev ( '/' ) -1 );
        QString tmp = QString ( "Directory %1 is not empty'.\nDo you want to delete all it's entries?" )
                      .arg ( temp );
        int ret = QMessageBox::warning ( this,mainWindowCaption(),tmp,
                                         QMessageBox::Yes | QMessageBox::Default,
                                         QMessageBox::No | QMessageBox::Escape,
                                         QMessageBox::Cancel );
        if ( ret == QMessageBox::Cancel )
            done ( QDialog::Rejected );
        //	   qWarning("all it's entries will be deleted" );
        if ( ret == QMessageBox::Yes ) {
            QString systemStr = QString ( "\\rm -r  %1/*" ).arg ( DirectoryName );
            system ( systemStr.ascii() );
        }

    }

    QApplication::setOverrideCursor ( Qt::WaitCursor );
    int curItem =   GetComboBox()->currentItem();
    if ( curItem == 2 ) MainWindow::self->exportDispersionCurves ( DirectoryName );
    if ( curItem == 1 ) MainWindow::self->exportAhAsciiRecord ( DirectoryName,"0" ); // aascii record
    if ( curItem == 0 ) MainWindow::self->exportAhAsciiRecord ( DirectoryName,"1" ); // ah record
    QApplication::restoreOverrideCursor();

    done ( QDialog::Accepted );
}

AhFileDialog::~AhFileDialog() {
    delete label;
    delete combobox;

}


QString GetRelativePath ( QString workDirectory,QString nameFile ) {
    QString work = workDirectory;
    QString tmp  = nameFile;
    QDir dir(work);

    QString s;

    s = dir.relativeFilePath(tmp);
    return s;
    /*
        if ( tmp.left ( tmp.findRev ( '/' ) ) == work )
            return ( "./" + tmp.right ( tmp.length()  - tmp.findRev ( '/' ) - 1 ) );
        QStringList worklist = QStringList::split ( '/',work );
        QStringList tmplist = QStringList::split ( '/',tmp );
        QStringList::iterator it;
        int i = 0;
        int j =0;
        while ( worklist[i]  == tmplist[i] ) i++;
        j = i;
        QString tmpNew = "";
        QStringList::iterator itS = worklist.begin() ;
        for ( i =0; i<j; i++ ) itS++;
        for ( it = itS ; it != worklist .end(); ++it )
            tmpNew += "../";
        itS = tmplist.begin() ;
        for ( i =0; i<j; i++ ) itS++;
        for ( i = j, it = itS ; it != tmplist .end(); ++it ,i++ )
            tmpNew += tmplist[i] + "/";
        return tmpNew.left ( tmpNew.findRev ( '/' ) );
    */
}
MainWindow::~MainWindow () {
    if ( doc !=0 ) delete doc;

    if ( stationlist !=0 ) delete stationlist;

    if ( periodListDialog !=0 ) delete periodListDialog;

    actionMainWinList.clear();
    actionFtanWinList.clear();

}
void MainWindow::pageHelp ( QString page ) {
    QString home = fmtEnvVariable + "/doc/ftan/" + page;
    HelpWindow *help = new HelpWindow ( home, ".", 0, "help viewer" );
    help->setCaption ( mainWindowCaption() + " - Helpviewer" );
    if ( QApplication::desktop()->width() > 400
            && QApplication::desktop()->height() > 500 )
        help->show();
    else
        help->showMaximized();
}
void MainWindow::mainHelpSlot() {
    QString home = fmtEnvVariable + "/doc/ftan/Contens.html";
    HelpWindow *help = new HelpWindow ( home, ".", 0, "help viewer" );
    help->setCaption ( mainWindowCaption() + " - Helpviewer" );
    if ( QApplication::desktop()->width() > 400
            && QApplication::desktop()->height() > 500 )
        help->show();
    else
        help->showMaximized();
}

MainWindow::MainWindow ( QString fmtVar,QWidget *parent, const char *name )
        : Q3MainWindow ( parent, name ) {

    fmtEnvVariable = fmtVar;
    self = this;
    propx  =  propy =  propw =  proph = 0;
    mpropx  =  mpropy =  mpropw =  mproph = 0;
    createIconSet();
    createActions();
    createWhatsThis();
    createMenus();
    createToolBars();
    createStatusBar();
    createAdditionalConnect();
    readSettings();
    EnableMainWinAction ( FALSE );
    EnableFtanWinAction ( FALSE );
    setCaption ( mainWindowCaption() );

    setIcon ( QPixmap ( qPixmapFromMimeSource ( "LogoEarth16.png" ) ) );

    modified = false;
    modifiedFlt  = false;
    isCleanedRecordSaved = false;
    doc = 0;
    stationlist = 0;
    findDialog = 0;
    process = 0;
    periodListDialog = 0;

    show();
}
void MainWindow::EnableFtanWinActionAfterSaveRecord ( bool b ) {
    if ( b ) waveAct->setEnabled ( TRUE );
    else waveAct->setEnabled ( FALSE );
    if ( b ) filterAct->setEnabled ( TRUE );
    else filterAct->setEnabled ( FALSE );
    if ( b ) ftaAct->setEnabled ( TRUE );
    else ftaAct->setEnabled ( FALSE );
}
void MainWindow::EnableFtanWinAction ( bool b ) {
    QAction* act;

    for ( act = actionFtanWinList.first(); act; act = actionFtanWinList.next() )
        if ( b ) act->setEnabled ( TRUE );
        else act->setEnabled ( FALSE );
}
void MainWindow::EnableMainWinAction ( bool b ) {
    QAction* act;

    for ( act = actionMainWinList.first(); act; act = actionMainWinList.next() )
        if ( b ) act->setEnabled ( TRUE );
        else act->setEnabled ( FALSE );

    if ( b ) orbitToolButton->setEnabled ( TRUE );
    else orbitToolButton->setEnabled ( FALSE );

    if ( b ) settingsMenu->setItemEnabled ( idItemOrbitOfSettingMenu, TRUE );
    else settingsMenu->setItemEnabled ( idItemOrbitOfSettingMenu, FALSE );

    if ( b ) setPostscriptPolarOrbitActions();
}
void MainWindow::setPostscriptPolarOrbitActions() {
    emit ( orbitSlot ( doc->GetFtaOrbit()->GetValue().toInt()-1 ) );
    if ( doc->GetPostScript()->GetValue() == "0" ) emit ( pscriptOnOffToggled ( FALSE ) );
    else  emit ( pscriptOnOffToggled ( TRUE ) );
    if ( doc->GetPolar()->GetValue() == "0" ) emit ( polarOnOffToggled ( FALSE ) );
    else  emit ( polarOnOffToggled ( TRUE ) );
}
void MainWindow::createAdditionalConnect() {
    connect ( pscriptOnOffAct, SIGNAL ( toggled ( bool ) ),
              this, SLOT ( pscriptOnOffToggled ( bool ) ) );
    connect ( polarOnOffAct, SIGNAL ( toggled ( bool ) ),
              this, SLOT ( polarOnOffToggled ( bool ) ) );

    connect ( orbitPopupmenu, SIGNAL ( activated ( int ) ),
              this, SLOT ( orbitSlot ( int ) ) );
}

void MainWindow::pscriptOnOffToggled ( bool tog ) {
    //    qWarning("MainWindow::pscriptOnOffToggled(bool tog)");
    if ( tog ) {
        pscriptOnOffAct->setOn ( TRUE );
        doc->GetPostScript()->SetValue ( "1" );
        doc->GetPostScript()->SetValueToResetvalue();
        pscriptOnOffIconSet->setPixmap ( QPixmap ( qPixmapFromMimeSource ( "ftan_SavePs.png" ) ), QIcon::Automatic,QIcon::Active,QIcon::On );
        pscriptOnOffIconSet->setPixmap ( QPixmap ( qPixmapFromMimeSource ( "ftan_SavePs.png" ) ),QIcon::Automatic,QIcon::Normal,QIcon::On );
        pscriptOnOffAct->setIconSet ( *pscriptOnOffIconSet );
        //qWarning("toggled On") ;
    } else {
        pscriptOnOffAct->setOn ( FALSE );
        doc->GetPostScript()->SetValue ( "0" );
        doc->GetPostScript()->SetValueToResetvalue();
        pscriptOnOffIconSet->setPixmap ( QPixmap ( qPixmapFromMimeSource ( "ftan_d_SavePs.png" ) ),QIcon::Automatic,QIcon::Active,QIcon::Off );
        pscriptOnOffIconSet->setPixmap ( QPixmap ( qPixmapFromMimeSource ( "ftan_d_SavePs.png" ) ),QIcon::Automatic,QIcon::Normal,QIcon::Off );
        pscriptOnOffAct->setIconSet ( *pscriptOnOffIconSet );
        //qWarning("toggled Off") ;
    }
}
void MainWindow::polarOnOffToggled ( bool tog ) {
    if ( tog ) {
        polarOnOffAct->setOn ( TRUE );
        doc->GetPolar()->SetValue ( "1" );
        doc->GetPolar()->SetValueToResetvalue();
        polarOnOffIconSet->setPixmap ( QPixmap ( qPixmapFromMimeSource ( "ftan_Polarization.png" ) ),QIcon::Automatic,QIcon::Active,QIcon::On );
        polarOnOffIconSet->setPixmap ( QPixmap ( qPixmapFromMimeSource ( "ftan_Polarization.png" ) ),QIcon::Automatic,QIcon::Normal,QIcon::On );
        polarOnOffAct->setIconSet ( *polarOnOffIconSet );
        //qWarning("toggled On") ;
    } else {
        polarOnOffAct->setOn ( FALSE );
        doc->GetPolar()->SetValue ( "0" );
        doc->GetPolar()->SetValueToResetvalue();
        polarOnOffIconSet->setPixmap ( QPixmap ( qPixmapFromMimeSource ( "ftan_d_Polarization.png" ) ),QIcon::Automatic,QIcon::Active,QIcon::Off );
        polarOnOffIconSet->setPixmap ( QPixmap ( qPixmapFromMimeSource ( "ftan_d_Polarization.png" ) ),QIcon::Automatic,QIcon::Normal,QIcon::Off );
        polarOnOffAct->setIconSet ( *polarOnOffIconSet );
        //qWarning("toggled Off") ;
    }
}

void MainWindow::createActions() {
///---------------------------------------------------------------------------------
//    newAct = new QAction ( QIcon ( ":/images/project_new.png" ), tr ( "&New" ), this );
//    newAct->setShortcut ( tr ( "Ctrl+N" ) );
//    newAct->setStatusTip ( tr ( "Create a new project" ) );
///-----------------------------------------------------------------------------------
    newAct = new QAction ( tr ( "&New" ), tr ( "Ctrl+N" ), this,"newAct" );
    newAct->setIconSet ( QPixmap ( qPixmapFromMimeSource ( "folder_new.png" ) ) );
    newAct->setStatusTip ( tr ( "Create a new location" ) );
    connect ( newAct, SIGNAL ( activated() ), this, SLOT ( newLocation() ) );

    openAct = new QAction ( tr ( "&Open..." ), tr ( "Ctrl+O" ), this,"openAct" );
    openAct->setIconSet ( QPixmap ( qPixmapFromMimeSource ( "folder_open.png" ) ) );
    openAct->setStatusTip ( tr ( "Open an existing location" ) );
    connect ( openAct, SIGNAL ( activated() ), this, SLOT ( open() ) );

    saveAct = new QAction ( tr ( "&Save" ), tr ( "Ctrl+S" ), this,"saveAct" );
    saveAct->setIconSet ( *saveIconSet );
    saveAct->setStatusTip ( tr ( "Save the currently open location" ) );
    connect ( saveAct, SIGNAL ( activated() ), this, SLOT ( save() ) );
    actionMainWinList.append ( saveAct );



    saveAsAct = new QAction ( tr ( "Save As..." ), 0, this,"saveAsAct" );
    saveAsAct->setIconSet ( *saveAsIconSet );
    saveAsAct->setStatusTip ( tr ( "Save the location under a new "
                                   "name" ) );
    connect ( saveAsAct, SIGNAL ( activated() ), this, SLOT ( saveAs() ) );
    actionMainWinList.append ( saveAsAct );

    exportAct = new QAction ( tr ( "Export" ), 0, this,"Export" );
    exportAct->setIconSet ( *exportIconSet );
    exportAct->setStatusTip ( tr ( "Export the cleaned wave forms or dispersion curves" ) );
    connect ( exportAct, SIGNAL ( activated() ), this, SLOT ( exportAh() ) );
    actionMainWinList.append ( exportAct );


    zoominAct = new QAction ( tr ( "&ZoomIn" ), tr ( "Ctrl+Z" ), this,"zoominAct" );
    zoominAct->setIconSet ( QPixmap ( qPixmapFromMimeSource ( "zoomin.png" ) ) );
    zoominAct->setStatusTip ( tr ( "Increase font in the application" ) );
    connect ( zoominAct, SIGNAL ( activated() ), this, SLOT ( zoomin() ) );

    zoomoutAct = new QAction ( tr ( "ZoomO&Ut" ), tr ( "Ctrl+U" ), this,"zoomoutAct" );
    zoomoutAct->setIconSet ( QPixmap ( qPixmapFromMimeSource ( "zoomout.png" ) ) );
    zoomoutAct->setStatusTip ( tr ( "Decrease font in the application" ) );
    connect ( zoomoutAct, SIGNAL ( activated() ), this, SLOT ( zoomout() ) );

    exitAct = new QAction ( tr ( "E&xit" ), tr ( "Ctrl+Q" ), this,"exitAct" );
    exitAct->setIconSet ( QPixmap ( qPixmapFromMimeSource ( "exit.png" ) ) );
    exitAct->setStatusTip ( tr ( "Exit the application" ) );
    connect ( exitAct, SIGNAL ( activated() ), this, SLOT ( close() ) );

    showGridAct = new QAction ( tr ( "&Show Grid" ), 0, this,"showGridAct" );
    showGridAct->setToggleAction ( true );
    //showGridAct->setOn(spreadsheet->showGrid());
    showGridAct->setStatusTip ( tr ( "Show or hide the spreadsheet's "
                                     "grid" ) );
    //connect(showGridAct, SIGNAL(toggled(bool)),
    //        spreadsheet, SLOT(setShowGrid(bool)));

    autoRecalcAct = new QAction ( tr ( "&Auto-recalculate" ), 0, this,"autoRecalcAct" );
    autoRecalcAct->setToggleAction ( true );
    //autoRecalcAct->setOn(spreadsheet->autoRecalculate());
    autoRecalcAct->setStatusTip ( tr ( "Switch auto-recalculation on or "
                                       "off" ) );
    //connect(autoRecalcAct, SIGNAL(toggled(bool)),
    //        spreadsheet, SLOT(setAutoRecalculate(bool)));

    contentAct = new QAction ( tr ( "Content " ), tr ( "F1" ), this,"contentAct" );
    contentAct->setStatusTip ( tr ( "Show the Content of ftan manual" ) );
    connect ( contentAct, SIGNAL ( activated() ), this, SLOT ( mainHelpSlot() ) );



    aboutAct = new QAction ( tr ( "About" ), 0, this,"aboutAct" );
    aboutAct->setStatusTip ( tr ( "Show the application's About box" ) );
    connect ( aboutAct, SIGNAL ( activated() ), this, SLOT ( about() ) );

    aboutQtAct = new QAction ( tr ( "About Qt" ), 0, this,"aboutQtAct" );
    aboutQtAct->setStatusTip ( tr ( "Show the Qt library's About box" ) );
    connect ( aboutQtAct, SIGNAL ( activated() ), qApp, SLOT ( aboutQt() ) );

    ///////////////////////ftanToolBar///////////////////////////////////

    startAct = new QAction ( tr ( "Sta&rt" ), tr ( "Alt+R" ), this,"startAct" );
    startAct->setIconSet ( *startIconSet );
    startAct->setStatusTip ( tr ( "Start wave form analysis" ) );
    connect ( startAct, SIGNAL ( activated() ), this, SLOT ( startSlot() ) );
    actionMainWinList.append ( startAct );

    waveAct = new QAction ( tr ( "&Wave" ), tr ( "Alt+W" ), this,"waveAct" );
    waveAct->setIconSet ( *waveIconSet );
    waveAct->setStatusTip ( tr ( "Draw wave form" ) );
    connect ( waveAct, SIGNAL ( activated() ), this, SLOT ( waveSlot() ) );
    actionFtanWinList.append ( waveAct );

    filterAct = new QAction ( tr ( "F&ilter" ), tr ( "Alt+I" ), this,"filterAct" );
    filterAct->setIconSet ( *filterIconSet );
    filterAct->setStatusTip ( tr ( "Filter wave form" ) );
    connect ( filterAct, SIGNAL ( activated() ), this, SLOT ( filterSlot() ) );
    actionFtanWinList.append ( filterAct );

    ftaAct = new QAction ( tr ( "&Fta" ), tr ( "Alt+F" ), this,"ftaAct" );
    ftaAct->setIconSet ( *ftaIconSet );
    ftaAct->setStatusTip ( tr ( "Draw ftan diagram" ) );
    connect ( ftaAct, SIGNAL ( activated() ), this, SLOT ( ftaSlot() ) );
    actionFtanWinList.append ( ftaAct );

    velAct = new QAction ( tr ( "&Velocity" ), tr ( "Alt+V" ), this,"velAct" );
    velAct->setIconSet ( *velIconSet );
    velAct->setStatusTip ( tr ( "Draw velocities" ) );
    connect ( velAct, SIGNAL ( activated() ), this, SLOT ( velSlot() ) );
    actionFtanWinList.append ( velAct );

    ampAct = new QAction ( tr ( "&Amplitude" ), tr ( "Alt+A" ), this,"ampAct" );
    ampAct->setIconSet ( *ampIconSet );
    ampAct->setStatusTip ( tr ( "Draw amplitude" ) );
    connect ( ampAct, SIGNAL ( activated() ), this, SLOT ( ampSlot() ) );
    actionFtanWinList.append ( ampAct );

    polarAct = new QAction ( tr ( "&Polarity" ), tr ( "Alt+P" ), this,"polarAct" );
    polarAct->setIconSet ( *polarIconSet );
    polarAct->setStatusTip ( tr ( "Draw polarization" ) );
    connect ( polarAct, SIGNAL ( activated() ), this, SLOT ( polarSlot() ) );
    actionFtanWinList.append ( polarAct );

    ovrAct = new QAction ( tr ( "&Overlay" ), tr ( "Alt+O" ), this,"ovrAct" );
    ovrAct->setIconSet ( *ovrIconSet );
    ovrAct->setStatusTip ( tr ( "Draw overlay" ) );
    connect ( ovrAct, SIGNAL ( activated() ), this, SLOT ( ovrSlot() ) );
    actionFtanWinList.append ( ovrAct );

    imageAct = new QAction ( tr ( "I&mage" ), tr ( "Alt+M" ), this,"imageAct" );
    imageAct->setIconSet ( *imageIconSet );
    imageAct->setStatusTip ( tr ( "Draw images" ) );
    connect ( imageAct, SIGNAL ( activated() ), this, SLOT ( imageSlot() ) );
    actionFtanWinList.append ( imageAct );

    saveRecAct = new QAction ( tr ( "Sav&e" ), tr ( "Alt+E" ), this,"saveRecAct" );
    saveRecAct->setIconSet ( *saveRecIconSet );
    saveRecAct->setStatusTip ( tr ( "Save records" ) );
    connect ( saveRecAct, SIGNAL ( activated() ), this, SLOT ( saveRecSlot() ) );
    actionFtanWinList.append ( saveRecAct );

    cleanRecAct = new QAction ( tr ( "Clea&n" ), tr ( "Alt+N" ), this,"cleanRecAct" );
    cleanRecAct->setIconSet ( *cleanRecIconSet );
    cleanRecAct->setStatusTip ( tr ( "Clean records" ) );
    connect ( cleanRecAct, SIGNAL ( activated() ), this, SLOT ( cleanRecSlot() ) );
    actionFtanWinList.append ( cleanRecAct );

    periodListAct = new QAction ( tr ( "Period &List" ), tr ( "Alt+L" ), this,"periodListAct" );
    periodListAct->setIconSet ( QPixmap ( qPixmapFromMimeSource ( "periodlist.png" ) ) );
    periodListAct->setStatusTip ( tr ( "Period list table" ) );
    connect ( periodListAct, SIGNAL ( activated() ), this, SLOT ( periodListSlot() ) );
    actionMainWinList.append ( periodListAct );

    mapAct = new QAction ( tr ( "Draw S&tation Map" ), tr ( "Alt+T" ), this,"mapAct" );
    mapAct->setIconSet ( QPixmap ( qPixmapFromMimeSource ( "globe.png" ) ) );
    mapAct->setStatusTip ( tr ( "Draw Station Map" ) );
    connect ( mapAct, SIGNAL ( activated() ), this, SLOT ( stationMapSlot() ) );
    actionMainWinList.append ( mapAct );

    ///////////////////ftanToolBar////////////////////////////////////////
    ///////////////////mainSetingsToolBar////////////////////////////////////////
    allParamAct = new QAction ( tr ( "Total Settings..." ), 0, this,"allParamAct" );
    allParamAct->setStatusTip ( tr ( "Full configuration of all perameters" ) );
    connect ( allParamAct, SIGNAL ( activated() ), this, SLOT ( SettingsAllParameters() ) );
    actionMainWinList.append ( allParamAct );

    mainParamAct = new QAction ( tr ( "&Main Settings" ),tr ( "Ctrl+M" ), this,"mainParamAct" );
    mainParamAct->setStatusTip ( tr ( "Configuration of main perameters" ) );
    mainParamAct->setIconSet ( *mainParamIconSet );
    connect ( mainParamAct, SIGNAL ( activated() ), this, SLOT ( SettingsMainParameters() ) );
    actionMainWinList.append ( mainParamAct );

    pscriptOnOffAct = new QAction ( tr ( "&Ps On/Off" ), tr ( "Ctrl+P" ), this,"pscriptOnOffAct" );
    pscriptOnOffAct->setIconSet ( *pscriptOnOffIconSet );
    pscriptOnOffAct->setStatusTip ( tr ( "PostScript On/Off" ) );
    pscriptOnOffAct->setToggleAction ( TRUE );
    connect ( pscriptOnOffAct, SIGNAL ( activated() ), this, SLOT ( pscriptOnOffSlot() ) );
    actionMainWinList.append ( pscriptOnOffAct );

    polarOnOffAct = new QAction ( tr ( "Pola&r On/Off" ), tr ( "Ctrl+R" ), this,"polarOnOffAct" );
    polarOnOffAct->setIconSet ( *polarOnOffIconSet );
    polarOnOffAct->setStatusTip ( tr ( "Polarization On/Off" ) );
    polarOnOffAct->setToggleAction ( TRUE );
    connect ( polarOnOffAct, SIGNAL ( activated() ), this, SLOT ( polarOnOffSlot() ) );
    actionMainWinList.append ( polarOnOffAct );

    originAct = new QAction ( tr ( "Ori&gin" ), tr ( "Ctrl+G" ), this,"originAct" );
    originAct->setIconSet ( *originIconSet );
    originAct->setStatusTip ( tr ( "Set Quake Date" ) );
    connect ( originAct, SIGNAL ( activated() ), this, SLOT ( originSlot() ) );
    actionMainWinList.append ( originAct );

    filterSpecAct = new QAction ( tr ( "&Filter Spec" ), tr ( "Ctrl+F" ), this,"filterSpecAct" );
    filterSpecAct->setIconSet ( *filterSpecIconSet );
    filterSpecAct->setStatusTip ( tr ( "Wave form filter Specs" ) );
    connect ( filterSpecAct, SIGNAL ( activated() ), this, SLOT ( filterSpecSlot() ) );
    actionMainWinList.append ( filterSpecAct );

    ftaSpecAct = new QAction ( tr ( "Fta &Window" ), tr ( "Ctrl+W" ), this,"ftaSpecAct" );
    ftaSpecAct->setIconSet ( *ftaSpecIconSet );
    ftaSpecAct->setStatusTip ( tr ( "min/max group vel & period" ) );
    connect ( ftaSpecAct, SIGNAL ( activated() ), this, SLOT ( ftaSpecSlot() ) );
    actionMainWinList.append ( ftaSpecAct );

    plotCompAct = new QAction ( tr ( "P&lot Comp" ), tr ( "Ctrl+L" ), this,"plotCompAct" );
    plotCompAct->setIconSet ( *plotCompIconSet );
    plotCompAct->setStatusTip ( tr ( "Choose suitable 'plot' components" ) );
    connect ( plotCompAct, SIGNAL ( activated() ), this, SLOT ( plotCompSlot() ) );
    actionMainWinList.append ( plotCompAct );
    ftaCompAct = new QAction ( tr ( "F&ta Comp" ), tr ( "Ctrl+T" ), this,"ftaCompAct" );
    ftaCompAct->setIconSet ( *ftaCompIconSet );
    ftaCompAct->setStatusTip ( tr ( "Choose suitable 'fta' components" ) );
    connect ( ftaCompAct, SIGNAL ( activated() ), this, SLOT ( ftaCompSlot() ) );
    actionMainWinList.append ( ftaCompAct );
    /*
    orbitCompAct = new QAction(tr("Orbit"), tr("Ctrl+v"), this);
    orbitCompAct->setIconSet(*orbitIconSet);
    orbitCompAct->setStatusTip(tr("Choose suitable orbit"));
    connect(orbitCompAct, SIGNAL(activated()), this, SLOT(orbitSlot()));
    */

    modeCompAct = new QAction ( tr ( "Mo&de" ), tr ( "Ctrl+D" ), this,"modeCompAct" );
    modeCompAct->setIconSet ( *modeIconSet );
    modeCompAct->setStatusTip ( tr ( "Choose suitable mode" ) );
    connect ( modeCompAct, SIGNAL ( activated() ), this, SLOT ( modeSlot() ) );
    actionMainWinList.append ( modeCompAct );


    for ( int i = 0; i < MaxRecentFiles; ++i ) {
        recentProjectFileActs[i] = new QAction ( this );
        recentProjectFileActs[i]->setVisible ( false );
        connect ( recentProjectFileActs[i], SIGNAL ( triggered() ),
                  this, SLOT ( openRecentProjectFile() ) );
    }

}
///////////////////ftanToolBar////////////////////////////////////////
void  MainWindow::createWhatsThis() {
    ///////////////////  location tool bar////////////////////////////////////////
    const char * locationOpenText = "<p><img source=\"folder_open.png\"> "
                                    "Click this button to open a <em> existing location</em>."
                                    "You can also select the <b>Open</b> command "
                                    "from the <b>Location</b> menu. Keyboard shortcut is  <b>(Ctrl+O)</b></p>";
    openAct->setWhatsThis ( locationOpenText );

    const char * locationNewText = "<p><img source=\"folder_new.png\"> "
                                   "Click this button to create a <em>new location</em>."
                                   "You can also select the <b>New</b> command "
                                   "from the <b>Location</b> menu. Keyboard shortcut is  <b>(Ctrl+N)</b></p>";

    newAct->setWhatsThis ( locationNewText );

    const char * locationSaveText = "<p><img source=\"filesave.png\"> "
                                    "Click this button to save a <em>currently open location</em>."
                                    "You can also select the <b>Save </b> command "
                                    "from the <b>Location</b> menu. Keyboard shortcut is  <b>(Ctrl+S)</b></p>";

    saveAct->setWhatsThis ( locationSaveText );

    const char * locationSaveAsText = "<p><img source=\"filesaveas.png\"> "
                                      "Click this button to save a <em>currently location under a new name</em>."
                                      "You can also select the <b>Save as ... </b> command "
                                      "from the <b>Location</b> menu. </p>";

    saveAsAct->setWhatsThis ( locationSaveAsText );

    const char * locationExportText = "<p><img source=\"ftan_export.png\"> "
                                      "Click this button to export the <em>cleaned wave forms </em> in AH, AH ASCII format and ASCII dispersion curves into the selected directory."
                                      "You can also select the <b>Export </b> command  "
                                      "from the <b>Location</b> menu. </p>";

    exportAct->setWhatsThis ( locationExportText );

    const char * locationExitText = "<p><img source=\"exit.png\"> "
                                    "Click this button to close the <b> ftan progran. </b> All child windows of ftan program will be also closed."
                                    "You can also select the <b>Exit </b> command  "
                                    "from the <b>Location</b> menu.  Keyboard shortcut is  <b>(Ctrl+Q)</b></p>";
    exitAct->setWhatsThis ( locationExitText );

    const char * locationZoomInText = "<p><img source=\"zoomin.png\"> "
                                      "Click this button to decrease the <em>font size</em> in all windows of the ftan program. "
                                      "Keyboard shortcut is  <b>(Ctrl++)</b></p>";
    zoominAct->setWhatsThis ( locationZoomInText );

    const char * locationZoomOutText = "<p><img source=\"zoomout.png\"> "
                                       "Click this button to increase the <em>font size</em> in all windows of the ftan program. "
                                       "Keyboard shortcut is  <b>(Ctrl+-)</b></p>";
    zoomoutAct->setWhatsThis ( locationZoomOutText );
    ///////////////////  location tool bar   ////////////////////////////////////////
    ///////////////////  tools  tool bar   ////////////////////////////////////////
    const char * toolStartFtanText = "<p><img source=\"ftan_Start.png\"> "
                                     "Click this button to start the <em>ftan processing. </em>"
                                     "You can also select the <b>Start </b> command "
                                     "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+R)</b></p>";
    startAct->setWhatsThis ( toolStartFtanText );

    const char * toolWavetFtanText = "<p><img source=\"ftan_WaveForms.png\"> "
                                     "Click this button to plot selected the <em>wave forms. </em>"
                                     "You can also select the <b>Wave </b> command "
                                     "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+W)</b></p>";
    waveAct->setWhatsThis ( toolWavetFtanText );

    const char * toolWaveFtanText = "<p><img source=\"ftan_Filter.png\"> "
                                    "Click this button to apply bandpass filtering to <em>waveforms raw data. </em>"
                                    "You can also select the <b>Filter </b> command "
                                    "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+I)</b></p>";
    filterAct->setWhatsThis ( toolWaveFtanText );

    const char * toolFtaFtanText = "<p><img source=\"ftan_Fta.png\"> "
                                   "Click this button to  start the performance of <em>floating filtering. </em>"
                                   "You can also select the <b>Filter </b> command "
                                   "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+F)</b></p>";
    ftaAct->setWhatsThis ( toolFtaFtanText );

    const char * toolVelFtanText = "<p><img source=\"ftan_Vel.png\"> "
                                   "Click this button to view <em>calculated group velocity curves. </em>"
                                   "You can also select the <b>Velocity </b> command "
                                   "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+F)</b></p>";
    velAct->setWhatsThis ( toolVelFtanText );

    const char * toolAmpFtanText = "<p><img source=\"ftan_Amp.png\"> "
                                   "Click this button to view  <em>cleaned and raw amplitude spectra. </em>"
                                   "You can also select the <b>Amplitude </b> command "
                                   "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+A)</b></p>";
    ampAct->setWhatsThis ( toolAmpFtanText );

    const char * toolPolarFtanText = "<p><img source=\"ftan_Polar.png\"> "
                                     "Click this button to view  <em>estimated polarization anomalies. </em>"
                                     "You can also select the <b>Polarity </b> command "
                                     "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+P)</b></p>";
    polarAct->setWhatsThis ( toolPolarFtanText );

    const char * toolOvrFtanText = "<p><img source=\"ftan_Ovr.png\"> "
                                   "Click this button to view  <em> cleaned and raw seismograms. </em>"
                                   "You can also select the <b>Overlay </b> command "
                                   "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+O)</b></p>";
    ovrAct->setWhatsThis ( toolOvrFtanText );

    const char * toolImageFtanText = "<p><img source=\"ftan_Image.png\"> "
                                     "Click this button to view <em> a FTAN diagrams for cleaned and raw seismograms. </em>"
                                     "You can also select the <b>Image </b> command "
                                     "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+M)</b></p>";
    imageAct->setWhatsThis ( toolImageFtanText );

    const char * toolSaveFtanText = "<p><img source=\"ftan_SaveResults.png\"> "
                                    "Click this button to save <em> results of processing. </em>"
                                    "You can also select the <b>Save </b> command "
                                    "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+E)</b></p>";
    saveRecAct->setWhatsThis ( toolSaveFtanText );

    const char * toolCleanFtanText = "<p><img source=\"ftan_Clean.png\"> "
                                     "Click this button to clean <em> results of processing for chosen components. </em>"
                                     "You can also select the <b>Clean </b> command "
                                     "from the <b>Tools</b> menu.  Keyboard shortcut is  <b>(Alt+N)</b></p>";
    cleanRecAct->setWhatsThis ( toolCleanFtanText );

    ///////////////////  tools  tool bar   ////////////////////////////////////////

    ///////////////////  settings  tool bar   ////////////////////////////////////////
    const char * setSetFtanText = "<p><img source=\"ftan_Settings.png\"> "
                                  "Click this button to set <em>main parameters. </em>"
                                  "You can also select the <b>Main </b> command "
                                  "from the <b>Settings</b> menu.  Keyboard shortcut is  <b>(Ctrl+M)</b></p>";
    mainParamAct->setWhatsThis ( setSetFtanText );

    const char * setPsFtanText = "<p><img source=\"ftan_SavePs.png\"> "
                                 " Toggle button. If the button is pressed then <em>postscript files </em>will be created."
                                 "You can also select the <b>Ps On/Off </b> command "
                                 "from the <b>Settings</b> menu.  Keyboard shortcut is  <b>(Ctrl+P)</b></p>";
    pscriptOnOffAct->setWhatsThis ( setPsFtanText );

    const char * setPolarFtanText = "<p><img source=\"ftan_Polarization.png\"> "
                                    " Toggle button. If the button is pressed then <em>polarization measurement </em>will be performed."
                                    "You can also select the <b>Polar On/Off </b> command "
                                    "from the <b>Settings</b> menu.  Keyboard shortcut is  <b>(Ctrl+R)</b></p>";
    polarOnOffAct->setWhatsThis ( setPolarFtanText );

    const char * setFilterFtanText = "<p><img source=\"ftan_FilterSpec.png\"> "
                                     " Assignment of parameters for <em> bandpass filtering.</em>"
                                     "You can also select the <b>Filter Spec </b> command "
                                     "from the <b>Settings</b> menu.  Keyboard shortcut is  <b>(Ctrl+F)</b></p>";
    filterSpecAct->setWhatsThis ( setFilterFtanText );

    const char * setFtaSpecFtanText = "<p><img source=\"ftan_Window.png\"> "
                                      " Assignment of parameters  defining <em> FTAN window.</em>"
                                      "You can also select the <b>Fta Window  </b> command "
                                      "from the <b>Settings</b> menu.  Keyboard shortcut is  <b>(Ctrl+W)</b></p>";
    ftaSpecAct->setWhatsThis ( setFtaSpecFtanText );

    const char * setPlotCompFtanText = "<p><img source=\"ftan_PlotCompts.png\"> "
                                       " Selection of <em> wave form components </em> to be plotted."
                                       "You can also select the <b>Plot Comp  </b> command "
                                       "from the <b>Settings</b> menu.  Keyboard shortcut is  <b>(Ctrl+L)</b></p>";
    plotCompAct->setWhatsThis ( setPlotCompFtanText );

    const char * setFtaCompFtanText = "<p><img source=\"ftan_FtaCompts.png\"> "
                                      " Selection of <em> wave form components </em> for FTAN processing."
                                      "You can also select the <b>Fta Comp  </b> command "
                                      "from the <b>Settings</b> menu.  Keyboard shortcut is  <b>(Ctrl+T)</b></p>";
    ftaCompAct->setWhatsThis ( setFtaCompFtanText );

    const char * setModeCompFtanText = "<p><img source=\"ftan_Mode.png\"> "
                                       " Assignment of  <em> mode number. </em>"
                                       "You can also select the <b>Mode  </b> command "
                                       "from the <b>Settings</b> menu.  Keyboard shortcut is  <b>(Ctrl+D)</b></p>";
    modeCompAct->setWhatsThis ( setModeCompFtanText );

}

void  MainWindow::createIconSet() {
    saveIconSet = new QIcon;
    SetImageToIconSet ( saveIconSet,"filesave.png","file_d_save.png" );
    saveAsIconSet = new QIcon;
    SetImageToIconSet ( saveAsIconSet,"filesaveas.png","file_d_saveas.png" );
    exportIconSet = new QIcon;
    SetImageToIconSet ( exportIconSet,"ftan_export.png","ftan_d_export.png" );
    startIconSet = new QIcon;
    SetImageToIconSet ( startIconSet,"ftan_Stop.png","ftan_Stop.png" );
    waveIconSet = new QIcon;
    SetImageToIconSet ( waveIconSet,"ftan_WaveForms.png","ftan_d_WaveForms.png" );
    filterIconSet = new QIcon;
    SetImageToIconSet ( filterIconSet,"ftan_Filter.png","ftan_d_Filter.png" );
    ftaIconSet = new QIcon;
    SetImageToIconSet ( ftaIconSet,"ftan_Fta.png","ftan_d_Fta.png" );
    velIconSet = new QIcon;
    SetImageToIconSet ( velIconSet,"ftan_Vel.png","ftan_d_Vel.png" );
    ampIconSet = new QIcon;
    SetImageToIconSet ( ampIconSet,"ftan_Amp.png","ftan_d_Amp.png" );
    polarIconSet = new QIcon;
    SetImageToIconSet ( polarIconSet,"ftan_Polar.png","ftan_d_Polar.png" );
    ovrIconSet = new QIcon;
    SetImageToIconSet ( ovrIconSet,"ftan_Ovr.png","ftan_d_Ovr.png" );
    imageIconSet = new QIcon;
    SetImageToIconSet ( imageIconSet,"ftan_Image.png","ftan_d_Image.png" );
    saveRecIconSet = new QIcon;
    SetImageToIconSet ( saveRecIconSet,"ftan_SaveResults.png","ftan_d_SaveResults.png" );
    cleanRecIconSet = new QIcon;
    SetImageToIconSet ( cleanRecIconSet,"ftan_Clean.png","ftan_d_Clean.png" );

    mainParamIconSet = new QIcon;
    SetImageToIconSet ( mainParamIconSet,"ftan_Settings.png","ftan_d_Settings.png" );


    pscriptOnOffIconSet = new QIcon;
    SetImageToIconSet ( pscriptOnOffIconSet,"ftan_SavePs.png","ftan_d_SavePs.png" );

    polarOnOffIconSet = new QIcon;
    SetImageToIconSet ( polarOnOffIconSet,"ftan_Polarization.png","ftan_d_Polarization.png" );

    originIconSet = new QIcon;
    SetImageToIconSet ( originIconSet,"ftan_OriginTime.png","ftan_d_OriginTime.png" );
    filterSpecIconSet = new QIcon;
    SetImageToIconSet ( filterSpecIconSet,"ftan_FilterSpec.png","ftan_d_FilterSpec.png" );

    ftaSpecIconSet = new QIcon;
    SetImageToIconSet ( ftaSpecIconSet,"ftan_Window.png","ftan_d_Window.png" );

    plotCompIconSet = new QIcon;
    SetImageToIconSet ( plotCompIconSet,"ftan_PlotCompts.png","ftan_d_PlotCompts.png" );

    ftaCompIconSet = new QIcon;
    SetImageToIconSet ( ftaCompIconSet,"ftan_FtaCompts.png","ftan_d_FtaCompts.png" );

    orbitIconSet = new QIcon;
    SetImageToIconSet ( orbitIconSet,"ftan_orbit1.png","ftan_d_Orbit.png" );

    modeIconSet = new QIcon;
    SetImageToIconSet ( modeIconSet,"ftan_Mode.png","ftan_d_Mode.png" );


}

void  MainWindow::SetImageToIconSet ( QIcon *icon,const QString & normalname,
                                      const QString & disabledname ) {

//QPixmap(qPixmapFromMimeSource("zoomout.png"))
    icon->setPixmap ( QPixmap ( qPixmapFromMimeSource ( normalname ) ),QIcon::Automatic,QIcon::Normal,QIcon::On );
    icon->setPixmap ( QPixmap ( qPixmapFromMimeSource ( normalname ) ),QIcon::Automatic,QIcon::Normal,QIcon::Off );

    icon->setPixmap ( QPixmap ( qPixmapFromMimeSource ( disabledname ) ),QIcon::Automatic,QIcon::Disabled,QIcon::On );
    icon->setPixmap ( QPixmap ( qPixmapFromMimeSource ( disabledname ) ),QIcon::Automatic,QIcon::Disabled,QIcon::Off );

    icon->setPixmap ( QPixmap ( qPixmapFromMimeSource ( normalname ) ),QIcon::Automatic,QIcon::Active,QIcon::On );
    icon->setPixmap ( QPixmap ( qPixmapFromMimeSource ( normalname ) ),QIcon::Automatic,QIcon::Active,QIcon::Off );
}

///////////////////ftanToolBar////////////////////////////////////////
void MainWindow::createMenus() {

    locationMenu = new Q3PopupMenu ( this );
    newAct->addTo ( locationMenu );
    openAct->addTo ( locationMenu );
    saveAct->addTo ( locationMenu );
    saveAsAct->addTo ( locationMenu );
    exportAct->addTo ( locationMenu );

    separatorProjectAct = locationMenu->addSeparator();
    for ( int i = 0; i < MaxRecentFiles; ++i )
        locationMenu->addAction ( recentProjectFileActs[i] );
    locationMenu->addSeparator();

    exitAct->addTo ( locationMenu );

    updateRecentProjectFileActions();

    settingsMenu = new Q3PopupMenu ( this );
    allParamAct->addTo ( settingsMenu );
    settingsMenu->insertSeparator();
    mainParamAct->addTo ( settingsMenu );
    settingsMenu->insertSeparator();
    pscriptOnOffAct->addTo ( settingsMenu );
    polarOnOffAct->addTo ( settingsMenu );
    // originAct->addTo(settingsMenu);
    filterSpecAct->addTo ( settingsMenu );
    ftaSpecAct->addTo ( settingsMenu );
    plotCompAct->addTo ( settingsMenu );
    ftaCompAct->addTo ( settingsMenu );


    orbitPopupmenu = new Q3PopupMenu ( settingsMenu );
    orbitPopupmenu->insertItem ( "1",0 );
    orbitPopupmenu->insertItem ( "2",1 );
    orbitPopupmenu->insertItem ( "3",2 );
    orbitPopupmenu->insertItem ( "4",3 );
    orbitPopupmenu->insertItem ( "5",4 );
    orbitPopupmenu->insertItem ( "6",5 );
    orbitPopupmenu->insertItem ( "7",6 );
    orbitPopupmenu->insertItem ( "8",7 );
    orbitPopupmenu->insertItem ( "9",8 );
    orbitPopupmenu->insertItem ( "10",9 );
    orbitPopupmenu->insertItem ( "11",10 );
    orbitPopupmenu->insertItem ( "12",11 );
    orbitPopupmenu->insertItem ( "13",12 );
    orbitPopupmenu->insertItem ( "14",13 );
    orbitPopupmenu->insertItem ( "15",14 );
    orbitPopupmenu->insertItem ( "16",15 );

    QIcon temp ( *orbitIconSet );
    idItemOrbitOfSettingMenu=    settingsMenu->insertItem ( temp, "Orbit :  1",orbitPopupmenu );

    modeCompAct->addTo ( settingsMenu );

    toolsMenu = new Q3PopupMenu ( this );
    startAct->addTo ( toolsMenu );
    waveAct->addTo ( toolsMenu );
    filterAct->addTo ( toolsMenu );
    ftaAct->addTo ( toolsMenu );
    velAct->addTo ( toolsMenu );
    ampAct->addTo ( toolsMenu );
    polarAct->addTo ( toolsMenu );
    ovrAct->addTo ( toolsMenu );
    imageAct->addTo ( toolsMenu );
    cleanRecAct->addTo ( toolsMenu );
    saveRecAct->addTo ( toolsMenu );

///!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
/// !!!!    periodListAct->addTo ( toolsMenu );
///!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    mapAct->addTo ( toolsMenu );



    helpMenu = new Q3PopupMenu ( this );
    contentAct->addTo ( helpMenu );

    aboutAct->addTo ( helpMenu );
    aboutQtAct->addTo ( helpMenu );
    helpMenu ->insertItem ( "What's &This", this, SLOT ( whatsThis() ), Qt::Key_Shift + Qt::Key_F1 );

    menuBar()->insertItem ( tr ( "&Location" ), locationMenu );
    menuBar()->insertItem ( tr ( "&Settings" ), settingsMenu );
    menuBar()->insertItem ( tr ( "&Tools" ), toolsMenu );
    menuBar()->insertSeparator();
    menuBar()->insertItem ( tr ( "&Help" ), helpMenu );

}

void MainWindow::createToolBars() {
    locationToolBar = new Q3ToolBar ( tr ( "Location" ), this );
    newAct->addTo ( locationToolBar );
    openAct->addTo ( locationToolBar );
    saveAct->addTo ( locationToolBar );
    saveAsAct->addTo ( locationToolBar );
    zoominAct->addTo ( locationToolBar );
    zoomoutAct->addTo ( locationToolBar );
    exportAct->addTo ( locationToolBar );


    QToolButton * whatsThisButton = Q3WhatsThis::whatsThisButton ( locationToolBar );
    whatsThisButton->setAccel ( tr ( "Shift+F1" ) );

    locationToolBar->addSeparator ();
    exitAct->addTo ( locationToolBar );
    ////////////////////////ftanToolBar/////////////////////////
    ftanToolBar = new Q3ToolBar ( tr ( "Tools" ), this );

    startAct->addTo ( ftanToolBar );
    waveAct->addTo ( ftanToolBar );
    ftanToolBar->addSeparator ();
    filterAct->addTo ( ftanToolBar );
    ftaAct->addTo ( ftanToolBar );
    ftanToolBar->addSeparator ();
    velAct->addTo ( ftanToolBar );
    ampAct->addTo ( ftanToolBar );
    polarAct->addTo ( ftanToolBar );
    ovrAct->addTo ( ftanToolBar );
    imageAct->addTo ( ftanToolBar );
    cleanRecAct->addTo ( ftanToolBar );
    ftanToolBar->addSeparator ();
    saveRecAct->addTo ( ftanToolBar );
    ftanToolBar->addSeparator ();
///!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
/// !!!!    periodListAct->addTo ( ftanToolBar );
///!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    mapAct->addTo ( ftanToolBar );
    ftanToolBar->addSeparator ();

    // ftanToolBar->setNewLine (TRUE);
    moveDockWindow ( ftanToolBar, Qt::DockLeft );

    ////////////////////////ftanToolBar/////////////////////////
    ////////////////////////mainSetingsToolBar/////////////////////////
    mainSetingsToolBar = new Q3ToolBar ( tr ( "Main Settings" ), this );
    mainParamAct->addTo ( mainSetingsToolBar );
    mainSetingsToolBar->addSeparator ();
    pscriptOnOffAct->addTo ( mainSetingsToolBar );
    mainSetingsToolBar->addSeparator ();
    polarOnOffAct->addTo ( mainSetingsToolBar );
    mainSetingsToolBar->addSeparator ();
    // originAct->addTo(mainSetingsToolBar);
    filterSpecAct->addTo ( mainSetingsToolBar );
    ftaSpecAct->addTo ( mainSetingsToolBar );
    plotCompAct->addTo ( mainSetingsToolBar );
    ftaCompAct->addTo ( mainSetingsToolBar );

    //orbitCompAct->addTo(mainSetingsToolBar);
    ////////////////////////////////////////////////////////////////////////////
    QIcon temp ( *orbitIconSet );
    orbitToolButton =
        new QToolButton ( temp, tr ( "Orbit" ),
                          tr ( "Choose suitable orbit" ),
                          NULL,NULL,
                          mainSetingsToolBar, tr ( "Orbit" ) );
    orbitToolButton->setPopupMode(QToolButton::InstantPopup);
    orbitToolButton->setPopup ( orbitPopupmenu );
    const char * setOrbitCompFtanText = "<p><img source=\"ftan_orbit1.png\"> "
                                        " Assignment of  <em>  orbit number. </em>"
                                        "You can also select the <b>Orbit  </b> command "
                                        "from the <b>Settings</b> menu.</p>";
    Q3WhatsThis::add ( orbitToolButton, setOrbitCompFtanText );

    ///////////////////////////////////////////////////////////////////////////

    modeCompAct->addTo ( mainSetingsToolBar );
    mainSetingsToolBar->setNewLine ( TRUE );
    moveDockWindow ( mainSetingsToolBar, Qt::DockTop );

    ////////////////////////mainSetingsToolBar/////////////////////////
    /*
    editToolBar = new QToolBar(tr("Edit"), this);
    cutAct->addTo(editToolBar);
    copyAct->addTo(editToolBar);
    pasteAct->addTo(editToolBar);
    editToolBar->addSeparator();
    findAct->addTo(editToolBar);
    goToCellAct->addTo(editToolBar);
    */
}

void MainWindow::newLocation() {
    if ( maybeSave() ) {
        //  spreadsheet->clear();
        setCurrentDirectory ( "" );
    }
    NewDialog dialog ( this,false );
    if ( dialog.exec() ) {
    }
}
void MainWindow::zoomout() {
    QFont f ( font() );
    f.setPointSize ( f.pointSize() - 1 );
    setFont ( f );
}
void MainWindow::zoomin() {
    QFont f ( font() );
    f.setPointSize ( f.pointSize() + 1 );
    setFont ( f );

}
void MainWindow::open() {
    if ( maybeSave() ) {
        QString DirectoryName = Q3FileDialog::getExistingDirectory (
                                    "./",
                                    this,
                                    "get existing directory",
                                    "Open location",
                                    TRUE );


        if ( !DirectoryName.isEmpty() ) {
            QDir d ( DirectoryName );
            if ( !d.exists ( FTAN_PARAMETRS_FILE_NAME ) ) {
                QMessageBox::warning ( 0,mainWindowCaption(),QString ( "Directory %1  does not contain ftan materials " ).arg ( DirectoryName ) );

                return;
            }
            DirectoryName =  DirectoryName.left ( DirectoryName.findRev ( '/' ) );
            loadProjectDirectory ( DirectoryName );
        } else {
            statusBar()->message ( tr ( "Loading canceled" ), 2000 );
        }
    }
}

void MainWindow::loadProjectDirectory ( const QString &DirectoryName ) {
    statusBar()->~QStatusBar ();
    createStatusBar();
    if ( !savedFilteringRecord.isEmpty() ) savedFilteringRecord.clear();
    if ( doc != 0 ) {
        delete doc;
        doc = 0;
    }
    QString tmp = DirectoryName +"/" +FTAN_PARAMETRS_FILE_NAME;
    doc = new FDocument ( tmp );
    wfdiscAbsPath   =  doc->GetWfdiscAbsPath() ;
    rootAbsPath       =  doc->GetRootAbsPath() ;
    originAbsPath     =  doc->GetOriginAbsPath();
    eventInfo            =  doc->GetEventInfo();
    numOriginRow    =  doc->GetNumOriginRow();
    if ( !tempDir.isEmpty() ) {
        QString systemStr = QString ( "\\rm -r  %1" ).arg ( tempDir );
        system ( systemStr.ascii() );
    }
    QString workingDirectory =  DirectoryName.left ( DirectoryName.findRev ( '/' ) );
//  Check workingDirectory has last char '/'
//    workingDirectory =  workingDirectory.left(workingDirectory.findRev('/') );

    QDir::setCurrent ( workingDirectory );
    QDate date = QDate::currentDate ();
    QTime time = QTime::currentTime ();
    QDateTime datetime ( date, time ) ;
    uint currentTime = datetime.toTime_t ();
    tempDir = QString ( "%1%2" ).arg ( TEMPRARY_FTAN_PREFIX ).arg ( currentTime );
    QDir d ( workingDirectory );
    d.mkdir ( tempDir );
    fwoutDir = tempDir + "/" + FTAN_WFOUT_DIRECTORY_NAME;
    d.mkdir ( fwoutDir );
    setCurrentDirectory ( DirectoryName );
    statusBar()->message ( tr ( "Location loaded" ), 2000 );
    //    doc->printFDocument();
    if ( !verifyAbsPaths() ) return;
    setTemporaryMaterials ( DirectoryName );
    startFtan ( workingDirectory );
    if ( !doc->GetProjectFileGood() )
        if ( !doc->ReadFileListCtachan() ) return;
    QString tempWfDiscName =  tempDir + "/" + FTAN_TABLE_OUT_NAME + ".wfdisc";
    if ( d.exists ( tempWfDiscName ) )
        if ( !GetSavedRecordNames ( tempWfDiscName,savedFilteringRecord ) ) return;
    initCentralWidget();
}

bool MainWindow::save() {
    if ( curDirectory.isEmpty() ) {
        return saveAs();
    } else {
        QString systemStr = QString ( "\\rm -r  %1/*" ).arg ( curDirectory );
        system ( systemStr.ascii() );
        saveProjectDirectory ( curDirectory );
        return true;
    }
}

void MainWindow::saveProjectDirectory ( QString &DirectoryName ) {
    QString relpathwf;
    QString relpathRoot ;
    QString relpathOrigin;
    QString newWorkingDirectory =  DirectoryName.left ( DirectoryName.findRev ( '/' ) );

    relpathwf = GetRelativePath ( newWorkingDirectory , wfdiscAbsPath );
    int maximum = MAXIMUM_FTAN_DBTABLE_NAME_LENGTH;
    if ( relpathwf.length() >= maximum ) {
        QString tmp;
        tmp = QString ( "New relative wfdisc table name (%1)\nis too long (maximum length is %2).\n"
                        "Relative file names begin with a directory name or a file name\n"
                        " and specify a path relative to the new  working  directory\n %3." ).arg ( relpathwf ).arg ( maximum ).arg ( newWorkingDirectory );
        QMessageBox::critical ( this,caption(),tmp );
        return ;
    }

    relpathRoot = GetRelativePath ( newWorkingDirectory ,rootAbsPath );
    if ( relpathRoot.length() >= maximum ) {
        QString tmp;
        tmp = QString ( "Inputed relative root name (%1)\nis too long (maximum length maximum is %2).\n"
                        "Relative file names begin with a directory name or a file name\n"
                        " and specify a path relative to the new  working directory\n %3." ).arg ( relpathRoot ).arg ( maximum ).arg ( newWorkingDirectory );
        QMessageBox::critical ( this,caption(),tmp );
        return ;
    }
    relpathOrigin = GetRelativePath ( newWorkingDirectory ,originAbsPath );
    if ( relpathOrigin.length() >= maximum ) {
        QString tmp;
        tmp = QString ( "Inputed relative origin table name (%1)\nis too long (maximum length is %2).\n"
                        "Relative file names begin with a directory name or a file name\n"
                        " and specify a path relative to the new  working  directory\n %3." ).arg ( relpathOrigin ).arg ( maximum ).arg ( newWorkingDirectory );
        QMessageBox::critical ( this,caption(),tmp );
        return ;
    }

    SaveWorkingMaterials ( DirectoryName );
    QString tmp = DirectoryName+"/" +FTAN_PARAMETRS_FILE_NAME;
    //        doc->printFDocument();
    //   qWarning("save dir'%s' param name '%s ",DirectoryName.ascii(),tmp.ascii());
    //  qWarning("new work dir  '%s' old work dir '%s'",newWorkingDirectory.ascii(),QDir::currentDirPath().ascii());
    periodListDialog->list->SavePeriodListInfoToStaChanOutList();
    if ( doc->saveBinary ( tmp ) ) {
        setCurrentDirectory ( DirectoryName );
        statusBar()->message ( tr ( "Location saved" ), 2000 );
    } else {
        statusBar()->message ( tr ( "Saving canceled" ), 2000 );
    }
    if ( newWorkingDirectory != QDir::currentDirPath () )
        loadProjectDirectory ( DirectoryName );
}

bool MainWindow::exportAh () {
    AhFileDialog* fd = new AhFileDialog ( this,"AhFileDialog" );
    fd->setCaption ( "Export the cleaned wave forms or dispersion curves" );
    if ( fd->exec() ) { }

    delete fd;
    return true;
}
bool MainWindow::saveAs() {
    QString DirectoryName = Q3FileDialog::getExistingDirectory (
                                "./",
                                this,
                                "get existing directory",
                                "Save As Location",
                                TRUE );
    if ( DirectoryName != QString::null ) {
        DirectoryName =  DirectoryName.left ( DirectoryName.findRev ( '/' ) );
        QDir d ( DirectoryName );
        uint count = d.count ();
        if ( count >2 ) {
            //	   qWarning("Choosen directory '%s is not empty'",DirectoryName.ascii() );
            QString temp =DirectoryName.right ( DirectoryName.length()  - DirectoryName.findRev ( '/' ) -1 );
            QString tmp = QString ( "Directory %1 is not empty'.\nDo you want to delete all it's entries?" )
                          .arg ( temp );
            int ret = QMessageBox::warning ( this,mainWindowCaption(),tmp,
                                             QMessageBox::Yes | QMessageBox::Default,
                                             QMessageBox::No | QMessageBox::Escape );
            if ( ret == QMessageBox::No )
                return false;
            //	   qWarning("all it's entries will be deleted" );
            QString systemStr = QString ( "\\rm -r  %1/*" ).arg ( DirectoryName );
            system ( systemStr.ascii() );

        }
        saveProjectDirectory ( DirectoryName );
        return true;
    }
    return false;


}

void MainWindow::closeEvent ( QCloseEvent *event ) {
    QFile fil ( "list_stachan" );
    if ( fil.exists() )
        if ( !fil.remove() ) {
            QMessageBox::warning ( 0,mainWindowCaption(),"Can't remove file 'list_stachan'" );
        }
    if ( maybeSave() ) {
        writeSettings();
        event->accept();
    } else {
        event->ignore();
        return;
    }

    if ( process!=0 )  closeFtan();

    QString systemStr;
    if ( !tempDir.isEmpty() ) {
        QString systemStr = QString ( "\\rm -r  %1" ).arg ( tempDir );
        system ( systemStr.ascii() );
    }
    //    if (d.exists ( fwoutDir) ) {
    //	systemStr = QString ("\\rm -r  %1").arg( fwoutDir);
    //	qWarning("main:>  '%s'",systemStr.ascii());
    //	system(systemStr.ascii());
    //    }

}

bool MainWindow::maybeSave() {
    if ( modified ||  modifiedFlt ) {
        int ret = QMessageBox::warning ( this,mainWindowCaption(),
                                         tr ( "The document has been modified.\n"
                                              "Do you want to save your changes?" ),
                                         QMessageBox::Yes | QMessageBox::Default,
                                         QMessageBox::No,
                                         QMessageBox::Cancel | QMessageBox::Escape );
        if ( ret == QMessageBox::Yes )
            return save();
        else if ( ret == QMessageBox::Cancel )
            return false;
    }
    return true;
}

void MainWindow::setCurrentDirectory ( const QString &DirectoryName ) {
    curDirectory = DirectoryName;
    modLabel->clear();
    modified = false;
    modifiedFlt = false;
    if ( curDirectory.isEmpty() ) {
        setWindowTitle ( QString ( "%1 - %2" ).arg ( "unnamed" ).arg ( mainWindowCaption() ) );
        return;
    }

        setWindowTitle ( QString ( "%1 - %2" ).arg (strippedName(curDirectory) ).arg ( mainWindowCaption() ) );
    QSettings settings ( "mitp.ru", "FtanControlPanel" );
    QStringList files = settings.value ( "/recentProjectLocationList" ).toStringList();

    files.removeAll ( DirectoryName );
    files.prepend ( DirectoryName );
    while ( files.size() > MaxRecentFiles )
        files.removeLast();

    settings.setValue ( "recentProjectLocationList", files );

    foreach ( QWidget *widget, QApplication::topLevelWidgets() ) {
        MainWindow *mainWin = qobject_cast<MainWindow *> ( widget );
        if ( mainWin )
            mainWin->updateRecentProjectFileActions();
    }
}

QString MainWindow::strippedName ( const QString &fullDirName ) {
    return QDir ( fullDirName ).dirName();

}

void MainWindow::updateRecentProjectFileActions() {
    QSettings settings ( "mitp.ru", "FtanControlPanel" );

    QStringList files = settings.value ( "recentProjectLocationList" ).toStringList();

    int numRecentFiles = qMin ( files.size(), ( int ) MaxRecentFiles );

    for ( int i = 0; i < numRecentFiles; ++i ) {
        QString text = tr ( "&%1 %2" ).arg ( i + 1 ).arg ( strippedName ( files[i] ) );
        recentProjectFileActs[i]->setText ( text );
        recentProjectFileActs[i]->setData ( files[i] );
        recentProjectFileActs[i]->setVisible ( true );
    }
    for ( int j = numRecentFiles; j < MaxRecentFiles; ++j )
        recentProjectFileActs[j]->setVisible ( false );

    separatorProjectAct->setVisible ( numRecentFiles > 0 );
}

void MainWindow::openRecentProjectFile() {
    if ( maybeSave() ) {
        QAction *action = qobject_cast<QAction *> ( sender() );
        if ( action ) {
            QString dirName = action->data().toString();
            if ( QDir ( dirName ).exists() ) {
                loadProjectDirectory ( dirName );
            } else  QMessageBox::critical ( this,mainWindowCaption(),
                                                QString ( "Location directory does not exist" ).arg ( dirName ),
                                                QMessageBox::Close );
        }
    }
}

void MainWindow::createStatusBar() {
    locationLabel = new QLabel ( "Ftan", this );
    locationLabel->setAlignment ( Qt::AlignHCenter );
    locationLabel->setMinimumSize ( locationLabel->sizeHint() );

    formulaLabel = new QLabel ( this );
    formulaLabel->setText ( "           " );
    modLabel = new QLabel ( tr ( "      " ), this );
    modLabel->setAlignment ( Qt::AlignHCenter );
    modLabel->setMinimumSize ( modLabel->sizeHint() );
    // modLabel->clear();

    statusBar()->addWidget ( locationLabel );
    statusBar()->addWidget ( formulaLabel, 1 );
    statusBar()->addWidget ( modLabel );

}

void MainWindow::about() {
    QMessageBox::about ( this, tr ( "About Ftan" ),
                         tr ( "<h2>ftan 1.2.1</h2>"
                              "<p>Copyright &copy; 2004 MITPAN RAS."
                              "<p><b>ftan</b> is an application for "
                              "processing  of  seismic  surface  waves  records by"
                              " methods of spectral and frequency time analysis"
                              "<p><b>ftan</b> is single-source portability across <b>Linux</b> and <b>Unix</b> "
                              "<p>See http://www.mitp.ru/soft/index.html "
                            ) );
}

void MainWindow::writeSettings() {
    QSettings settings ( "mitp.ru", "FtanControlPanel" );
    settings.beginGroup ( "FtanMainPanel" );
    settings.setValue ( "geometry/x", x() );
    settings.setValue ( "geometry/y", y() );
    settings.setValue ( "geometry/width", width() );
    settings.setValue ( "geometry/height", height() );
    settings.setValue ( "fontPointSize", font().pointSize() );
    settings.setValue ( "showGrid", showGridAct->isOn() );
    settings.setValue ( "autoRecalc", showGridAct->isOn() );
    settings.endGroup();

    settings.beginGroup ( "PropertyDialogPanel" );
    settings.setValue ( "geometry/x",propx );
    settings.setValue ( "geometry/y", propy );
    settings.setValue ( "geometry/width", propw );
    settings.setValue ( "geometry/height", proph );
    settings.endGroup();

    settings.beginGroup ( "PropertyMainDialogPanel" );
    settings.setValue ( "geometry/x",mpropx );
    settings.setValue ( "geometry/y", mpropy );
    settings.setValue ( "geometry/width", mpropw );
    settings.setValue ( "geometry/height", mproph );
    settings.endGroup();
}

void MainWindow::readSettings() {
    QSettings settings ( "mitp.ru", "FtanControlPanel" );
    settings.beginGroup ( "FtanMainPanel" );

    int x = settings.value ( "geometry/x", 200 ).toInt();
    int y = settings.value ( "geometry/y", 200 ).toInt();
    int w = settings.value ( "geometry/width", 400 ).toInt();
    int h = settings.value ( "geometry/height", 400 ).toInt();
    move ( x, y );
    resize ( w, h );


    int fontPointSize = settings.value ( "fontPointSize", 12 ).toInt();
    QFont f ( font() );
    f.setPointSize ( fontPointSize );
    setFont ( f );

    showGridAct->setOn (
        settings.value ( "showGrid", true ).toBool() );
    autoRecalcAct->setOn (
        settings.value ( "autoRecalc", true ).toBool() );

    settings.endGroup();

    settings.beginGroup ( "PropertyDialogPanel" );
    propx = settings.value ( "geometry/x",100 ).toInt();
    propy = settings.value ( "geometry/y", 100 ).toInt();
    propw = settings.value ( "geometry/width", 800 ).toInt();
    proph= settings.value ( "geometry/height", 700 ).toInt();
    settings.endGroup();

    settings.beginGroup ( "PropertyMainDialogPanel" );
    mpropx = settings.value ( "geometry/x",100 ).toInt();
    mpropy = settings.value ( "geometry/y", 100 ).toInt();
    mpropw = settings.value ( "geometry/width", 800 ).toInt();
    mproph= settings.value ( "geometry/height", 400 ).toInt();
    settings.endGroup();
}

void MainWindow::newFDocument() {
    statusBar()->~QStatusBar ();
    createStatusBar();
    if ( !savedFilteringRecord.isEmpty() ) savedFilteringRecord.clear();
    if ( doc != 0 ) {
        delete doc;
        doc = 0;
    }
//QMessageBox::warning(0,"","newFDocument 0");
    doc = new FDocument ( wfdiscAbsPath, rootAbsPath, originAbsPath,eventInfo,numOriginRow );

//QMessageBox::warning(0,"","newFDocument 1");
    QString workingDirectory = QDir::currentDirPath () ;
    QDate date = QDate::currentDate ();
    QTime time = QTime::currentTime ();
    QDateTime datetime ( date, time ) ;
    uint currentTime = datetime.toTime_t ();
    if ( !tempDir.isEmpty() ) {
        QString systemStr = QString ( "\\rm -r  %1" ).arg ( tempDir );
        system ( systemStr.ascii() );
    }
    tempDir = QString ( "%1%2" ).arg ( TEMPRARY_FTAN_PREFIX ).arg ( currentTime );
    QDir d ( workingDirectory );
    d.mkdir ( tempDir );
    fwoutDir = tempDir + "/" + FTAN_WFOUT_DIRECTORY_NAME;
    d.mkdir ( fwoutDir );
    //    doc->printFDocument();
    //   QMessageBox::warning(0,mainWindowCaption(),"POINT new doc 0");

    startFtan ( workingDirectory );
    if ( !doc->ReadFileListCtachan() ) return;
    initCentralWidget();
}

void MainWindow::initCentralWidget() {

    EnableMainWinAction ( TRUE );
    if ( stationlist != 0 ) {
        delete stationlist;
        stationlist=0;
    }

    stationlist = new StationListImpl ( this,doc );
    if ( periodListDialog != 0 ) {
        delete periodListDialog;
        periodListDialog=0;
    }
    periodListDialog = new SettingImpl ( doc,this );
    periodListDialog->hide();
    stationlist->setCaption ( ( "Station Channel List" ) );
    setCentralWidget ( stationlist );
    stationlist->show();
}
bool MainWindow::verifyAbsPaths() {


    qWarning ( "Absolute Dbase Table Pathes:>\nwfdisc: '%s.wfdisc' \ninstrument: '%s.instrument' \norigin '%s.origin'\n",wfdiscAbsPath.ascii(),rootAbsPath.ascii(),originAbsPath.ascii() );

    if ( !QFile ( wfdiscAbsPath + ".wfdisc" ).exists () ||
            !QFile ( rootAbsPath   + ".instrument" ).exists () ||
            !QFile ( originAbsPath + ".origin" ).exists () ) {
        int ret = QMessageBox::warning ( this,mainWindowCaption(),"Dbase Pathes are not found. Try to find its.",
                                         QMessageBox::Yes | QMessageBox::Default,
                                         QMessageBox::No | QMessageBox::Escape );
        if ( ret == QMessageBox::No )
            return false;
        NewDialog dialog ( this,true );

        if ( ( ret = dialog.exec() ) ) {}
        if ( ret == QDialog::Rejected )  return false;
        doc->GetWfdiscAbsPath()  =  wfdiscAbsPath ;
        doc->GetRootAbsPath()    =  rootAbsPath ;
        doc->GetOriginAbsPath()  =  originAbsPath ;
        doc->GetEventInfo()           =  eventInfo  ;
        doc->GetNumOriginRow() = numOriginRow ;
        modifiedFlt = true;
        return true;
    }

    return true;
}

void MainWindow::periodListSlot() {

    if ( periodListDialog->isHidden( ) )   periodListDialog->show();
    periodListDialog->raise();

}
///---------------------------------------------------------------------------------------------
void MainWindow::stationMapSlot() {
    if (stationlist->GetTabStaWidget()->currentIndex () == 1 && stationlist->GetStaOut()->empty()) {
        QMessageBox::warning(0,mainWindowCaption(),QString("Out Station list is empty"));
        return;

    }
    QString FLTWFDISC ="";
    if (stationlist->GetTabStaWidget()->currentIndex () == 0) {
        FLTWFDISC = wfdiscAbsPath;
        FLTWFDISC += ".wfdisc";
    }
    if (stationlist->GetTabStaWidget()->currentIndex () == 1) {
        FLTWFDISC = QString("%1/table.wfdisc").arg(tempDir);
    }
    QString SITE = rootAbsPath;//GetRelativePath(workingDirectory, doc->GetRootAbsPath());
    SITE += ".site";
    QString ORIGIN = rootAbsPath;//GetRelativePath(workingDirectory, doc->GetOriginAbsPath());
    ORIGIN += ".origin";
    QString line;
    QFile file(ORIGIN);
    if ( file.open( QIODevice::ReadOnly ) ) {
        Q3TextStream stream( &file );

        while ( !stream.atEnd() ) {
            line = stream.readLine();
        }
        file.close();
    } else {
        QMessageBox::warning(0,mainWindowCaption(),QString("Can't open flle for reading\n%1'").arg(ORIGIN));
        return;
    }



    QStringList lst = line.split(' ',QString::SkipEmptyParts);
    QString lat = lst.at(0);
    QString lon = lst.at(1);
    QString range = "180";
    QString postscriptName = "inDbaseMap";
    if (stationlist->GetTabStaWidget()->currentIndex () == 1) postscriptName = "outDbaseMap";

    QString str = QString(" %1 %2 %3 %4 %5 %6 %7").arg(FLTWFDISC).arg(SITE).arg(ORIGIN).arg(lat).arg(lon).arg(range).arg(postscriptName);


    char buf[9048];

    sprintf(buf,"csh %s/bin/FmtMapScript %s &",rootPath().toAscii().data(),str.toAscii().data());
    system(buf);

    /*
    //QMessageBox::warning(0,mainWindowCaption(),str);
    QStringList argumentList = str.split(' ');
        gzip = new QProcess;
        gzip->setWorkingDirectory (workingDirectory);
        gzip->setProcessChannelMode(QProcess::MergedChannels);
        gzip->setReadChannel ( QProcess::StandardOutput);
    QStringList environment = QProcess::systemEnvironment();
    gzip->setEnvironment(environment);
        connect(gzip, SIGNAL( readyReadStandardOutput () ), this, SLOT(ReadStandardOutput ()));
        connect(gzip, SIGNAL( readyReadStandardError () ), this, SLOT(ReadStandardError ()));

        gzip->start("csh  /opt/fmt/bin/FmtMapScript ", argumentList);

        if (!gzip->waitForStarted()) {
           // QMessageBox::warning(this,"",QString("Abnormal start script %1").arg(strippedName(script)));
            return;

        }

        if (!gzip->waitForFinished()) {

          // QMessageBox::warning(this,"",QString("Abnormal finish script %1").arg(strippedName(script)));
            return;
        }
    //QMessageBox::warning(0,"",QString("FLTWFDISC '%1'\nSITE '%2'\nORIGIN '%3 lat %4 lon %5' ").arg(FLTWFDISC).arg(SITE).arg(ORIGIN).arg(lat).arg(lon));


    // FLTWFDISC - wfdisc Dbe Table Name
    // SITE - site Dbe Table Name
    // ORIGIN - origin Dbe Table Name
    // LAT    - Event Latitude
    // LON    - Event Longitude
    // RANGE  - The map plot range in degrees from the origin
    //                    to  the  edges  of the map.
    // OUTNAMEPS - Name of postscript out file without extension name '.ps'
    */

}
///----------------------------------------------------------------------------------------------
void MainWindow::ReadStandardOutput() {
    QByteArray bytearray = gzip->readAllStandardOutput ();
}
void MainWindow::ReadStandardError() {
    QByteArray bytearray = gzip->readAllStandardError ();

}
void MainWindow::GetNewPeriodList() {
    bool showwin = false;
    if ( !periodListDialog->isHidden( ) ) showwin = true;
    if ( periodListDialog != 0 ) {
        delete periodListDialog;
        periodListDialog=0;
    }

    periodListDialog = new SettingImpl ( doc,this );
    if (showwin) periodListDialog->show();
}











