#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <q3mainwindow.h>
#include <qstringlist.h>
#include <q3ptrlist.h> 
#include <qdatetime.h>
#include <q3filedialog.h>
#include <Q3TextStream>
#include <QProcess>
//Added by qt3to4:
#include <QLabel>
#include <Q3PopupMenu>
#include <QCloseEvent>
const QString TEMPRARY_FTAN_PREFIX                 = "temp-";
const  QString FTAN_WFOUT_DIRECTORY_NAME = "wf";
const  QString  FTAN_DISPOUT_DIRECTORY_NAME = "disp";
const  QString FTAN_TABLE_OUT_NAME = "table";
const  QString FTAN_PARAMETRS_FILE_NAME = "parameters.bin";
const  QString FTAN_EXPORT_AH_DIRECTORY_NAME = "wfah";
const  QString FTAN_EXPORT_ASCII_DIRECTORY_NAME = "wfascii";
const  QString FTAN_EXPORT_DISP_DIRECTORY_NAME = "dispascii"; 
const uint  MAXIMUM_FTAN_DBTABLE_NAME_LENGTH = 70;
QString GetRelativePath(QString workDirectory,QString nameFile);
class QAction;
class QLabel;
class QIcon;
class QSplitter;
class QToolButton;
class Q3Process;
class QFile;
class Q3TextStream;
class QStringList;
class QDateTime;
class Q3ListViewItem;
class QLabel;
class QComboBox;
class FindDialog;
class StationListImpl;
class FDocument;
class SettingImpl;
class AhFileDialog : public Q3FileDialog
{
        Q_OBJECT
private:
QLabel* label;
QComboBox* combobox;
public:
AhFileDialog(QWidget* parent, const char* name); 
~AhFileDialog ();
QComboBox*   GetComboBox  (){return combobox;}
public slots:
void accept ();
};
class MainWindow : public Q3MainWindow
{
    Q_OBJECT
public:

    MainWindow(QString fmtVar,QWidget *parent = 0, const char *name = 0);
    void SetImageToIconSet(QIcon *icon,const QString & normalname,
				    const QString & disabledname); 
    ~MainWindow();    
    FDocument* GetDocument(){return doc;}
    void newFDocument();
    void loadProjectDirectory(const QString &DirectoryName);
    void saveProjectDirectory(QString &DirectoryName);
    static MainWindow *self;
    void SendChangedValueToFtan(int idValue);
    void FtanSettingView();
    void ChangeDbTable(QString dbTableName,QString newValue,int index,int lenght);
    StationListImpl* GetStationlist() {return stationlist;}     
    bool GetSavedRecordNames(QString tempWfDiscName,QStringList &savedFilteringRecord);
    void DeleteExcludedStachanMaterials(QString  prefixPs,QString  cleanedWf,QString cleanedDisp,QString dispName);
    void RemoveRecordsFromTableAndDir(QString dbTableName,QString dirName,QString recordName,QString fileName="");
    void SetModifedFlt(bool b ) { modifiedFlt = b;}
    void GetListPS(QString  prefixPs,QStringList &listPs);
    void SetStateStartToolBarButton(Q3ListViewItem * item);
    void exportDispersionCurves(QString dirName);
    void exportAhAsciiRecord(QString dirName,QString  indAhOrAscii);
    bool verifyAbsPaths();
    void pageHelp(QString page);
    SettingImpl*  GetPeriodListDialog(){  return periodListDialog;}
    QString fmtEnvVariable;
    Q3PopupMenu *settingsMenu;    
    Q3PopupMenu *orbitPopupmenu;
    QToolButton *orbitToolButton;
    
    QIcon *saveIconSet;
    QIcon *saveAsIconSet;
    QIcon *exportIconSet;
    QIcon *startIconSet;
    QIcon *waveIconSet;
    QIcon *filterIconSet;
    QIcon *ftaIconSet;
    QIcon *velIconSet;
    QIcon *ampIconSet;
    QIcon *polarIconSet;
    QIcon *ovrIconSet;
    QIcon *imageIconSet;
    QIcon *saveRecIconSet;
    QIcon *cleanRecIconSet;    
    QIcon *mainParamIconSet;   
    QIcon *pscriptOnOffIconSet;
    QIcon *polarOnOffIconSet;
    QIcon *originIconSet;
    QIcon *filterSpecIconSet;
    QIcon *ftaSpecIconSet;
    QIcon *plotCompIconSet;
    QIcon *ftaCompIconSet;       
    QIcon *orbitIconSet; 
    QIcon *modeIconSet;              

    QString wfdiscAbsPath;
    QString rootAbsPath;
    QString originAbsPath;
    QString eventInfo;      
    QString numOriginRow;    
    QLabel *locationLabel;
    QLabel *formulaLabel;
    QLabel *modLabel; 
    QString savedStationName;
    void GetNewPeriodList();
protected:
    void closeEvent(QCloseEvent *event);
public slots:
    virtual void processExited();
    virtual void updateStdOut();
    virtual void WroteToStdin();
    void showDialogHelp();
    void showDialogHelpOut();
    void mainHelpSlot();
protected slots:
    void ReadStandardOutput();
    void ReadStandardError();
private slots:
    void newLocation();
    void open();
    bool save();
    bool saveAs();
    bool exportAh();
    void zoomin();
    void zoomout();
    void about();
    void openRecentProjectFile();
    void pscriptOnOffToggled(bool tog);
    void polarOnOffToggled(bool tog);
    void startFtan(QString workingDirectory);
    void closeFtan();

    void  startSlot  ();
    void  waveSlot   ();
    void  filterSlot ();
    void  ftaSlot    ();
    void  velSlot    ();
    void  ampSlot    ();
    void  polarSlot  ();
    void  ovrSlot    ();
    void  imageSlot  ();
    void  saveRecSlot();
    void  periodListSlot();
    void  stationMapSlot();
    void  pscriptOnOffSlot();
    void  polarOnOffSlot();
    void  originSlot();
    void  filterSpecSlot();
    void  ftaSpecSlot();
    void  plotCompSlot();
    void  ftaCompSlot();
    void  orbitSlot(int id);
    void  modeSlot();
    void  SettingsAllParameters();
    void  SettingsMainParameters();
    void  cleanRecSlot();
private:
    QProcess* gzip;
    int propx,propy,propw,proph;
        int mpropx,mpropy,mpropw,mproph;
     int idItemOrbitOfSettingMenu ;
    FDocument* doc;    
    Q3Process *process;
    void SaveWorkingMaterials(QString DirectoryName);
    void setTemporaryMaterials(QString DirectoryName);
    void initCentralWidget();
    void setInitialValues();
    void EnableMainWinAction(bool b );
    void EnableFtanWinAction(bool b );
    void EnableFtanWinActionAfterSaveRecord(bool b );
    void setPostscriptPolarOrbitActions();
    void createActions();
    void createMenus();
    void createToolBars();
    void createStatusBar();
    void createIconSet();
    void createWhatsThis();
    void createAdditionalConnect();
    void readSettings();
    void writeSettings();
    bool maybeSave();
    void setCurrentDirectory(const QString &DirectoryName);
    QString strippedName(const QString &fullFileName);    
    FindDialog *findDialog;

    QString curDirectory;
    bool modified;
    bool modifiedFlt;

    void updateRecentProjectFileActions();
	enum { MaxRecentFiles = 5 };
    QAction *recentProjectFileActs[MaxRecentFiles];

    Q3PopupMenu *locationMenu;
    Q3PopupMenu *selectSubMenu;
    Q3PopupMenu *toolsMenu;
    Q3PopupMenu *helpMenu;
    Q3ToolBar *locationToolBar;
    Q3ToolBar *ftanToolBar;
    Q3ToolBar *mainSetingsToolBar; 

    StationListImpl  *stationlist;
    QSplitter* horisontalSplitter; 

    QAction *startAct;
    QAction *waveAct;
    QAction *filterAct;
    QAction *ftaAct;
    QAction *velAct;
    QAction *ampAct;
    QAction *polarAct;
    QAction *ovrAct;
    QAction *imageAct;
    QAction *saveRecAct;
    QAction *periodListAct;
    QAction *mapAct;
    QAction *cleanRecAct;
    
    QAction *allParamAct;     
    QAction *mainParamAct;    
    QAction *pscriptOnOffAct;    
    QAction *polarOnOffAct;    
    QAction *originAct;    
    QAction *filterSpecAct;    
    QAction *ftaSpecAct;    
    QAction *plotCompAct;    
    QAction *ftaCompAct;     
//    QAction *orbitCompAct;     
    QAction *modeCompAct;    
    
    QAction *newAct;
    QAction *openAct;
    QAction *saveAct;
    QAction *saveAsAct;
    QAction *exportAct;    
    QAction *zoominAct;
    QAction *zoomoutAct;   
    QAction *exitAct;
    QAction *cutAct;
    QAction *copyAct;
    QAction *pasteAct;
    QAction *deleteAct;
    QAction *selectRowAct;
    QAction *selectColumnAct;
    QAction *selectAllAct;
    QAction *findAct;
    QAction *goToCellAct;
    QAction *recalculateAct;
    QAction *sortAct;
    QAction *showGridAct;
    QAction *autoRecalcAct;
    QAction *contentAct;
    QAction *aboutAct;
    QAction *aboutQtAct;
    Q3PtrList<QAction > actionMainWinList; 
    Q3PtrList<QAction > actionFtanWinList;
    QAction *separatorProjectAct;
    void SetWidowSize();
    void SetWidowMode();  
    void SetPostscript();
    void SetTypeForOverplot();
    void SetGroupVelocity();
    void SetXaxisScaling();
    void SetEditApplied();
    void SetInterpolateNominalGrid();
    void CommandPlotsCopts();
    void SetWaveformFilter();
    void SetOutputImagePhase();
    void SetItstrumentResponse();
    void SetChangeAlphaFilter();
    void SetComptsToBeProcessed();
    void SetFtanPolarMeasurements();
    void SetPhaseVelocityMesarumenrs();
    void SetPhaseVelocityBounds();
    void SetPhaseVelocityReference();
    void SetGroupVelBound();
    void SetPeriodBound();
    void SetNumberOrbitMode();
    void SetRawSpectrumVelWidth();
    void SetReadCentrydMomentRelations();       
    QString GetPlotCompString();
    QString GetToBeProcessedCompString();
    QFile* fstd;
    Q3TextStream tlog;
    bool stdinlog;
    QString tempDir;
    QString fwoutDir;
    QStringList savedFilteringRecord;
    bool isCleanedRecordSaved;
    SettingImpl*  periodListDialog;
};

#endif
