#include <qstring.h>
#include <qlabel.h>
#include <q3filedialog.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qfileinfo.h>
#include <qlineedit.h> 
#include <q3filedialog.h> 
#include <qfont.h>
#include <qmessagebox.h> 
#include <q3listbox.h> 
#include <qdir.h> 
#include <q3accel.h> 
#include "mainwindow.h"
#include "newdialogimpl.h"
#include "selecteventimpl.h"

extern "C"{
int OpenOrigin (char *Origin_name, ORIG*** origin,int* recCount,char *ErrorString);
void freeOriginStructure(ORIG*** origin,int recCount);
}

NewDialog::~NewDialog(){
if(origin !=0)
    freeOriginStructure(&origin,recCount);    
}
NewDialog::NewDialog( QWidget *parent,bool justverify )
    : QDialog( parent)
{
    verify = justverify;
    setFont( parent->font() );

    setupUi(this);
    pushButtonEvent->hide();
    textLabelEvent->hide();
     origin = 0;
     Q3Accel *a = new Q3Accel(this );       
     a->connectItem( a->insertItem(Qt::ALT + Qt::Key_W), 
		     this,               
		     SLOT(browseWfdisc()) ); 
     Q3Accel *b = new Q3Accel(this );       
     b->connectItem( b->insertItem(Qt::ALT + Qt::Key_I), 
		     this,               
		     SLOT(browseRoot()) ); 
     Q3Accel *c = new Q3Accel(this );       
     c->connectItem( c->insertItem(Qt::ALT + Qt::Key_G), 
		     this,               
		     SLOT(browseOrigin()) );      
     Q3Accel *d = new Q3Accel(this );       
     c->connectItem( d->insertItem(Qt::ALT + Qt::Key_E), 
		     this,               
		     SLOT(selectEvent()) );           
     
}
void NewDialog::accept()
{
  
if (!IsChecked()) return;
//qWarning("NewDialog::accept()");  
done( Accepted );    
}
void NewDialog::reject()
{
//qWarning("NewDialog::reject()");    
done( Rejected );    
}

QString openDbaseFileDirectory = "./";
void NewDialog::browseWfdisc()
{
   QString s = Q3FileDialog::getOpenFileName(
                    openDbaseFileDirectory,
                    "Tables (*.wfdisc )",
                    this,
                    "open file dialog",
                    "Choose a file to open" );
   if (s != QString::null) {
       wfdiscAbsPath = s;
       lineEditWfdisk->setText (s); 
       openDbaseFileDirectory = QFileInfo(s).absolutePath ();
}
}


void NewDialog::browseRoot()
{
   QString s = Q3FileDialog::getOpenFileName(
                    openDbaseFileDirectory,
                    "Tables (*.instrument)",
                    this,
                    "open file dialog",
                    "Choose a file to open" );
   if (s != QString::null) { 
       rootAbsPath = s;
       lineEditRoot->setText (s); 
       openDbaseFileDirectory = QFileInfo(s).absolutePath ();
}
}


void NewDialog::browseOrigin()
{
   QString s = Q3FileDialog::getOpenFileName(
                    openDbaseFileDirectory,
                    "Tables (*.origin )",
                    this,
                    "open file dialog",
                    "Choose a file to open" );
   if (s != QString::null) {
       originAbsPath = s;
       lineEditOrigin->setText (s);  
       getEventInfo();
       openDbaseFileDirectory = QFileInfo(s).absolutePath ();
  
}
}

void NewDialog::error(const QString &message){
    QMessageBox::critical(this,"Input tables names",message);    
}
bool NewDialog::IsChecked() {

	if(wfdiscAbsPath .isEmpty()) {
	    error("Inputed wfdisc table name is Empty.");
	    browseWfdisc();
	    return false;
	}
	if(rootAbsPath.isEmpty())  {
	    error("Inputed instrument tables name is Empty.");
	    browseRoot();
	     return false;
	}
	if(originAbsPath.isEmpty()) {
	    error("Inputed origin table name is Empty.");
	    browseOrigin();
	    return false;
	}


	if (wfdiscAbsPath.findRev(".wfdisc") == -1) {
	    error("Inputed wfdisc name is not contain extension name '.wfdisc'");
	    browseWfdisc();
	    return false;
	}
	if (rootAbsPath.findRev(".instrument") == -1 ) {
	    error("Inputed instrument name is not contain extension name '.instrument'");
	    browseRoot();
	    return false;
	}	

	if (originAbsPath.findRev(".origin") == -1) {
	    error("Inputed origin name is not contain extension name '.origin'.");
	    browseOrigin();
	    return false;
	}	
/*	
	if (wfdiscAbsPath.left(wfdiscAbsPath.findRev('/') )  != rootAbsPath.left(rootAbsPath.findRev('/') ) ) {
	    QString tmp;
	    tmp = QString("Inputed absolute path of wfdisc table name\n'%1' \nand absolute path of root table name\n'%2'\nmust be the same!\n").
		    arg(wfdiscAbsPath.left(wfdiscAbsPath.findRev('/')))
		    .arg(rootAbsPath.left(rootAbsPath.findRev('/')));
	    error(tmp);
	    return false;	
	
	}	
*/	


	QString dirpath = QDir::currentDirPath ();

	QString relpathwf = GetRelativePath(dirpath, wfdiscAbsPath);
	relpathwf =  relpathwf.left(relpathwf.findRev('.') );
	int maximum = MAXIMUM_FTAN_DBTABLE_NAME_LENGTH;



	if (relpathwf.length() >=maximum ) {


	    QString tmp;
	    tmp = QString("Inputed relative wfdisc table name (%1)\n is too long (maximum length is %2).\n"
		"Relative file names begin with a directory name or a file name\n"
		" and specify a path relative to the current working directory\n %3.").arg(relpathwf).arg(maximum).arg(dirpath);


	    error(tmp);
	    browseWfdisc();
	    return false;	
	}

	QString relpathRoot = GetRelativePath(dirpath,rootAbsPath);
	relpathRoot =  relpathRoot.left(relpathRoot.findRev('.') );
	if (relpathRoot.length() >=maximum ) {
	    QString tmp;
	    tmp = QString("Inputed relative root name (%1)\n is too long (maximum length is %2).\n"
		"Relative file names begin with a directory name or a file name\n"
		" and specify a path relative to the current working directory\n %3.").arg(relpathRoot).arg(maximum).arg(dirpath);
	    error(tmp);
	   browseRoot();
	    return false;	
	}	


	QString relpathOrigin = GetRelativePath(dirpath,originAbsPath);
	relpathOrigin =  relpathOrigin.left(relpathOrigin.findRev('.') );  
	if (relpathOrigin.length() >=maximum ) {
	    QString tmp;
	    tmp = QString("Inputed relative origin table name (%1)\n is too long (maximum length is %2).\n"
		"Relative file names begin with a directory name or a file name\n"
		" and specify a path relative to the current working directory\n %3.").arg(relpathOrigin).arg(maximum).arg(dirpath);
	    error(tmp);
	   browseOrigin();
	    return false;	
	}

	MainWindow::self->wfdiscAbsPath = wfdiscAbsPath.left(wfdiscAbsPath.findRev('.') );  
	MainWindow::self->rootAbsPath = rootAbsPath.left(rootAbsPath.findRev('.') );  
	MainWindow::self->originAbsPath = originAbsPath.left(originAbsPath.findRev('.') ); 
	MainWindow::self->eventInfo  =  eventInfo; 
	MainWindow::self->numOriginRow =  numOriginRow; 

	if(!verify)MainWindow::self->newFDocument();

	 return true;
}
void NewDialog::getEventInfo(){
    char  ErrorString[254];    
    if (OpenOrigin((char*)originAbsPath.ascii(),&origin,&recCount,ErrorString) ) {
	qWarning("Error: %s",ErrorString ); return;
    }  
    QString tm;
    tm.sprintf("Event: %d/%d/%d %d:%d:%5.2f  %7.3f %8.3f %4.0f",origin[0]->day,origin[0]->month,origin[0]->year,
	       origin[0]->hour,origin[0]->minute,
	       origin[0]->second,origin[0]->latitude,origin[0]->longitude,origin[0]->dep);  
    eventInfo.sprintf("%d %d %d %d %5.2f",origin[0]->year,origin[0]->doy,origin[0]->hour,origin[0]->minute,origin[0]->second);	
    numOriginRow = "1";
    if (recCount == 1) {
	pushButtonEvent->hide();
	textLabelEvent->show();
    }else {
	pushButtonEvent->show();
	textLabelEvent->show();    
	tm.append(QString("").sprintf(" #1 of %d",recCount));
    }
   textLabelEvent->setText(tm);
}

void NewDialog::selectEvent()
{
//qWarning("NewDialog::selectEvent()");  
    SelectDialog dialog(this,origin,recCount);
    if (dialog.exec()) {
    int i =   dialog.GetListBoxEvent()->currentItem ();
    numOriginRow =QString("%1").arg( i+1);        
   QString tm;
   tm.sprintf("Event: %d/%d/%d %d:%d:%5.2f  %7.3f %8.3f %4.0f #%d of %d",origin[i]->day,origin[i]->month,
	      origin[i]->year,
	      origin[i]->hour,origin[i]->minute,
	      origin[i]->second,origin[i]->latitude,origin[i]->longitude,
	      origin[i]->dep,i+1,recCount);  
   eventInfo.sprintf("%d %d %d %d %5.2f",origin[i]->year,origin[i]->doy,origin[i]->hour,origin[i]->minute,origin[0]->second); 
   textLabelEvent->setText(tm);
    }    
}
