#ifndef _PROPERTY_EDITOR_H
#define _PROPERTY_EDITOR_H
#include <qvariant.h>
#include <q3listview.h>
#include <qlineedit.h> 
#include <qspinbox.h> 
#include <qpointer.h>
#include <q3ptrlist.h>
//Added by qt3to4:
#include <QLabel>
#include <vector>
using namespace std;
class QString; 
class QPushButton;
class Q3HBox;
class QComboBox;
class QLabel;
class QPainter;
class QColorGroup;
class Q3DateTimeEdit;
class QCheckBox;
class QSpinBox;
class ReorganizeWindow;
class RecalMag;
class CommonMagPriority;
class DeltaDialog;
class PropertyValue;
class PropertyBoolValue;
class PropertyFloatValue;
class PropertyIntValue;
class PropertyEnumValue;
//------------------------------------------------------------------------------------------------------------------------------------ 
class PropertyItem : public QObject,public Q3ListViewItem
{
        Q_OBJECT
public:
    PropertyItem( Q3ListViewItem * parent, Q3ListViewItem * after, Q3ListView* l, const QString &propName, PropertyValue* propval = 0 );
    PropertyItem(Q3ListView * parent, Q3ListViewItem * after, Q3ListView* l, const QString &propName , PropertyValue* propval = 0);
    PropertyItem(Q3ListViewItem * parent, Q3ListView* l, const QString &propName, PropertyValue* propval = 0 );

    ~PropertyItem(); 

   void placeEditor( QWidget *w );
   virtual void showEditor();


   virtual void SetTextFromChild(){}
   virtual void    isChangedFromChild(){}
   virtual void hideEditor();   
   virtual void setValue( const QString  &v );
    virtual void setValue( const QVariant &v );
   QVariant value() const;
   void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int align );
   void paintBranches( QPainter * p, const QColorGroup & cg,
			int w, int y, int h );
   bool isChanged() const;
   bool IsEditorShown()  const;
   bool &GetChanged() {return changed;}
   void updateBackColor();
   virtual bool hasSubItems() const;
   virtual bool hasCustomContents() const;
   virtual void drawCustomContents( QPainter *p, const QRect &r );
   virtual QString getTextForCol1() {return text(1);}
   QString name() const;
   const PropertyValue*  GetPropvalue() const {return propvalue; }
protected:
    Q3ListView *listview;      
    QVariant val;
    PropertyValue*  propvalue;
    QString propertyName;
    bool open, changed,shown;
    QPointer<Q3HBox> box;
    QColor *backColor1;
    QColor *backColor2;
    QColor *selectedBack;
    void createDefaultButton();
    QPushButton *defaultButton;
    QPushButton *buttonCancel;
public slots:
   virtual void cancel(){}
   virtual void setDefault(){}
   virtual void setReset(){}
   virtual void setInitial(){}
private:
   QColor backgroundColor();
    void updateDefaultButtonState();
private:

    QColor backColor;


};
//------------------------------------------------------------------------------------------------------------------------------------ 
class LineEditInt : public QLineEdit 
{
    Q_OBJECT
 
public:    
    LineEditInt(QWidget * parent, const char * name,int min,int max, bool s);
    ~LineEditInt();
private slots:
	void setValue( const QString   &v );    
        void setValue();
private:    
    int minimum;
    int maximum;
    bool signedValue;
};
//------------------------------------------------------------------------------------------------------------------------------------ 
class LineEditDouble : public QLineEdit 
{
    Q_OBJECT
 
public:    
    LineEditDouble(QWidget * parent, const char * name,double min,double max,int dec,bool shortWidht = TRUE);
    ~LineEditDouble();
private slots:
	void setValue( const QString   &v );  
        void setValue();
protected:
   
private:    
    double minimum;
    double maximum;
    int decimals;
};
//------------------------------------------------------------------------------------------------------------------------------------ 
class PropertyNoDialogTopItem : 
			 public PropertyItem
{
    Q_OBJECT

public:
    PropertyNoDialogTopItem( Q3ListView * parent, Q3ListViewItem * after, Q3ListView* l, const QString propName,QString textCol1 = "");
    PropertyNoDialogTopItem( Q3ListViewItem * parent, Q3ListViewItem * after, Q3ListView* l, const QString propName,QString textCol1 = "");
    ~PropertyNoDialogTopItem(); 
protected:

private slots:

private:

};
//------------------------------------------------------------------------------------------------------------------------------------ 
class PropertyBoolItem : 
			 public PropertyItem
{
    Q_OBJECT

public:
    PropertyBoolItem( Q3ListViewItem * parent, Q3ListViewItem * after, Q3ListView* l, const QString &propName,PropertyBoolValue* boolval);
    ~PropertyBoolItem(); 
    void hideEditor();
protected:
        Q3ListView *listview;  
private slots:
    void cancel();
    void setDefault();
    void setReset();
    void setInitial();
private:
    
    QPointer<QComboBox> comboBoxInfo;
};
//------------------------------------------------------------------------------------------------------------------------------------ 
class PropertyDoubleItem : 
			 public PropertyItem
{
    Q_OBJECT
 
public:
    PropertyDoubleItem( Q3ListViewItem * parent, Q3ListViewItem * after, Q3ListView* l, const QString &propName, PropertyFloatValue* boolval);
    ~PropertyDoubleItem(); 
    void hideEditor();
protected:
    Q3ListView *listview;  
private slots:
    void cancel();
    void setDefault();
    void setReset();
    void setInitial();
private:
    LineEditDouble* lineEdit;
    int decimal;
};

//------------------------------------------------------------------------------------------------------------------------------------ 
class SpinBoxItem  :  public QSpinBox 
{
    Q_OBJECT

public:
    SpinBoxItem(QWidget * parent, const char * name,int min,int max, bool s);
    ~SpinBoxItem();

private slots:


private:
     int minimum;
     int maximum;
     bool signedValue;


};
//----------------------------------------------------------------------------------------------------------------------------------
class PropertyIntItem : 
			 public PropertyItem
{
    Q_OBJECT
 
public:
    PropertyIntItem( Q3ListViewItem * parent, Q3ListViewItem * after, Q3ListView* l, const QString &propName, PropertyIntValue* boolval);
    ~PropertyIntItem(); 
    void hideEditor();
protected:
    Q3ListView *listview;  
private slots:
    void cancel();
    void setDefault();
    void setReset();
    void setInitial();    
private:
    SpinBoxItem* spinBox;
     bool signedValue;
};

//------------------------------------------------------------------------------------------------------------------------------------ 
class PropertySetItem : 
			 public PropertyItem
{
    typedef vector<PropertyValue* >  PropValVector;
    typedef vector<PropertyValue* > ::iterator PropValIterator;
    Q_OBJECT
 
public:
    PropertySetItem( Q3ListViewItem * parent, Q3ListViewItem * after, Q3ListView* l, const QString &propName, PropValVector*  listv, Q3PtrList <PropertyItem >* mprop,bool ascending = TRUE);
    ~PropertySetItem(); 
    void hideEditor();
    void SetTextFromChild();
    void isChangedFromChild() ;
    bool GetAscending(){return ascending;}
    bool CheckAscending();
protected:
    Q3ListView *listview;  
private slots:
    void cancel();
    void setDefault();
private:
    QPointer<QLineEdit> lined; 
     PropValVector*  listval;
     Q3PtrList<PropertyItem > propList; 
     QString defaultValue;
     bool ascending;
};
//------------------------------------------------------------------------------------------------------------------------------------ 
class PropertyEnumItem : 
			 public PropertyItem
{
    Q_OBJECT
 
public:
   PropertyEnumItem( Q3ListViewItem * parent, Q3ListViewItem * after, Q3ListView* l, const QString &propName, PropertyEnumValue*enumval);
    ~PropertyEnumItem(); 
    void hideEditor();
protected:
    Q3ListView *listview;  
private slots:
    void cancel();
    void setDefault();
    void setReset();
    void setInitial();
private:
    Q3PtrList<QCheckBox  > enumList; 
};
//------------------------------------------------------------------------------------------------------------------------------------ 
class PropertyComboItem : 
			 public PropertyItem
{
    Q_OBJECT

public:
    PropertyComboItem( Q3ListViewItem * parent, Q3ListViewItem * after, Q3ListView* l, const QString &propName, PropertyEnumValue*enumval);
    ~PropertyComboItem(); 
    void hideEditor();
protected:
        Q3ListView *listview;  
private slots:
    void cancel();
    void setDefault();
    void setReset();
    void setInitial();
private:
    
    QPointer<QComboBox> comboBoxInfo;
};



#endif // _PROPERTY_EDITOR_H
