#include <QtGui>
#include <QMainWindow>
#include "mainwindow.h"
#include "setting.h"
#include "listproperty.h"
#include "document.h"
#include "helpwindow.h"
#include "editline.h"
#include "defaults.h"
SettingImpl::~SettingImpl() {
    if (help !=0) {
        delete help;
        help =0;
    }

    if (!propDocLine.empty()) {
        foreach (LineDocProperty* prop, propDocLine) {
            delete prop;
            prop = 0;
        }
        propDocLine.clear();
    }

    if (!propValues.empty()) {
        foreach (PropertyValue* prop, propValues) {
            delete prop;
            prop = 0;
        }
        propValues.clear();
    }

}
SettingImpl::SettingImpl(FDocument* doc,QWidget* parent)
        : QMainWindow(parent),doc(doc) {
    setupUi(this);

    setFont( parent->font() );
    help =0;
    gridLayout->removeWidget(listWidget);
    listWidget->hide();
    list = new SettingProperty(doc,5,this, "Setting" );
    //gridLayout->addWidget(list, 0, 0, 1, 1);
    gridLayout5->addWidget(list, 0, 0, 1, 1);
    modifed = false;
    connect(buttonHelp, SIGNAL(clicked()), this, SLOT(Help()));

    QSettings settings("mitp.ru", "FtanControlPanel");
    settings.beginGroup("PeriodList");
    QPoint Pos  = settings.value("Windowpos", QPoint(200, 200)).toPoint();
    QSize  Size = settings.value("Windowsize", QSize(400, 300)).toSize();
    settings.endGroup();
    InitDialog();
    resize(Size);
    move(Pos);

}
void SettingImpl::InitDialogFtaComponent() {

    QStringList valuelist = doc->GetFtaCompt()->GetValue ().split (' ');
// Z R T
    if ( valuelist[0] == "0")  groupBoxZ->hide();
    else groupBoxZ->show();
    if ( valuelist[1] == "0")  groupBoxR->hide ();
    else groupBoxR->show();
    if ( valuelist[2] == "0")  groupBoxT->hide ();
    else groupBoxT->show();
}
void SettingImpl::GetBoundsOfPeriod(float &validatorMin,float &validatorMax) {

    float shortCorner =  doc->GetShortPeriodCorner()->GetValue().toFloat();
    float longCorner =  doc->GetLongPeriodCorner()->GetValue().toFloat();
    float boungMin = doc->GetPeriodBoundMinimum()->GetValue().toFloat();
    float boungMax = doc->GetPeriodBoundMaximum()->GetValue().toFloat();
    if (shortCorner < boungMin) validatorMin = boungMin;
    else validatorMin = shortCorner;
    if (longCorner < boungMax) validatorMax = longCorner;
    else validatorMax = boungMax;
}
void SettingImpl::ChangeDialogEditLines() {

    float validatorMin = 0;
    float validatorMax = 0;
    GetBoundsOfPeriod(validatorMin,validatorMax);

    QString defMin = QString("%1").arg(validatorMin);
    QString defMax = QString("%1").arg(validatorMax);
    labelLimits->setText(QString("Current limits for period boundaries: [ %1 , %2 ]").arg(validatorMin).arg(validatorMax));
    groupBoxPeriod->setTitle("Selected values of period boundaries:");
    foreach (PropertyValue* prop, propValues) {
        PropertyFloatValue * p = (PropertyFloatValue*) prop;
        if (prop->GetId() == 1 || prop->GetId() == 3 || prop->GetId() == 5) {
            prop->SetValue(defMin);
        }
        if (prop->GetId() == 2 || prop->GetId() == 4 || prop->GetId() == 6) {
            prop->SetValue(defMax);
        }
        p->SetMin(validatorMin);
        p->SetMax(validatorMax);
    }
    foreach (LineDocProperty* prop, propDocLine) {
        LineEditor* ed = prop->editor;
        ed->SetEditedProperty();
        QDoubleValidator* vld = ed->vld;
        vld->setBottom(validatorMin);
        vld->setTop(validatorMax);

    }
    foreach (LineDocProperty *docprop, propDocLine) docprop->SetValueFromDoc();
 //   update();
//list->update();
}
void SettingImpl::InitDialogEditLines() {

    float validatorMin = 0;
    float validatorMax = 0;
    GetBoundsOfPeriod(validatorMin,validatorMax);


    QString defMin = QString("%1").arg(validatorMin);
    QString defMax = QString("%1").arg(validatorMax);



    labelLimits->setText(QString("Current limits for period boundaries: [ %1 , %2 ]").arg(validatorMin).arg(validatorMax));
    groupBoxPeriod->setTitle("Selected values of period boundaries:");


    groupBoxZ->setTitle(QString("Component Z:"));
    groupBoxT->setTitle(QString("Component T:"));
    groupBoxR->setTitle(QString("Component R:"));
    PropertyFloatValue* p     = new PropertyFloatValue( 1,defMin,"Component Z frame: min edit line", validatorMin,validatorMax,2);
    propValues.append(p);
    propDocLine.append(new LineDocProperty(lineEditMinZ,p));

    p     = new PropertyFloatValue( 2,defMax,"Component Z frame: max edit line", validatorMin,validatorMax,2);
    propValues.append(p);

    propDocLine.append(new LineDocProperty(lineEditMaxZ,p));


    p     = new PropertyFloatValue( 3,defMin,"Component T frame: min edit line",validatorMin,validatorMax,2);
    propValues.append(p);
    propDocLine.append(new LineDocProperty(lineEditMinT,p));

    p     = new PropertyFloatValue( 4,defMax,"Component T frame: max edit line",validatorMin,validatorMax,2);
    propValues.append(p);
    propDocLine.append(new LineDocProperty(lineEditMaxT,p));

    p     = new PropertyFloatValue( 5,defMin,"Component R frame: min edit line",validatorMin,validatorMax,2);
    propValues.append(p);
    propDocLine.append(new LineDocProperty(lineEditMinR,p));

    p     = new PropertyFloatValue( 6,defMax,"Component R frame: max edit line",validatorMin,validatorMax,2);
    propValues.append(p);
    propDocLine.append(new LineDocProperty(lineEditMaxR,p));

    foreach (LineDocProperty *docprop, propDocLine) docprop->SetValueFromDoc();
    // update();
}
void SettingImpl::InitDialog() {

    InitDialogEditLines();
    InitDialogFtaComponent();

}
void SettingImpl::GetValuesZ(QString &valMin,QString &valMax) {
    valMin = lineEditMinZ->text();
    valMax = lineEditMaxZ->text();
}
void SettingImpl::GetValuesT(QString &valMin,QString &valMax) {
    valMin = lineEditMinT->text();
    valMax = lineEditMaxT->text();
//QMessageBox::warning ( 0,"",QString ( "GetValuesT min %1 max %2").arg(valMin).arg(valMax));
}

void SettingImpl::GetValuesR(QString &valMin,QString &valMax) {
    valMin = lineEditMinR->text();
    valMax = lineEditMaxR->text();
}

void SettingImpl::RejectCloseImpl() {
//doc->write();

    QSettings settings("mitp.ru", "FtanControlPanel");
    settings.beginGroup("PeriodList");
    settings.setValue("Windowpos", pos());
    settings.setValue("Windowsize",size());
    settings.endGroup();
}

void SettingImpl::closeEvent(QCloseEvent *event) {
// like as reject
    RejectCloseImpl();
    event->accept();
}
void SettingImpl::Help() {
    /*
        QString home = searchHelpPath() + "/edcat-settings.html";
        if(help !=0) {delete help; help =0;}
        help = new HelpWindow(home,this);
        if ( QApplication::desktop()->width() > 400
             && QApplication::desktop()->height() > 500 )
             help->show();
        else
            help->showMaximized();
    */
}
void SettingImpl::SetNewChannel(const QString &name) {
    QMessageBox::warning ( 0,0,QString("SettingImpl::SetNewChannel '%1'").arg(name));
}

///====================================================================================
//-----------------------------------------------------------------------------------------
SettingProperty::~SettingProperty() {
}
SettingProperty::SettingProperty(FDocument* doc,int numCol,QWidget* parent, const char *)
        : doc(doc),numCol(numCol) {
    QFont f = parent->font();
    setFont( f );
    parentWindow = (SettingImpl*)parent;
    setAlternatingRowColors (TRUE);


    setSelectionMode (QAbstractItemView::NoSelection);
    // setSelectionBehavior ( QAbstractItemView::SelectItems);

    setEditTriggers (QAbstractItemView::AllEditTriggers);
    // setEditTriggers (QTreeView::DoubleClicked );
    edIndex =  QModelIndex();
    indexOpenEditor = QModelIndex();
    model = new TreePropertyModel(numCol,this);
    setModel(model);

    delegate = new TreePropertyDelegate;
    setItemDelegate(delegate);

    InitTreeView();
    connect( this, SIGNAL( clicked(QModelIndex) ),
             this, SLOT( clickedRowCol(QModelIndex ) ) );
}
///-------------------------------------------------------------------------------------------
void  SettingProperty::showSavedStation() {
    QString savedStationName = MainWindow::self->savedStationName;
    int rowsSta = model->rowCount(QModelIndex());
    for (int i = 0; i < rowsSta; ++i) {
        QModelIndex indexStation = model->index(i, 0, QModelIndex());
        QStandardItem* itemStation = model->itemFromIndex(indexStation);
        QString StaName = itemStation->data(Qt::DisplayRole).toString();

        if (savedStationName == StaName) {

//------------------------------------------------
            float validatorMin = 0;
            float validatorMax = 0;
            parentWindow->GetBoundsOfPeriod(validatorMin,validatorMax);
            QModelIndex indexCol2 = model->index(i, 2, QModelIndex());
            QString format = formatColumnPeriod();
            QString tmp = QString(format).arg(validatorMin).arg(validatorMax);

            model->setData(indexCol2, QVariant(),Qt::EditRole );
//------------------------------------------------------


            setExpanded(indexStation,true);
            selectionCommand(indexStation);
        }

    }
}
void  SettingProperty::SavePeriodListInfoToStaChanOutList() {

    int rowsSta = model->rowCount(QModelIndex());
    vStaIt itSta = staouts->begin();
    for (int i = 0; i < rowsSta; ++i) {

        QModelIndex indexStation = model->index(i, 0, QModelIndex());
        QStandardItem* itemStation = model->itemFromIndex(indexStation);
        int rowsChan = itemStation->rowCount ();
        QString StaName = itemStation->data(Qt::DisplayRole).toString();

         QStandardItem* it = model->itemFromIndex(model->index(i, 2, QModelIndex()));
//        QString col3 = it->data(Qt::DisplayRole).toString();

//        QStringList lst = col3.split(' ');
//        c valmin = lst.at(1);
//        QString valmax = lst.at(3);

            float validatorMin = 0;
            float validatorMax = 0;
            parentWindow->GetBoundsOfPeriod(validatorMin,validatorMax);
        (*itSta)->SetMinPeriod(QString("%1").arg(validatorMin));
        (*itSta)->SetMaxPeriod(QString("%1").arg(validatorMax));


        it = model->itemFromIndex(model->index(i, 4, QModelIndex()));
        QString comment = it->data(Qt::DisplayRole).toString();
        (*itSta)->SetComment(comment);

        vChan ch = (*itSta)->GetChans();
        vChanIt itChan = ch.end();

        for (int  j = 0; j < rowsChan; ++j) {
            itChan--;
            QModelIndex indexCol0 = model->index(j, 0, indexStation);
            QString   col0 = model->data(indexCol0,Qt::DisplayRole).toString();

            QModelIndex indexCol1 = model->index(j, 1, indexStation);
            QString   col1 = model->data(indexCol1,Qt::DisplayRole).toString();

            QModelIndex indexminmax = model->index(j, 2, indexStation);
            QString   col3 = model->data(indexminmax,Qt::DisplayRole).toString();

            QStringList lst = col3.split(' ');
            QString valmin = lst.at(1);
            QString valmax = lst.at(3);
            (*itChan)->SetMinPeriod(valmin);
            (*itChan)->SetMaxPeriod(valmax);

            QModelIndex checkChanIndex = model->index(j, 3, indexStation);
            QStandardItem* checkChanItem = model->itemFromIndex(checkChanIndex);

            if (checkChanItem->checkState () == Qt::Checked) (*itChan)->SetAccept(true);
            else (*itChan)->SetAccept(false);

            QModelIndex indexcomment = model->index(j, 4, indexStation);
            QString   col4 = model->data(indexcomment,Qt::DisplayRole).toString();
            (*itChan)->SetComment(col4);


        }

        itSta++;
    }
}
///-------------------------------------------------------------------------------------------

void SettingProperty::InitTreeView() {
    if (model->rowCount() != 0)  {
        model->removeRows ( 0, model->rowCount());
        model->SetNumRow(0);
        model->minMap.clear();
        model->maxMap.clear();
        model->redStaMap.clear();
    }
    PropertyValue *p  = 0;
    QString title = QString();
    staouts = doc->GetStaOut();
    int numSta = 0;
    int commonNumChan = 0;
    vStaIt itSta;
    if (!staouts->empty()) {
        for  ( itSta = staouts->begin();  itSta != staouts->end(); itSta++)	{
            if ((*itSta)->GetMarkDelete()) continue;

            float minperiod = (*itSta)->GetMinPeriod().toFloat();
            float maxperiod = (*itSta)->GetMaxPeriod().toFloat();
            //        p  =  new PropertyStringValue(numSta,(*itSta)->GetName(),(*itSta)->GetName(),(*itSta)->GetTextCol1());
//        p  = doc->GetWorkSpaceSize();
            model->SetItem(itSta);

            vChan ch = (*itSta)->GetChans();
            vChanIt itChan;
            int numChan = 0;



            QModelIndex indexParent0Col0 = model->index(numSta, 0, QModelIndex());
///           model->insertRows ( 0,ch.size(), indexParent0Col0 );
            model->insertColumns( 0,numCol, indexParent0Col0);
//-------------
            itChan = ch.end();
            //          for  ( itChan = ch.begin();  itChan != ch.end();itChan++) {
            do {
                itChan--;
                if ((*itChan)->GetMarkDelete()) continue;
                p  =  new
                PropertyStringValue(numChan,(*itChan)->GetName(),(*itChan)->GetName(),(*itChan)->GetTextCol1());
//QMessageBox::warning(0,"",QString("chan %1").arg((*itChan)->GetName()));


                PropertyValue *pmin  = new
                PropertyFloatValue(numChan,(*itChan)->GetMinPeriod(),(*itChan)->GetMinPeriod(),"Edit line min" ,minperiod,maxperiod,2);



                PropertyValue *pmax  = new                              PropertyFloatValue(numChan,(*itChan)->GetMaxPeriod(),(*itChan)->GetMaxPeriod(),"Edit line max",minperiod,maxperiod,2);

                PropertyValue *pcheck  = 0;
                if ((*itChan)->GetAccept()) {
                    pcheck  = new PropertyBoolValue (numChan,"1","1","name");
                } else {
                    pcheck  = new PropertyBoolValue (numChan,"0","0","name");
                }


                PropertyValue *pcomment  = new
                PropertyStringValue(numChan,(*itChan)->GetComment(),(*itChan)->GetComment(),"name");

                model->SetItem(numSta,numChan,p,pmin,pmax,pcheck,pcomment);
                numChan++;
            } while (itChan != ch.begin());
//--------------------------------------------------------
            commonNumChan += numChan;
            if (numSta == 0)
                setExpanded(indexParent0Col0,true);
            numSta++;
        }
        parentWindow->GetLabelInfo()->setText(QString("stations: %1 chanels: %2").arg(numSta).arg(commonNumChan));
    } else parentWindow->GetLabelInfo()->setText("Out list is empty");



    resizeColumnToContents(0);
    resizeColumnToContents(1);
    resizeColumnToContents(2);
    resizeColumnToContents(3);
    resizeColumnToContents(4);
    resizeColumnToContents(5);
///-------------------------------------------------------------------------------------------
}
///-------------------------------------------------------------------------------------------

void  SettingProperty::OpenEditor(QModelIndex &index) {
    QModelIndex parent = index.parent();
    if (indexOpenEditor != QModelIndex() && index != indexOpenEditor) {
        clearSelection ();
        QModelIndex temp = model->index( index.row(),1, QModelIndex());
        if (indexOpenEditor == temp) return;
        closePersistentEditor(indexOpenEditor);
        QModelIndex sel = model->index(index.row(), 0, QModelIndex());
        setCurrentIndex (sel);
        indexOpenEditor = temp;
        openPersistentEditor(indexOpenEditor);
    }
}
void SettingProperty::clickedRowCol(QModelIndex index) {
    QModelIndex parent = index.parent();
    if (parent !=  QModelIndex()) {
        if (index.column() == 3) {
            /*
                        QStandardItem* item = model->itemFromIndex(index);
                        if (item->checkState () == Qt::Unchecked)
                            item->setCheckState(Qt::Checked);
                        else
                            item->setCheckState(Qt::Unchecked);
            */
            QModelIndex updateIndex = model->index(index.row(), 0, parent);
            update (updateIndex);
            update (parent);
        }
    }


}


void SettingProperty::drawBranches(QPainter *painter, const QRect &rect, const QModelIndex &index) const {
    QStyleOptionViewItem opt = viewOptions();
    QStyleOptionViewItem option = opt;

    if (selectionModel()->isSelected(index))
        painter->fillRect(option.rect, option.palette.brush(QPalette::Highlight));

    if (model->hasChildren(index)) {
        static const int size = 9;
        opt.state |= QStyle::State_Children;
        opt.rect.setRect(rect.width() - (indentation() + size) / 2,
                         rect.y() + (rect.height() - size) / 2, size, size);
        if (isExpanded(index))
            opt.state |= QStyle::State_Open;
        painter->fillRect(opt.rect, Qt::white);
        style()->drawPrimitive(QStyle::PE_IndicatorBranch, &opt, painter, this);
    }
    painter->drawLine(rect.x(), rect.bottom(), rect.right(), rect.bottom());
}



