
#include <qstring.h>
#include <qstringlist.h>
#include <q3ptrlist.h>
#include <q3iconview.h>
#include <qcombobox.h>
#include <qlabel.h>
#include <q3filedialog.h>
#include <qtabwidget.h>
#include <qpoint.h>
#include <qobject.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qfileinfo.h>
#include <qmap.h>
#include <qdatetime.h>
#include <qapplication.h>
#include <qcheckbox.h>
#include <q3url.h>
#include <qfont.h>
#include <qlineedit.h> 
#include <qmessagebox.h> 
//Added by qt3to4:
#include <QPixmap>
#include "mainwindow.h"
#include "startdialogimpl.h"
#include "newdialogimpl.h"

FileDialog::FileDialog( const QString &dir, QWidget *parent )
    : Q3FileDialog( dir, QString::null, parent )
    
{
    setMode ( Q3FileDialog::DirectoryOnly ); 
}

void FileDialog::accept()
{
    emit fileSelected();

}


StartDialog::StartDialog( QWidget *parent, const QString &tempPath )
    : QDialog( parent)
{
    templatePath = tempPath;
    setFont( parent->font() );
    setupUi(this);
    recentFiles.clear();
    initTabOpen();
    initTabNew();
    showInFuture = TRUE;
    
   // adjustSize();
   
    connect( recentView, SIGNAL( doubleClicked(Q3IconViewItem*) ),
	     this, SLOT( accept() ) );
    connect( recentView, SIGNAL( returnPressed(Q3IconViewItem*) ),
	     this, SLOT( accept() ) );
    connect( fd, SIGNAL( fileSelected() ), this, SLOT( accept() ) );
}
void StartDialog::error(const QString &message){
    QMessageBox::warning(0,"StartDialog",message);    
}
void StartDialog::accept()
{  
   
    showInFuture = !checkShowInFuture->isChecked(); // means don't show it anymore

    int tabindex = tabWidget->currentPageIndex();
    QString filename;
    if( !tabindex ) {
	if (!newdialog->IsChecked()) return;
	hide();
    } else if ( tabindex == 1 ) {
	filename = fd->selectedFile();
	if (!filename.isEmpty()){
	    if (filename == "/") return;
	   QDir d(filename);
	    if (!d.exists ( FTAN_PARAMETRS_FILE_NAME) ) {
		error(QString("Directory %1  does not contain ftan materials ").arg(filename)); 
		return;
	    }
	    MainWindow::self->loadProjectDirectory(filename );
	    hide();
	} else return;
    } else if ( tabindex == 2 ) {
	filename = recentFiles[recentView->currentItem()->index()];
	QFile fi( filename);
	if (fi.exists()){
	    MainWindow::self->loadProjectDirectory(filename);
	    hide();
	} else {
	    error(QString("Directory %1  does not exist ").arg(filename)); 
	   return; 
	}
    }

    done( Accepted );
}

void StartDialog::reject()
{
//    qWarning("StartDialog::reject");
    done( Rejected );
}

void StartDialog::recentItemChanged( Q3IconViewItem *item )
{
    QString msg( recentFiles[item->index()] );
    QFileInfo f( recentFiles[item->index()] );
    uint s = f.size();
    QString unit( "B" );
    if( s > 1024 ) {
	s /= 1024;
	unit = "KB";
    }
    if ( s > 1024 ) {
	s /= 1024;
	unit = "MB";
    }
    QDateTime dt( f.lastModified() );
    QString date( dt.toString( "MMMM dd hh:mm" ));
    msg = QString( "%1 (%2 %3)  %4" ).arg(msg).arg(s).arg(unit).arg(date);
    fileInfoLabel->setText( msg );
}

void StartDialog::clearFileInfo()
{
    fileInfoLabel->clear();
}

void StartDialog::setRecentlyFiles( QStringList &files )
{
    insertRecentItems( files, FALSE );
}

void StartDialog::setRecentlyProjects( QStringList &projects )
{
    insertRecentItems( projects, TRUE );
}

void StartDialog::insertRecentItems( QStringList &files, bool isProject )
{
    QString iconName = "LogoEarth16.png";
   if ( isProject );
//	iconName = "designer_project.png";
    Q3IconViewItem *item;
    QStringList::iterator it = files.begin();
    for( ; it != files.end(); ++it ) {
	QFileInfo fi( *it );
	item = new Q3IconViewItem( recentView, fi.fileName() );
	recentFiles[recentView->index( item )] = *it;
	item->setPixmap(QPixmap(qPixmapFromMimeSource( iconName )) );
	item->setDragEnabled( FALSE );
    }
}

void StartDialog::initTabOpen()
{
    QString encode = QDir::currentDirPath();
    Q3Url::encode( encode );
    fd = new FileDialog( encode, this );
    QPoint point( 0, 0 );
    fd->reparent( tabOpen, point );

    QObjectList l = fd->queryList( "QPushButton" );

    //
    foreach (QObject* obj,l) ((QPushButton*)obj)->hide();

/*
     QObjectListIt it( l );
    while ( (obj = it.current()) != 0 ) {
        ++it;
	((QPushButton*)obj)->hide();
    }
*/
    fd->setSizeGripEnabled ( FALSE );
layout ()->addWidget( fd );
    //tabOpenLayout->addWidget( fd );

    fd->show();
}
void StartDialog::initTabNew() {    

    newdialog = new NewDialog(this,false);
/*
    QPoint point( 0, 0 );
    newdialog->reparent( tabNew, point );
   
    newdialog->GetButtonHelp()->hide();
    newdialog->GetButtonOk()->hide();
    newdialog->GetButtonCancel()->hide();
    
    newdialog->setSizeGripEnabled ( FALSE );

 QMessageBox::warning(0,0,"initTabNew 2");
    layout()->addWidget( newdialog );
*/
}
