#include <q3popupmenu.h>
#include <qicon.h>
#include <qtoolbutton.h>
#include <q3listview.h>
#include <q3header.h>
#include <qstringlist.h>
#include <qstring.h>
#include <qcombobox.h>
#include <qdatetime.h>
#include <qlabel.h>
#include <algorithm>
#include <qmessagebox.h>
#include <qapplication.h>
#include <stdlib.h>
#include "mainwindow.h"
#include "stationlistimpl.h"
#include "stationlisteditor.h"
#include "document.h"
#include "setting.h"
ViewPsImpl::~ViewPsImpl() {}
ViewPsImpl::ViewPsImpl (QWidget *parent,QString &StaChanName,QStringList  &listPs)
        : QDialog( parent) {
    setFont( parent->font() );
    setupUi(this);
    listView->clear();
    for ( QStringList::Iterator it = listPs.begin(); it != listPs.end(); ++it ) {
        if (( *it ).contains("wf.ps") ) {
            new Q3ListViewItem( listView, "Cleaned and raw seismograms" );
            mapPs["Cleaned and raw seismograms"] = ( *it );
        }
        if (( *it ).contains("a.ps") ) {
            new Q3ListViewItem( listView, "Cleaned and raw amplitude spectra" );
            mapPs["Cleaned and raw amplitude spectra"] = ( *it );
        }
        if (( *it ).contains("p.ps") ) {
            new Q3ListViewItem( listView, "Estimated polarization anomalies" );
            mapPs["Estimated polarization anomalies"] = ( *it );
        }
        if (( *it ).contains("g.ps") ) {
            new Q3ListViewItem( listView, "Calculated group velocity curves" );
            mapPs["Calculated group velocity curves"] = ( *it );
        }
        if (( *it ).contains("image.ps") ) {
            new Q3ListViewItem( listView, "Diagrams for cleaned and raw records" );
            mapPs["Diagrams for cleaned and raw records"] = ( *it );
        }
    }
    listView->setSorting( -1 );
    if (mapPs.empty()) new Q3ListViewItem( listView, "empty" );
    listView->header()->setLabel( 0,StaChanName);
    listView->header()->setStretchEnabled (TRUE, 0 );
    listView->header()->adjustHeaderSize ();
    listView->adjustColumn (0);
    listView->adjustSize();
    setSizeGripEnabled ( TRUE );
    adjustSize();

}
void ViewPsImpl::accept() {
    Q3ListViewItem * item =  listView->selectedItem ();
    if (item == 0) {
        QMessageBox::warning(0,"View Postcript  Control Panel","No Selected Ps Name");
        return;
    }
    QString namePs = listView->selectedItem()->text(0);
//    qWarning("namePs '%s' '%s'",namePs.ascii(), mapPs[namePs].ascii());
    char *st =getenv("FMT_ARCHITECTURE_");
    int linuxPlatphorm = 0;
    if (st == NULL)		{
        QMessageBox::warning(0,"View Postcript  Control Panel","It is not define env variable 'FMT_ARCHITECTURE_'");
    } else	{
        if (strstr(st,"linux") !=0)	linuxPlatphorm = 1;
        else linuxPlatphorm = 0;

    }

    if (linuxPlatphorm == 1) {
        QString systemStr = "ghostview  " + mapPs[namePs]  + " &";
        system(systemStr.ascii());
    }
    if (linuxPlatphorm == 0) {
        QString systemStr = "gv  " + mapPs[namePs]  + " &";
        system(systemStr.ascii());
    }
    return;
}
void ViewPsImpl::reject() {
    done( Rejected );
}
StationListImpl::StationListImpl( QWidget * parent,FDocument* dc)
        : QDialog(parent) {
    doc= dc;
    itemInProcess = 0;
    setupUi(this);
    stations= doc->GetStaIn();
    staouts = doc->GetStaOut();

    QPoint point( 0, 0 );
    reparent( parent, point );


    InlistView->header()->setStretchEnabled (TRUE, 0 );
    OutlistView->header()->setStretchEnabled (TRUE, 0 );
    InlistView->header()->setStretchEnabled (TRUE, 1 );
    OutlistView->header()->setStretchEnabled (TRUE, 1 );


    InlistView->header()->adjustHeaderSize ();
    OutlistView->header()->adjustHeaderSize ();

    InlistView->adjustColumn (0);

    OutlistView->adjustColumn (0);

    setSizeGripEnabled ( FALSE );
    InlistView->clear();

    OutlistView->clear();
    comboBoxChanIn->clear ();
    comboBoxChanOut->clear ();
    SetComboBoxChan(comboBoxChanIn,stations);
    comboBoxChanIn->setCurrentText ("All");
    DecorateRowList(InlistView,"All",stations,textLabelCountIn) ;

    if (!staouts->empty())  {
        SetComboBoxChan(comboBoxChanOut,staouts);
        comboBoxChanOut->setCurrentText ("All");
        DecorateRowList(OutlistView,"All",staouts,textLabelCountOut) ;
    }

    popUpMenuIn = new Q3PopupMenu();
    popUpMenuIn->insertItem( "reject", this, SLOT( RejectMenuIn() ) );

    popUpMenuOut = new Q3PopupMenu();
    popUpMenuOut->insertItem( "view ps", this, SLOT( ViewPsMenuOut() ) );
    popUpMenuOut->insertItem( "delete", this, SLOT( DeleteMenuOut() ) );


    connect( toolButtonHelpIn, SIGNAL( clicked() ),MainWindow::self, SLOT( showDialogHelp() ) );
    connect( toolButtonHelpOut, SIGNAL( clicked() ),MainWindow::self, SLOT( showDialogHelpOut() ) );
    connect( InlistView, SIGNAL( contextMenuRequested(Q3ListViewItem*,const QPoint&,int) ), this, SLOT( popUpMenuInSlot(Q3ListViewItem*,const QPoint&,int) ) );

    connect( OutlistView, SIGNAL( contextMenuRequested(Q3ListViewItem*,const QPoint&,int) ), this, SLOT( popUpMenuOutSlot(Q3ListViewItem*,const QPoint&,int) ) );

    connect(InlistView, SIGNAL( collapsed( Q3ListViewItem* ) ), this, SLOT( InlistViewCollapsed( Q3ListViewItem* ) ) );
    connect( InlistView, SIGNAL( expanded( Q3ListViewItem* ) ), this, SLOT( InlistViewExpanded( Q3ListViewItem* ) ) );
    connect( InlistView, SIGNAL( clicked ( Q3ListViewItem * , const QPoint & , int  ) ), this, SLOT( InlistViewClicked(Q3ListViewItem * , const QPoint & , int ) ) );

    connect( comboBoxChanIn, SIGNAL(activated ( const QString &  ) ), this, SLOT( GetInBoxText(const QString&) ) );
    connect( comboBoxChanOut, SIGNAL( activated ( const QString &  )), this, SLOT( GetOutBoxText(const QString&) ) );

    //  repaint();
}

void  StationListImpl::SetComboBoxChan(QComboBox* box,vector<StaValue* >* lst) {
    set <QString> chList;
    vStaIt itSta;
    vChanIt itChan;
    vChan Chan;
    itSta = lst->begin();
    while (itSta != lst->end()) {
        Chan = (*itSta)->GetChans();
        for  ( itChan = Chan.begin();  itChan != Chan.end(); itChan++) {
            QString tmp = (*itChan)->GetName();
            if (  tmp[tmp.length()-1]  == 'Z' || tmp[tmp.length()-1]  == 'R')
                tmp = COMBOBOX_OUT_RAYLEIGN;
            if (  tmp[tmp.length()-1]  == 'T')
                tmp = COMBOBOX_OUT_LOVE;
            chList.insert(tmp);
        }
        itSta++;
    }

    box->clear ();
    box->insertItem ( "All");
    set <QString>::iterator ct;
    for  ( ct = chList.begin();  ct != chList.end(); ct++)
        box->insertItem ((*ct));

    box->adjustSize();
}
/*
void  StationListImpl::GetStationChanNumber(vector<StaValue* > lst,int &nsta,int &nchan){
    if(lst.empty()) {
	nsta= 0; nchan = 0;
	return;
    }
    nsta= 0; nchan = 0;
    vStaIt itSta;
    vChanIt itChan;
    vChan Chan;
    itSta = lst.begin();
    while (itSta != lst.end()) {
	nsta++;
	Chan = (*itSta)->GetChans();
	for  ( itChan = Chan.begin();  itChan != Chan.end(); itChan++) nchan++;
	itSta++;
    }
}
*/
bool StationListImpl::isChanInStation(vector<StaValue* >::iterator iteratorSta,QString chan) {
    vStaIt itSta = iteratorSta;
    vChanIt itChan;
    vChan Chan;
    bool isChan = false;
    Chan = (*itSta)->GetChans();
    for  ( itChan = Chan.begin();  itChan != Chan.end(); itChan++)
        if ((*itChan)->GetName().find(chan) !=-1) {
            isChan = true;
            break;
        }

    return isChan;
}
bool StationListImpl::isChanInStation(vector<StaValue* >::iterator iteratorSta,QChar chan) {
    vStaIt itSta = iteratorSta;
    vChanIt itChan;
    vChan Chan;
    bool isChan = false;
    Chan = (*itSta)->GetChans();
    for  ( itChan = Chan.begin();  itChan != Chan.end(); itChan++)  {
        QString  nCh = (*itChan)->GetName();
        if (nCh[nCh.length() -1] == chan) {
            isChan = true;
            break;
        }
    }

    return isChan;
}
void  StationListImpl::DecorateRowList(Q3ListView* rowlist,QString  chan,vector<StaValue* >* lst,QLabel* lbl) {
    rowlist->clear();
    rowlist->setRootIsDecorated( TRUE );
    vector<RowPropertyItem* > parentList;
    vector<RowPropertyItem* >::iterator pIt;
    vStaIt itSta;

 //   sort(lst->begin(),lst->end(),sta_Comp());

    Q3ListViewItem *item = 0;
    for  ( itSta = lst->begin();  itSta != lst->end(); itSta++)	{
        if ((*itSta)->GetMarkDelete()) continue;
        if (!(chan == COMBOBOX_OUT_LOVE || chan == COMBOBOX_OUT_RAYLEIGN)) {
            if (chan != "All" && !isChanInStation(itSta,chan)) continue;
        } else {
            if (chan == COMBOBOX_OUT_LOVE ) {
                if (!isChanInStation(itSta,'T') )continue;
            }
            if (chan == COMBOBOX_OUT_RAYLEIGN ) {
                if (! (  isChanInStation(itSta,'Z' )  || isChanInStation(itSta,'R' )) )continue;
            }
        }
        parentList.push_back( new StationItem(rowlist, (*itSta)->GetName(), rowlist,*itSta));
        pIt = parentList.end();
        pIt --;
        item = *pIt;
        vChan ch = (*itSta)->GetChans();
//        sort(ch.begin(),ch.end(),chan_Comp());
        vChanIt itChan;
        for  ( itChan = ch.begin();  itChan != ch.end();itChan++) {
            if ((*itChan)->GetMarkDelete()) continue;
            if (!(chan == COMBOBOX_OUT_LOVE || chan == COMBOBOX_OUT_RAYLEIGN)) {
                if (chan != "All" && (*itChan)->GetName() != chan ) continue;
            } else {
                QString nCh =  (*itChan)->GetName() ;
                uint ln = nCh.length();
                if (chan == COMBOBOX_OUT_LOVE ) {
                    if ( nCh[ln - 1] != 'T') continue;
                }

                if (chan == COMBOBOX_OUT_RAYLEIGN ) {
                    if (!( nCh[ln - 1] == 'Z' || nCh[ln - 1] == 'R'  ) ) continue;
                }
            }
//QMessageBox::warning(0,"",QString("chan %1").arg((*itChan)->GetName()));
            (void)new ChanItem(item, (*itChan)->GetName(), rowlist,*itChan);
        }

    }

    Q3ListViewItem * myChild = rowlist->firstChild();
    int j = 0;
    while ( myChild ) {
        j += myChild->childCount ();
        myChild = myChild->nextSibling();
    }
    lbl->setText( QString("sta: %1 chan: %2 ").arg(rowlist->childCount ()).arg(j));
}

/*
 *  Destroys the object and frees any allocated resources
 */
StationListImpl::~StationListImpl() {

}
int StationListImpl::GetIdChannal() {
    Q3ListViewItem * item = InlistView->selectedItem ();
    if (item == 0) return 0;
    itemInProcess = item;
    RowPropertyItem * it =  dynamic_cast<RowPropertyItem *>(item);
    return it->GetPropvalue()->GetId();
}

void StationListImpl::SetChanToOutList(QStringList &newRecordForOutlist,QStringList &newPsName) {
    if (newRecordForOutlist.isEmpty())    return;
    Q3ListViewItem * item = itemInProcess;
    if (item == 0) return;
    item->setText(1,OUT_LIST_SELECTED );
    RowPropertyItem * it =  dynamic_cast<RowPropertyItem *>(item);
    RowValue* rw = it->GetPropvalue();
    rw->SetTextCol1(OUT_LIST_SELECTED);
    int id = rw->GetId();
    Q3ListViewItem * parent = item->parent ();

    RowPropertyItem * itt =   dynamic_cast<RowPropertyItem *>(parent);
    RowValue* rwParent = itt->GetPropvalue();
    parent->setText(1,OUT_LIST_SELECTED);
    rwParent->SetTextCol1(OUT_LIST_SELECTED);


    QString sta = itt->GetPropvalue()->GetName();
    MainWindow::self->savedStationName = sta;

    QStringList::iterator itCh;
    int i = 0;
    for ( itCh = newRecordForOutlist.begin(),i = 0 ;itCh!= newRecordForOutlist.end(); ++itCh ,i++) {
        QString textcol1 = (* itCh).left((* itCh) .find('.'));
        //qWarning("ZZZZZ'%s' ",textcol1.ascii());
        uint time_t = textcol1.toUInt ();
        QDateTime dateTime ;

        dateTime.setTime_t(time_t,Qt::UTC);
        textcol1 =  dateTime.toString ("dd.MM.yyyy hh:mm:ss" ) ;
        textcol1 = doc->GetFtaOrbit()->GetValue()+" " + textcol1;
        QString textcolPs = dateTime.toString ("dd.MM.yyyy_hh:mm:ss" ) ;
        QString cha  = (* itCh).right((* itCh).length()  - (* itCh).findRev("cl_"));

        cha = cha.right(cha.length()  - cha.findRev('.') - 1);
        QString chan = cha.right( cha.length()  -1 );
        int len = chan.length() -1;
        if (chan[len ] != 'Z' && cha[0] == 'L')  chan[len ] = 'T';
        if (chan[len] != 'Z' && cha[0] == 'R')  chan[len] = 'R';
        SetOutlistItem(id,sta,chan,textcol1,(* itCh));

        chan.remove( chan.length()-1, 1);
        QString tmp = sta + "_" + chan +  "_"  + doc->GetFtaOrbit()->GetValue()+"_" +textcolPs;
        newPsName.append(tmp);
    }
    doc->sortStationList(staouts);
    SetComboBoxChan(comboBoxChanOut,staouts);
    comboBoxChanOut->setCurrentText ("All");
    DecorateRowList(OutlistView,"All",staouts,textLabelCountOut) ;
//doc->printFDocument();
}

void StationListImpl::HelpSlot() {

}

void  StationListImpl::SetOutlistItem(int id,QString  sta,QString  chan,QString  textcol1,QString  dfile) {
    vStaIt itSta;
    SettingImpl*  periodlist = MainWindow::self->GetPeriodListDialog();
    float shortCorner =  doc->GetShortPeriodCorner()->GetValue().toFloat();
    float longCorner =  doc->GetLongPeriodCorner()->GetValue().toFloat();
    float boungMin = doc->GetPeriodBoundMinimum()->GetValue().toFloat();
    float boungMax = doc->GetPeriodBoundMaximum()->GetValue().toFloat();
    float validatorMin = 0;
    float validatorMax = 0;
    if (shortCorner < boungMin) validatorMin = boungMin;
    else validatorMin = shortCorner;
    if (longCorner < boungMax) validatorMax = longCorner;
    else validatorMax = boungMax;
    QString defMin = QString("%1").arg(validatorMin);
    QString defMax = QString("%1").arg(validatorMax);

QString valMin = "";
QString valMax = "";
int len = chan.length() -1;
if (chan[len ] == 'Z') periodlist->GetValuesZ(valMin,valMax);
if (chan[len ] == 'T') periodlist->GetValuesT(valMin,valMax);
if (chan[len ] == 'R') periodlist->GetValuesR(valMin,valMax);
//QMessageBox::warning ( 0,"",QString ( "sta '%1' chan %2 min %3 max %4").arg(sta).arg(chan).arg(valMin).arg(valMax));
    QString minperiodSta = defMin;
    QString maxperiodSta = defMax;
    QString commentSta = QString();

    QString minperiodChan = valMin;
    QString maxperiodChan = valMax;
    QString commentChan = QString();
    bool acceptChan = false;
    if ( (itSta = doc->GetStaIterator(sta,staouts)) != staouts->end() )  {
        ChanValue* newChan = new ChanValue(id,chan,textcol1,dfile);

        newChan->SetMinPeriod(minperiodChan);
        newChan->SetMaxPeriod(maxperiodChan);
        newChan->SetComment(commentChan);
        newChan->SetAccept(acceptChan);

        (*itSta)->GetChans().push_back(newChan);
        (*itSta)->SetMarkDelete(false);
    } else {
        StaValue* newSta = new StaValue(sta);
        newSta->SetMinPeriod(minperiodSta);
        newSta->SetMaxPeriod(maxperiodSta);
        newSta->SetComment(commentSta);
        staouts->push_back(newSta);
        itSta = staouts->end();
        itSta--;
        ChanValue* newChan = new ChanValue(id,chan,textcol1,dfile);

        newChan->SetMinPeriod(minperiodChan);
        newChan->SetMaxPeriod(maxperiodChan);
        newChan->SetComment(commentChan);
        newChan->SetAccept(acceptChan);

        (*itSta)->GetChans().push_back(newChan);
    }
    int count = 0;
    vChan ch = (*itSta)->GetChans();
    vChanIt itChan;
    for  ( itChan = ch.begin();  itChan != ch.end();itChan++)
        if (!(*itChan)->GetMarkDelete())  count++;
    (*itSta)->SetTextCol1(QString("# %1").arg(count));
}

void  StationListImpl::InlistViewClicked( Q3ListViewItem * item, const QPoint & pnt, int c) {
    QPoint pPoint(0,0);
    pPoint += pnt;
    c =0;
    if (item == 0) return;
    MainWindow::self->SetStateStartToolBarButton(item);

}
void  StationListImpl::InlistViewCollapsed( Q3ListViewItem*  item) {
    item = 0;
}
void  StationListImpl::InlistViewExpanded( Q3ListViewItem*  item) {
    item = 0;
}
void  StationListImpl::GetInBoxText(const QString &text) {

    DecorateRowList(InlistView,text,stations,textLabelCountIn) ;
}
void  StationListImpl::GetOutBoxText(const QString &text) {

    DecorateRowList(OutlistView,text,staouts,textLabelCountOut) ;
}

void StationListImpl::popUpMenuInSlot(Q3ListViewItem* item,const QPoint& point,int i) {

    if ( item && dynamic_cast<RowPropertyItem *>(item) == dynamic_cast<ChanItem *>(item ) ) {
        chanItemMenuIn = dynamic_cast<ChanItem *>(item );
        if (! (chanItemMenuIn->text(1) == OUT_LIST_SELECTED || chanItemMenuIn->text(1) == OUT_LIST_REJECTED) ) {
            popUpMenuIn->popup( point );
            stationItemMenuIn = 0;
        }
    }
    if ( item && dynamic_cast<RowPropertyItem *>(item) == dynamic_cast<StationItem *>(item ) ) {
        stationItemMenuIn = dynamic_cast<StationItem *>(item );
        if (! (stationItemMenuIn->text(1) == OUT_LIST_SELECTED || stationItemMenuIn->text(1) == OUT_LIST_REJECTED) ) {
            popUpMenuIn->popup( point );
            chanItemMenuIn = 0;
        }
    }
    i  = 0;
}
void StationListImpl::RejectMenuIn() {
    if (stationItemMenuIn == 0 && chanItemMenuIn != 0)    {
        chanItemMenuIn->setText(1,OUT_LIST_REJECTED);
        chanItemMenuIn->GetPropvalue()->SetTextCol1(OUT_LIST_REJECTED);

        Q3ListViewItem * parent = (dynamic_cast<Q3ListViewItem*>(chanItemMenuIn))->parent ();
        Q3ListViewItem * child = parent->firstChild ();
        int allReject = 0;
        while (child != 0) {
            if (child->text(1) == OUT_LIST_REJECTED) {
                allReject++;
            }
            child = child->nextSibling ();
        }
        if (allReject == parent->childCount ()) {
            parent->setText(1,OUT_LIST_REJECTED);
            StationItem *staItem = dynamic_cast<StationItem *>(parent);
            staItem->GetPropvalue()->SetTextCol1(OUT_LIST_REJECTED);
        }

        MainWindow::self->SetModifedFlt(true );
    }
    if (stationItemMenuIn != 0 && chanItemMenuIn == 0)    {
        stationItemMenuIn->GetPropvalue()->SetTextCol1(OUT_LIST_REJECTED);
        stationItemMenuIn->setText(1,OUT_LIST_REJECTED);
        Q3ListViewItem * child = stationItemMenuIn->firstChild ();
        while (child != 0) {
            ChanItem *chItem = dynamic_cast<ChanItem *>(child);
            chItem->GetPropvalue()->SetTextCol1(OUT_LIST_REJECTED);
            chItem->setText(1,OUT_LIST_REJECTED);
            child = child->nextSibling ();
        }
        MainWindow::self->SetModifedFlt(true );
    }
}

void StationListImpl::popUpMenuOutSlot(Q3ListViewItem* item,const QPoint& point,int i) {

    if ( item && dynamic_cast<RowPropertyItem *>(item) == dynamic_cast<ChanItem *>(item ) ) {
        chanItemMenuOut = dynamic_cast<ChanItem *>(item );
        popUpMenuOut->popup( point );
    }
    i = 0;
}

void StationListImpl::ViewPsMenuOut() {
    RowValue* rwChan = chanItemMenuOut->GetPropvalue();
    QString chan = rwChan->GetName() ;
    QString textCol1 = rwChan->GetTextCol1();
    QString temp = chan  + " " + textCol1;
    Q3ListViewItem * parent = (dynamic_cast<Q3ListViewItem*>(chanItemMenuOut))->parent ();
    RowValue* rwSta =    (dynamic_cast<StationItem *>(parent))->GetPropvalue();
    QString sta = rwSta ->GetName();
    temp = sta + " " + temp;
    QString prefixPs =  sta + " " + chan.left(chan.length() -1) + " " + textCol1;
    prefixPs.replace( QChar(' '), "_" ) + "_";
    QStringList listPs;
    MainWindow::self->GetListPS(prefixPs,listPs);
    ViewPsImpl  dialog(this,temp,listPs);
    // dialog.show();
    if (dialog.exec()) {

    }
}
void StationListImpl:: DeleteMenuOut() {

    RowValue* rwChan = chanItemMenuOut->GetPropvalue();
    QString chan = rwChan->GetName() ;
    QString textCol1 = rwChan->GetTextCol1();
    QString temp = chan  + " " + textCol1;
    Q3ListViewItem * parent = (dynamic_cast<Q3ListViewItem*>(chanItemMenuOut))->parent ();
    RowValue* rwSta =    (dynamic_cast<StationItem *>(parent))->GetPropvalue();
    QString sta = rwSta ->GetName();
    temp = sta + " " + temp;
    QString tmp = QString("Do you really want to delete %1\nfrom out sta:chan list?").arg(temp);
    int ret = QMessageBox::warning(this,"Out Station List" ,tmp,
                                   QMessageBox::Yes | QMessageBox::Default,
                                   QMessageBox::No | QMessageBox::Escape);
    if (ret == QMessageBox::No)
        return;
    int i = 0;
    Q3ListViewItem * child = parent->firstChild ();
    while (child != 0) {
//  qWarning("YYYY 0 '%s' <-> '%s'",child->text(1).ascii(),textCol1.ascii());
        if (child->text(1) == textCol1) i++;
        child = child->nextSibling ();
    }

    QString prefixPs =  sta + " " + chan.left(chan.length() -1) + " " + textCol1;


//    qWarning("YYYY 0 %s",prefixPs.ascii());
    prefixPs.replace( QChar(' '), "_" ) + "_";
//    qWarning("YYYY 1 %s",prefixPs.ascii());
    QString dispName = FTAN_DISP_EXPORT_PREFIX + "_" + sta + "_" + textCol1 + "_" + chan;

    dispName.replace( QChar(' '), "_" );
    if (i>1) prefixPs = "";
    QString cleanedWf = rwChan->GetDfile();
    cleanedWf = cleanedWf.right(cleanedWf.length()  - cleanedWf.findRev("cl_"));
    QString cleanedDisp = cleanedWf;

    QString oldchan =  cleanedDisp.right(cleanedDisp.length() - cleanedDisp.findRev('.'));
    cleanedDisp.replace(oldchan, "." + chan);
    MainWindow::self->DeleteExcludedStachanMaterials(prefixPs,cleanedWf,cleanedDisp,dispName);

    delete (Q3ListViewItem * )chanItemMenuOut;
    if (parent->childCount () == 0) {
        delete parent;
    }

    bool outStaListHasChan = false;
    vStaIt itSta;
    for  ( itSta = staouts->begin();  itSta != staouts->end(); itSta++)	{
        vChanIt itChan,searchCh;
        if ( (*itSta)->GetName()  == sta ) {
            vChan ch = (*itSta)->GetChans();
            bool indChan = false;

            for  ( itChan = ch.begin();  itChan != ch.end();itChan++) {
                if ( (*itChan )->GetName() == chan && (*itChan )->GetTextCol1()  == textCol1) {
                    indChan=true;
                    searchCh = itChan;
                    break;
                }
            }

            if (indChan == true) {
                (*searchCh)->SetMarkDelete(true);
                uint markDel = 0;
                for  ( itChan = ch.begin();  itChan != ch.end();itChan++)
                    if ((*itChan)->GetMarkDelete()) markDel++;
                if (ch.size() == markDel)  {
                    (*itSta)->SetMarkDelete(true);
                }
                QString inCha = chan.left(chan.length() -1);
                for  ( itChan = ch.begin();  itChan != ch.end();itChan++) {
                    QString curCha = (*itChan )->GetName();
                    curCha = curCha.left(curCha.length() -1);
                    if (!(*itChan)->GetMarkDelete() && curCha == inCha ) outStaListHasChan = true;
                }
            }


            int count = 0;
            ch = (*itSta)->GetChans();
            for  ( itChan = ch.begin();  itChan != ch.end();itChan++)
                if (!(*itChan)->GetMarkDelete())  count++;
            (*itSta)->SetTextCol1(QString("# %1").arg(count));
            break;
        }
    }

    itSta = doc->GetStaIterator(sta,stations);
    QString inChan = chan.left(chan.length() -1);
    vChan ch = (*itSta)->GetChans();

    bool indSta = false;
    child = InlistView->firstChild ();
    while (child != 0) {
        if (child->text(0) == sta) {
            indSta = true;
            break;
        }
        child = child->nextSibling ();
    }
    if (indSta == true) {
        StationItem *staItem = dynamic_cast<StationItem *>(child);
        child = staItem->firstChild ();

        ChanItem * chanItem = 0;
        while (child != 0) {

            if (child->text(0) == inChan) {
                chanItem  = dynamic_cast<ChanItem  *>(child);
            }
            child = child->nextSibling ();
        }
        if (chanItem != 0) {
            if (!outStaListHasChan) {
                chanItem->setText(1,OUT_LIST_REJECTED);
                chanItem->GetPropvalue()->SetTextCol1(OUT_LIST_REJECTED);
            }
            int allReject = 0;
            //bool indSel = false;
            child = staItem->firstChild ();
            while (child != 0) {
                if (child->text(1) == OUT_LIST_REJECTED) {
                    allReject++;
                }
                //if (child->text(1) == OUT_LIST_SELECTED){ indSel = true;}
                child = child->nextSibling ();
            }

            if (allReject == staItem->childCount ()) {
                staItem->setText(1,OUT_LIST_REJECTED);
                staItem->GetPropvalue()->SetTextCol1(OUT_LIST_REJECTED);
            }
            // if(indSel == false) {
            //	staItem->setText(1,"");
            //	staItem->GetPropvalue()->SetTextCol1(QString::null);
            // }
        }


    }
//      doc->printFDocument();
    SetComboBoxChan(comboBoxChanOut,staouts);
    comboBoxChanOut->setCurrentText ("All");
    DecorateRowList(OutlistView,"All",staouts,textLabelCountOut) ;

    MainWindow::self->GetNewPeriodList();

}
