//===============================================================
// fmtdirsel.cpp - vDirSelect class functions - X11R5
//
// Copyright (C) 1995,1996  Bruce E. Wampler
//
// This file is part of the V C++ GUI Framework, and is covered
// under the terms of the GNU Library General Public License,
// Version 2. This library has NO WARRANTY. See the source file
// vapp.cxx for more complete information about license terms.
//===============================================================

// These member functions  modified from vfilesel.cxx &
// vfilesel.h Bruce E. Wampler code by A. Mostinski in 10.1998.
// MITPAN Moscow mostinsk@mitp.ru 

#include "fmtdirsel.h"		// our header
#include <v/vnotice.h>		// we use notice
#include <v/vicon.h>		// for icons

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
//#include <sys/types.h>
#include <sys/stat.h>
#include <dirent.h>

extern vIcon btnCancel;
extern vIcon btnOk;
extern vIcon IbtnHome;
extern vIcon IbtnSelDir;
// Define static data of the class

    enum {
	fsMSG = 100,
	fsLFN,
	fsFN,
	fsLCD,
	fsCD,
	fsLFLT,
	fsFLT,
	fsLIST,
	fsSEL,
	fsHOME,
	fsSHOWDOT,
	fsBLNK,
	fsBLNK2,
	fsLBLDIR,
	fsLISTDIR,
	fsLBLITEM
      };

    static char* filterList[] =		// The default filter list
      {
	"*", 0
      };

    static char* emptyList[] =
      {
	"./",
	"../",
	0
      };

#define FilterIndex 1
#define FileListIndex 8
#define DirListIndex 6
#define LS "ls -1aLF"

    static CommandObject FileSelectDialog[] =
      {
	{C_Label, fsLFLT, 0, "Filter:", 
		(void*)NoList,CA_None,isSens,NoFrame, 0,0},

	{C_ComboBox,fsFLT,0,"ComboBox",(void*)filterList,	// index 1
		CA_None,isSens,NoFrame,0,fsLFLT},

        {C_Label, fsMSG, 0, "Select File",(void*)NoList,
                CA_MainMsg,isSens,NoFrame, fsFLT,0},

	{C_Label, fsLCD, 0, "Directory:", 
		(void*)NoList,CA_None,isSens,NoFrame, 0,fsFLT},
        {C_Label, fsCD, 0, ".", (void*)NoList,
                CA_None,isSens,NoFrame,fsLCD,fsFLT},

	{C_Label, fsLBLDIR, 0, "Directories",
	   (void*) NoList,CA_None,isSens,NoFrame,0,fsLCD},

	{C_List, fsLISTDIR, 150, "List", (void*)emptyList,	// index 6
	    	CA_ListWidth | CA_Size,isSens,NoFrame,0,fsLBLDIR},
	
	{C_Label, fsLBLITEM, 0, "Items",
	    (void*)NoList,CA_None,isSens,NoFrame,fsLISTDIR,fsLCD},

	{C_List, fsLIST, 150, "List", (void*)emptyList,		// index 8
		 CA_ListWidth | CA_Size,isSens,NoFrame,fsLISTDIR,fsLBLITEM},


	{C_Label, fsLFN, 0, "Selection",(void*) NoList,CA_None,isSens,NoFrame, 0,fsLIST},

	{C_Blank, fsBLNK2, 0, "       ",(void*)NoList,CA_None,isSens,NoFrame,fsLFN,fsLIST},

	{C_CheckBox,fsSHOWDOT,0,"Show \".hidden\"",(void*)NoList,CA_None,isSens,
		NoFrame,fsBLNK2,fsLIST},


       {C_TextIn, fsFN, 0, "",(void*) NoList,
             CA_Large,isSens,NoFrame,0,fsSHOWDOT},


        {C_IconButton, M_OK, M_OK, " OK ", (void*)&btnOk,CA_DefaultButton,
                isSens,NoFrame,0,fsFN},
        {C_IconButton, fsSEL, fsSEL, " Select ", (void*)&IbtnSelDir,CA_None,
                isSens,NoFrame,M_OK,fsFN},
        {C_IconButton, M_Cancel, M_Cancel, " Cancel ", (void*)&btnCancel, CA_None,
                isSens,NoFrame,fsSEL,fsFN},
	{C_IconButton, fsHOME, fsHOME, "Home",(void*)&IbtnHome, CA_None,
                isSens,NoFrame,M_Cancel,fsFN},


        {C_EndOfList,0,0,0,0,CA_None,0,0,0}
      };


  static int dirsort(const char**, const char**);
  static int wild_match(const char* , const char*);

//======================>>> vDirSelect::FileSelect <<<=======================
  int vDirSelect::DirSelect(VCONST char* msg, char* filename, 
	const int maxlen, char** filter, int& filterIndex)
  {
    //	Show the file selection dialog.
    //	returns 0 on cancel, 1 otherwise

    int ans;
    char temp[maxFileLen];

    if (!filename)
	return 0;

    _showHidden = 0;
    origFile[0] = 0;
    fileList[0] = 0;
    dirList[0] = 0;

    // If the user supplies a filter, use it. Otherwise, use the default.

    if (filter != 0 && *filter != 0)
      {
	_curFilter = filterIndex;	// which filter we used
	filterPtr = filter;		// so we can change
	fileFilter = filter[_curFilter];
	FileSelectDialog[FilterIndex].itemList = (void *)filter;
	FileSelectDialog[FilterIndex].retVal = _curFilter;
      }
    else
      {
	_curFilter = 0;
	filterPtr = filterList;		// so we can change
	fileFilter = filterList[0];
      }

    // Fill this in dynamically so we can have dynamic heap array

    FileSelectDialog[FileListIndex].itemList = (void *)fileList;
    FileSelectDialog[DirListIndex].itemList = (void *)dirList;

    GetDirList(".", fileFilter, fileList, maxFiles, dirList, maxDirs);

    dirSel = 		// No file selected
    curSel = -1;		// No file selected

    if (!_cmdsAdded)		// Only once
      {
	AddDialogCmds(FileSelectDialog);	// Set up standard dialog
	_cmdsAdded = 1;
      }

    // Read the current directory

    // Note: this SetString won't work on Windows...

    if (getcwd(temp,maxFileLen-1))	// get the current directory
	SetString(fsCD,temp);

    strcpy(curDir,temp);		// preload input with name

/*
    if (*filename)		// provided a base name
	strcpy(origFile,filename);

    if (*filename != 0)
      {
	SetString(fsFN,filename);	// the filename provided
      }
    else
      {
	strcpy(temp,curDir);		// set to curdir
	if (strcmp(temp,"/") != 0)
	    strcat(temp,"/");
	SetString(fsFN,temp);
      }
*/
    (void) ShowModalDialog(msg, ans);	// show and wait

    if (ans != M_Cancel)
      {
	//(void) GetTextIn(fsFN, filename, maxlen);

        strncpy(filename,DirectoryName,maxlen);
	filterIndex = _curFilter;	// copy back out
      }

    return ans != M_Cancel;
  }

//======================>>> vDirSelect::FileSelect <<<=======================
  int vDirSelect::FileSelectSave(VCONST char* msg, char* filename, 
	const int maxlen, char** filter, int& filterIndex)
  {
    return DirSelect(msg, filename, maxlen, filter, filterIndex);
  }

//====================>>> vDirSelect::DialogCommand <<<=======================
  void vDirSelect::DialogCommand(ItemVal id, ItemVal val, CmdType ctype)
  {
    char temp[maxFileLen];

    switch (id)
      {
	case fsFLT:		// new filter
	  {
	    if (*filterPtr[val] == 0)
		break;
	    _curFilter = val;
	    fileFilter = filterPtr[_curFilter];
	    GetDirList(".", fileFilter, fileList, maxFiles, dirList, maxDirs);
	    SetValue(fsLIST,0,ChangeList);
	    SetValue(fsLISTDIR,0,ChangeList);
	    SetValue(fsLIST,-1,Value);	// turn off file highlight
	    SetValue(fsLISTDIR,-1,Value);	// turn off file highlight
	    dirSel =
	    curSel = -1;		// No file selected
	    break;
	  }

	case fsLISTDIR:		// item selected
	  {
         int lvalfsLISTDIR = GetValue(fsLISTDIR);
          if (lvalfsLISTDIR == -1 ) break;
	    if (val != dirSel)	// This trick implements double click
	      {
		SetValue(fsLIST,-1,Value);	// turn off file highlight
		dirSel = val;
		break;
	      }
	    // else - change dirs
	    strcpy(temp,dirList[dirSel]);
	    int len = strlen(temp);
	    if (temp[len-1] != '/')	// not a directory!
		break;
	    temp[len-1] = 0;	// kill the /
	    GetDirList(temp, fileFilter, fileList, maxFiles, dirList, maxDirs);
	    if (getcwd(curDir,maxFileLen-1))	// get the current directory
		SetString(fsCD,curDir);
	    else
	      {
		SetString(fsCD,".");
		strcpy(curDir,".");
	      }
	    SetValue(fsLIST,0,ChangeList);
	    SetValue(fsLISTDIR,0,ChangeList);
	    SetValue(fsLIST,-1,Value);	// turn off file highlight
	    SetValue(fsLISTDIR,-1,Value);	// turn off file highlight
/*
            strcpy(temp,curDir);
	    if (strcmp(temp,"/") != 0)
		strcat(temp,"/");
	    if (*origFile)
		strcat(temp,origFile);
	    SetString(fsFN,temp);
*/
            strcpy(temp,strrchr(curDir,'/') + 1);
            strcat(temp,"/");
		SetString(fsFN,temp);

	    dirSel =
	    curSel = -1;		// No file selected
	    break;
	  }
	case fsSEL:		// Do select
	  {
         int lvalfsLISTDIR = GetValue(fsLISTDIR);
          if (lvalfsLISTDIR == -1 || lvalfsLISTDIR == 0 ) {
	    SetValue(fsLIST,-1,Value);	// turn off file highlight
	    SetValue(fsLISTDIR,-1,Value);	// turn off file highlight
	    dirSel =
	    curSel = -1;		// No file selected

	 break;

	}
          GetDirList(".", fileFilter, fileList, maxFiles, dirList, maxDirs);
	    SetValue(fsLIST,0,ChangeList);
	    SetValue(fsLISTDIR,0,ChangeList);
	    SetValue(fsLIST,-1,Value);	// turn off file highlight
	    SetValue(fsLISTDIR,-1,Value);	// turn off file highlight
           strcpy(temp,dirList[lvalfsLISTDIR]);
		SetString(fsFN,temp);
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	   

getcwd(curDir,maxFileLen-1); // get the current directory

strcat(curDir,"/");
strcat(curDir,temp); *strrchr(curDir,'/') = '\0';
strcpy(DirectoryName,curDir);
	    dirSel =
	    curSel = -1;		// No file selected


	    break;

	}
	case fsLIST:		// item selected
	  {
         int lvalfsLIST = GetValue(fsLIST);
          if (lvalfsLIST == -1 ){
		SetValue(fsLISTDIR,-1,Value);	// turn off file highlight
	    dirSel =
		curSel = val;

	 break;
	}
/*
	    if (val != curSel)	// This trick implements double click
	      {
		SetValue(fsLISTDIR,-1,Value);	// turn off file highlight
		curSel = val;
		break;
	      }
*/
		SetValue(fsLISTDIR,-1,Value);	// turn off file highlight
	    dirSel =
		curSel = -1;

	    // else fall through to fsSEL!
           break;
	  }

	// WARNING - fall through from previous case!

	

	case fsHOME:		// change to home directory
	  {
	    char *hp = getenv("HOME");

	    if (hp == 0)
		strcpy(temp,".");
	    else
		strcpy(temp,hp);
	    // now change to HOME
	    GetDirList(temp, fileFilter, fileList, maxFiles, dirList, maxDirs);
	    if (getcwd(curDir,maxFileLen-1))	// get the current directory
		SetString(fsCD,curDir);
	    else
	      {
		SetString(fsCD,".");
		strcpy(curDir,".");
	      }
	    SetValue(fsLIST,0,ChangeList);
	    SetValue(fsLISTDIR,0,ChangeList);
	    SetValue(fsLIST,-1,Value);	// turn off file highlight
	    SetValue(fsLISTDIR,-1,Value);	// turn off file highlight

	    strcpy(temp,curDir);
            strcpy(temp,strrchr(curDir,'/') + 1);
            strcat(temp,"/");
		SetString(fsFN,temp);

	    dirSel =
	    curSel = -1;		// No file selected
	    break;
	  }

	case fsSHOWDOT:
 	  {
	    _showHidden = val;		// need to repaint
	    GetDirList(".", fileFilter, fileList, maxFiles, dirList, maxDirs);
	    SetValue(fsLIST,0,ChangeList);
	    SetValue(fsLISTDIR,0,ChangeList);
	    SetValue(fsLIST,-1,Value);	// turn off file highlight
	    SetValue(fsLISTDIR,-1,Value);	// turn off file highlight
	    dirSel =
	    curSel = -1;		// No file selected
	    break;
	  }

	case M_OK:
	  {
vNoticeDialog note(this);
	if (strlen(curDir) > maxFileLen - 1) {
         strcpy(temp,curDir);
		    strcat(temp,"\nis not a valid file name.");
note.Notice(temp);
id = 0;
}  else
strcpy(DirectoryName,curDir);

break;
	  }

	// WARNING - fall through from previous case!
	default:
	  {
	    vModalDialog::DialogCommand(id,val,ctype);
	    break;
	  }
      }

    if (id == M_OK || id == M_Cancel)
	CloseDialog();
  }

//====================>>> vDirSelect::GetDirList <<<=======================
  void vDirSelect::GetDirList(const char *dir, const char* wild, 
	char** filelist, const int max, char** dirlist, const int maxdir)
  {
    DIR *dirp;		// for reading a directory

    struct dirent *e;

    char fn[200];

    char** fl;
    char** dl;

    struct stat	statbuf;		// for check

    // make sure we can do this
    if (stat(dir, &statbuf) < 0 || (statbuf.st_mode & S_IFDIR) == 0)
	return;

    if ((dirp = opendir(dir)) == NULL)
	return;

    if (chdir(dir) != 0)		// change to new directory
      {
	SysDebug1(BadVals,"Unable to chdir to %s\n",dir);
	return;
      }

    // ok - will build a new list, so it is safe to kill the old one.
    for (fl = filelist ; *fl ; ++fl)	// free the space
      {
	delete [] *fl;
	*fl = 0;
      }
    for (dl = dirlist ; *dl ; ++dl)	// free the space
      {
	delete [] *dl;
	*dl = 0;
      }

    fl = filelist;
    dl = dirlist;

    int ix, dx;
    for (ix = 0, dx = 0; ix < max && dx < maxdir; )
      {
	if ((e = readdir(dirp)) == NULL)	// read entry
	    break;

	if (strlen(e->d_name) >= 199)		// just ignore too long names
	    continue;
	else
	    strcpy(fn,e->d_name);		// make a copy

	if (strcmp(fn,".") == 0)		// skip the "."
	  {
	    continue;
	  }
	if (strcmp(fn,"..") == 0)		// special entry
	  {
	    dl[dx] = new char[4];
	    strcpy(dl[dx],"../");		// make it look like ../
	    dx++;				// bump list counter
	    continue;
	  }
	if (!_showHidden && *fn == '.')		// hide hidden?
	  {
	    continue;
	  }
	if (stat(fn, &statbuf) < 0)		// need to stat for type
	  {
	    fl[ix] = new char[strlen(fn)+1];	// default action
	    strcpy(fl[ix], fn);
	    ix++;				// bump list counter
	    continue;
	  }
	// OK, to here, then have a stat check file type
	if ((statbuf.st_mode & S_IFDIR) != 0)	// this is a dir
	  {
	    dl[dx] = new char[strlen(fn)+2];	// space for name + /
	    strcpy(dl[dx], fn);
	    strcat(dl[dx],"/");
	    dx++;				// bump list counter
	    continue;
	  }
	// this would allow files only, but we will show all for now
	// if ((statbuf.st_mode & (S_IFMT & ~S_IFLNK)) == 0)
	else if (wild_match(fn,wild))
	  {
	    fl[ix] = new char[strlen(fn)+1];	// space for name + /
	    strcpy(fl[ix], fn);
	    ix++;				// bump list counter
	    continue;
	  }
      }

    fl[ix] = 0;		// mark end of the list
    dl[dx] = 0;

    closedir(dirp);	// close directory

    // sort the lists
    qsort(fl, ix, sizeof(char *),
	(int (*)(const void *,const void *))dirsort);

    qsort(dl, dx, sizeof(char *),
	(int (*)(const void *,const void *))dirsort);
  }

//==========================>>> wild_match <<<==============================
  static int wild_match(const char* file, const char* wild)
  {
    // compares list of file suffixes in form .x or *.x  e.g.:"*.c *.h"

    char curpat[100] = "";
    int fileLen = strlen(file);

    if (wild == 0 || wild[0] == 0 || strcmp(wild,"*") == 0)
	return 1;

    char* pat = curpat;			// copy to current pattern
    *pat = 0;

    for (const char *cp = wild ; ; )		// scan all suffixes
      {
	// The X version doesn't handle patterns like XXXX* very well
	// It will treat XXX* the same as XXX*.ext the same - oh well...
	if (*cp == '*' && *curpat != 0)			// pattern of form XXX* found
	  {				// we will be stupid for now
	    *pat = 0;			// finish the pattern
	    // First, see if we have a match...
	    if (strstr(file,curpat)== file)
		return 1;
	    for (++cp ; ;++cp)		// skip till pattern break
	      {
		if (*cp == ' ' || *cp == '\t' || *cp == 0 || *cp == ';')
		    break;
	      }
	    while (*cp == ' ' || *cp == '\t' || *cp == ';' )
		++cp;			// skip whitespace
	    // at beginning of next pattern
	    if (*cp == 0)			// all done?
		break;
	    pat = curpat;		// start over
	    *pat = 0;
	    continue;			// try next pattern
	  }
	else if (*cp == '*')
	  {
	    ++cp;
	    continue;			// ignore leading *'s
	  }
	// look for separator - means we've build a suffix to check
	if (*cp == ' ' || *cp == '\t' || *cp == 0 || *cp == ';')
	  {
	    *pat = 0;			// end pattern string
	    int patLen = strlen(curpat);  // length of pattern
	    if (fileLen < patLen)	// gotta be >=
	      {
		if (*cp == 0)		// out of matches, return 0
		    return 0;
	      }
	    // a match is possible
	    else if (strcmp(&file[fileLen-patLen],curpat) == 0)
		return 1;

	    pat = curpat;		// start over
	    *pat = 0;
	    while (*cp == ' ' || *cp == '\t' || *cp == ';' )
		++cp;			// skip whitespace
	    // at beginning of next pattern
	    if (*cp == 0)			// all done?
		break;
	  }
	else
	    *pat++ = *cp++;		// copy pattern
      }
    return 0;
  }

//==========================>>> dirsort <<<==============================
  static int dirsort(const char **a, const char **b)
  {
    // utility function to sort dir entries
    const char* astr = *a;
    const char* bstr = *b;
    const char* aend = astr + strlen(astr) - 1;
    const char* bend = bstr + strlen(bstr) - 1;

    if (strncmp(astr, "../", 3) == 0)	// this goes first
	return -1;
    if (strncmp(bstr, "../", 3) == 0)
	return  1;

    if (*aend == '/' && *bend != '/')	// directories are next
	return -1;
    if (*aend != '/' && *bend == '/')
	return  1;
    return strcmp(astr, bstr);		// just normal order
  }
